pub fn credential_ticket_status(account: &str) -> Option<CredentialTicketStatus>Expand description
Return non-sensitive metadata about the cached auth ticket for diagnostics.
pub fn credential_ticket_status(account: &str) -> Option<CredentialTicketStatus>Return non-sensitive metadata about the cached auth ticket for diagnostics.