install_default_rustls_crypto_provider

Function install_default_rustls_crypto_provider 

pub fn install_default_rustls_crypto_provider()
rustls 0.23 requires an explicit process-level crypto provider when more than one provider feature is present. WebTCP uses rustls directly, so do this before the first ClientConfig::builder() call.