#[repr(i32)]pub enum LayeringType {
Layering1 = 1,
Layering2 = 2,
Layering3 = 3,
Layering4 = 4,
Layering5 = 5,
Layering6 = 6,
Layering7 = 7,
Layering8 = 8,
Layering9 = 9,
Layering10 = 10,
}Expand description
子单下单档位(1-10)
Variants
Layering1 = 1
Layering2 = 2
Layering3 = 3
Layering4 = 4
Layering5 = 5
Layering6 = 6
Layering7 = 7
Layering8 = 8
Layering9 = 9
Layering10 = 10
Implementations
Sourceimpl LayeringType
impl LayeringType
Sourceimpl LayeringType
impl LayeringType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.