CurrencyData

Struct CurrencyData 

pub struct CurrencyData {
    pub currency: Option<String>,
    pub cur_price: Option<String>,
    pub mv: Option<String>,
    pub diluted_cost: Option<String>,
    pub diluted_profit: Option<String>,
    pub diluted_profit_ratio: Option<String>,
    pub average_cost: Option<String>,
    pub average_profit: Option<String>,
    pub average_profit_ratio: Option<String>,
    pub unrealized_profit: Option<String>,
    pub realized_profit: Option<String>,
    pub today_profit: Option<String>,
}
币种相关字段,按currency币种统计计算

Fields

currency: Option<String>

币种代码,比如HKD、USD

cur_price: Option<String>

当前价

mv: Option<String>

市值

diluted_cost: Option<String>

摊薄成本

diluted_profit: Option<String>

持仓盈亏(摊薄成本价)

diluted_profit_ratio: Option<String>

盈亏比例(摊薄成本价)

average_cost: Option<String>

平均成本

average_profit: Option<String>

持仓盈亏(平均成本价)

average_profit_ratio: Option<String>

盈亏比例(摊薄成本价)

unrealized_profit: Option<String>

未实现盈亏

realized_profit: Option<String>

已实现盈亏

today_profit: Option<String>

今日盈亏

Implementations

Source

impl CurrencyData

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn cur_price(&self) -> &str

Returns the value of cur_price, or the default value if cur_price is unset.

pub fn mv(&self) -> &str

Returns the value of mv, or the default value if mv is unset.

pub fn diluted_cost(&self) -> &str

Returns the value of diluted_cost, or the default value if diluted_cost is unset.

pub fn diluted_profit(&self) -> &str

Returns the value of diluted_profit, or the default value if diluted_profit is unset.

pub fn diluted_profit_ratio(&self) -> &str

Returns the value of diluted_profit_ratio, or the default value if diluted_profit_ratio is unset.

pub fn average_cost(&self) -> &str

Returns the value of average_cost, or the default value if average_cost is unset.

pub fn average_profit(&self) -> &str

Returns the value of average_profit, or the default value if average_profit is unset.

pub fn average_profit_ratio(&self) -> &str

Returns the value of average_profit_ratio, or the default value if average_profit_ratio is unset.

pub fn unrealized_profit(&self) -> &str

Returns the value of unrealized_profit, or the default value if unrealized_profit is unset.

pub fn realized_profit(&self) -> &str

Returns the value of realized_profit, or the default value if realized_profit is unset.

pub fn today_profit(&self) -> &str

Returns the value of today_profit, or the default value if today_profit is unset.