AccFundInfo

Struct AccFundInfo 

pub struct AccFundInfo {
Show 14 fields pub currency: Option<String>, pub total_asset: Option<String>, pub hold: Option<String>, pub available: Option<String>, pub drawable: Option<String>, pub mv: Option<String>, pub long_mv: Option<String>, pub short_mv: Option<String>, pub unrealized_profit: Option<String>, pub realized_profit: Option<String>, pub average_profit: Option<String>, pub diluted_profit: Option<String>, pub max_power_long: Option<String>, pub max_power_short: Option<String>,
}
账户资金信息

Fields

currency: Option<String>

标准货币代码,参考ISO_4217,目前支持币种如HKD, USD,CNH,SGD,JPY

total_asset: Option<String>

资产净值

hold: Option<String>

冻结资金

available: Option<String>

可用资金

drawable: Option<String>

最大可提金额

mv: Option<String>

持仓市值

long_mv: Option<String>

多头持仓市值

short_mv: Option<String>

空头持仓市值

unrealized_profit: Option<String>

未实现盈亏

realized_profit: Option<String>

已实现盈亏

average_profit: Option<String>

累计持仓盈亏(股票)/收益(基金)

diluted_profit: Option<String>

累计持仓盈亏(股票)/收益(基金)

max_power_long: Option<String>

max_power_long/max_power_short 这两个字段是临时方案,为了快速实现客户端区分是否需要刷新可买可卖数量的需求, 【其他场景不要使用】 这里的概念有歧义,是历史包袱,还没有时间整体梳理优化

最大最多购买力,max_power_long=available

max_power_short: Option<String>

最大做空购买力,max_power_short=0

Implementations

Source

impl AccFundInfo

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn total_asset(&self) -> &str

Returns the value of total_asset, or the default value if total_asset is unset.

pub fn hold(&self) -> &str

Returns the value of hold, or the default value if hold is unset.

pub fn available(&self) -> &str

Returns the value of available, or the default value if available is unset.

pub fn drawable(&self) -> &str

Returns the value of drawable, or the default value if drawable is unset.

pub fn mv(&self) -> &str

Returns the value of mv, or the default value if mv is unset.

pub fn long_mv(&self) -> &str

Returns the value of long_mv, or the default value if long_mv is unset.

pub fn short_mv(&self) -> &str

Returns the value of short_mv, or the default value if short_mv is unset.

pub fn unrealized_profit(&self) -> &str

Returns the value of unrealized_profit, or the default value if unrealized_profit is unset.

pub fn realized_profit(&self) -> &str

Returns the value of realized_profit, or the default value if realized_profit is unset.

pub fn average_profit(&self) -> &str

Returns the value of average_profit, or the default value if average_profit is unset.

pub fn diluted_profit(&self) -> &str

Returns the value of diluted_profit, or the default value if diluted_profit is unset.

pub fn max_power_long(&self) -> &str

Returns the value of max_power_long, or the default value if max_power_long is unset.

pub fn max_power_short(&self) -> &str

Returns the value of max_power_short, or the default value if max_power_short is unset.