AccPstnInfo

Struct AccPstnInfo 

pub struct AccPstnInfo {
Show 23 fields pub pstn_id: Option<String>, pub pstn_type: Option<i32>, pub account_market: Option<u32>, pub futu_symbol: Option<String>, pub qty: Option<String>, pub qty_hold: Option<String>, pub qty_avbl: Option<String>, pub diluted_cost: Option<String>, pub average_cost: Option<String>, pub cur_price: Option<String>, pub mv: Option<String>, pub diluted_profit: Option<String>, pub diluted_profit_ratio: Option<String>, pub today_profit: Option<String>, pub stock_name: Option<String>, pub currency: Option<String>, pub unrealized_profit: Option<String>, pub realized_profit: Option<String>, pub average_profit: Option<String>, pub average_profit_ratio: Option<String>, pub exchange: Option<String>, pub stock_id: Option<String>, pub stock_market: Option<u32>,
}
账户单个持仓信息

Fields

pstn_id: Option<String>

server保证唯一

pstn_type: Option<i32>

0->多仓, 1->空仓

account_market: Option<u32>

账号对应的市场, 取值参考odr_sys_cmn.AccountMarket

futu_symbol: Option<String>

持仓代码(即futu_symbol,港、A股带前缀0,eg: 00700)

qty: Option<String>

空仓为负数,若数量为0,则显示 –

qty_hold: Option<String>

冻结数量

qty_avbl: Option<String>

可用数量

diluted_cost: Option<String>

摊薄成本,期货没使用这个字段,若该字段数字无效,svr返回 –

average_cost: Option<String>

平均成本,也是期货的开仓价,若该字段数字无效,svr返回 –

cur_price: Option<String>

当前价

mv: Option<String>

市值

diluted_profit: Option<String>

持仓盈亏(股票)/收益(基金),当选择使用摊薄成本时使用该字段

diluted_profit_ratio: Option<String>

摊薄成本盈亏比例(股票)/收益率(基金),当选择使用摊薄成本时使用该字段,若该字段数字无效,svr返回 –

today_profit: Option<String>stock_name: Option<String>currency: Option<String>

持仓的计价货币,对于数字货币持仓来说,客户指定了某个币种,会换算成该币种对应的现价、市值、成本、盈亏等

unrealized_profit: Option<String>

标准货币代码,参考ISO_4217,目前支持币种如HKD, USD,CNH,SGD,JPY

未实现盈亏

realized_profit: Option<String>

已实现盈亏

average_profit: Option<String>

持仓盈亏(股票)/收益(基金),当选择使用平均成本时使用该字段

average_profit_ratio: Option<String>

平均成本盈亏比例(股票)/收益率(基金),当选择使用平均成本时使用该字段

exchange: Option<String>

期货所属交易所代码,如HKFE

stock_id: Option<String>

持仓行情ID

stock_market: Option<u32>

持仓对应的市场, 取值参考odr_sys_cmn.StockMarket

Implementations

Source

impl AccPstnInfo

pub fn pstn_id(&self) -> &str

Returns the value of pstn_id, or the default value if pstn_id is unset.

pub fn pstn_type(&self) -> i32

Returns the value of pstn_type, or the default value if pstn_type is unset.

pub fn account_market(&self) -> u32

Returns the value of account_market, or the default value if account_market is unset.

pub fn futu_symbol(&self) -> &str

Returns the value of futu_symbol, or the default value if futu_symbol is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn qty_hold(&self) -> &str

Returns the value of qty_hold, or the default value if qty_hold is unset.

pub fn qty_avbl(&self) -> &str

Returns the value of qty_avbl, or the default value if qty_avbl is unset.

pub fn diluted_cost(&self) -> &str

Returns the value of diluted_cost, or the default value if diluted_cost is unset.

pub fn average_cost(&self) -> &str

Returns the value of average_cost, or the default value if average_cost is unset.

pub fn cur_price(&self) -> &str

Returns the value of cur_price, or the default value if cur_price is unset.

pub fn mv(&self) -> &str

Returns the value of mv, or the default value if mv is unset.

pub fn diluted_profit(&self) -> &str

Returns the value of diluted_profit, or the default value if diluted_profit is unset.

pub fn diluted_profit_ratio(&self) -> &str

Returns the value of diluted_profit_ratio, or the default value if diluted_profit_ratio is unset.

pub fn today_profit(&self) -> &str

Returns the value of today_profit, or the default value if today_profit is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn unrealized_profit(&self) -> &str

Returns the value of unrealized_profit, or the default value if unrealized_profit is unset.

pub fn realized_profit(&self) -> &str

Returns the value of realized_profit, or the default value if realized_profit is unset.

pub fn average_profit(&self) -> &str

Returns the value of average_profit, or the default value if average_profit is unset.

pub fn average_profit_ratio(&self) -> &str

Returns the value of average_profit_ratio, or the default value if average_profit_ratio is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn stock_id(&self) -> &str

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn stock_market(&self) -> u32

Returns the value of stock_market, or the default value if stock_market is unset.