pub struct GetHistoryAccountPlReq {
pub account_id_list: Vec<u64>,
pub market: Option<u32>,
pub broker_id: Option<u32>,
pub period: Option<u32>,
pub union_currency: Option<String>,
}Fields
account_id_list: Vec<u64>账户信息列表,不能超过20个
market: Option<u32>市场
broker_id: Option<u32>券商ID
period: Option<u32>日期
union_currency: Option<String>统一币种
Implementations
Sourceimpl GetHistoryAccountPlReq
impl GetHistoryAccountPlReq
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn period(&self) -> u32
pub fn period(&self) -> u32
Returns the value of period, or the default value if period is unset.
Sourcepub fn union_currency(&self) -> &str
pub fn union_currency(&self) -> &str
Returns the value of union_currency, or the default value if union_currency is unset.