PositionLimitInfo

Struct PositionLimitInfo 

pub struct PositionLimitInfo {
    pub position_limit: Option<String>,
    pub total_position: Option<String>,
    pub remaining_position_limit: Option<String>,
    pub position_limit_status: Option<i32>,
    pub currency: Option<String>,
}

Fields

position_limit: Option<String>

持仓限额

total_position: Option<String>

当前虚拟资产买单及持仓总额

remaining_position_limit: Option<String>

剩余持仓限额

position_limit_status: Option<i32>

持仓限额状态

currency: Option<String>

币种,如USD、HKD等

Implementations

Source

impl PositionLimitInfo

pub fn position_limit(&self) -> &str

Returns the value of position_limit, or the default value if position_limit is unset.

pub fn total_position(&self) -> &str

Returns the value of total_position, or the default value if total_position is unset.

pub fn remaining_position_limit(&self) -> &str

Returns the value of remaining_position_limit, or the default value if remaining_position_limit is unset.

pub fn position_limit_status(&self) -> PositionLimitStatus

Returns the enum value of position_limit_status, or the default if the field is unset or set to an invalid enum value.

pub fn set_position_limit_status(&mut self, value: PositionLimitStatus)

Sets position_limit_status to the provided enum value.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.