TodayTrdStatistic

Struct TodayTrdStatistic 

pub struct TodayTrdStatistic {
    pub date: Option<f64>,
    pub open_balance: Option<String>,
    pub open_mv: Option<String>,
    pub profit: Option<String>,
    pub profit_ratio: Option<String>,
    pub long_pstn_num: Option<u32>,
    pub short_pstn_num: Option<u32>,
    pub currency: Option<String>,
    pub stock_market: Option<u32>,
}
今日交易统计信息

Fields

date: Option<f64>

今日日期时间戳,单位秒 (对美股市场做夜盘调整)

open_balance: Option<String>

今日开盘前现金结余

open_mv: Option<String>

今日开盘前股票市值

profit: Option<String>

今日总盈亏

profit_ratio: Option<String>

今日盈亏比例

long_pstn_num: Option<u32>

多头持有数量

short_pstn_num: Option<u32>

空头持有数量

currency: Option<String>

标准货币代码,参考ISO_4217,目前支持币种如HKD, USD,CNH,SGD,JPY

stock_market: Option<u32>

持仓对应的市场, 取值参考odr_sys_cmn.StockMarket

Implementations

Source

impl TodayTrdStatistic

pub fn date(&self) -> f64

Returns the value of date, or the default value if date is unset.

pub fn open_balance(&self) -> &str

Returns the value of open_balance, or the default value if open_balance is unset.

pub fn open_mv(&self) -> &str

Returns the value of open_mv, or the default value if open_mv is unset.

pub fn profit(&self) -> &str

Returns the value of profit, or the default value if profit is unset.

pub fn profit_ratio(&self) -> &str

Returns the value of profit_ratio, or the default value if profit_ratio is unset.

pub fn long_pstn_num(&self) -> u32

Returns the value of long_pstn_num, or the default value if long_pstn_num is unset.

pub fn short_pstn_num(&self) -> u32

Returns the value of short_pstn_num, or the default value if short_pstn_num is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn stock_market(&self) -> u32

Returns the value of stock_market, or the default value if stock_market is unset.