#[repr(i32)]pub enum SelectField {
UnionFundInfo = 1,
UnionTodayStatistic = 2,
UnionCashInfo = 3,
FundInfoList = 4,
TodayStatisticList = 5,
CashInfoList = 6,
PstnInfoList = 7,
FundPstnInfoList = 8,
}Expand description
option optimize_for = “LITE_RUNTIME”;
Variants
UnionFundInfo = 1
统一成换算币种的资金信息
UnionTodayStatistic = 2
统一成换算币种的今日交易统计信息
UnionCashInfo = 3
统一成换算币种的现金信息列表
FundInfoList = 4
分币种的资金信息列表,目前只有RISK OA需要
TodayStatisticList = 5
分币种的今日交易统计信息列表,目前只有RISK OA需要
CashInfoList = 6
分币种的现金信息列表
PstnInfoList = 7
分币种的持仓信息列表
FundPstnInfoList = 8
分币种的基金持仓信息列表
Implementations
Sourceimpl SelectField
impl SelectField
Sourceimpl SelectField
impl SelectField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.