pub struct AccCashInfo {
pub currency: Option<u32>,
pub balance: Option<String>,
pub cash_drawable: Option<String>,
pub settled: Option<String>,
pub unsettled_list: Vec<Unsettled>,
pub disable: Option<bool>,
pub securities_cash: Option<String>,
pub swept_cash: Option<String>,
pub cash_buypower: Option<String>,
}Expand description
账户现金信息
Fields
currency: Option<u32>货币类型,取值参考 Currency
balance: Option<String>现金结余
cash_drawable: Option<String>现金可提金额
settled: Option<String>一下字段只有客服自查系统专用
已交收数量
unsettled_list: Vec<Unsettled>待交收列表
disable: Option<bool>原现金宝现金化开关,为兼容客户端旧版本保留,目前废弃
securities_cash: Option<String>证券账号现金结余
swept_cash: Option<String>银行现金结余
cash_buypower: Option<String>现金购买力(分币种)
Implementations
Sourceimpl AccCashInfo
impl AccCashInfo
Sourcepub fn currency(&self) -> u32
pub fn currency(&self) -> u32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn balance(&self) -> &str
pub fn balance(&self) -> &str
Returns the value of balance, or the default value if balance is unset.
Sourcepub fn cash_drawable(&self) -> &str
pub fn cash_drawable(&self) -> &str
Returns the value of cash_drawable, or the default value if cash_drawable is unset.
Sourcepub fn settled(&self) -> &str
pub fn settled(&self) -> &str
Returns the value of settled, or the default value if settled is unset.
Sourcepub fn disable(&self) -> bool
pub fn disable(&self) -> bool
Returns the value of disable, or the default value if disable is unset.
Sourcepub fn securities_cash(&self) -> &str
pub fn securities_cash(&self) -> &str
Returns the value of securities_cash, or the default value if securities_cash is unset.
Sourcepub fn swept_cash(&self) -> &str
pub fn swept_cash(&self) -> &str
Returns the value of swept_cash, or the default value if swept_cash is unset.
Sourcepub fn cash_buypower(&self) -> &str
pub fn cash_buypower(&self) -> &str
Returns the value of cash_buypower, or the default value if cash_buypower is unset.