pub struct TodayTrdStatistic {Show 13 fields
pub date: Option<f64>,
pub open_balance: Option<String>,
pub open_mv: Option<String>,
pub order_fill_cnt: Option<String>,
pub turnover: Option<String>,
pub profit: Option<String>,
pub profit_ratio: Option<String>,
pub disable: Option<String>,
pub sell_fill_cnt: Option<String>,
pub buy_fill_cnt: Option<String>,
pub long_pstn_num: Option<u32>,
pub short_pstn_num: Option<u32>,
pub currency: Option<u32>,
}Expand description
今日交易统计信息
Fields
date: Option<f64>今日日期时间戳,单位秒
open_balance: Option<String>今日开盘前现金结余
open_mv: Option<String>今日开盘前股票市值
order_fill_cnt: Option<String>今日成交笔数,请从交易接口查询,或者客户端自己算
turnover: Option<String>今日成交总额,请从交易接口查询,或者客户端自己算
profit: Option<String>今日总盈亏
profit_ratio: Option<String>今日盈亏比例
disable: Option<String>废弃
sell_fill_cnt: Option<String>今日卖出成交笔数,请从交易接口查询,或者客户端自己算
buy_fill_cnt: Option<String>今日买入成交笔数,请从交易接口查询,或者客户端自己算
long_pstn_num: Option<u32>多头持有数量
short_pstn_num: Option<u32>空头持有数量
currency: Option<u32>货币类型,取值参考 Currency 枚举
Implementations
Sourceimpl TodayTrdStatistic
impl TodayTrdStatistic
Sourcepub fn open_balance(&self) -> &str
pub fn open_balance(&self) -> &str
Returns the value of open_balance, or the default value if open_balance is unset.
Sourcepub fn open_mv(&self) -> &str
pub fn open_mv(&self) -> &str
Returns the value of open_mv, or the default value if open_mv is unset.
Sourcepub fn order_fill_cnt(&self) -> &str
pub fn order_fill_cnt(&self) -> &str
Returns the value of order_fill_cnt, or the default value if order_fill_cnt is unset.
Sourcepub fn turnover(&self) -> &str
pub fn turnover(&self) -> &str
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn profit(&self) -> &str
pub fn profit(&self) -> &str
Returns the value of profit, or the default value if profit is unset.
Sourcepub fn profit_ratio(&self) -> &str
pub fn profit_ratio(&self) -> &str
Returns the value of profit_ratio, or the default value if profit_ratio is unset.
Sourcepub fn disable(&self) -> &str
pub fn disable(&self) -> &str
Returns the value of disable, or the default value if disable is unset.
Sourcepub fn sell_fill_cnt(&self) -> &str
pub fn sell_fill_cnt(&self) -> &str
Returns the value of sell_fill_cnt, or the default value if sell_fill_cnt is unset.
Sourcepub fn buy_fill_cnt(&self) -> &str
pub fn buy_fill_cnt(&self) -> &str
Returns the value of buy_fill_cnt, or the default value if buy_fill_cnt is unset.
Sourcepub fn long_pstn_num(&self) -> u32
pub fn long_pstn_num(&self) -> u32
Returns the value of long_pstn_num, or the default value if long_pstn_num is unset.
Sourcepub fn short_pstn_num(&self) -> u32
pub fn short_pstn_num(&self) -> u32
Returns the value of short_pstn_num, or the default value if short_pstn_num is unset.