pub struct CltActionOpenUrl {
pub title: Option<String>,
pub content: Option<String>,
pub confirm_button_title: Option<String>,
pub confirm_url: Option<String>,
pub content_url_title: Option<String>,
pub content_url: Option<String>,
pub cancel_button_title: Option<String>,
}Expand description
CltActionOpenURL (mobile bond_client_view::CltActionOpenURL)
Fields
title: Option<String>content: Option<String>confirm_url: Option<String>content_url_title: Option<String>content_url: Option<String>Implementations
Sourceimpl CltActionOpenUrl
impl CltActionOpenUrl
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn content(&self) -> &str
pub fn content(&self) -> &str
Returns the value of content, or the default value if content is unset.
Returns the value of confirm_button_title, or the default value if confirm_button_title is unset.
Sourcepub fn confirm_url(&self) -> &str
pub fn confirm_url(&self) -> &str
Returns the value of confirm_url, or the default value if confirm_url is unset.
Sourcepub fn content_url_title(&self) -> &str
pub fn content_url_title(&self) -> &str
Returns the value of content_url_title, or the default value if content_url_title is unset.
Sourcepub fn content_url(&self) -> &str
pub fn content_url(&self) -> &str
Returns the value of content_url, or the default value if content_url is unset.
Returns the value of cancel_button_title, or the default value if cancel_button_title is unset.