ReqHead

Struct ReqHead 

pub struct ReqHead {
    pub market: Option<u32>,
    pub nn_uid: Option<u64>,
    pub account_id: Option<u64>,
    pub created: Option<u64>,
}
公共请求头 (mobile bond_client_view::ReqHead)

Fields

market: Option<u32>

市场: HK=13 / US=23 / SG_UNIVERSAL=6

nn_uid: Option<u64>

牛牛号 (daemon 自动派生, client 不需传)

account_id: Option<u64>

业务账户 ID (daemon 从 acc_id 派生)

created: Option<u64>

请求时间戳 (可选)

Implementations

Source

impl ReqHead

pub fn market(&self) -> u32

Returns the value of market, or the default value if market is unset.

pub fn nn_uid(&self) -> u64

Returns the value of nn_uid, or the default value if nn_uid is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn created(&self) -> u64

Returns the value of created, or the default value if created is unset.