pub struct TenBrokerHoldRsp {
pub result: Option<i32>,
pub stock_id: Option<u64>,
pub broker_item: Vec<BuySellBrokerItem>,
pub message: Option<String>,
pub time_stamp: Option<u64>,
}Fields
result: Option<i32>stock_id: Option<u64>broker_item: Vec<BuySellBrokerItem>message: Option<String>time_stamp: Option<u64>Implementations
Sourceimpl TenBrokerHoldRsp
impl TenBrokerHoldRsp
Sourcepub fn result(&self) -> i32
pub fn result(&self) -> i32
Returns the value of result, or the default value if result is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn time_stamp(&self) -> u64
pub fn time_stamp(&self) -> u64
Returns the value of time_stamp, or the default value if time_stamp is unset.