CashLog

pub struct CashLog {
Show 16 fields pub log_id: Option<String>, pub title: Option<String>, pub label: Option<String>, pub label_desc: Option<String>, pub created_time: Option<String>, pub cash_change: Option<String>, pub balance: Option<String>, pub stock_name: Option<String>, pub icon_url: Option<String>, pub futu_symbol: Option<String>, pub symbol_name: Option<String>, pub created_timestamp: Option<u32>, pub label_list: Vec<Label>, pub stock_id: Option<u64>, pub process_date: Option<u32>, pub currency: Option<String>,
}

Fields

log_id: Option<String>

流水id,不展示,给下面get_cash_detail接口使用

title: Option<String>

标题

label: Option<String>

标签,有则展示。已废弃,请使用label_list

label_desc: Option<String>

标签说明,跟标签同时出现。已废弃,请使用label_list

created_time: Option<String>

时间,字符串,直接展示

cash_change: Option<String>

变动量,字符串数值

balance: Option<String>

余额,字符串数值(注意,可能没有balance,比如历史流水)

stock_name: Option<String>

股票代码和名称

icon_url: Option<String>

icon链接

futu_symbol: Option<String>

股票代码,futu_symbol

symbol_name: Option<String>

股票名称

created_timestamp: Option<u32>

时间,10位时间戳

label_list: Vec<Label>

标签列表,目前最多返回两个

stock_id: Option<u64>

只用于取行情标签,其他场景不能使用。取不到stock id的返回0

process_date: Option<u32>

可能取不到stock id,部分代码复用的,stock id为最新代码的。过期期权取不到stock id

流水变更所在日期

currency: Option<String>

币种,如USD、HKD

Implementations

Source

impl CashLog

pub fn log_id(&self) -> &str

Returns the value of log_id, or the default value if log_id is unset.

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn label_desc(&self) -> &str

Returns the value of label_desc, or the default value if label_desc is unset.

pub fn created_time(&self) -> &str

Returns the value of created_time, or the default value if created_time is unset.

pub fn cash_change(&self) -> &str

Returns the value of cash_change, or the default value if cash_change is unset.

pub fn balance(&self) -> &str

Returns the value of balance, or the default value if balance is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn icon_url(&self) -> &str

Returns the value of icon_url, or the default value if icon_url is unset.

pub fn futu_symbol(&self) -> &str

Returns the value of futu_symbol, or the default value if futu_symbol is unset.

pub fn symbol_name(&self) -> &str

Returns the value of symbol_name, or the default value if symbol_name is unset.

pub fn created_timestamp(&self) -> u32

Returns the value of created_timestamp, or the default value if created_timestamp is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn process_date(&self) -> u32

Returns the value of process_date, or the default value if process_date is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.