Detail

pub struct Detail {
    pub title: Option<String>,
    pub value: Option<String>,
    pub url: Option<String>,
    pub old_value: Option<String>,
    pub icon_url_id: Option<String>,
    pub type_id: Option<u32>,
}

Fields

title: Option<String>

标题(key)

value: Option<String>

项目值

url: Option<String>

外部超链接

old_value: Option<String>

原始的项目值,需要以中划线等特殊展示

icon_url_id: Option<String>

icon超链接id

type_id: Option<u32>

客户端上报类型ID,目前对应icon_url_id

Implementations

Source

impl Detail

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn value(&self) -> &str

Returns the value of value, or the default value if value is unset.

pub fn url(&self) -> &str

Returns the value of url, or the default value if url is unset.

pub fn old_value(&self) -> &str

Returns the value of old_value, or the default value if old_value is unset.

pub fn icon_url_id(&self) -> &str

Returns the value of icon_url_id, or the default value if icon_url_id is unset.

pub fn type_id(&self) -> u32

Returns the value of type_id, or the default value if type_id is unset.