TradeConfig

Struct TradeConfig 

pub struct TradeConfig {
Show 14 fields pub currency_pair: Option<CurrencyPair>, pub base_tick_size: Option<String>, pub quote_tick_size: Option<String>, pub symbol: Option<String>, pub exchange: Option<String>, pub minimum_qty: Option<String>, pub maximum_qty: Option<String>, pub min_amount: Option<String>, pub max_amount: Option<String>, pub status: Option<String>, pub pi_only: Option<bool>, pub amount_tick_size: Option<String>, pub price_protection_pct: Option<String>, pub upstream_exchanges: Vec<String>,
}

Fields

currency_pair: Option<CurrencyPair>

交易货币对

base_tick_size: Option<String>

基础货币的数量精度,例如 0.0005

quote_tick_size: Option<String>

报价货币的价格精度,例如 0.02

symbol: Option<String>

交易代码,eg.BTCUSD

exchange: Option<String>

交易所(用于匹配,并不代表关联的真实交易所),eg.CRYPTO

minimum_qty: Option<String>

最小委托数量

maximum_qty: Option<String>

最大委托数量

min_amount: Option<String>

最小委托金额

max_amount: Option<String>

最大委托金额

status: Option<String>

交易对状态,详见TradeConfigStatus

pi_only: Option<bool>

是否仅支持PI(专业投资者)用户交易,true:仅支持PI用户交易,false:所有用户均可交易

amount_tick_size: Option<String>

金额的精度,例如 0.00000001

price_protection_pct: Option<String>

价格保护百分比Price Protection Percentage,例如 3.5%的值为0.035

upstream_exchanges: Vec<String>

支持的上游交易所列表,eg.Coinbase,DDex,PantherTrade,HashKey

Implementations

Source

impl TradeConfig

pub fn base_tick_size(&self) -> &str

Returns the value of base_tick_size, or the default value if base_tick_size is unset.

pub fn quote_tick_size(&self) -> &str

Returns the value of quote_tick_size, or the default value if quote_tick_size is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn minimum_qty(&self) -> &str

Returns the value of minimum_qty, or the default value if minimum_qty is unset.

pub fn maximum_qty(&self) -> &str

Returns the value of maximum_qty, or the default value if maximum_qty is unset.

pub fn min_amount(&self) -> &str

Returns the value of min_amount, or the default value if min_amount is unset.

pub fn max_amount(&self) -> &str

Returns the value of max_amount, or the default value if max_amount is unset.

pub fn status(&self) -> &str

Returns the value of status, or the default value if status is unset.

pub fn pi_only(&self) -> bool

Returns the value of pi_only, or the default value if pi_only is unset.

pub fn amount_tick_size(&self) -> &str

Returns the value of amount_tick_size, or the default value if amount_tick_size is unset.

pub fn price_protection_pct(&self) -> &str

Returns the value of price_protection_pct, or the default value if price_protection_pct is unset.