pub struct AssetChangeNtfMsg {
pub account_id: Option<u64>,
pub market: Option<u32>,
pub version: Option<u64>,
pub ntf_type: Option<u32>,
pub request_id: Option<String>,
pub cid: Option<u64>,
pub asset_change_log: Option<AssetChangeLog>,
pub ftrace_context: Option<String>,
}Fields
account_id: Option<u64>账户号码
market: Option<u32>市场
version: Option<u64>资产版本号
ntf_type: Option<u32>通知类型,见NtfType枚举
request_id: Option<String>请求ID,表示此变更事件的唯一ID
cid: Option<u64>资产变更用户
asset_change_log: Option<AssetChangeLog>资产变更流水
ftrace_context: Option<String>跟踪上下文
Implementations
Sourceimpl AssetChangeNtfMsg
impl AssetChangeNtfMsg
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn version(&self) -> u64
pub fn version(&self) -> u64
Returns the value of version, or the default value if version is unset.
Sourcepub fn ntf_type(&self) -> u32
pub fn ntf_type(&self) -> u32
Returns the value of ntf_type, or the default value if ntf_type is unset.
Sourcepub fn request_id(&self) -> &str
pub fn request_id(&self) -> &str
Returns the value of request_id, or the default value if request_id is unset.
Sourcepub fn ftrace_context(&self) -> &str
pub fn ftrace_context(&self) -> &str
Returns the value of ftrace_context, or the default value if ftrace_context is unset.