pub struct CashChange {
pub currency: Option<String>,
pub quantity: Option<String>,
pub settle_date: Option<u32>,
pub detail_item_list: Vec<DetailItem>,
}Expand description
现金变动
Fields
currency: Option<String>货币代码
quantity: Option<String>变动量,减现金为负,比如“-100.123“表示减去现金100.123。加现金为正,比如“100.123“
settle_date: Option<u32>交收日,立即交收填0,不确定交收填99999999
detail_item_list: Vec<DetailItem>变更详情列表
Implementations
Sourceimpl CashChange
impl CashChange
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn settle_date(&self) -> u32
pub fn settle_date(&self) -> u32
Returns the value of settle_date, or the default value if settle_date is unset.