ChangeAssetRsp

Struct ChangeAssetRsp 

pub struct ChangeAssetRsp {
    pub result: Option<i32>,
    pub retry: Option<bool>,
    pub err_msg: Option<String>,
}
变更资产-回包

Fields

result: Option<i32>

成功0,失败见最下面【result返回值含义】

retry: Option<bool>

当失败时(result不为0),是否可无感重试

err_msg: Option<String>

错误信息

Implementations

Source

impl ChangeAssetRsp

pub fn result(&self) -> i32

Returns the value of result, or the default value if result is unset.

pub fn retry(&self) -> bool

Returns the value of retry, or the default value if retry is unset.

pub fn err_msg(&self) -> &str

Returns the value of err_msg, or the default value if err_msg is unset.