PositionChange

Struct PositionChange 

pub struct PositionChange {
    pub futu_symbol: Option<String>,
    pub exchange: Option<String>,
    pub long_short: Option<String>,
    pub buy_quantity: Option<String>,
    pub buy_cost: Option<String>,
    pub sell_quantity: Option<String>,
    pub sell_income: Option<String>,
    pub settle_date: Option<u32>,
    pub currency: Option<String>,
}
持仓变动

Fields

futu_symbol: Option<String>

股票代码,比如BABA

exchange: Option<String>

交易所

long_short: Option<String>

多空类型,LONG为多,SHORT为空

buy_quantity: Option<String>

买入数量

buy_cost: Option<String>

买入支出

sell_quantity: Option<String>

卖出数量

sell_income: Option<String>

卖出收入

settle_date: Option<u32>

交收日,立即交收填0,不确定交收填99999999

currency: Option<String>

数字货币的币对,必填,否则无法区分buy_cost和sell_income,资产会将。目前可交易币对的币种有USD、SGD、JPY

Implementations

Source

impl PositionChange

pub fn futu_symbol(&self) -> &str

Returns the value of futu_symbol, or the default value if futu_symbol is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn long_short(&self) -> &str

Returns the value of long_short, or the default value if long_short is unset.

pub fn buy_quantity(&self) -> &str

Returns the value of buy_quantity, or the default value if buy_quantity is unset.

pub fn buy_cost(&self) -> &str

Returns the value of buy_cost, or the default value if buy_cost is unset.

pub fn sell_quantity(&self) -> &str

Returns the value of sell_quantity, or the default value if sell_quantity is unset.

pub fn sell_income(&self) -> &str

Returns the value of sell_income, or the default value if sell_income is unset.

pub fn settle_date(&self) -> u32

Returns the value of settle_date, or the default value if settle_date is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.