CashAsset

pub struct CashAsset {
    pub currency: Option<String>,
    pub quantity: Option<String>,
    pub available: Option<String>,
    pub hold: Option<String>,
    pub drawable: Option<String>,
    pub buy_power: Option<String>,
}

Fields

currency: Option<String>

货币单位

quantity: Option<String>

数量

available: Option<String>

可用

hold: Option<String>

冻结

drawable: Option<String>

可提

buy_power: Option<String>

购买力

Implementations

Source

impl CashAsset

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn quantity(&self) -> &str

Returns the value of quantity, or the default value if quantity is unset.

pub fn available(&self) -> &str

Returns the value of available, or the default value if available is unset.

pub fn hold(&self) -> &str

Returns the value of hold, or the default value if hold is unset.

pub fn drawable(&self) -> &str

Returns the value of drawable, or the default value if drawable is unset.

pub fn buy_power(&self) -> &str

Returns the value of buy_power, or the default value if buy_power is unset.