#[repr(i32)]pub enum AccountStatus {
Closed = 1,
}Variants
Closed = 1
已关闭
Implementations
Sourceimpl AccountStatus
impl AccountStatus
Sourceimpl AccountStatus
impl AccountStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.