pub struct GetPositionInfoRsp {
pub position_limit: Option<String>,
pub total_position: Option<String>,
pub remaining_position_limit: Option<String>,
pub position_limit_status: Option<i32>,
pub currency: Option<String>,
pub user_position_amount: Option<String>,
pub user_pending_buy_order_amount: Option<String>,
}Fields
position_limit: Option<String>持仓限额
total_position: Option<String>当前虚拟资产买单及持仓总额,= user_position_amount + user_pending_buy_order_amount
remaining_position_limit: Option<String>剩余持仓限额
position_limit_status: Option<i32>持仓限额状态
currency: Option<String>持仓限额计价单位,与请求参数一致,默认是USD
user_position_amount: Option<String>用户当前持仓总额
user_pending_buy_order_amount: Option<String>用户当前买单挂单总额
Implementations
Sourceimpl GetPositionInfoRsp
impl GetPositionInfoRsp
Sourcepub fn position_limit(&self) -> &str
pub fn position_limit(&self) -> &str
Returns the value of position_limit, or the default value if position_limit is unset.
Sourcepub fn total_position(&self) -> &str
pub fn total_position(&self) -> &str
Returns the value of total_position, or the default value if total_position is unset.
Sourcepub fn remaining_position_limit(&self) -> &str
pub fn remaining_position_limit(&self) -> &str
Returns the value of remaining_position_limit, or the default value if remaining_position_limit is unset.
Sourcepub fn position_limit_status(&self) -> PositionLimitStatus
pub fn position_limit_status(&self) -> PositionLimitStatus
Returns the enum value of position_limit_status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_position_limit_status(&mut self, value: PositionLimitStatus)
pub fn set_position_limit_status(&mut self, value: PositionLimitStatus)
Sets position_limit_status to the provided enum value.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn user_position_amount(&self) -> &str
pub fn user_position_amount(&self) -> &str
Returns the value of user_position_amount, or the default value if user_position_amount is unset.
Sourcepub fn user_pending_buy_order_amount(&self) -> &str
pub fn user_pending_buy_order_amount(&self) -> &str
Returns the value of user_pending_buy_order_amount, or the default value if user_pending_buy_order_amount is unset.