pub struct RuleList {Show 20 fields
pub if_crypto_wallet_use_vpn: Option<IfCryptoWalletUseVpn>,
pub if_id_belongs_to_legal_area: Option<IfIdBelongsToLegalArea>,
pub is_given_tax_area: Option<IsGivenTaxArea>,
pub if_address_belongs_to_legal_area: Option<IfAddressBelongsToLegalArea>,
pub is_given_account_status: Option<IsGivenAccountStatus>,
pub if_match_deposit_position_limit: Option<IfMatchDepositPositionLimit>,
pub if_forbidden_deposit: Option<IsForbiddenDeposit>,
pub if_forbidden_withdraw: Option<IsForbiddenWithdraw>,
pub is_pi: Option<IsPi>,
pub if_pass_risk_level: Option<IfPassRiskLevel>,
pub if_account_deficit: Option<IfAccountDeficit>,
pub is_coin_open_for_deposit: Option<IsCoinOpenForDeposit>,
pub is_coin_open_for_withdraw: Option<IsCoinOpenForWithdraw>,
pub is_active_crypto_account: Option<IsActiveCryptoAccount>,
pub is_individual_customer: Option<IsIndividualCustomer>,
pub is_login_mainland_china_days_below_threshold: Option<IsLoginMainlandChinaDaysBelowThreshold>,
pub is_hong_kong_non_permanent_resident: Option<IsHongKongNonPermanentResident>,
pub has_overseas_identity: Option<HasOverseasIdentity>,
pub is_given_nationality: Option<IsGivenNationality>,
pub is_in_legal_state: Option<IsInLegalState>,
}Expand description
RuleList 所有检查规则项,在请求体中result字段无意义;在响应体中result字段有意义,其他字段与请求参数相同
Fields
if_crypto_wallet_use_vpn: Option<IfCryptoWalletUseVpn>if_id_belongs_to_legal_area: Option<IfIdBelongsToLegalArea>is_given_tax_area: Option<IsGivenTaxArea>if_address_belongs_to_legal_area: Option<IfAddressBelongsToLegalArea>is_given_account_status: Option<IsGivenAccountStatus>👎Deprecated
建议使用is_active_crypto_account;
if_match_deposit_position_limit: Option<IfMatchDepositPositionLimit>if_forbidden_deposit: Option<IsForbiddenDeposit>if_forbidden_withdraw: Option<IsForbiddenWithdraw>is_pi: Option<IsPi>if_pass_risk_level: Option<IfPassRiskLevel>if_account_deficit: Option<IfAccountDeficit>is_coin_open_for_deposit: Option<IsCoinOpenForDeposit>is_coin_open_for_withdraw: Option<IsCoinOpenForWithdraw>is_active_crypto_account: Option<IsActiveCryptoAccount>is_individual_customer: Option<IsIndividualCustomer>is_login_mainland_china_days_below_threshold: Option<IsLoginMainlandChinaDaysBelowThreshold>is_hong_kong_non_permanent_resident: Option<IsHongKongNonPermanentResident>has_overseas_identity: Option<HasOverseasIdentity>is_given_nationality: Option<IsGivenNationality>is_in_legal_state: Option<IsInLegalState>Trait Implementations
Sourceimpl Message for RuleList
impl Message for RuleList
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Eq for RuleList
impl StructuralPartialEq for RuleList