NotifyMsg

Struct NotifyMsg 

pub struct NotifyMsg {
    pub notice_header: Option<NoticeHeader>,
    pub notice_type: Option<i32>,
    pub sub_notice_type: Option<i32>,
}

Fields

notice_header: Option<NoticeHeader>

参考 NoticeHeader

notice_type: Option<i32>

参考 NoticeType

sub_notice_type: Option<i32>

参考 SubNoticeType

Implementations

Source

impl NotifyMsg

pub fn notice_type(&self) -> NoticeType

Returns the enum value of notice_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_notice_type(&mut self, value: NoticeType)

Sets notice_type to the provided enum value.

pub fn sub_notice_type(&self) -> SubNoticeType

Returns the enum value of sub_notice_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_sub_notice_type(&mut self, value: SubNoticeType)

Sets sub_notice_type to the provided enum value.