pub struct Order {
pub order_id: Option<String>,
pub order_type: Option<u32>,
pub currency: Option<String>,
pub coin: Option<String>,
pub exchange: Option<String>,
pub side: Option<u32>,
pub quantity: Option<String>,
pub price: Option<String>,
pub is_manual: Option<bool>,
pub is_multi_day: Option<bool>,
}Expand description
订单定义
Fields
order_id: Option<String>交易系统里的订单唯一id
order_type: Option<u32>订单类型 enum OrderType
currency: Option<String>计价货币,可以为法币或数字币
coin: Option<String>基础货币,数字货币
exchange: Option<String>👎Deprecated
交易所代码
side: Option<u32>交易方向 enum OrderSide
quantity: Option<String>订单股数
price: Option<String>订单价格
is_manual: Option<bool>是否为人工单
is_multi_day: Option<bool>多日单
Implementations
Sourceimpl Order
impl Order
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn order_type(&self) -> u32
pub fn order_type(&self) -> u32
Returns the value of order_type, or the default value if order_type is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn is_manual(&self) -> bool
pub fn is_manual(&self) -> bool
Returns the value of is_manual, or the default value if is_manual is unset.
Sourcepub fn is_multi_day(&self) -> bool
pub fn is_multi_day(&self) -> bool
Returns the value of is_multi_day, or the default value if is_multi_day is unset.