DividendInfo

Struct DividendInfo 

pub struct DividendInfo {
    pub year: Option<String>,
    pub stock_id: Option<u64>,
    pub statement: Option<String>,
    pub record_date: Option<String>,
    pub ex_date: Option<String>,
    pub dividend_payable_date: Option<String>,
    pub process: Option<String>,
    pub pub_date: Option<String>,
}

Fields

year: Option<String>stock_id: Option<u64>statement: Option<String>record_date: Option<String>ex_date: Option<String>dividend_payable_date: Option<String>process: Option<String>pub_date: Option<String>

Implementations

Source

impl DividendInfo

pub fn year(&self) -> &str

Returns the value of year, or the default value if year is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn statement(&self) -> &str

Returns the value of statement, or the default value if statement is unset.

pub fn record_date(&self) -> &str

Returns the value of record_date, or the default value if record_date is unset.

pub fn ex_date(&self) -> &str

Returns the value of ex_date, or the default value if ex_date is unset.

pub fn dividend_payable_date(&self) -> &str

Returns the value of dividend_payable_date, or the default value if dividend_payable_date is unset.

pub fn process(&self) -> &str

Returns the value of process, or the default value if process is unset.

pub fn pub_date(&self) -> &str

Returns the value of pub_date, or the default value if pub_date is unset.