pub struct ABuyBackitems {Show 22 fields
pub change_reg_date: Option<u64>,
pub change_date: Option<u64>,
pub event_proce_desc: Option<String>,
pub advance_date: Option<u64>,
pub meetpass_date: Option<u64>,
pub start_date: Option<u64>,
pub end_date: Option<u64>,
pub pay_date: Option<u64>,
pub purpose: Option<String>,
pub seller: Option<String>,
pub funds_source: Option<String>,
pub buyback_mode: Option<String>,
pub share_type: Option<String>,
pub buyback_sum: Option<i64>,
pub buyback_money: Option<f64>,
pub percentage: Option<f64>,
pub price_ceiling: Option<f64>,
pub price_floor: Option<f64>,
pub volume_floor: Option<f64>,
pub volume_ceiling: Option<f64>,
pub value_floor: Option<f64>,
pub value_ceiling: Option<f64>,
}Fields
change_reg_date: Option<u64>change_date: Option<u64>event_proce_desc: Option<String>advance_date: Option<u64>meetpass_date: Option<u64>start_date: Option<u64>end_date: Option<u64>pay_date: Option<u64>purpose: Option<String>seller: Option<String>funds_source: Option<String>buyback_mode: Option<String>buyback_sum: Option<i64>buyback_money: Option<f64>percentage: Option<f64>price_ceiling: Option<f64>price_floor: Option<f64>volume_floor: Option<f64>volume_ceiling: Option<f64>value_floor: Option<f64>value_ceiling: Option<f64>Implementations
Sourceimpl ABuyBackitems
impl ABuyBackitems
Sourcepub fn change_reg_date(&self) -> u64
pub fn change_reg_date(&self) -> u64
Returns the value of change_reg_date, or the default value if change_reg_date is unset.
Sourcepub fn change_date(&self) -> u64
pub fn change_date(&self) -> u64
Returns the value of change_date, or the default value if change_date is unset.
Sourcepub fn event_proce_desc(&self) -> &str
pub fn event_proce_desc(&self) -> &str
Returns the value of event_proce_desc, or the default value if event_proce_desc is unset.
Sourcepub fn advance_date(&self) -> u64
pub fn advance_date(&self) -> u64
Returns the value of advance_date, or the default value if advance_date is unset.
Sourcepub fn meetpass_date(&self) -> u64
pub fn meetpass_date(&self) -> u64
Returns the value of meetpass_date, or the default value if meetpass_date is unset.
Sourcepub fn start_date(&self) -> u64
pub fn start_date(&self) -> u64
Returns the value of start_date, or the default value if start_date is unset.
Sourcepub fn end_date(&self) -> u64
pub fn end_date(&self) -> u64
Returns the value of end_date, or the default value if end_date is unset.
Sourcepub fn pay_date(&self) -> u64
pub fn pay_date(&self) -> u64
Returns the value of pay_date, or the default value if pay_date is unset.
Sourcepub fn purpose(&self) -> &str
pub fn purpose(&self) -> &str
Returns the value of purpose, or the default value if purpose is unset.
Sourcepub fn seller(&self) -> &str
pub fn seller(&self) -> &str
Returns the value of seller, or the default value if seller is unset.
Sourcepub fn funds_source(&self) -> &str
pub fn funds_source(&self) -> &str
Returns the value of funds_source, or the default value if funds_source is unset.
Sourcepub fn buyback_mode(&self) -> &str
pub fn buyback_mode(&self) -> &str
Returns the value of buyback_mode, or the default value if buyback_mode is unset.
Returns the value of share_type, or the default value if share_type is unset.
Sourcepub fn buyback_sum(&self) -> i64
pub fn buyback_sum(&self) -> i64
Returns the value of buyback_sum, or the default value if buyback_sum is unset.
Sourcepub fn buyback_money(&self) -> f64
pub fn buyback_money(&self) -> f64
Returns the value of buyback_money, or the default value if buyback_money is unset.
Sourcepub fn percentage(&self) -> f64
pub fn percentage(&self) -> f64
Returns the value of percentage, or the default value if percentage is unset.
Sourcepub fn price_ceiling(&self) -> f64
pub fn price_ceiling(&self) -> f64
Returns the value of price_ceiling, or the default value if price_ceiling is unset.
Sourcepub fn price_floor(&self) -> f64
pub fn price_floor(&self) -> f64
Returns the value of price_floor, or the default value if price_floor is unset.
Sourcepub fn volume_floor(&self) -> f64
pub fn volume_floor(&self) -> f64
Returns the value of volume_floor, or the default value if volume_floor is unset.
Sourcepub fn volume_ceiling(&self) -> f64
pub fn volume_ceiling(&self) -> f64
Returns the value of volume_ceiling, or the default value if volume_ceiling is unset.
Sourcepub fn value_floor(&self) -> f64
pub fn value_floor(&self) -> f64
Returns the value of value_floor, or the default value if value_floor is unset.
Sourcepub fn value_ceiling(&self) -> f64
pub fn value_ceiling(&self) -> f64
Returns the value of value_ceiling, or the default value if value_ceiling is unset.