QueryFinancialReq

Struct QueryFinancialReq 

pub struct QueryFinancialReq {
    pub stock_id: Option<u64>,
    pub fiscal_statements_type: Option<u32>,
    pub f10_type: Option<u32>,
    pub date: Option<u64>,
    pub before_after: Option<u32>,
    pub count: Option<u32>,
    pub currency_id: Option<u32>,
    pub currency_code: Option<String>,
    pub last_unique_key: Option<String>,
}

Fields

stock_id: Option<u64>fiscal_statements_type: Option<u32>f10_type: Option<u32>date: Option<u64>before_after: Option<u32>count: Option<u32>currency_id: Option<u32>currency_code: Option<String>last_unique_key: Option<String>

Implementations

Source

impl QueryFinancialReq

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn fiscal_statements_type(&self) -> u32

Returns the value of fiscal_statements_type, or the default value if fiscal_statements_type is unset.

pub fn f10_type(&self) -> u32

Returns the value of f10_type, or the default value if f10_type is unset.

pub fn date(&self) -> u64

Returns the value of date, or the default value if date is unset.

pub fn before_after(&self) -> u32

Returns the value of before_after, or the default value if before_after is unset.

pub fn count(&self) -> u32

Returns the value of count, or the default value if count is unset.

pub fn currency_id(&self) -> u32

Returns the value of currency_id, or the default value if currency_id is unset.

pub fn currency_code(&self) -> &str

Returns the value of currency_code, or the default value if currency_code is unset.

pub fn last_unique_key(&self) -> &str

Returns the value of last_unique_key, or the default value if last_unique_key is unset.