pub struct Response {
pub result: i32,
pub be_uid64: u64,
pub data_ok: Option<ResponseDataOk>,
pub data_non_ok: Option<ResponseDataNonOk>,
}Expand description
// CMD2008 响应包
Fields
result: i32结果
be_uid64: u64data_ok: Option<ResponseDataOk>当result是ok时,一定会有的数据
data_non_ok: Option<ResponseDataNonOk>当result不是ok时,一定会有的数据
Implementations
Sourceimpl Response
impl Response
Sourcepub fn result(&self) -> ResultCode
pub fn result(&self) -> ResultCode
Returns the enum value of result, or the default if the field is set to an invalid enum value.
Sourcepub fn set_result(&mut self, value: ResultCode)
pub fn set_result(&mut self, value: ResultCode)
Sets result to the provided enum value.