ResponseDataOk

Struct ResponseDataOk 

pub struct ResponseDataOk {
    pub next_page_flag: i32,
    pub trd_pswd_mode: i32,
    pub acc_list: Vec<TrdAcc>,
    pub version: Option<u64>,
    pub trade_pswd_upgrade_prompt: Option<bool>,
    pub fund_acc_list: Vec<FundAcc>,
}
// CMD2008 响应为“ok“时的数据字段

Fields

next_page_flag: i32

如果是-1则表示拉取结束

trd_pswd_mode: i32

交易密碼模式

acc_list: Vec<TrdAcc>

交易账户列表

version: Option<u64>

数据版本。如果数据有变化则版本也会变化,客户端可用此数值对账户列表做优化处理

trade_pswd_upgrade_prompt: Option<bool>

是否需要提示客户升级到6位数字交易密码

fund_acc_list: Vec<FundAcc>

基金账户列表

Implementations

Source

impl ResponseDataOk

pub fn trd_pswd_mode(&self) -> TrdPswdMode

Returns the enum value of trd_pswd_mode, or the default if the field is set to an invalid enum value.

pub fn set_trd_pswd_mode(&mut self, value: TrdPswdMode)

Sets trd_pswd_mode to the provided enum value.

pub fn version(&self) -> u64

Returns the value of version, or the default value if version is unset.

pub fn trade_pswd_upgrade_prompt(&self) -> bool

Returns the value of trade_pswd_upgrade_prompt, or the default value if trade_pswd_upgrade_prompt is unset.