#[repr(i32)]pub enum SortField {
SortByName = 1,
SortByCode = 2,
SortFirstDayPriceChange = 3,
SortIpoPrice = 4,
SortIpoTime = 5,
SortPrice = 6,
SortSubActual = 7,
SortSubActualRatio = 8,
SortSubPlan = 9,
SortSubPlanRatio = 10,
}Expand description
历史项目排序字段
Variants
SortByName = 1
按项目名称排序
SortByCode = 2
按项目代码排序
SortFirstDayPriceChange = 3
按首日涨跌幅排序
SortIpoPrice = 4
按上市价格排序
SortIpoTime = 5
按上市时间排序(默认情况)
SortPrice = 6
按当前价格排序
SortSubActual = 7
按实际认购数排序
SortSubActualRatio = 8
按实际认购比例排序
SortSubPlan = 9
按计划认购数排序
SortSubPlanRatio = 10
按计划认购比例排序
Implementations
Sourceimpl SortField
impl SortField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.