ApplProofCompanyItem

Struct ApplProofCompanyItem 

pub struct ApplProofCompanyItem {
    pub name: Option<String>,
    pub process: Option<i32>,
    pub process_desc: Option<String>,
    pub apply_date: Option<String>,
    pub apply_date_timestamp: Option<u64>,
    pub plate_name: Option<String>,
    pub listed_sector: Option<i32>,
    pub book_link: Option<String>,
}

Fields

name: Option<String>

企业名称

process: Option<i32>

取值为1和2

process_desc: Option<String>

状态描述,状态1表示 “正在处理”,2表示“已通过聆讯”

apply_date: Option<String>

申请时间,格式为“xxxx-xx-xx xx:xx:xx”,状态为“已递表”时,意义为“刊发申请版本日期”;状态为“已通过聆讯”时,意义为“刊发聆讯后资料集日期”

apply_date_timestamp: Option<u64>

申请时间对应的时间戳

plate_name: Option<String>

板块名称,通过listed_sector字段关联其它表获得该值。1表示主板,6表示创业板。

listed_sector: Option<i32>

聚源表中的板块标识,1表示主板,6表示创业板。

book_link: Option<String>

招股书链接,聚源目前没有,先留着这个字段

Implementations

Source

impl ApplProofCompanyItem

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn process(&self) -> i32

Returns the value of process, or the default value if process is unset.

pub fn process_desc(&self) -> &str

Returns the value of process_desc, or the default value if process_desc is unset.

pub fn apply_date(&self) -> &str

Returns the value of apply_date, or the default value if apply_date is unset.

pub fn plate_name(&self) -> &str

Returns the value of plate_name, or the default value if plate_name is unset.

pub fn listed_sector(&self) -> i32

Returns the value of listed_sector, or the default value if listed_sector is unset.

Returns the value of book_link, or the default value if book_link is unset.

pub fn apply_date_timestamp(&self) -> u64

Returns the value of apply_date_timestamp, or the default value if apply_date_timestamp is unset.