CnIpoListItem

Struct CnIpoListItem 

pub struct CnIpoListItem {
Show 20 fields pub apply_date: Option<String>, pub stock_name: Option<String>, pub code: Option<String>, pub stock_id: Option<u64>, pub apply_code: Option<String>, pub ipo_price: Option<String>, pub is_ipo_price_preview: Option<u32>, pub apply_limit: Option<String>, pub is_apply_limit_preview: Option<u32>, pub pe: Option<String>, pub lucky_ratio: Option<String>, pub is_lucky_ratio_preview: Option<u32>, pub lucky_date: Option<String>, pub lucky_ok: Option<u32>, pub ipo_date: Option<String>, pub apply_limit_num: Option<i64>, pub pe_num: Option<i64>, pub apply_date_timestamp: Option<u64>, pub lucky_date_timestamp: Option<u64>, pub ipo_date_timestamp: Option<u64>,
}

Fields

apply_date: Option<String>

申购日期

stock_name: Option<String>

股票名称

code: Option<String>

股票代码

stock_id: Option<u64>apply_code: Option<String>

申购代码

ipo_price: Option<String>

发行价

is_ipo_price_preview: Option<u32>

发行价是否预估值(0为否,1为是)

apply_limit: Option<String>

申购上限

is_apply_limit_preview: Option<u32>

申购上限是否预估值

pe: Option<String>

发行市盈率

lucky_ratio: Option<String>

中签率

is_lucky_ratio_preview: Option<u32>

中签率是否预估

lucky_date: Option<String>

公布中签日

lucky_ok: Option<u32>

中签号是否已经公布

ipo_date: Option<String>

上市日期

apply_limit_num: Option<i64>

申购上限,数值格式

pe_num: Option<i64>

发行市盈率,数值格式,两位精度(即2012表示 20.12)

apply_date_timestamp: Option<u64>

申购日, 时间戳

lucky_date_timestamp: Option<u64>

公布中签日, 时间戳

ipo_date_timestamp: Option<u64>

上市日期, 时间戳

Implementations

Source

impl CnIpoListItem

pub fn apply_date(&self) -> &str

Returns the value of apply_date, or the default value if apply_date is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn code(&self) -> &str

Returns the value of code, or the default value if code is unset.

pub fn apply_code(&self) -> &str

Returns the value of apply_code, or the default value if apply_code is unset.

pub fn ipo_price(&self) -> &str

Returns the value of ipo_price, or the default value if ipo_price is unset.

pub fn is_ipo_price_preview(&self) -> u32

Returns the value of is_ipo_price_preview, or the default value if is_ipo_price_preview is unset.

pub fn apply_limit(&self) -> &str

Returns the value of apply_limit, or the default value if apply_limit is unset.

pub fn is_apply_limit_preview(&self) -> u32

Returns the value of is_apply_limit_preview, or the default value if is_apply_limit_preview is unset.

pub fn pe(&self) -> &str

Returns the value of pe, or the default value if pe is unset.

pub fn lucky_ratio(&self) -> &str

Returns the value of lucky_ratio, or the default value if lucky_ratio is unset.

pub fn is_lucky_ratio_preview(&self) -> u32

Returns the value of is_lucky_ratio_preview, or the default value if is_lucky_ratio_preview is unset.

pub fn lucky_date(&self) -> &str

Returns the value of lucky_date, or the default value if lucky_date is unset.

pub fn lucky_ok(&self) -> u32

Returns the value of lucky_ok, or the default value if lucky_ok is unset.

pub fn ipo_date(&self) -> &str

Returns the value of ipo_date, or the default value if ipo_date is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn apply_limit_num(&self) -> i64

Returns the value of apply_limit_num, or the default value if apply_limit_num is unset.

pub fn pe_num(&self) -> i64

Returns the value of pe_num, or the default value if pe_num is unset.

pub fn apply_date_timestamp(&self) -> u64

Returns the value of apply_date_timestamp, or the default value if apply_date_timestamp is unset.

pub fn lucky_date_timestamp(&self) -> u64

Returns the value of lucky_date_timestamp, or the default value if lucky_date_timestamp is unset.

pub fn ipo_date_timestamp(&self) -> u64

Returns the value of ipo_date_timestamp, or the default value if ipo_date_timestamp is unset.