HkApplyMessage

Struct HkApplyMessage 

pub struct HkApplyMessage {
Show 44 fields pub ipo_price_range: Option<String>, pub ipo_price: Option<String>, pub lot_size: Option<String>, pub entrance_fee: Option<String>, pub eipo_flag: Option<u32>, pub margin_fee_ratio: Option<u32>, pub margin_lever_ratio: Option<u32>, pub sponsor: Option<String>, pub market_cap: Option<String>, pub publish_shares: Option<String>, pub apply_multiple: Option<String>, pub lucky_ratio: Option<String>, pub ipo_book_pdf: Option<String>, pub ipo_book_link: Option<String>, pub start_apply_flag: Option<u32>, pub industry_name: Option<String>, pub industry_code: Option<u32>, pub fund_purposes: Vec<String>, pub ipo_price_low: Option<u32>, pub ipo_price_high: Option<u32>, pub entrance_fee_num: Option<u32>, pub international_placing_apply_limit: Option<u32>, pub margin_fee_ratio_low: Option<u32>, pub margin_fee_ratio_high: Option<u32>, pub international_placing_apply_limit_str: Option<String>, pub apply_step_list: Vec<u32>, pub lot_size_num: Option<u32>, pub security_type: Option<i32>, pub offer_type: Option<i32>, pub is_support_dark_trade: Option<i32>, pub tranche_warrant: Option<String>, pub etf_distributors: Option<String>, pub etf_introduction_link: Option<String>, pub etf_prospectus_link: Option<String>, pub min_apply_shares: Option<i64>, pub real_margin_lever_ratio: Option<u32>, pub etf_ipo_price_display: Option<String>, pub ipo_detail: Option<UserApplyDetail>, pub placing_detail: Option<UserApplyDetail>, pub etf_apply_detail: Option<UserApplyDetail>, pub clawback_type: Option<i32>, pub public_ratio: Option<i32>, pub clawback: Option<String>, pub public_share_rate_show: Option<String>,
}
港股申购及基础详情

Fields

ipo_price_range: Option<String>

发售价范围

ipo_price: Option<String>

上市价

lot_size: Option<String>

每手股数

entrance_fee: Option<String>

入场费

eipo_flag: Option<u32>

是否支持认购,0-不支持,其它-支持

margin_fee_ratio: Option<u32>

融资认购利率,放大100000,例如12345表示12.345%.如果后台没有数据,则不返回这个字段

margin_lever_ratio: Option<u32>

融资杠杆倍数,放大1000倍,例如5000表示5倍.如果后台没有数据,则不返回这个字段

sponsor: Option<String>

保荐人.如果后台没有数据,则返回’–’

market_cap: Option<String>

发行市值.如果后台没有数据,则返回’–’

publish_shares: Option<String>

发行量.如果后台没有数据,则返回’–’

apply_multiple: Option<String>

申购倍数.如果后台没有数据,则返回’–’

lucky_ratio: Option<String>

一手中签率.如果后台没有数据,则返回’–’

ipo_book_pdf: Option<String>

招股书PDF链接.如果后台没有数据,则不返回该字段

ipo_book_link: Option<String>

原始招股书链接.如果后台没有数据,则不返回该字段

start_apply_flag: Option<u32>

是否开始认购。0-未开始,1-已开始

industry_name: Option<String>

行业名

industry_code: Option<u32>

行业id

fund_purposes: Vec<String>

募資用途 募资用途可能有几点,每点为一个string

ipo_price_low: Option<u32>

发售价下界,保留两位精度(即123代表1.23)

ipo_price_high: Option<u32>

发售价上界,保留两位精度(即123代表1.23)ipo_price_low和ipo_price_high 组成了发售价区间

entrance_fee_num: Option<u32>

入场费,保留2位精度,即123456表示 1234.56

international_placing_apply_limit: Option<u32>

国际配售最低认购金额

margin_fee_ratio_low: Option<u32>

最低融资认购利率

margin_fee_ratio_high: Option<u32>

最高融资认购利率

international_placing_apply_limit_str: Option<String>

国际配售最低认购金额文本

apply_step_list: Vec<u32>

认购梯度

lot_size_num: Option<u32>

数值形式的每手股数

security_type: Option<i32>

股票类型

offer_type: Option<i32>

新股发售类型

is_support_dark_trade: Option<i32>

是否支持暗盘交易

tranche_warrant: Option<String>

SPAC权证权利

etf_distributors: Option<String>

ETF发行公司

etf_introduction_link: Option<String>

ETF产品概要文件链接

etf_prospectus_link: Option<String>

ETF发行章程文件链接

min_apply_shares: Option<i64>

最少认购股数

real_margin_lever_ratio: Option<u32>

实际可用融资杠杆倍数

etf_ipo_price_display: Option<String>

ETF发行价展示文案

ipo_detail: Option<UserApplyDetail>

公开认购详情

placing_detail: Option<UserApplyDetail>

国际配售认购详情

etf_apply_detail: Option<UserApplyDetail>

ETF认购详情

clawback_type: Option<i32>

回拨机制类型

public_ratio: Option<i32>

公开发售比例

clawback: Option<String>

回拨机制

public_share_rate_show: Option<String>

公开发售比例展示

Implementations

Source

impl HkApplyMessage

pub fn ipo_price_range(&self) -> &str

Returns the value of ipo_price_range, or the default value if ipo_price_range is unset.

pub fn ipo_price(&self) -> &str

Returns the value of ipo_price, or the default value if ipo_price is unset.

pub fn lot_size(&self) -> &str

Returns the value of lot_size, or the default value if lot_size is unset.

pub fn entrance_fee(&self) -> &str

Returns the value of entrance_fee, or the default value if entrance_fee is unset.

pub fn eipo_flag(&self) -> u32

Returns the value of eipo_flag, or the default value if eipo_flag is unset.

pub fn margin_fee_ratio(&self) -> u32

Returns the value of margin_fee_ratio, or the default value if margin_fee_ratio is unset.

pub fn margin_lever_ratio(&self) -> u32

Returns the value of margin_lever_ratio, or the default value if margin_lever_ratio is unset.

pub fn sponsor(&self) -> &str

Returns the value of sponsor, or the default value if sponsor is unset.

pub fn market_cap(&self) -> &str

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn publish_shares(&self) -> &str

Returns the value of publish_shares, or the default value if publish_shares is unset.

pub fn apply_multiple(&self) -> &str

Returns the value of apply_multiple, or the default value if apply_multiple is unset.

pub fn lucky_ratio(&self) -> &str

Returns the value of lucky_ratio, or the default value if lucky_ratio is unset.

pub fn ipo_book_pdf(&self) -> &str

Returns the value of ipo_book_pdf, or the default value if ipo_book_pdf is unset.

Returns the value of ipo_book_link, or the default value if ipo_book_link is unset.

pub fn start_apply_flag(&self) -> u32

Returns the value of start_apply_flag, or the default value if start_apply_flag is unset.

pub fn industry_name(&self) -> &str

Returns the value of industry_name, or the default value if industry_name is unset.

pub fn industry_code(&self) -> u32

Returns the value of industry_code, or the default value if industry_code is unset.

pub fn ipo_price_low(&self) -> u32

Returns the value of ipo_price_low, or the default value if ipo_price_low is unset.

pub fn ipo_price_high(&self) -> u32

Returns the value of ipo_price_high, or the default value if ipo_price_high is unset.

pub fn entrance_fee_num(&self) -> u32

Returns the value of entrance_fee_num, or the default value if entrance_fee_num is unset.

pub fn international_placing_apply_limit(&self) -> u32

Returns the value of international_placing_apply_limit, or the default value if international_placing_apply_limit is unset.

pub fn margin_fee_ratio_low(&self) -> u32

Returns the value of margin_fee_ratio_low, or the default value if margin_fee_ratio_low is unset.

pub fn margin_fee_ratio_high(&self) -> u32

Returns the value of margin_fee_ratio_high, or the default value if margin_fee_ratio_high is unset.

pub fn international_placing_apply_limit_str(&self) -> &str

Returns the value of international_placing_apply_limit_str, or the default value if international_placing_apply_limit_str is unset.

pub fn lot_size_num(&self) -> u32

Returns the value of lot_size_num, or the default value if lot_size_num is unset.

pub fn security_type(&self) -> i32

Returns the value of security_type, or the default value if security_type is unset.

pub fn offer_type(&self) -> i32

Returns the value of offer_type, or the default value if offer_type is unset.

pub fn is_support_dark_trade(&self) -> i32

Returns the value of is_support_dark_trade, or the default value if is_support_dark_trade is unset.

pub fn tranche_warrant(&self) -> &str

Returns the value of tranche_warrant, or the default value if tranche_warrant is unset.

pub fn etf_distributors(&self) -> &str

Returns the value of etf_distributors, or the default value if etf_distributors is unset.

Returns the value of etf_introduction_link, or the default value if etf_introduction_link is unset.

Returns the value of etf_prospectus_link, or the default value if etf_prospectus_link is unset.

pub fn min_apply_shares(&self) -> i64

Returns the value of min_apply_shares, or the default value if min_apply_shares is unset.

pub fn real_margin_lever_ratio(&self) -> u32

Returns the value of real_margin_lever_ratio, or the default value if real_margin_lever_ratio is unset.

pub fn etf_ipo_price_display(&self) -> &str

Returns the value of etf_ipo_price_display, or the default value if etf_ipo_price_display is unset.

pub fn clawback_type(&self) -> i32

Returns the value of clawback_type, or the default value if clawback_type is unset.

pub fn public_ratio(&self) -> i32

Returns the value of public_ratio, or the default value if public_ratio is unset.

pub fn clawback(&self) -> &str

Returns the value of clawback, or the default value if clawback is unset.

pub fn public_share_rate_show(&self) -> &str

Returns the value of public_share_rate_show, or the default value if public_share_rate_show is unset.