MyIpoItem

pub struct MyIpoItem {
Show 29 fields pub stock_id: Option<u64>, pub broker_type: Option<i32>, pub stock_name: Option<String>, pub code: Option<String>, pub apply_limit: Option<i64>, pub offer_price: Option<i64>, pub fund_amount: Option<i64>, pub manager_code: Option<String>, pub manager: Option<String>, pub industry_plate_id: Option<i64>, pub industry_plate: Option<String>, pub market_cap: Option<i64>, pub business: Option<String>, pub ipo_book_link: Option<String>, pub security_type: Option<u32>, pub currency: Option<String>, pub apply_start_date_timestamp: Option<u64>, pub apply_end_date_timestamp: Option<u64>, pub draw_date_timestamp: Option<u64>, pub lucky_date_timestamp: Option<u64>, pub ipo_date_timestamp: Option<u64>, pub support_apply_flag: Option<u32>, pub user_apply_status: Option<u32>, pub offer_shares: Option<i64>, pub support_leverage_flag: Option<i32>, pub user_leverage_multiple: Option<i32>, pub user_leverage_rate: Option<i32>, pub leverage_end_timestamp: Option<i64>, pub broker_id: Option<i32>,
}

Fields

stock_id: Option<u64>

股票ID

broker_type: Option<i32>

券商类型

stock_name: Option<String>

股票名称

code: Option<String>

股票代码

apply_limit: Option<i64>

最小申购金额,放大10^3倍

offer_price: Option<i64>

发行价,放大10^3倍

fund_amount: Option<i64>

募资金额

manager_code: Option<String>

承销商代码

manager: Option<String>

承销商信息

industry_plate_id: Option<i64>

行业板块ID

industry_plate: Option<String>

行业板块名称

market_cap: Option<i64>

市值

business: Option<String>

公司介绍/业务信息

ipo_book_link: Option<String>

招股书链接

security_type: Option<u32>

参考SECURITY_TYPE

currency: Option<String>

货币代码

apply_start_date_timestamp: Option<u64>

零售开始认购时间

apply_end_date_timestamp: Option<u64>

零售截至认购时间

draw_date_timestamp: Option<u64>

零售抽签时间

lucky_date_timestamp: Option<u64>

零售中签公布时间

ipo_date_timestamp: Option<u64>

上市时间

support_apply_flag: Option<u32>

是否支持认购

user_apply_status: Option<u32>

用户认购状态

offer_shares: Option<i64>

发行量

support_leverage_flag: Option<i32>

是否支持杠杆

user_leverage_multiple: Option<i32>

用户融资杠杆倍数

user_leverage_rate: Option<i32>

用户融资杠杆利率

leverage_end_timestamp: Option<i64>

用户融资截止时间

broker_id: Option<i32>

券商id

Implementations

Source

impl MyIpoItem

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn broker_type(&self) -> i32

Returns the value of broker_type, or the default value if broker_type is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn code(&self) -> &str

Returns the value of code, or the default value if code is unset.

pub fn apply_limit(&self) -> i64

Returns the value of apply_limit, or the default value if apply_limit is unset.

pub fn offer_price(&self) -> i64

Returns the value of offer_price, or the default value if offer_price is unset.

pub fn fund_amount(&self) -> i64

Returns the value of fund_amount, or the default value if fund_amount is unset.

pub fn manager_code(&self) -> &str

Returns the value of manager_code, or the default value if manager_code is unset.

pub fn manager(&self) -> &str

Returns the value of manager, or the default value if manager is unset.

pub fn industry_plate_id(&self) -> i64

Returns the value of industry_plate_id, or the default value if industry_plate_id is unset.

pub fn industry_plate(&self) -> &str

Returns the value of industry_plate, or the default value if industry_plate is unset.

pub fn market_cap(&self) -> i64

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn business(&self) -> &str

Returns the value of business, or the default value if business is unset.

Returns the value of ipo_book_link, or the default value if ipo_book_link is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn apply_start_date_timestamp(&self) -> u64

Returns the value of apply_start_date_timestamp, or the default value if apply_start_date_timestamp is unset.

pub fn apply_end_date_timestamp(&self) -> u64

Returns the value of apply_end_date_timestamp, or the default value if apply_end_date_timestamp is unset.

pub fn draw_date_timestamp(&self) -> u64

Returns the value of draw_date_timestamp, or the default value if draw_date_timestamp is unset.

pub fn lucky_date_timestamp(&self) -> u64

Returns the value of lucky_date_timestamp, or the default value if lucky_date_timestamp is unset.

pub fn ipo_date_timestamp(&self) -> u64

Returns the value of ipo_date_timestamp, or the default value if ipo_date_timestamp is unset.

pub fn support_apply_flag(&self) -> u32

Returns the value of support_apply_flag, or the default value if support_apply_flag is unset.

pub fn user_apply_status(&self) -> u32

Returns the value of user_apply_status, or the default value if user_apply_status is unset.

pub fn offer_shares(&self) -> i64

Returns the value of offer_shares, or the default value if offer_shares is unset.

pub fn support_leverage_flag(&self) -> i32

Returns the value of support_leverage_flag, or the default value if support_leverage_flag is unset.

pub fn user_leverage_multiple(&self) -> i32

Returns the value of user_leverage_multiple, or the default value if user_leverage_multiple is unset.

pub fn user_leverage_rate(&self) -> i32

Returns the value of user_leverage_rate, or the default value if user_leverage_rate is unset.

pub fn leverage_end_timestamp(&self) -> i64

Returns the value of leverage_end_timestamp, or the default value if leverage_end_timestamp is unset.

pub fn broker_id(&self) -> i32

Returns the value of broker_id, or the default value if broker_id is unset.