SgIpoItem

pub struct SgIpoItem {
Show 24 fields pub stock_id: Option<u64>, pub stock_name: Option<String>, pub code: Option<String>, pub offer_price_low: Option<u32>, pub offer_price_high: Option<u32>, pub offer_price_disply: Option<String>, pub shares: Option<u64>, pub shares_disply: Option<String>, pub apply_limit: Option<u64>, pub apply_limitdisply: Option<String>, pub market_cap_disply: Option<String>, pub fund_amount_disply: Option<String>, pub industry_disply: Option<String>, pub managers_disply: Option<String>, pub business_disply: Option<String>, pub security_type: Option<u32>, pub ipo_book_link: Option<String>, pub apply_date_timestamp: Option<u64>, pub apply_end_date_timestamp: Option<u64>, pub lucky_date_timestamp: Option<u64>, pub ipo_date_timestamp: Option<u64>, pub user_apply_status: Option<u32>, pub broker_type: Option<i32>, pub broker_id: Option<i32>,
}

Fields

stock_id: Option<u64>

股票ID

stock_name: Option<String>

股票名称

code: Option<String>

股票代码

offer_price_low: Option<u32>

最小发行价,放大10^3倍

offer_price_high: Option<u32>

最大发行价,放大10^3倍

offer_price_disply: Option<String>

发行价文本展示

shares: Option<u64>

发行量

shares_disply: Option<String>

发行量文本展示

apply_limit: Option<u64>

最小申购金额,放大10^3倍

apply_limitdisply: Option<String>

最小申购金额文本展示

market_cap_disply: Option<String>

市值文本展示

fund_amount_disply: Option<String>

募资金额文本展示

industry_disply: Option<String>

行业信息文本展示

managers_disply: Option<String>

承销商信息文本展示

business_disply: Option<String>

公司介绍信息

security_type: Option<u32>

参考SECURITY_TYPE

ipo_book_link: Option<String>

招股书链接

apply_date_timestamp: Option<u64>

开始认购时间

apply_end_date_timestamp: Option<u64>

截止认购时间

lucky_date_timestamp: Option<u64>

中签公布时间

ipo_date_timestamp: Option<u64>

上市时间

user_apply_status: Option<u32>

用户认购状态

broker_type: Option<i32>

打新券商类型

broker_id: Option<i32>

券商id

Implementations

Source

impl SgIpoItem

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn code(&self) -> &str

Returns the value of code, or the default value if code is unset.

pub fn offer_price_low(&self) -> u32

Returns the value of offer_price_low, or the default value if offer_price_low is unset.

pub fn offer_price_high(&self) -> u32

Returns the value of offer_price_high, or the default value if offer_price_high is unset.

pub fn offer_price_disply(&self) -> &str

Returns the value of offer_price_disply, or the default value if offer_price_disply is unset.

pub fn shares(&self) -> u64

Returns the value of shares, or the default value if shares is unset.

pub fn shares_disply(&self) -> &str

Returns the value of shares_disply, or the default value if shares_disply is unset.

pub fn apply_limit(&self) -> u64

Returns the value of apply_limit, or the default value if apply_limit is unset.

pub fn apply_limitdisply(&self) -> &str

Returns the value of apply_limitdisply, or the default value if apply_limitdisply is unset.

pub fn market_cap_disply(&self) -> &str

Returns the value of market_cap_disply, or the default value if market_cap_disply is unset.

pub fn fund_amount_disply(&self) -> &str

Returns the value of fund_amount_disply, or the default value if fund_amount_disply is unset.

pub fn industry_disply(&self) -> &str

Returns the value of industry_disply, or the default value if industry_disply is unset.

pub fn managers_disply(&self) -> &str

Returns the value of managers_disply, or the default value if managers_disply is unset.

pub fn business_disply(&self) -> &str

Returns the value of business_disply, or the default value if business_disply is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

Returns the value of ipo_book_link, or the default value if ipo_book_link is unset.

pub fn apply_date_timestamp(&self) -> u64

Returns the value of apply_date_timestamp, or the default value if apply_date_timestamp is unset.

pub fn apply_end_date_timestamp(&self) -> u64

Returns the value of apply_end_date_timestamp, or the default value if apply_end_date_timestamp is unset.

pub fn lucky_date_timestamp(&self) -> u64

Returns the value of lucky_date_timestamp, or the default value if lucky_date_timestamp is unset.

pub fn ipo_date_timestamp(&self) -> u64

Returns the value of ipo_date_timestamp, or the default value if ipo_date_timestamp is unset.

pub fn user_apply_status(&self) -> u32

Returns the value of user_apply_status, or the default value if user_apply_status is unset.

pub fn broker_type(&self) -> i32

Returns the value of broker_type, or the default value if broker_type is unset.

pub fn broker_id(&self) -> i32

Returns the value of broker_id, or the default value if broker_id is unset.