UsIpoListItem

Struct UsIpoListItem 

pub struct UsIpoListItem {
Show 23 fields pub stock_id: Option<u64>, pub stock_name: Option<String>, pub code: Option<String>, pub ipo_price_range: Option<String>, pub shares: Option<String>, pub expected_ipo_date: Option<String>, pub ipo_price_low: Option<u32>, pub ipo_price_high: Option<u32>, pub ipo_date_timestamp: Option<u64>, pub shares_num: Option<i64>, pub apply_limit: Option<u32>, pub futu_apply_end_timestamp: Option<u64>, pub lucky_timestamp: Option<u32>, pub stock_status: Option<u32>, pub user_apply_status: Option<u32>, pub futu_apply_timestamp: Option<u64>, pub offer_type: Option<i32>, pub placing_apply_limit: Option<u32>, pub placing_apply_timestamp: Option<u64>, pub placing_apply_end_timestamp: Option<u64>, pub placing_user_ability: Option<u32>, pub placing_user_apply_status: Option<u32>, pub broker_id: Option<i32>,
}

Fields

stock_id: Option<u64>

股票内部ID

stock_name: Option<String>

股票名称(简体)

code: Option<String>

股票代码, 例如“AAPL“

ipo_price_range: Option<String>

发行价区间, 例如“12.00~14.00“

shares: Option<String>

发行量

expected_ipo_date: Option<String>

预计上市日

ipo_price_low: Option<u32>

发行价区间,下界,保留两位精度,即1234表示12.34

ipo_price_high: Option<u32>

发行价区间,上界,保留两位精度,即1234表示12.34

ipo_date_timestamp: Option<u64>

预计上市日, 时间戳

shares_num: Option<i64>

发行量,数值格式

apply_limit: Option<u32>

最低认购金额,单位为0.01

futu_apply_end_timestamp: Option<u64>

截止认购时间戳

lucky_timestamp: Option<u32>

预计公布中签时间戳

stock_status: Option<u32>

新股状态

user_apply_status: Option<u32>

用户认购状态

futu_apply_timestamp: Option<u64>

开始认购时间戳

offer_type: Option<i32>

新股发售类型

placing_apply_limit: Option<u32>

国配最小认购金额

placing_apply_timestamp: Option<u64>

国配开始认购时间戳

placing_apply_end_timestamp: Option<u64>

国配截止认购时间戳

placing_user_ability: Option<u32>

当前用户国配认购能力

placing_user_apply_status: Option<u32>

用户国配认购状态

broker_id: Option<i32>

券商id

Implementations

Source

impl UsIpoListItem

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn code(&self) -> &str

Returns the value of code, or the default value if code is unset.

pub fn ipo_price_range(&self) -> &str

Returns the value of ipo_price_range, or the default value if ipo_price_range is unset.

pub fn shares(&self) -> &str

Returns the value of shares, or the default value if shares is unset.

pub fn expected_ipo_date(&self) -> &str

Returns the value of expected_ipo_date, or the default value if expected_ipo_date is unset.

pub fn ipo_price_low(&self) -> u32

Returns the value of ipo_price_low, or the default value if ipo_price_low is unset.

pub fn ipo_price_high(&self) -> u32

Returns the value of ipo_price_high, or the default value if ipo_price_high is unset.

pub fn ipo_date_timestamp(&self) -> u64

Returns the value of ipo_date_timestamp, or the default value if ipo_date_timestamp is unset.

pub fn shares_num(&self) -> i64

Returns the value of shares_num, or the default value if shares_num is unset.

pub fn apply_limit(&self) -> u32

Returns the value of apply_limit, or the default value if apply_limit is unset.

pub fn futu_apply_end_timestamp(&self) -> u64

Returns the value of futu_apply_end_timestamp, or the default value if futu_apply_end_timestamp is unset.

pub fn lucky_timestamp(&self) -> u32

Returns the value of lucky_timestamp, or the default value if lucky_timestamp is unset.

pub fn stock_status(&self) -> u32

Returns the value of stock_status, or the default value if stock_status is unset.

pub fn user_apply_status(&self) -> u32

Returns the value of user_apply_status, or the default value if user_apply_status is unset.

pub fn futu_apply_timestamp(&self) -> u64

Returns the value of futu_apply_timestamp, or the default value if futu_apply_timestamp is unset.

pub fn offer_type(&self) -> i32

Returns the value of offer_type, or the default value if offer_type is unset.

pub fn placing_apply_limit(&self) -> u32

Returns the value of placing_apply_limit, or the default value if placing_apply_limit is unset.

pub fn placing_apply_timestamp(&self) -> u64

Returns the value of placing_apply_timestamp, or the default value if placing_apply_timestamp is unset.

pub fn placing_apply_end_timestamp(&self) -> u64

Returns the value of placing_apply_end_timestamp, or the default value if placing_apply_end_timestamp is unset.

pub fn placing_user_ability(&self) -> u32

Returns the value of placing_user_ability, or the default value if placing_user_ability is unset.

pub fn placing_user_apply_status(&self) -> u32

Returns the value of placing_user_apply_status, or the default value if placing_user_apply_status is unset.

pub fn broker_id(&self) -> i32

Returns the value of broker_id, or the default value if broker_id is unset.