UsIssueMessage

Struct UsIssueMessage 

pub struct UsIssueMessage {
Show 26 fields pub price_range: Option<String>, pub shares: Option<String>, pub market_cap: Option<String>, pub industry: Option<String>, pub apply_limit: Option<u32>, pub managers: Option<String>, pub business: Option<String>, pub apply_limit_new: Option<u32>, pub fund_amount: Option<String>, pub security_type: Option<u32>, pub ipo_book_link: Option<String>, pub stock_status: Option<u32>, pub user_apply_status: Option<u32>, pub platform_code: Option<u64>, pub sponsor: Option<String>, pub offer_type: Option<i32>, pub placing_apply_limit: Option<u32>, pub placing_user_ability: Option<u32>, pub placing_user_apply_status: Option<u32>, pub shares_outstanding: Option<String>, pub applicable: Option<u64>, pub currency_code: Option<i32>, pub stock_name: Option<String>, pub ipo_price_low: Option<u32>, pub ipo_price_high: Option<u32>, pub apply_url: Option<String>,
}

Fields

price_range: Option<String>

发行价区间

shares: Option<String>

预计发行量

market_cap: Option<String>

市值

industry: Option<String>

行业

apply_limit: Option<u32>

最低认购

managers: Option<String>

承销商

business: Option<String>

公司相关介绍

apply_limit_new: Option<u32>

最低认购,单位0.01

fund_amount: Option<String>

募资金额

security_type: Option<u32>

参考SECURITY_TYPE

ipo_book_link: Option<String>

招股书链接

stock_status: Option<u32>

新股状态

user_apply_status: Option<u32>

用户认购状态

platform_code: Option<u64>

行业板块id

sponsor: Option<String>

发起人

offer_type: Option<i32>

新股发售类型

placing_apply_limit: Option<u32>

国配最小认购金额

placing_user_ability: Option<u32>

国配认购能力

placing_user_apply_status: Option<u32>

用户国配认购状态

shares_outstanding: Option<String>

总发行量

applicable: Option<u64>

是否可申购

currency_code: Option<i32>

货币代码

stock_name: Option<String>

新股名称

ipo_price_low: Option<u32>

发行价区间下界

ipo_price_high: Option<u32>

发行价区间上界

apply_url: Option<String>

认购URL

Implementations

Source

impl UsIssueMessage

pub fn price_range(&self) -> &str

Returns the value of price_range, or the default value if price_range is unset.

pub fn shares(&self) -> &str

Returns the value of shares, or the default value if shares is unset.

pub fn market_cap(&self) -> &str

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn industry(&self) -> &str

Returns the value of industry, or the default value if industry is unset.

pub fn apply_limit(&self) -> u32

Returns the value of apply_limit, or the default value if apply_limit is unset.

pub fn managers(&self) -> &str

Returns the value of managers, or the default value if managers is unset.

pub fn business(&self) -> &str

Returns the value of business, or the default value if business is unset.

pub fn apply_limit_new(&self) -> u32

Returns the value of apply_limit_new, or the default value if apply_limit_new is unset.

pub fn fund_amount(&self) -> &str

Returns the value of fund_amount, or the default value if fund_amount is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

Returns the value of ipo_book_link, or the default value if ipo_book_link is unset.

pub fn stock_status(&self) -> u32

Returns the value of stock_status, or the default value if stock_status is unset.

pub fn user_apply_status(&self) -> u32

Returns the value of user_apply_status, or the default value if user_apply_status is unset.

pub fn platform_code(&self) -> u64

Returns the value of platform_code, or the default value if platform_code is unset.

pub fn sponsor(&self) -> &str

Returns the value of sponsor, or the default value if sponsor is unset.

pub fn offer_type(&self) -> i32

Returns the value of offer_type, or the default value if offer_type is unset.

pub fn placing_apply_limit(&self) -> u32

Returns the value of placing_apply_limit, or the default value if placing_apply_limit is unset.

pub fn placing_user_ability(&self) -> u32

Returns the value of placing_user_ability, or the default value if placing_user_ability is unset.

pub fn placing_user_apply_status(&self) -> u32

Returns the value of placing_user_apply_status, or the default value if placing_user_apply_status is unset.

pub fn shares_outstanding(&self) -> &str

Returns the value of shares_outstanding, or the default value if shares_outstanding is unset.

pub fn applicable(&self) -> u64

Returns the value of applicable, or the default value if applicable is unset.

pub fn currency_code(&self) -> i32

Returns the value of currency_code, or the default value if currency_code is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn ipo_price_low(&self) -> u32

Returns the value of ipo_price_low, or the default value if ipo_price_low is unset.

pub fn ipo_price_high(&self) -> u32

Returns the value of ipo_price_high, or the default value if ipo_price_high is unset.

pub fn apply_url(&self) -> &str

Returns the value of apply_url, or the default value if apply_url is unset.