UserApplyDetail

Struct UserApplyDetail 

pub struct UserApplyDetail {
    pub applied: Option<i32>,
    pub status: Option<i32>,
    pub is_lucky: Option<i32>,
}

Fields

applied: Option<i32>

1表示已认购,0表示未认购

status: Option<i32>

0待处理 1处理中(已扣款) 2已完成(已公布中签)

is_lucky: Option<i32>

是否中签

Implementations

Source

impl UserApplyDetail

pub fn applied(&self) -> i32

Returns the value of applied, or the default value if applied is unset.

pub fn status(&self) -> i32

Returns the value of status, or the default value if status is unset.

pub fn is_lucky(&self) -> i32

Returns the value of is_lucky, or the default value if is_lucky is unset.