#[repr(i32)]pub enum RequestSection {
Normal = 0,
Full = 1,
Premarket = 2,
Afterhours = 3,
HkDark = 4,
Overnight = 5,
}Expand description
请求的交易阶段
Variants
Normal = 0
正常盘中交易阶段,默认
Full = 1
完整交易阶段,包括盘前、盘后交易
Premarket = 2
盘前交易阶段
Afterhours = 3
盘后交易阶段
HkDark = 4
港股暗盘阶段
Overnight = 5
美股夜盘阶段
Implementations
Sourceimpl RequestSection
impl RequestSection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.