#[repr(i32)]pub enum TradeSection {
Auction = 1,
Morning = 2,
Afternoon = 3,
Night = 4,
Premarket = 5,
Afterhours = 6,
TypeHkDarkTrade = 7,
TypeFuturePart1 = 8,
TypeFuturePart2 = 9,
StibAfterhours = 10,
TypeOvernight = 11,
}Expand description
交易阶段
Variants
Auction = 1
盘前竞价
Morning = 2
早盘
Afternoon = 3
午盘
Night = 4
夜市(港股期货)
Premarket = 5
盘前交易(美股)
Afterhours = 6
盘后交易(美股)
TypeHkDarkTrade = 7
上市前一天暗盘交易(港股)
TypeFuturePart1 = 8
期货盘中1(美国期货)
TypeFuturePart2 = 9
期货盘中2(美国期货)
StibAfterhours = 10
科创板盘后
TypeOvernight = 11
美股夜盘
Implementations
Sourceimpl TradeSection
impl TradeSection
Sourceimpl TradeSection
impl TradeSection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.