TimeSharePoint

Struct TimeSharePoint 

pub struct TimeSharePoint {
    pub time: Option<u64>,
    pub open_price: Option<i64>,
    pub highest_price: Option<i64>,
    pub lowest_price: Option<i64>,
    pub close_price: Option<i64>,
    pub volume: Option<u64>,
    pub turnover: Option<u64>,
    pub implied_volatility: Option<i64>,
    pub exright_type: Option<u32>,
    pub ytm: Option<i64>,
}
分时数据-单点

Fields

time: Option<u64>

时间戳(UTC,按分钟圆整),必有

open_price: Option<i64>

以下数据,可能没有,比如当前交易时间未到time

highest_price: Option<i64>lowest_price: Option<i64>close_price: Option<i64>

收盘价,单位: *10^9

volume: Option<u64>

成交量,单位: 1

turnover: Option<u64>

成交额,单位: *10^3

implied_volatility: Option<i64>

期权的隐含波动率(引申波幅),放大1000倍。例如:协议值12345,表示12.345%

exright_type: Option<u32>

回传复权类型,见ExrightType枚举

ytm: Option<i64>

到期收益率*10^9, 例如:协议值12345000000,表示12.345%

Implementations

Source

impl TimeSharePoint

pub fn time(&self) -> u64

Returns the value of time, or the default value if time is unset.

pub fn close_price(&self) -> i64

Returns the value of close_price, or the default value if close_price is unset.

pub fn volume(&self) -> u64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> u64

Returns the value of turnover, or the default value if turnover is unset.

pub fn open_price(&self) -> i64

Returns the value of open_price, or the default value if open_price is unset.

pub fn highest_price(&self) -> i64

Returns the value of highest_price, or the default value if highest_price is unset.

pub fn lowest_price(&self) -> i64

Returns the value of lowest_price, or the default value if lowest_price is unset.

pub fn implied_volatility(&self) -> i64

Returns the value of implied_volatility, or the default value if implied_volatility is unset.

pub fn exright_type(&self) -> u32

Returns the value of exright_type, or the default value if exright_type is unset.

pub fn ytm(&self) -> i64

Returns the value of ytm, or the default value if ytm is unset.