ChainStatisticInfo

Struct ChainStatisticInfo 

pub struct ChainStatisticInfo {
    pub expect_move: Option<i64>,
    pub ivx: Option<i64>,
    pub call_volume: Option<i64>,
    pub put_volume: Option<i64>,
    pub volume: Option<i64>,
}
注意注意注意: 后台svr实现时,有基于reflect解析字段,假设ChainStatisticInfo在被引用的名称为chain,则其子字段在svr解析为chain_xxx,es存储也需按如此命名,es字段确定后很难修改,这里需要小心

Fields

expect_move: Option<i64>

预期波动,精度为10**5 (eg: 1.5%,则返回1500)

ivx: Option<i64>

到期日ivx,精度为10**5 (eg: 1.5%,则返回1500)

call_volume: Option<i64>

call成交量

put_volume: Option<i64>

put成交量

volume: Option<i64>

成交量

Implementations

Source

impl ChainStatisticInfo

pub fn expect_move(&self) -> i64

Returns the value of expect_move, or the default value if expect_move is unset.

pub fn ivx(&self) -> i64

Returns the value of ivx, or the default value if ivx is unset.

pub fn call_volume(&self) -> i64

Returns the value of call_volume, or the default value if call_volume is unset.

pub fn put_volume(&self) -> i64

Returns the value of put_volume, or the default value if put_volume is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.