OptionItem

Struct OptionItem 

pub struct OptionItem {
Show 67 fields pub option_id: Option<i64>, pub hp_strike_price: Option<i64>, pub strike_date: Option<i64>, pub option_type: Option<i32>, pub exercise_type: Option<i32>, pub expiration_type: Option<i32>, pub in_the_money: Option<i32>, pub price: Option<i64>, pub mid_price: Option<i64>, pub bid_price: Option<i64>, pub ask_price: Option<i64>, pub bid_ask_spread: Option<i64>, pub bid_volume: Option<i64>, pub ask_volume: Option<i64>, pub bid_ask_volume_ratio: Option<i64>, pub chg_ratio: Option<i64>, pub volume: Option<i64>, pub turnover: Option<i64>, pub open_interest: Option<i64>, pub open_interest_market_cap: Option<i64>, pub oi_day_chg: Option<i64>, pub oi_week_chg: Option<i64>, pub vol_day_chg_ratio: Option<i64>, pub oi_day_chg_ratio: Option<i64>, pub vol_week_chg_ratio: Option<i64>, pub oi_week_chg_ratio: Option<i64>, pub implied_volatility: Option<i64>, pub history_volatility: Option<i64>, pub iv_hv_ratio: Option<i64>, pub delta: Option<i64>, pub gamma: Option<i64>, pub vega: Option<i64>, pub theta: Option<i64>, pub rho: Option<i64>, pub leverage_ratio: Option<i64>, pub effective_gearing: Option<i64>, pub buy_to_bep: Option<i64>, pub sell_to_bep: Option<i64>, pub buy_profit_probability: Option<i64>, pub sell_profit_probability: Option<i64>, pub intrinsi_value_per: Option<i64>, pub time_value_per: Option<i64>, pub itm_degree: Option<i64>, pub otm_degree: Option<i64>, pub itm_probability: Option<i64>, pub otm_probability: Option<i64>, pub sell_annualized_return: Option<i64>, pub underlying_info: Option<UnderlyingStatisticInfo>, pub standard_type: Option<i32>, pub option_name: Option<String>, pub premium: Option<i64>, pub interval_return: Option<i64>, pub striked_interval_return: Option<i64>, pub striked_annualized_return: Option<i64>, pub vol_oi_ratio: Option<i64>, pub vol_avg: Option<MultiDayAvg>, pub oi_avg: Option<MultiDayAvg>, pub left_day: Option<i32>, pub underlying_instrument_type_v2: Option<i32>, pub oi_day_market_cap_chg: Option<i64>, pub oi_week_market_cap_chg: Option<i64>, pub product_code: Option<String>, pub multiplier: Option<i64>, pub contract_share_size: Option<i64>, pub chain: Option<ChainStatisticInfo>, pub strike_date_timestamp: Option<i64>, pub spread_table_code: Option<i32>,
}

Fields

option_id: Option<i64>

期权id

hp_strike_price: Option<i64>

行权价,精度10**9

strike_date: Option<i64>

行权日,格式为年月日(eg: 20240305)

option_type: Option<i32>

期权类型, 行权方向:call/put,参考OptionType

exercise_type: Option<i32>

行权方式:美式、欧式等,参考OptionExerciseMethodType

expiration_type: Option<i32>

到期类型:周期权、月期权、季期权等,参考ExpirationType

in_the_money: Option<i32>

是否实值期权(价内、价外),1:实值期权(价内),0:虚值期权(价外),参考InTheMoneyType

price: Option<i64>

期权价格, 精度10**9

mid_price: Option<i64>

期权中间价, 精度10*9

bid_price: Option<i64>

期权买价, 精度10*9

ask_price: Option<i64>

期权卖价, 精度10*9

bid_ask_spread: Option<i64>

期权买卖价差, 精度10*9

bid_volume: Option<i64>

期权买量,单位为1

ask_volume: Option<i64>

期权卖量,单位为1

bid_ask_volume_ratio: Option<i64>

期权买卖量比,精度为10**5 (eg: 买量130,卖量100,则返回130000)

chg_ratio: Option<i64>

期权涨跌幅,精度为10**5 (eg: 涨幅1.5%,则返回1500)

volume: Option<i64>

期权成交量,单位为1

turnover: Option<i64>

期权成交额,精度为10**3 (eg: 1000.5元,则返回1000500)

open_interest: Option<i64>

期权持仓量,单位为1

open_interest_market_cap: Option<i64>

持仓市值,精度为10**3 (eg: 1000.5元,则返回1000500)

oi_day_chg: Option<i64>

持仓量日变化量,单位为1(>0 为增仓,<0 为减仓)

oi_week_chg: Option<i64>

持仓量周变化量,单位为1(>0 为增仓,<0 为减仓

vol_day_chg_ratio: Option<i64>

成交量日变化率,精度为10**5 (eg: 1.5%,则返回1500)

oi_day_chg_ratio: Option<i64>

持仓量日变化率,精度为10**5 (eg: 1.5%,则返回1500)

vol_week_chg_ratio: Option<i64>

成交量周变化率,精度为10**5 (eg: 1.5%,则返回1500)

oi_week_chg_ratio: Option<i64>

持仓量周变化率,精度为10**5 (eg: 1.5%,则返回1500)

implied_volatility: Option<i64>

隐含波动率,精度为10**5 (eg: 20.5%,则返回20500)

history_volatility: Option<i64>

历史波动率,精度为10**5 (eg: 20.5%,则返回20500)

iv_hv_ratio: Option<i64>

iv/hv,精度为10**5 (eg: 1.5,则返回150000)

delta: Option<i64>

delta,精度为10**5 (eg: 1.5%,则返回1500)

gamma: Option<i64>

gamma,精度为10**5 (eg: 1.5%,则返回1500)

vega: Option<i64>

vega,精度为10**5 (eg: 1.5%,则返回1500)

theta: Option<i64>

theta,精度为10**5 (eg: 1.5%,则返回1500)

rho: Option<i64>

rho,精度为10**5 (eg: 1.5%,则返回1500)

leverage_ratio: Option<i64>

杠杆比率,精度为10**5 (eg: 1.5,则返回150000)

effective_gearing: Option<i64>

有效杠杆,精度为10**5 (eg: 1.5,则返回150000)

buy_to_bep: Option<i64>

买入到盈亏平衡点,精度为10**5 (eg: 1.5%,则返回1500)

sell_to_bep: Option<i64>

卖出到盈亏平衡点,精度为10**5 (eg: 1.5%,则返回1500)

buy_profit_probability: Option<i64>

买入盈利概率,精度为10**5 (eg: 1.5%,则返回1500)

sell_profit_probability: Option<i64>

卖出盈利概率,精度为10**5 (eg: 1.5%,则返回1500)

intrinsi_value_per: Option<i64>

内在价值百分比,精度为10**5 (eg: 1.5%,则返回1500)

time_value_per: Option<i64>

时间价值百分比,精度为10**5 (eg: 1.5%,则返回1500)

itm_degree: Option<i64>

价内程度,精度为10**5 (eg: 1.5,则返回150000) itm: in the money otm : out of the money

otm_degree: Option<i64>

价外程度,精度为10**5 (eg: 1.5,则返回150000)

itm_probability: Option<i64>

价内概率(又称行权概率),精度为10**5 (eg: 1.5%,则返回1500)

otm_probability: Option<i64>

价外概率,精度为10**5 (eg: 1.5%,则返回1500)

sell_annualized_return: Option<i64>

卖出年化收益率,精度为10**5 (eg: 1.5%,则返回1500)

underlying_info: Option<UnderlyingStatisticInfo>

标的资产期权数据

standard_type: Option<i32>

是否标准期权,参考StandardType(svr内部使用,客户端忽略)

option_name: Option<String>

期权名称

premium: Option<i64>

权利金,精度10^9

interval_return: Option<i64>

区间收益率,精度10^5

striked_interval_return: Option<i64>

被行权区间收益率,精度10^5

striked_annualized_return: Option<i64>

被行权年化收益率,精度10^5

vol_oi_ratio: Option<i64>

成交量/持仓量,精度为10**5 (eg: 1.5,则返回150000)

vol_avg: Option<MultiDayAvg>

多日成交量均值,精度为10**3(eg: 1.5,则返回1500)

oi_avg: Option<MultiDayAvg>

多日持仓量均值,精度为10**3(eg: 1.5,则返回1500)

left_day: Option<i32>

距离到期日,单位:天,精度为1

underlying_instrument_type_v2: Option<i32>

标的品类类型,@fservice公共协议security_type.proto 的InstrumentTypeV2枚举,可用于筛选标的是否正股/ETF等

oi_day_market_cap_chg: Option<i64>

持仓市值日变化量,精度10*3,(>0 为增仓市值,<0 为减仓市值)

oi_week_market_cap_chg: Option<i64>

持仓市值周变化量,精度10*3,(>0 为增仓市值,<0 为减仓市值)

product_code: Option<String>

链的prodoct_code/symbol

multiplier: Option<i64>

合约乘数,精度10*9

contract_share_size: Option<i64>

合约规模,精度10*9

chain: Option<ChainStatisticInfo>

链的统计信息

strike_date_timestamp: Option<i64>

行权日时间戳,单位:秒

spread_table_code: Option<i32>

期权静态信息,仅用于展示,不参与筛选、排序的字段,字段序号100-200

价位表代码

Implementations

Source

impl OptionItem

pub fn option_id(&self) -> i64

Returns the value of option_id, or the default value if option_id is unset.

pub fn hp_strike_price(&self) -> i64

Returns the value of hp_strike_price, or the default value if hp_strike_price is unset.

pub fn strike_date(&self) -> i64

Returns the value of strike_date, or the default value if strike_date is unset.

pub fn option_type(&self) -> i32

Returns the value of option_type, or the default value if option_type is unset.

pub fn exercise_type(&self) -> i32

Returns the value of exercise_type, or the default value if exercise_type is unset.

pub fn expiration_type(&self) -> i32

Returns the value of expiration_type, or the default value if expiration_type is unset.

pub fn in_the_money(&self) -> i32

Returns the value of in_the_money, or the default value if in_the_money is unset.

pub fn price(&self) -> i64

Returns the value of price, or the default value if price is unset.

pub fn mid_price(&self) -> i64

Returns the value of mid_price, or the default value if mid_price is unset.

pub fn bid_price(&self) -> i64

Returns the value of bid_price, or the default value if bid_price is unset.

pub fn ask_price(&self) -> i64

Returns the value of ask_price, or the default value if ask_price is unset.

pub fn bid_ask_spread(&self) -> i64

Returns the value of bid_ask_spread, or the default value if bid_ask_spread is unset.

pub fn bid_volume(&self) -> i64

Returns the value of bid_volume, or the default value if bid_volume is unset.

pub fn ask_volume(&self) -> i64

Returns the value of ask_volume, or the default value if ask_volume is unset.

pub fn bid_ask_volume_ratio(&self) -> i64

Returns the value of bid_ask_volume_ratio, or the default value if bid_ask_volume_ratio is unset.

pub fn chg_ratio(&self) -> i64

Returns the value of chg_ratio, or the default value if chg_ratio is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> i64

Returns the value of turnover, or the default value if turnover is unset.

pub fn open_interest(&self) -> i64

Returns the value of open_interest, or the default value if open_interest is unset.

pub fn open_interest_market_cap(&self) -> i64

Returns the value of open_interest_market_cap, or the default value if open_interest_market_cap is unset.

pub fn oi_day_chg(&self) -> i64

Returns the value of oi_day_chg, or the default value if oi_day_chg is unset.

pub fn oi_week_chg(&self) -> i64

Returns the value of oi_week_chg, or the default value if oi_week_chg is unset.

pub fn vol_day_chg_ratio(&self) -> i64

Returns the value of vol_day_chg_ratio, or the default value if vol_day_chg_ratio is unset.

pub fn oi_day_chg_ratio(&self) -> i64

Returns the value of oi_day_chg_ratio, or the default value if oi_day_chg_ratio is unset.

pub fn vol_week_chg_ratio(&self) -> i64

Returns the value of vol_week_chg_ratio, or the default value if vol_week_chg_ratio is unset.

pub fn oi_week_chg_ratio(&self) -> i64

Returns the value of oi_week_chg_ratio, or the default value if oi_week_chg_ratio is unset.

pub fn implied_volatility(&self) -> i64

Returns the value of implied_volatility, or the default value if implied_volatility is unset.

pub fn history_volatility(&self) -> i64

Returns the value of history_volatility, or the default value if history_volatility is unset.

pub fn iv_hv_ratio(&self) -> i64

Returns the value of iv_hv_ratio, or the default value if iv_hv_ratio is unset.

pub fn delta(&self) -> i64

Returns the value of delta, or the default value if delta is unset.

pub fn gamma(&self) -> i64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> i64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> i64

Returns the value of theta, or the default value if theta is unset.

pub fn rho(&self) -> i64

Returns the value of rho, or the default value if rho is unset.

pub fn leverage_ratio(&self) -> i64

Returns the value of leverage_ratio, or the default value if leverage_ratio is unset.

pub fn effective_gearing(&self) -> i64

Returns the value of effective_gearing, or the default value if effective_gearing is unset.

pub fn buy_to_bep(&self) -> i64

Returns the value of buy_to_bep, or the default value if buy_to_bep is unset.

pub fn sell_to_bep(&self) -> i64

Returns the value of sell_to_bep, or the default value if sell_to_bep is unset.

pub fn buy_profit_probability(&self) -> i64

Returns the value of buy_profit_probability, or the default value if buy_profit_probability is unset.

pub fn sell_profit_probability(&self) -> i64

Returns the value of sell_profit_probability, or the default value if sell_profit_probability is unset.

pub fn intrinsi_value_per(&self) -> i64

Returns the value of intrinsi_value_per, or the default value if intrinsi_value_per is unset.

pub fn time_value_per(&self) -> i64

Returns the value of time_value_per, or the default value if time_value_per is unset.

pub fn itm_degree(&self) -> i64

Returns the value of itm_degree, or the default value if itm_degree is unset.

pub fn otm_degree(&self) -> i64

Returns the value of otm_degree, or the default value if otm_degree is unset.

pub fn itm_probability(&self) -> i64

Returns the value of itm_probability, or the default value if itm_probability is unset.

pub fn otm_probability(&self) -> i64

Returns the value of otm_probability, or the default value if otm_probability is unset.

pub fn sell_annualized_return(&self) -> i64

Returns the value of sell_annualized_return, or the default value if sell_annualized_return is unset.

pub fn standard_type(&self) -> i32

Returns the value of standard_type, or the default value if standard_type is unset.

pub fn option_name(&self) -> &str

Returns the value of option_name, or the default value if option_name is unset.

pub fn premium(&self) -> i64

Returns the value of premium, or the default value if premium is unset.

pub fn interval_return(&self) -> i64

Returns the value of interval_return, or the default value if interval_return is unset.

pub fn striked_interval_return(&self) -> i64

Returns the value of striked_interval_return, or the default value if striked_interval_return is unset.

pub fn striked_annualized_return(&self) -> i64

Returns the value of striked_annualized_return, or the default value if striked_annualized_return is unset.

pub fn vol_oi_ratio(&self) -> i64

Returns the value of vol_oi_ratio, or the default value if vol_oi_ratio is unset.

pub fn left_day(&self) -> i32

Returns the value of left_day, or the default value if left_day is unset.

pub fn underlying_instrument_type_v2(&self) -> i32

Returns the value of underlying_instrument_type_v2, or the default value if underlying_instrument_type_v2 is unset.

pub fn oi_day_market_cap_chg(&self) -> i64

Returns the value of oi_day_market_cap_chg, or the default value if oi_day_market_cap_chg is unset.

pub fn oi_week_market_cap_chg(&self) -> i64

Returns the value of oi_week_market_cap_chg, or the default value if oi_week_market_cap_chg is unset.

pub fn product_code(&self) -> &str

Returns the value of product_code, or the default value if product_code is unset.

pub fn multiplier(&self) -> i64

Returns the value of multiplier, or the default value if multiplier is unset.

pub fn contract_share_size(&self) -> i64

Returns the value of contract_share_size, or the default value if contract_share_size is unset.

pub fn strike_date_timestamp(&self) -> i64

Returns the value of strike_date_timestamp, or the default value if strike_date_timestamp is unset.

pub fn spread_table_code(&self) -> i32

Returns the value of spread_table_code, or the default value if spread_table_code is unset.