UnderlyingStatisticInfo

Struct UnderlyingStatisticInfo 

pub struct UnderlyingStatisticInfo {
Show 16 fields pub stock_id: Option<u64>, pub volume: Option<i64>, pub open_interest: Option<i64>, pub iv: Option<i64>, pub hv: Option<i64>, pub iv_rank: Option<i64>, pub iv_percentile: Option<i64>, pub iv_chg: Option<i64>, pub iv_chg_ratio: Option<i64>, pub market_cap: Option<i64>, pub iv_hv_ratio: Option<i64>, pub iv_hv_spread: Option<i64>, pub price: Option<i64>, pub chg_ratio: Option<i64>, pub earnings: Option<EarningsInfo>, pub index_type: Option<i32>,
}

Fields

stock_id: Option<u64>volume: Option<i64>

期权总成交量,精度1

open_interest: Option<i64>

期权总持仓量,精度1

iv: Option<i64>

标的IV,空表示不存在,精度10**5 (eg: 1.5%,则返回1500)

hv: Option<i64>

标的HV,空表示不存在,精度10**5 (eg: 1.5%,则返回1500) note: HV数据有多个周期类型,这里选用的30天

iv_rank: Option<i64>

标的IV Rank,空表示不存在,精度10**5 (eg: 1.5%,则返回1500)

iv_percentile: Option<i64>

标的IV Percentile,空表示不存在,精度10**5 (eg: 1.5%,则返回1500)

iv_chg: Option<i64>

标的IV变化量,精度10**5 (eg: 1.5%,则返回1500)

iv_chg_ratio: Option<i64>

标的IV变化率,精度10**5 (eg: 1.5%,则返回1500)

market_cap: Option<i64>

标的市值,精度10**3(eg: 15,则返回15000)

iv_hv_ratio: Option<i64>

标的iv/标的hv,精度10**5(eg: iv为30%,hv为15%,则返回200000)

iv_hv_spread: Option<i64>

标的iv-标的hv, 精度10**5(eg: iv为30%,hv为15%,则返回15000)

price: Option<i64>

标的价格, 精度10**9

chg_ratio: Option<i64>

标的涨跌幅,精度为10**5 (eg: 涨幅1.5%,则返回1500)

earnings: Option<EarningsInfo>

标的财报相关数据

index_type: Option<i32>

指数类型,参考IndexOptionType,与stock_id一起构成唯一键,用于区分大小恒指、大小国指、大小日经

Implementations

Source

impl UnderlyingStatisticInfo

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn open_interest(&self) -> i64

Returns the value of open_interest, or the default value if open_interest is unset.

pub fn iv(&self) -> i64

Returns the value of iv, or the default value if iv is unset.

pub fn hv(&self) -> i64

Returns the value of hv, or the default value if hv is unset.

pub fn iv_rank(&self) -> i64

Returns the value of iv_rank, or the default value if iv_rank is unset.

pub fn iv_percentile(&self) -> i64

Returns the value of iv_percentile, or the default value if iv_percentile is unset.

pub fn iv_chg(&self) -> i64

Returns the value of iv_chg, or the default value if iv_chg is unset.

pub fn iv_chg_ratio(&self) -> i64

Returns the value of iv_chg_ratio, or the default value if iv_chg_ratio is unset.

pub fn market_cap(&self) -> i64

Returns the value of market_cap, or the default value if market_cap is unset.

pub fn iv_hv_ratio(&self) -> i64

Returns the value of iv_hv_ratio, or the default value if iv_hv_ratio is unset.

pub fn iv_hv_spread(&self) -> i64

Returns the value of iv_hv_spread, or the default value if iv_hv_spread is unset.

pub fn price(&self) -> i64

Returns the value of price, or the default value if price is unset.

pub fn chg_ratio(&self) -> i64

Returns the value of chg_ratio, or the default value if chg_ratio is unset.

pub fn index_type(&self) -> i32

Returns the value of index_type, or the default value if index_type is unset.