#[repr(i32)]pub enum FundSetDefine {
FundSetCnAll = 9_800_609,
}Expand description
基金集合
Variants
FundSetCnAll = 9_800_609
所有基金类型
Implementations
Sourceimpl FundSetDefine
impl FundSetDefine
Sourceimpl FundSetDefine
impl FundSetDefine
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.