#[repr(i32)]pub enum LinkagePlate {
Shhk = 9_700_900,
Szhk = 9_700_903,
Hshk = 10_009_700,
}Expand description
关联市场板块
Variants
Implementations
Sourceimpl LinkagePlate
impl LinkagePlate
Sourceimpl LinkagePlate
impl LinkagePlate
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.