#[repr(i32)]pub enum LinkagePlateSortMarket {
SortMarketMain = 0,
SortMarketLink = 1,
SortMarketComp = 2,
}Expand description
多市场联动板块,根据哪个市场的股票进行排序
Variants
Implementations
Sourceimpl LinkagePlateSortMarket
impl LinkagePlateSortMarket
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of LinkagePlateSortMarket.
Sourcepub fn from_i32(value: i32) -> Option<LinkagePlateSortMarket>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<LinkagePlateSortMarket>
Converts an i32 to a LinkagePlateSortMarket, or None if value is not a valid variant.
Sourceimpl LinkagePlateSortMarket
impl LinkagePlateSortMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.