PlateId

Enum PlateId 

#[repr(i32)]
pub enum PlateId {
Show 27 variants HkFund = 900_075, HkHsi = 999_901, HkCei = 999_902, HkMainboard = 999_910, HkGem = 999_911, HkIndex = 999_912, HkAll = 10_001_910, HkMainboardH = 10_001_911, HkGemH = 10_001_912, HkSubnew = 10_001_921, HkMargin = 10_001_609, HkAdr = 10_001_983, UsNyse = 200_301, UsNasdaq = 200_302, UsAmex = 200_303, UsChinese = 200_304, UsStar = 200_305, UsAll = 200_306, UsSubnew = 10_002_921, UsMargin = 10_002_609, CnShMainboard = 3_000_000, CnSzMainboard = 3_000_001, CnHsIndex = 3_000_002, CnSzSme = 3_000_003, CnSzGem = 3_000_004, CnHsA = 3_000_005, CnSubnew = 10_000_921,
}
一些板块ID

Variants



HkFund = 900_075

港股-基金



HkHsi = 999_901

港股-恒指成份股



HkCei = 999_902

港股-国指成份股



HkMainboard = 999_910

港股-主板



HkGem = 999_911

港股-创业板



HkIndex = 999_912

港股-港指数



HkAll = 10_001_910

港股-全部港股



HkMainboardH = 10_001_911

港股-主板H股



HkGemH = 10_001_912

港股-创业板H股



HkSubnew = 10_001_921

港股-已上市新股



HkMargin = 10_001_609

港股-可抵押融资



HkAdr = 10_001_983

港股ADR



UsNyse = 200_301

美股-纽交所



UsNasdaq = 200_302

美股-纳斯达克



UsAmex = 200_303

美股-美交所



UsChinese = 200_304

美股-中概股



UsStar = 200_305

美股-明星股



UsAll = 200_306

美股-全部美股



UsSubnew = 10_002_921

美股-已上市新股



UsMargin = 10_002_609

美股-可融资融券



CnShMainboard = 3_000_000

A股-上海主板



CnSzMainboard = 3_000_001

A股-深证主板



CnHsIndex = 3_000_002

A股-沪深指数



CnSzSme = 3_000_003

A股-中小板



CnSzGem = 3_000_004

A股-创业板



CnHsA = 3_000_005

A股-沪深A股



CnSubnew = 10_000_921

A股-已上市新股

Implementations

Source

impl PlateId

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PlateId.

pub fn from_i32(value: i32) -> Option<PlateId>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PlateId, or None if value is not a valid variant.

Source

impl PlateId

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.