PlateSetDefine

Enum PlateSetDefine 

#[repr(i32)]
pub enum PlateSetDefine {
Show 25 variants PlateSetHkTrade = 9_700_000, PlateSetHkConcept = 9_700_001, PlateSetHkFutu = 9_700_003, PlateSetHkOther = 9_700_008, PlateSetHkAll = 9_700_009, PlateSetUsTrade = 9_700_300, PlateSetUsConcept = 9_700_301, PlateSetUsFutu = 9_700_303, PlateSetUsOther = 9_700_308, PlateSetUsAll = 9_700_309, PlateSetUsEtfHome = 9_700_310, PlateSetUsEtfQy = 9_700_311, PlateSetUsEtfDpzs = 9_700_312, PlateSetUsEtfDzsp = 9_700_313, PlateSetUsEtfZq = 9_700_314, PlateSetUsEtfWh = 9_700_315, PlateSetUsEtfXy = 9_700_316, PlateSetUsEtfJrrd = 9_700_317, PlateSetUsEtfOther = 9_700_319, PlateSetCnTrade = 9_700_600, PlateSetCnConcept = 9_700_601, PlateSetCnRegion = 9_700_602, PlateSetCnFutu = 9_700_603, PlateSetCnOther = 9_700_608, PlateSetCnAll = 9_700_609,
}
板块集合

Variants



PlateSetHkTrade = 9_700_000

行业板块(港股)



PlateSetHkConcept = 9_700_001

概念板块(港股)



PlateSetHkFutu = 9_700_003

特色板块(港股)



PlateSetHkOther = 9_700_008

其他板块(港股)



PlateSetHkAll = 9_700_009

所有板块(港股)



PlateSetUsTrade = 9_700_300

行业板块(美股)



PlateSetUsConcept = 9_700_301

概念板块(美股)



PlateSetUsFutu = 9_700_303

特色板块(美股)



PlateSetUsOther = 9_700_308

其他板块(美股)



PlateSetUsAll = 9_700_309

所有板块(美股)



PlateSetUsEtfHome = 9_700_310

美股ETF-首页



PlateSetUsEtfQy = 9_700_311

美股ETF-区域型



PlateSetUsEtfDpzs = 9_700_312

美股ETF-美股大盘指数型



PlateSetUsEtfDzsp = 9_700_313

美股ETF-大宗商品型



PlateSetUsEtfZq = 9_700_314

美股ETF-债券型



PlateSetUsEtfWh = 9_700_315

美股ETF-外汇型



PlateSetUsEtfXy = 9_700_316

美股ETF-行业型



PlateSetUsEtfJrrd = 9_700_317

美股ETF-今日热点



PlateSetUsEtfOther = 9_700_319

美股ETF-其他



PlateSetCnTrade = 9_700_600

行业板块(A股)



PlateSetCnConcept = 9_700_601

概念板块(A股)



PlateSetCnRegion = 9_700_602

地域板块(A股)



PlateSetCnFutu = 9_700_603

特色板块(A股)



PlateSetCnOther = 9_700_608

其他板块(A股)



PlateSetCnAll = 9_700_609

所有板块(A股)

Implementations

Source

impl PlateSetDefine

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PlateSetDefine.

pub fn from_i32(value: i32) -> Option<PlateSetDefine>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PlateSetDefine, or None if value is not a valid variant.

Source

impl PlateSetDefine

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.