PlateSortId

Enum PlateSortId 

#[repr(i32)]
pub enum PlateSortId {
Show 67 variants SortIdBasicCode = 100, SortIdPriceChangeRatio = 101, SortIdBasicName = 118, SortIdMarketVal = 119, SortIdPriceChangeNum = 120, SortIdPriceNominal = 1_000, SortIdPriceChangespeed = 1_003, SortIdTradeTurnover = 1_004, SortIdTradeVolumn = 1_005, SortIdPriceHighest = 1_006, SortIdPriceLowest = 1_007, SortIdPriceTodayopen = 1_008, SortIdPriceLastclose = 1_009, SortIdFinancePe = 1_010, SortIdPriceSell = 1_012, SortIdPriceBuy = 1_013, SortIdVolumnAsk = 1_014, SortIdVolumnBuy = 1_015, SortIdTradeChangeraio = 1_016, SortIdBuysellRatio = 1_017, SortIdVolumnRatio = 1_018, SortIdPriceAmplitude = 1_019, SortIdCompPremium = 1_200, SortIdPriceRiseCount = 1_300, SortIdMarginable = 1_401, SortIdMortgageRate = 1_402, SortIdShortSelling = 1_403, SortIdShortRefRate = 1_404, SortIdIpoPrice = 1_501, SortIdListingDate = 1_502, SortIdIpoPe = 1_503, SortIdIpoPriceChangeRatio = 1_504, SortIdContinuousRiseDayCnt = 1_505, SortIdFirstDayPcr = 1_506, SortIdFirstDayRealPcr = 1_507, SortIdIpoIssueVol = 1_508, SortIdPremarketNominalPrice = 1_509, SortIdPremarketPriceChangeAmount = 1_510, SortIdPremarketPriceChangeRatio = 1_511, SortIdAfterhourNominalPrice = 1_512, SortIdAfterhourPriceChangeAmount = 1_513, SortIdAfterhourPriceChangeRatio = 1_514, SortIdPremarketAmplitude = 1_515, SortIdAfterhourAmplitude = 1_516, SortIdPremarketTurnover = 1_517, SortIdAfterhourTurnover = 1_518, SortIdPremarketTradeVol = 1_519, SortIdAfterhourTradeVol = 1_520, SortIdHsgHoldNum = 1_521, SortIdHsgHoldRatio = 1_522, SortChangeRatio5Days = 1_523, SortChangeRatio10Days = 1_524, SortChangeRatio20Days = 1_525, SortChangeRatio60Days = 1_526, SortChangeRatio120Days = 1_527, SortChangeRatio250Days = 1_528, SortChangeRatioYear = 1_529, SortChangeRatio5Min = 1_530, SortAdrCode = 1_531, SortAdrPrice = 1_532, SortAdrDiffPrice = 1_533, SortAdrDiffPer = 1_534, SortAdrConvertionRatio = 1_535, SortAdrRatio = 1_536, SortAdrTradVol = 1_537, SortIdHsgHoldAmount = 1_538, SortAdrPriceHk = 1_539,
}
排序数据列的定义

Variants



SortIdBasicCode = 100

代码



SortIdPriceChangeRatio = 101

涨跌%



SortIdBasicName = 118

名称



SortIdMarketVal = 119

市值



SortIdPriceChangeNum = 120

涨跌额



SortIdPriceNominal = 1_000

最新价



SortIdPriceChangespeed = 1_003

涨跌速率



SortIdTradeTurnover = 1_004

成交额



SortIdTradeVolumn = 1_005

成交量



SortIdPriceHighest = 1_006

最高价



SortIdPriceLowest = 1_007

最低价



SortIdPriceTodayopen = 1_008

今开



SortIdPriceLastclose = 1_009

昨收



SortIdFinancePe = 1_010

市盈率



SortIdPriceSell = 1_012

卖出价



SortIdPriceBuy = 1_013

买入价



SortIdVolumnAsk = 1_014

卖量



SortIdVolumnBuy = 1_015

买量



SortIdTradeChangeraio = 1_016

换手率



SortIdBuysellRatio = 1_017

委比



SortIdVolumnRatio = 1_018

量比



SortIdPriceAmplitude = 1_019

震幅



SortIdCompPremium = 1_200

比对溢价(%)



SortIdPriceRiseCount = 1_300

股票上涨家数



SortIdMarginable = 1_401

可融资



SortIdMortgageRate = 1_402

抵押率



SortIdShortSelling = 1_403

可卖空



SortIdShortRefRate = 1_404

卖空参考利率



SortIdIpoPrice = 1_501

ipo价(发行价)



SortIdListingDate = 1_502

上市日期



SortIdIpoPe = 1_503

发行市盈率



SortIdIpoPriceChangeRatio = 1_504

上市至今涨幅



SortIdContinuousRiseDayCnt = 1_505

连涨天数(自上市后至今,连续涨幅最长的天数)



SortIdFirstDayPcr = 1_506

首日涨幅



SortIdFirstDayRealPcr = 1_507

实际涨幅



SortIdIpoIssueVol = 1_508

发行量



SortIdPremarketNominalPrice = 1_509

盘前价



SortIdPremarketPriceChangeAmount = 1_510

盘前涨跌额



SortIdPremarketPriceChangeRatio = 1_511

盘前涨跌幅



SortIdAfterhourNominalPrice = 1_512

盘后价



SortIdAfterhourPriceChangeAmount = 1_513

盘后涨跌额



SortIdAfterhourPriceChangeRatio = 1_514

盘后涨跌幅



SortIdPremarketAmplitude = 1_515

盘前振幅



SortIdAfterhourAmplitude = 1_516

盘后振幅



SortIdPremarketTurnover = 1_517

盘前成交额



SortIdAfterhourTurnover = 1_518

盘后成交额



SortIdPremarketTradeVol = 1_519

盘前成交量



SortIdAfterhourTradeVol = 1_520

盘后成交量



SortIdHsgHoldNum = 1_521

沪深港通持股数



SortIdHsgHoldRatio = 1_522

沪深港通持股比例



SortChangeRatio5Days = 1_523

5日涨跌幅



SortChangeRatio10Days = 1_524

10日涨跌幅



SortChangeRatio20Days = 1_525

20日涨跌幅



SortChangeRatio60Days = 1_526

60日涨跌幅



SortChangeRatio120Days = 1_527

120日涨跌幅



SortChangeRatio250Days = 1_528

250日涨跌幅



SortChangeRatioYear = 1_529

年涨跌幅



SortChangeRatio5Min = 1_530

五分钟涨跌幅



SortAdrCode = 1_531

adr 代码



SortAdrPrice = 1_532

adr 价格



SortAdrDiffPrice = 1_533

adr 价差



SortAdrDiffPer = 1_534

adr 相对涨跌幅



SortAdrConvertionRatio = 1_535

adr 换股比例



SortAdrRatio = 1_536

adr 涨跌幅



SortAdrTradVol = 1_537

adr 成交量



SortIdHsgHoldAmount = 1_538

沪深港通持股额



SortAdrPriceHk = 1_539

adr 价格 HKD

Implementations

Source

impl PlateSortId

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PlateSortId.

pub fn from_i32(value: i32) -> Option<PlateSortId>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PlateSortId, or None if value is not a valid variant.

Source

impl PlateSortId

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.