#[repr(i32)]pub enum PriceFliter {
All = 0,
LessThan1 = 1,
Between110 = 2,
Between10100 = 3,
LargeThan100 = 4,
Near52H = 5,
Near52L = 6,
}Expand description
排序数据列的定义
Variants
All = 0
所有
LessThan1 = 1
小于1
Between110 = 2
1 10 之间
Between10100 = 3
10 100 之间
LargeThan100 = 4
大于100
Near52H = 5
接近52周最高
Near52L = 6
接近52周最低
Implementations
Sourceimpl PriceFliter
impl PriceFliter
Sourceimpl PriceFliter
impl PriceFliter
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.