#[repr(i32)]pub enum StockConnectId {
ShhkSh = 1_000_159,
ShhkHk = 9_700_902,
SzhkSz = 10_000_922,
SzhkHk = 10_001_922,
All = 10_002_922,
}Expand description
市场互联ID(板块ID或指数ID)
Variants
ShhkSh = 1_000_159
沪港通-沪股(指数)
ShhkHk = 9_700_902
沪港通-港股(板块)
SzhkSz = 10_000_922
深港通-深股(板块)
SzhkHk = 10_001_922
深港通-港股(板块)
All = 10_002_922
上述板块集合
Implementations
Sourceimpl StockConnectId
impl StockConnectId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.