#[repr(i32)]pub enum UsetfPlateAll {
UsEtfPlateAllRegion = 10_002_700,
UsEtfPlateAllMarketIdnex = 10_002_710,
UsEtfPlateAllCommodity = 10_002_720,
UsEtfPlateAllBond = 10_002_730,
UsEtfPlateAllExchange = 10_002_750,
UsEtfPlateAllTrade = 10_002_760,
UsEtfPlateAllHot = 10_002_770,
UsEtfPlateAllOther = 10_002_790,
UsEtfPlateAll = 10_002_799,
}Expand description
美股ETF-各板块集合的“全部”板块ID
Variants
UsEtfPlateAllRegion = 10_002_700
区域型
UsEtfPlateAllMarketIdnex = 10_002_710
美股大盘指数型
UsEtfPlateAllCommodity = 10_002_720
大宗商品型
UsEtfPlateAllBond = 10_002_730
债券型
UsEtfPlateAllExchange = 10_002_750
外汇型
UsEtfPlateAllTrade = 10_002_760
行业型
UsEtfPlateAllHot = 10_002_770
今日热点
UsEtfPlateAllOther = 10_002_790
其他
UsEtfPlateAll = 10_002_799
所有ETF
Implementations
Sourceimpl UsetfPlateAll
impl UsetfPlateAll
Sourceimpl UsetfPlateAll
impl UsetfPlateAll
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.