#[repr(i32)]pub enum NotifyTimePeriod {
TimePeriodUnknown = 0,
TimePeriodNormal = 1,
TimePeriodUsBefore = 2,
TimePeriodUsAfter = 3,
TimePeriodUsOvernight = 4,
}Expand description
提醒时段
Variants
TimePeriodUnknown = 0
未知,不允许业务使用
TimePeriodNormal = 1
默认时段, 例如:美股则是盘中
TimePeriodUsBefore = 2
美股盘前
TimePeriodUsAfter = 3
美股盘后
TimePeriodUsOvernight = 4
美股夜盘
Implementations
Sourceimpl NotifyTimePeriod
impl NotifyTimePeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.