RspCode

Enum RspCode 

#[repr(i32)]
pub enum RspCode {
Show 35 variants Succ = 0, ReqPbParseFailed = 1, InnerError = -1, NumLimit = 2, SaveDbFail = 3, TypeNumLimit = 4, WarnTypeInvalid = 5, KeyInvalid = 6, UpdateTimeInvalid = 7, NoteLenExcess = 8, OperTypeInvalid = 9, DeleteItemFail = 10, ModifyItemFail = 11, InfoWarnNumLimit = 12, StockInvalid = 13, HeadTypeVersionLack = 14, OldVersionLowLack = 15, NewVersionHighLack = 16, MultipleStockId = 101, GetIpPortError = 102, PricewarngetimplError = 103, GetIpPortByCmlbError = 104, GetAllIpPortError = 105, PricewarnsetimplError = 106, GetCmnwarnIpPortError = 107, CmnarninfoimplSendError = 108, CmnarninfoimplRetcodeError = 109, AllwarnInfoError = 110, CmnarnsetimplSendError = 111, CmnarnsetimplRetcodeError = 112, AllwarnSetError = 113, IndicatorGetError = 114, IndicatorSetError = 115, GetIndicatorIpPortError = 116, UidInvalid = 201,
}
返回错误码

Variants



Succ = 0

pricewarn_svr错误返回码,范围:[0-100]



ReqPbParseFailed = 1

请求PB解析失败



InnerError = -1

内部错误



NumLimit = 2

到价提醒上限



SaveDbFail = 3

保存数据库失败



TypeNumLimit = 4

一个提醒类型的提醒个数到达上限



WarnTypeInvalid = 5

到价提醒类型错误



KeyInvalid = 6

item中的key无效



UpdateTimeInvalid = 7

设置item时update_time错误



NoteLenExcess = 8

item中note过长



OperTypeInvalid = 9

ItemAttr.oper_type无效



DeleteItemFail = 10

删除item失败



ModifyItemFail = 11

修改item失败



InfoWarnNumLimit = 12

公告提醒到达设置上限



StockInvalid = 13

股票无效/退市



HeadTypeVersionLack = 14

包头缺失客户端类型或版本



OldVersionLowLack = 15

旧版客户端未设置低精度提醒字段



NewVersionHighLack = 16

新版客户端未设置高精度提醒字段



MultipleStockId = 101

pricewarn_proxy错误返回码,范围[101-200]

有多个stock_id



GetIpPortError = 102

get_ip_port error



PricewarngetimplError = 103

PriceWarnGetImpl err,拉取失败



GetIpPortByCmlbError = 104

get_ip_port_by_cmlb error



GetAllIpPortError = 105

get_all_ip_port error



PricewarnsetimplError = 106

PriceWarnSetImpl err,设置失败



GetCmnwarnIpPortError = 107

get_cmnwarn_ip_port error



CmnarninfoimplSendError = 108

通用提醒拉取失败



CmnarninfoimplRetcodeError = 109

通用提醒拉取返回码错误



AllwarnInfoError = 110

获取所有提醒信息失败



CmnarnsetimplSendError = 111

通用提醒设置失败



CmnarnsetimplRetcodeError = 112

通用提醒设置返回码错误



AllwarnSetError = 113

设置所有提醒信息失败



IndicatorGetError = 114

获取指标提醒信息失败



IndicatorSetError = 115

设置指标提醒信息失败



GetIndicatorIpPortError = 116

get_indicator_ip_port error



UidInvalid = 201

pricewarn_proxy 与 pricewarn_svr错误返回码,范围[201-300]

uid分区无效

Implementations

Source

impl RspCode

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of RspCode.

pub fn from_i32(value: i32) -> Option<RspCode>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a RspCode, or None if value is not a valid variant.

Source

impl RspCode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.