#[repr(i32)]pub enum UnitLvl {
Unknown = 0,
One = 1,
Two = 2,
Three = 3,
}Expand description
option optimize_for = LITE_RUNTIME; 三挡: 亿 B 二挡: 百万 M 一档: 万 K 中/日 其他 UnitLvl 枚举 筛选场景下的公共结构,例如筛选条件,标的、期权筛选均可以使用
Variants
Implementations
Sourceimpl UnitLvl
impl UnitLvl
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.