#[repr(i32)]pub enum HkcasStatus {
HkCasNone = 0,
HkCasBegin = 1,
HkCasIsHappening = 2,
HkCasEnd = 3,
}Expand description
港股盘后竞价状态
Variants
HkCasNone = 0
非CAS状态
HkCasBegin = 1
CAS开始, 参考价未确定
HkCasIsHappening = 2
CAS状态中, 参考价已经确定
HkCasEnd = 3
CAS结束
Implementations
Sourceimpl HkcasStatus
impl HkcasStatus
Sourceimpl HkcasStatus
impl HkcasStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.