#[repr(i32)]pub enum HkvcmStatus {
HkVcmNone = 0,
HkVcmTriggering = 1,
HkVcmEnd = 2,
}Expand description
VCM状态
Variants
Implementations
Sourceimpl HkvcmStatus
impl HkvcmStatus
Sourceimpl HkvcmStatus
impl HkvcmStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.