#[repr(i32)]pub enum UsPreMarketAfterHoursStatus {
UsPreAfterStatusHidden = 0,
UsPreAfterStatusPreMarket = 1,
UsPreAfterStatusAfterHours = 2,
}Expand description
美股盘前盘后状态
Variants
UsPreAfterStatusHidden = 0
不展示盘前或盘后价
UsPreAfterStatusPreMarket = 1
盘前
UsPreAfterStatusAfterHours = 2
盘后
Implementations
Sourceimpl UsPreMarketAfterHoursStatus
impl UsPreMarketAfterHoursStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of UsPreMarketAfterHoursStatus.
Sourcepub fn from_i32(value: i32) -> Option<UsPreMarketAfterHoursStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<UsPreMarketAfterHoursStatus>
Converts an i32 to a UsPreMarketAfterHoursStatus, or None if value is not a valid variant.
Sourceimpl UsPreMarketAfterHoursStatus
impl UsPreMarketAfterHoursStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.