OptionGreek

pub struct OptionGreek {
    pub delta: Option<i64>,
    pub gamma: Option<i64>,
    pub vega: Option<i64>,
    pub theta: Option<i64>,
    pub rho: Option<i64>,
    pub hp_delta: Option<i64>,
    pub hp_gamma: Option<i64>,
    pub hp_vega: Option<i64>,
    pub hp_theta: Option<i64>,
    pub hp_rho: Option<i64>,
}
美股期权希腊值

Fields

delta: Option<i64>

△ [放大10^3倍]

gamma: Option<i64>

γ [放大10^3倍]

vega: Option<i64>

ν [放大10^3倍]

theta: Option<i64>

θ [放大10^3倍]

rho: Option<i64>

ρ [放大10^3倍]

hp_delta: Option<i64>

*1e9

hp_gamma: Option<i64>

*1e9

hp_vega: Option<i64>

*1e9

hp_theta: Option<i64>

*1e9

hp_rho: Option<i64>

*1e9

Implementations

Source

impl OptionGreek

pub fn delta(&self) -> i64

Returns the value of delta, or the default value if delta is unset.

pub fn gamma(&self) -> i64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> i64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> i64

Returns the value of theta, or the default value if theta is unset.

pub fn rho(&self) -> i64

Returns the value of rho, or the default value if rho is unset.

pub fn hp_delta(&self) -> i64

Returns the value of hp_delta, or the default value if hp_delta is unset.

pub fn hp_gamma(&self) -> i64

Returns the value of hp_gamma, or the default value if hp_gamma is unset.

pub fn hp_vega(&self) -> i64

Returns the value of hp_vega, or the default value if hp_vega is unset.

pub fn hp_theta(&self) -> i64

Returns the value of hp_theta, or the default value if hp_theta is unset.

pub fn hp_rho(&self) -> i64

Returns the value of hp_rho, or the default value if hp_rho is unset.