Trust

pub struct Trust {
    pub dividend_yield: Option<i64>,
    pub aum: Option<u64>,
    pub outstanding_units: Option<u64>,
    pub net_asset_value: Option<u64>,
    pub premium: Option<i64>,
    pub asset_class_sc: Option<String>,
    pub asset_class_tc: Option<String>,
    pub asset_class_en: Option<String>,
    pub asset_class: Option<u32>,
}
基金类型

Fields

dividend_yield: Option<i64>

股息率, 10^5

aum: Option<u64>

资产规模

outstanding_units: Option<u64>

总发行量

net_asset_value: Option<u64>

单位净值, 10^9

premium: Option<i64>

溢价,[放大10^5倍],前端展示百分比

asset_class_sc: Option<String>

资产类别(简体中文)

asset_class_tc: Option<String>

资产类别(繁体中文)

asset_class_en: Option<String>

资产类别(英文)

asset_class: Option<u32>

资产类别 2-股票,3-债券,14-商品,15-货币市场,16-期货,17-掉期

Implementations

Source

impl Trust

pub fn dividend_yield(&self) -> i64

Returns the value of dividend_yield, or the default value if dividend_yield is unset.

pub fn aum(&self) -> u64

Returns the value of aum, or the default value if aum is unset.

pub fn outstanding_units(&self) -> u64

Returns the value of outstanding_units, or the default value if outstanding_units is unset.

pub fn net_asset_value(&self) -> u64

Returns the value of net_asset_value, or the default value if net_asset_value is unset.

pub fn premium(&self) -> i64

Returns the value of premium, or the default value if premium is unset.

pub fn asset_class_sc(&self) -> &str

Returns the value of asset_class_sc, or the default value if asset_class_sc is unset.

pub fn asset_class_tc(&self) -> &str

Returns the value of asset_class_tc, or the default value if asset_class_tc is unset.

pub fn asset_class_en(&self) -> &str

Returns the value of asset_class_en, or the default value if asset_class_en is unset.

pub fn asset_class(&self) -> u32

Returns the value of asset_class, or the default value if asset_class is unset.