UsPreMarketAfterHoursDetailItem

Struct UsPreMarketAfterHoursDetailItem 

pub struct UsPreMarketAfterHoursDetailItem {
    pub price: Option<i64>,
    pub price_highest: Option<i64>,
    pub price_lowest: Option<i64>,
    pub volume: Option<i64>,
    pub turnover: Option<i64>,
    pub price_change: Option<i64>,
    pub ratio_price_change: Option<i64>,
    pub amplitude_price: Option<i64>,
    pub price_update_time_ms: Option<i64>,
}
美股盘前或盘后详细信息

Fields

price: Option<i64>

盘前或盘后 - 价格

price_highest: Option<i64>

盘前或盘后 - 最高价

price_lowest: Option<i64>

盘前或盘后 - 最低价

volume: Option<i64>

盘前或盘后 - 成交量

turnover: Option<i64>

盘前或盘后 - 成交额

price_change: Option<i64>

盘前或盘后 - 涨跌额

ratio_price_change: Option<i64>

盘前或盘后 - 涨跌幅,[放大10^5倍],前端展示百分比

amplitude_price: Option<i64>

盘前或盘后 - 振幅,[放大10^5倍],前端展示百分比

price_update_time_ms: Option<i64>

价格更新时间 ms

Implementations

Source

impl UsPreMarketAfterHoursDetailItem

pub fn price(&self) -> i64

Returns the value of price, or the default value if price is unset.

pub fn price_highest(&self) -> i64

Returns the value of price_highest, or the default value if price_highest is unset.

pub fn price_lowest(&self) -> i64

Returns the value of price_lowest, or the default value if price_lowest is unset.

pub fn volume(&self) -> i64

Returns the value of volume, or the default value if volume is unset.

pub fn turnover(&self) -> i64

Returns the value of turnover, or the default value if turnover is unset.

pub fn price_change(&self) -> i64

Returns the value of price_change, or the default value if price_change is unset.

pub fn ratio_price_change(&self) -> i64

Returns the value of ratio_price_change, or the default value if ratio_price_change is unset.

pub fn amplitude_price(&self) -> i64

Returns the value of amplitude_price, or the default value if amplitude_price is unset.

pub fn price_update_time_ms(&self) -> i64

Returns the value of price_update_time_ms, or the default value if price_update_time_ms is unset.