#[repr(i32)]pub enum WarningCode {
WcodeTimerSubListChange = 1,
WcodeOverMaxSubCount = 2,
WcodeRecvWrongOrderSeq = 4,
}Variants
WcodeTimerSubListChange = 1
定时订阅列表不一致
WcodeOverMaxSubCount = 2
超过订阅数量上限
WcodeRecvWrongOrderSeq = 4
收包时序不对
Implementations
Sourceimpl WarningCode
impl WarningCode
Sourceimpl WarningCode
impl WarningCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.