#[repr(i32)]pub enum BitProbExtendedTimeSharingPlans {
BitProbBaTimeSharingDefault = 0,
BitProbBaTimeSharingExrightNone = 1,
BitProbBaTimeSharingExrightForward = 2,
BitProbBaTimeSharingExrightBackward = 4,
BitProbOvernightTimeSharingExrightNone = 8,
BitProbOvernightTimeSharingExrightForward = 16,
BitProbOvernightTimeSharingExrightBackward = 32,
}Expand description
订阅位属性值之一(附加值)- 延长时间分时 TimeSharingPlans SBIT_PRE_AFTER_TIME_SHARING_PLANS 支持或
Variants
BitProbBaTimeSharingDefault = 0
默认盘前盘后时段不复权
BitProbBaTimeSharingExrightNone = 1
盘前盘后时段
不复权
BitProbBaTimeSharingExrightForward = 2
前复权
BitProbBaTimeSharingExrightBackward = 4
后复权
BitProbOvernightTimeSharingExrightNone = 8
夜盘时段
不复权
BitProbOvernightTimeSharingExrightForward = 16
前复权
BitProbOvernightTimeSharingExrightBackward = 32
后复权
Implementations
Sourceimpl BitProbExtendedTimeSharingPlans
impl BitProbExtendedTimeSharingPlans
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of BitProbExtendedTimeSharingPlans.
Sourcepub fn from_i32(value: i32) -> Option<BitProbExtendedTimeSharingPlans>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<BitProbExtendedTimeSharingPlans>
Converts an i32 to a BitProbExtendedTimeSharingPlans, or None if value is not a valid variant.
Sourceimpl BitProbExtendedTimeSharingPlans
impl BitProbExtendedTimeSharingPlans
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.