#[repr(i32)]pub enum BitProbExtendedTrading {
BitProbNone = 0,
BitProbUsPremarketafter = 1,
BitProbAllTradingTime = 2,
}Expand description
订阅位属性值之一(附加值)- 延长交易时段 SBIT_SPECIFIC_TRADE_TIME
Variants
BitProbNone = 0
据这个市场是什么状态 就会发什么数据。如:在夜盘就发夜盘的, 在盘前就发 盘前的
无实际意义,兼容老客户端
BitProbUsPremarketafter = 1
美股盘前盘后 (不含夜盘)
BitProbAllTradingTime = 2
美股盘前,盘后,夜盘交易时段
Implementations
Sourceimpl BitProbExtendedTrading
impl BitProbExtendedTrading
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of BitProbExtendedTrading.
Sourcepub fn from_i32(value: i32) -> Option<BitProbExtendedTrading>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<BitProbExtendedTrading>
Converts an i32 to a BitProbExtendedTrading, or None if value is not a valid variant.
Sourceimpl BitProbExtendedTrading
impl BitProbExtendedTrading
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.