#[repr(i32)]pub enum BitProbKline {
ExrightNone = 1,
ExrightForward = 2,
ExrightBackward = 4,
BitProbMinuteBaKlineExrightNone = 8,
BitProbMinuteBaKlineExrightForward = 16,
BitProbMinuteBaKlineExrightBackward = 32,
BitProbOvernightKlineExrightNone = 64,
BitProbOvernightKlineExrightForward = 128,
BitProbOvernightKlineExrightBackward = 256,
}Expand description
订阅位属性值之一(附加值)- K线 SBIT_KLINE_*
Variants
ExrightNone = 1
不复权
ExrightForward = 2
前复权
ExrightBackward = 4
后复权
BitProbMinuteBaKlineExrightNone = 8
不复权的盘前盘后分K(仅对分K订阅位有效)
BitProbMinuteBaKlineExrightForward = 16
前复权的盘前盘后分K(仅对分K订阅位有效)
BitProbMinuteBaKlineExrightBackward = 32
后复权的盘前盘后分K(仅对分K订阅位有效)
BitProbOvernightKlineExrightNone = 64
不复权的夜盘分K(仅对分K订阅位有效)
BitProbOvernightKlineExrightForward = 128
前复权的夜盘分K(仅对分K订阅位有效)
BitProbOvernightKlineExrightBackward = 256
后复权的夜盘分K(仅对分K订阅位有效)
Implementations
Sourceimpl BitProbKline
impl BitProbKline
Sourceimpl BitProbKline
impl BitProbKline
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.