#[repr(i32)]pub enum BitProbOrderBook {
BitProbOrderBook40lNoId = 0,
AllNoId = 1,
AllWithId = 2,
SimpleUtp = 4,
SimpleBasic = 8,
SimpleOvernight = 16,
}Expand description
订阅位属性值之一(附加值)- 摆盘 SBIT_ORDER_BOOK
Variants
BitProbOrderBook40lNoId = 0
以下属性值仅港股sf摆盘需要
40档摆盘-无orderid列表(缺省值)
AllNoId = 1
全部档摆盘-无orderid列表
AllWithId = 2
全部档摆盘+orderid列表
SimpleUtp = 4
以下属性仅美股需要,同样适用于订阅位SBIT_ORDER_BOOK_SIMPLE 如果同时订阅utp和basic,发送prob=4|8,即(UTP | BASIC) 推送包也会通过带上prob=4或8,表示为utp或basic摆盘
utp bbo
SimpleBasic = 8
basic bbo
SimpleOvernight = 16
OVRENIGHT bbo
Implementations
Sourceimpl BitProbOrderBook
impl BitProbOrderBook
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.