#[repr(i32)]pub enum BitProbTick {
PeriodNormal = 1,
PeriodBefore = 2,
PeriodAfter = 4,
PeriodOvernight = 8,
}Expand description
订阅位属性值之一(附加值)- 逐笔 SBIT_TICK
Variants
Implementations
Sourceimpl BitProbTick
impl BitProbTick
Sourceimpl BitProbTick
impl BitProbTick
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.