SubscribeBit

#[repr(i32)]
pub enum SubscribeBit {
Show 41 variants SbitPrice = 0, SbitStockState = 1, SbitStockTypeSpecific = 2, SbitOrderBook = 3, SbitOrderBookSimple = 4, SbitDealStatistics = 5, SbitHistoryHighlowPrice = 6, SbitHistoryClosePrice = 7, SbitFinancialIndicator = 8, SbitHkBrokerQueue = 9, SbitAuction = 10, SbitHkVcm = 11, SbitUsPremarketAfterhours = 12, SbitUsPremarketAfterhoursDetail = 13, SbitCnOrderBookDetail = 14, SbitMarginInfo = 15, SbitDepositoryReceipt = 16, SbitUsLv2Order = 17, SbitStaticFinancialIndicator = 18, SbitUsoptLv2Order = 19, SbitTimeSharingPlans = 20, SbitKline1minute = 21, SbitKline3minute = 22, SbitKline5minute = 23, SbitKline15minute = 24, SbitKline30minute = 25, SbitKline60minute = 26, SbitKlineDay = 27, SbitKlineWeek = 28, SbitKlineMonth = 29, SbitKlineQuarter = 30, SbitKlineYear = 31, SbitPreAfterTimeSharingPlans = 32, SbitTick = 35, SbitKline120minute = 36, SbitKline240minute = 37, SbitBondAnalysis = 38, SbitMegerLv2Order = 39, SbitKline10minute = 40, SbitKline180minute = 41, SbitNoii = 42,
}
订阅位 备注:如果一些订阅位使用的数据类型需要单独添加字段,在本协议文件中定义一个新类型来组合已有类型,然后再添加字段。

Variants



SbitPrice = 0

覆盖型行情数据相关订阅位。除非特殊说明,对应的数据类型都在FTCmdStockQuoteCoverageData.proto文件中定义。

股票按盘价 Price



SbitStockState = 1

股票状态 StockState



SbitStockTypeSpecific = 2

各种类型股票特有的数据 StockTypeSpecific



SbitOrderBook = 3

委托摆盘(买卖档) OrderBook



SbitOrderBookSimple = 4

委托摆盘简要信息 OrderBookSimple



SbitDealStatistics = 5

成交统计 DealStatistics



SbitHistoryHighlowPrice = 6

历史高低价 FTCmdSubData.BitDataHistoryHighLowPrice



SbitHistoryClosePrice = 7

历史收盘价 HistoryClosePrice



SbitFinancialIndicator = 8

财务指标 FinacialIndicator



SbitHkBrokerQueue = 9

港股经纪队列 HKBrokerQueue



SbitAuction = 10

港股盘后竞价 & 通用竞价协议 AuctionInfo



SbitHkVcm = 11

港股冷静期机制 HKVCMInfo



SbitUsPremarketAfterhours = 12

美股盘前或盘后简要信息 USPreMarketAfterHours



SbitUsPremarketAfterhoursDetail = 13

美股盘前与盘后详情信息 USPreMarketAfterHoursDetail



SbitCnOrderBookDetail = 14

A股委托摆盘明细 CNOrderBookDetail



SbitMarginInfo = 15

融资融券信息 MarginInfo **** 订阅位废弃



SbitDepositoryReceipt = 16

存托凭证信息(ADR/CDR换算价) DepositoryReceipt



SbitUsLv2Order = 17

美股LV2订阅位 USLV2OrderList



SbitStaticFinancialIndicator = 18

静态财务指标 StaticFinancialIndicator。



SbitUsoptLv2Order = 19

美股期权lv2订阅位 USLV2OrderList



SbitTimeSharingPlans = 20

累积型行情类型 - 分时K线订阅位。对应的数据类型在FTCmdStockQuoteAccumulateData.proto文件中定义。

分时 TimeSharingPlans



SbitKline1minute = 21

1分K SBIT_KLINE_* 对应的类型为 Kline



SbitKline3minute = 22

3分K



SbitKline5minute = 23

5分K



SbitKline15minute = 24

15分K



SbitKline30minute = 25

30分K



SbitKline60minute = 26

60分K



SbitKlineDay = 27

日K



SbitKlineWeek = 28

周K



SbitKlineMonth = 29

月K



SbitKlineQuarter = 30

季K



SbitKlineYear = 31

年K



SbitPreAfterTimeSharingPlans = 32

(美股)盘前盘后分时 TimeSharingPlans



SbitTick = 35

累积型行情类型 - 逐笔订阅位。对应的数据类型在FTCmdStockQuoteAccumulateData.proto文件中定义。

逐笔 Tick



SbitKline120minute = 36

120分K



SbitKline240minute = 37

240分K



SbitBondAnalysis = 38

债券指标数据



SbitMegerLv2Order = 39

合单lv2摆盘,除订阅,请求、回报与SBIT_US_LV2_ORDER相同。



SbitKline10minute = 40

10分K



SbitKline180minute = 41

180分K



SbitNoii = 42

竞价分析订阅位 (需指定prob2,参考SBIT_US_LV2_ORDER) NoiiInfo

Implementations

Source

impl SubscribeBit

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of SubscribeBit.

pub fn from_i32(value: i32) -> Option<SubscribeBit>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a SubscribeBit, or None if value is not a valid variant.

Source

impl SubscribeBit

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.