BitInfo

pub struct BitInfo {
    pub bit: Option<u32>,
    pub prob: Option<i64>,
    pub prob2: Option<String>,
    pub prob2_v2: Option<Vec<u8>>,
}
订阅位信息

Fields

bit: Option<u32>

订阅位,见 SubscribeBit 枚举,必给

prob: Option<i64>

订阅位属性,附加值,非必需; SBIT_HISTORY_HIGHLOW_PRICE必须填复权类型FTCmdStockQuoteCoverageData.PriceExrightType

prob2: Option<String>

订阅位附加属性,xxxxSubProb类型的序列化数据。非必需

prob2_v2: Option<Vec<u8>>

订阅位附加属性二进制形式;C++ 用于 overnight / futures LV2 合单摆盘

Implementations

Source

impl BitInfo

pub fn bit(&self) -> u32

Returns the value of bit, or the default value if bit is unset.

pub fn prob(&self) -> i64

Returns the value of prob, or the default value if prob is unset.

pub fn prob2(&self) -> &str

Returns the value of prob2, or the default value if prob2 is unset.

pub fn prob2_v2(&self) -> &[u8]

Returns the value of prob2_v2, or the default value if prob2_v2 is unset.