#[repr(i32)]pub enum Broker {
ConcentratedDistributionHoldings = 6_101,
HoldingsChange = 6_102,
Num = 6_103,
Rank = 6_104,
HoldingsNum = 6_105,
CentralTradeHoldingsRatio = 6_106,
CentralTradeHoldingsChange = 6_107,
}Expand description
经纪商持股
Variants
ConcentratedDistributionHoldings = 6_101
持仓分布集中度 (其中的百分比单位:0.001% 倍率:100000)
HoldingsChange = 6_102
持仓经纪商变动 (其中的百分比单位:0.001% 倍率:100000)
Num = 6_103
持仓经纪商数量(单位:1 倍率:1)
Rank = 6_104
经纪商排行(单位:1 倍率:1)
HoldingsNum = 6_105
经纪商持仓量占比(单位:0.001% 倍率:100000)
CentralTradeHoldingsRatio = 6_106
中央结算持股占比(单位:0.001% 倍率:100000)
CentralTradeHoldingsChange = 6_107
中央结算持股变动(单位:0.001% 倍率:100000)
Implementations
Sourceimpl Broker
impl Broker
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.