#[repr(i32)]pub enum Indicator {
Show 38 variants
Unknown = 0,
Price = 1,
Ma5 = 11,
Ma10 = 12,
Ma20 = 13,
Ma30 = 14,
Ma60 = 15,
Ma120 = 16,
Ma250 = 17,
Ma = 18,
Ema5 = 21,
Ema10 = 22,
Ema20 = 23,
Ema30 = 24,
Ema60 = 25,
Ema120 = 26,
Ema250 = 27,
Ema = 28,
Kdj933K = 31,
Kdj933D = 32,
Kdj933J = 33,
KdjK = 34,
KdjD = 35,
KdjJ = 36,
Macd12269Dif = 41,
Macd12269Dea = 42,
Macd12269Macd = 43,
MacdDif = 44,
MacdDea = 45,
MacdMacd = 46,
Rsi12 = 51,
Rsi = 52,
Boll202Upper = 61,
Boll202Middle = 62,
Boll202Lower = 63,
BollUpper = 64,
BollMiddle = 65,
BollLower = 66,
}Variants
Unknown = 0
未知
Price = 1
最新价格 (单位:0.001元 倍率:1000)
Ma5 = 11
5日简单均线 (单位:0.001元 倍率:1000)
Ma10 = 12
10日简单均线 (单位:0.001元 倍率:1000)
Ma20 = 13
20日简单均线 (单位:0.001元 倍率:1000)
Ma30 = 14
30日简单均线 (单位:0.001元 倍率:1000)
Ma60 = 15
60日简单均线 (单位:0.001元 倍率:1000)
Ma120 = 16
120日简单均线 (单位:0.001元 倍率:1000)
Ma250 = 17
250日简单均线 (单位:0.001元 倍率:1000)
Ma = 18
动态简单均线 (单位:0.001元 倍率:1000)
Ema5 = 21
5日指数移动均线 (单位:0.001元 倍率:1000)
Ema10 = 22
10日指数移动均线 (单位:0.001元 倍率:1000)
Ema20 = 23
20日指数移动均线 (单位:0.001元 倍率:1000)
Ema30 = 24
30日指数移动均线 (单位:0.001元 倍率:1000)
Ema60 = 25
60日指数移动均线 (单位:0.001元 倍率:1000)
Ema120 = 26
120日指数移动均线 (单位:0.001元 倍率:1000)
Ema250 = 27
250日指数移动均线 (单位:0.001元 倍率:1000)
Ema = 28
动态指数移动均线 (单位:0.001元 倍率:1000)
Kdj933K = 31
KDJ(9,3,3)的K值 (单位:0.001% 倍率:100000)
Kdj933D = 32
KDJ(9,3,3)的D值 (单位:0.001% 倍率:100000)
Kdj933J = 33
KDJ(9,3,3)的J值 (单位:0.001% 倍率:100000)
KdjK = 34
动态KDJ的K值 (单位:0.001% 倍率:100000)
KdjD = 35
动态KDJ的D值 (单位:0.001% 倍率:100000)
KdjJ = 36
动态KDJ的J值 (单位:0.001% 倍率:100000)
Macd12269Dif = 41
MACD(12,26,9)的DIF值 (单位:0.001元 倍率:1000)
Macd12269Dea = 42
MACD(12,26,9)的DEA值 (单位:0.001元 倍率:1000)
Macd12269Macd = 43
MACD(12,26,9)的MACD值 (单位:0.001元 倍率:1000)
MacdDif = 44
动态MACD的DIF值 (单位:0.001元 倍率:1000)
MacdDea = 45
动态MACD的DEA值 (单位:0.001元 倍率:1000)
MacdMacd = 46
动态MACD的MACD值 (单位:0.001元 倍率:1000)
Rsi12 = 51
RSI(12) (单位:0.001% 倍率:100000)
Rsi = 52
动态RSI (单位:0.001% 倍率:100000)
Boll202Upper = 61
BOLL(20,2)的UPPER值 (单位:0.001元 倍率:1000)
Boll202Middle = 62
BOLL(20,2)的MIDDLER值 (单位:0.001元 倍率:1000)
Boll202Lower = 63
BOLL(20,2)的LOWER值 (单位:0.001元 倍率:1000)
BollUpper = 64
动态BOLL的UPPER值 (单位:0.001元 倍率:1000)
BollMiddle = 65
动态BOLL的MIDDLE值 (单位:0.001元 倍率:1000)
BollLower = 66
动态BOLL的LOWER值 (单位:0.001元 倍率:1000)
Implementations
Sourceimpl Indicator
impl Indicator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.