#[repr(i32)]pub enum Market {
MktUnknown = 0,
MktHk = 1,
MktUs = 2,
MktCn = 3,
MktSg = 4,
MktCa = 5,
MktAu = 6,
}Expand description
—————–Common Definitions—————–
Variants
MktUnknown = 0
未知
MktHk = 1
港股
MktUs = 2
美股
MktCn = 3
A股
MktSg = 4
新加坡股票
MktCa = 5
加拿大股票
MktAu = 6
澳大利亚股票
Implementations
Sourceimpl Market
impl Market
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.