#[repr(i32)]pub enum Pattern {
Show 21 variants
Unknown = 0,
MaAlignmentLong = 1,
MaAlignmentShort = 2,
EmaAlignmentLong = 3,
EmaAlignmentShort = 4,
KdjGoldCrossLow = 11,
KdjDeathCrossHigh = 12,
KdjTopDivergence = 13,
KdjBottomDivergence = 14,
MacdGoldCrossLow = 21,
MacdDeathCrossHigh = 22,
MacdTopDivergence = 23,
MacdBottomDivergence = 24,
RsiGoldCrossLow = 31,
RsiDeathCrossHigh = 32,
RsiTopDivergence = 33,
RsiBottomDivergence = 34,
BollBreakUpper = 41,
BollBreakLower = 42,
BollCrossMiddleUp = 43,
BollCrossMiddleDown = 44,
}Variants
Unknown = 0
未知
MaAlignmentLong = 1
MA多头排列
MaAlignmentShort = 2
MA空头排列
EmaAlignmentLong = 3
EMA多头排列
EmaAlignmentShort = 4
EMA空头排列
KdjGoldCrossLow = 11
KDJ低位金叉
KdjDeathCrossHigh = 12
KDJ高位死叉
KdjTopDivergence = 13
KDJ顶背离
KdjBottomDivergence = 14
KDJ底背离
MacdGoldCrossLow = 21
MACD低位金叉
MacdDeathCrossHigh = 22
MACD高位死叉
MacdTopDivergence = 23
MACD顶背离
MacdBottomDivergence = 24
MACD底背离
RsiGoldCrossLow = 31
RSI低位金叉
RsiDeathCrossHigh = 32
RSI高位死叉
RsiTopDivergence = 33
RSI顶背离
RsiBottomDivergence = 34
RSI底背离
BollBreakUpper = 41
BOLL突破上轨
BollBreakLower = 42
BOLL突破下轨
BollCrossMiddleUp = 43
BOLL向上破中轨
BollCrossMiddleDown = 44
BOLL向下破中轨
Implementations
Sourceimpl Pattern
impl Pattern
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.