#[repr(i32)]pub enum Period {
Unknown = 0,
Minute1 = 1,
Hour1 = 5,
Day1 = 11,
Week1 = 21,
Month1 = 31,
}Expand description
K线周期
Variants
Implementations
Sourceimpl Period
impl Period
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.