#[repr(i32)]pub enum Position {
Unknown = 0,
Over = 1,
Below = 2,
CrossUp = 3,
CrossDown = 4,
}Variants
Unknown = 0
未知
Over = 1
first位于second的上方
Below = 2
first位于second的下方
CrossUp = 3
first从下往上穿second
CrossDown = 4
first从上往下穿second
Implementations
Sourceimpl Position
impl Position
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.