#[repr(i32)]pub enum PropertyNameBasic {
PropertyBasicUnknown = 0,
PropertyBasicInfoCode = 1_101,
PropertyBasicInfoName = 1_102,
PropertyBasicInfoIndustry = 1_103,
}Expand description
—————–PropertyName Definitions—————–
Variants
PropertyBasicUnknown = 0
PropertyBasicInfoCode = 1_101
股票代码
PropertyBasicInfoName = 1_102
股票名称
PropertyBasicInfoIndustry = 1_103
所属行业
Implementations
Sourceimpl PropertyNameBasic
impl PropertyNameBasic
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.