#[repr(i32)]pub enum PropertyNameCumulative {
PropertyCumulativeUnknown = 0,
PropertyCumulativeQuotePriceChange = 3_101,
PropertyCumulativeQuotePriceChangePercentage = 3_102,
PropertyCumulativeQuotePriceAmplitude = 3_103,
PropertyCumulativeQuoteAverageVolume = 3_104,
PropertyCumulativeQuoteAverageTurnover = 3_105,
PropertyCumulativeQuoteTurnoverRatio = 3_106,
PropertyCumulativeQuotePriceTodayHighToNDaysHighRatio = 3_107,
PropertyCumulativeQuotePriceTodayLowToNDaysLowRatio = 3_108,
}Variants
PropertyCumulativeUnknown = 0
未知
PropertyCumulativeQuotePriceChange = 3_101
价格涨跌额 (单位:0.001元 倍率:1000)
PropertyCumulativeQuotePriceChangePercentage = 3_102
价格涨跌幅 (单位:0.001% 倍率:100000)
PropertyCumulativeQuotePriceAmplitude = 3_103
价格振幅 (单位:0.001% 倍率:100000)
PropertyCumulativeQuoteAverageVolume = 3_104
平均成交量 (单位:1股 倍率:1)
PropertyCumulativeQuoteAverageTurnover = 3_105
平均成交额 (单位:0.001元 倍率:1000)
PropertyCumulativeQuoteTurnoverRatio = 3_106
换手率 (单位:0.001% 倍率:100000)
PropertyCumulativeQuotePriceTodayHighToNDaysHighRatio = 3_107
(今日最高 - n日最高)/n日最高 (单位:0.001% 倍率:100000)
PropertyCumulativeQuotePriceTodayLowToNDaysLowRatio = 3_108
(今日最低 - n日最低)/n日最低 (单位:0.001% 倍率:100000)
Implementations
Sourceimpl PropertyNameCumulative
impl PropertyNameCumulative
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of PropertyNameCumulative.
Sourcepub fn from_i32(value: i32) -> Option<PropertyNameCumulative>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PropertyNameCumulative>
Converts an i32 to a PropertyNameCumulative, or None if value is not a valid variant.
Sourceimpl PropertyNameCumulative
impl PropertyNameCumulative
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.