PropertyNameFinancial

Enum PropertyNameFinancial 

#[repr(i32)]
pub enum PropertyNameFinancial {
Show 71 variants PropertyFinancialUnknown = 0, PropertyFinancialNetProfit = 4_101, PropertyFinancialNetProfitGrowth = 4_102, PropertyFinancialGrossProfit = 4_103, PropertyFinancialGrossProfitGrowth = 4_104, PropertyFinancialRevenue = 4_105, PropertyFinancialRevenueGrowth = 4_106, PropertyFinancialNetProfitRatio = 4_107, PropertyFinancialGrossProfitRatio = 4_108, PropertyFinancialDebtToAssetsRatio = 4_109, PropertyFinancialReturnToNetAssetsRatio = 4_110, PropertyFinancialEbitda = 4_201, PropertyFinancialRoic = 4_202, PropertyFinancialEbitMargin = 4_203, PropertyFinancialEbitdaMargin = 4_204, PropertyFinancialFinancialCostRate = 4_205, PropertyFinancialEbitTtm = 4_206, PropertyFinancialOperatingProfitTtm = 4_207, PropertyFinancialShareholdersProfitTtm = 4_208, PropertyFinancialRoaTtm = 4_209, PropertyFinancialOperatingMarginTtm = 4_210, PropertyFinancialNetProfitCashCoverTtm = 4_211, PropertyFinancialRdExpenseRatio = 4_212, PropertyFinancialSellingExpenseRatio = 4_213, PropertyFinancialManageExpenseRatio = 4_214, PropertyFinancialOperatingProfitRate = 4_215, PropertyFinancialProfitBeforeTaxRate = 4_216, PropertyFinancialDividendsTtm = 4_217, PropertyFinancialDividendsLfy = 4_218, PropertyFinancialDividendsTtmRatio = 4_219, PropertyFinancialDividendsLfyRatio = 4_220, PropertyFinancialCurrentRatio = 4_301, PropertyFinancialQuickRatio = 4_302, PropertyFinancialLongTermDebtShareholdersRatio = 4_303, PropertyFinancialFinancialLeverage = 4_304, PropertyFinancialInterestBearingDebtRatio = 4_305, PropertyFinancialCashAndCashEquivalents = 4_401, PropertyFinancialCurrentAssetRatio = 4_402, PropertyFinancialCurrentDebtRatio = 4_403, PropertyFinancialEquityMultiplier = 4_404, PropertyFinancialPropertyRatio = 4_405, PropertyFinancialAccountsReceviable = 4_501, PropertyFinancialTotalAssetTurnover = 4_502, PropertyFinancialFixedAssetTurnover = 4_503, PropertyFinancialInventoryTurnover = 4_504, PropertyFinancialOperatingCashFlowTtm = 4_505, PropertyFinancialMoneyTurnoverCycle = 4_506, PropertyFinancialAccountsReceivableRate = 4_507, PropertyFinancialFreeCashFlowIncomeRatio = 4_508, PropertyFinancialFreeCashFlowParentCompanyNetProfitRatio = 4_509, PropertyFinancialTurnoverRateCurrentAssetsRatio = 4_510, PropertyFinancialEbitGrowthRate = 4_601, PropertyFinancialOperatingProfitGrowthRate = 4_602, PropertyFinancialTotalAssetsGrowthRate = 4_603, PropertyFinancialProfitToShareholdersGrowthRate = 4_604, PropertyFinancialProfitBeforeTaxGrowthRate = 4_605, PropertyFinancialEpsGrowthRate = 4_606, PropertyFinancialRoeGrowthRate = 4_607, PropertyFinancialRoicGrowthRate = 4_608, PropertyFinancialNocfGrowthRate = 4_609, PropertyFinancialNocfPerShareGrowthRate = 4_610, PropertyFinancialOperatingRevenueCashCover = 4_701, PropertyFinancialOperatingProfitToTotalProfit = 4_702, PropertyFinancialBasicEps = 4_801, PropertyFinancialDilutedEps = 4_802, PropertyFinancialNocfPerShare = 4_803, PropertyFinancialTotalShare = 4_901, PropertyFinancialFloatShare = 4_902, PropertyFinancialFloatMarketCap = 4_903, PropertyFinancialPsTtm = 4_904, PropertyFinancialPriceCashFlowRatioTtm = 4_905,
}

Variants



PropertyFinancialUnknown = 0

基本财务因子

未知



PropertyFinancialNetProfit = 4_101

净利润 (单位:0.001元 倍率:1000)



PropertyFinancialNetProfitGrowth = 4_102

净利润增长率 (单位:0.001% 倍率:100000)



PropertyFinancialGrossProfit = 4_103

毛利润 (单位:0.001元 倍率:1000)



PropertyFinancialGrossProfitGrowth = 4_104

毛利润增长率 (单位:0.001% 倍率:100000)



PropertyFinancialRevenue = 4_105

营业额 (单位:0.001元 倍率:1000)



PropertyFinancialRevenueGrowth = 4_106

营业额增长率 (单位:0.001% 倍率:100000)



PropertyFinancialNetProfitRatio = 4_107

净利率 (单位:0.001% 倍率:100000)



PropertyFinancialGrossProfitRatio = 4_108

毛利率 (单位:0.001% 倍率:100000)



PropertyFinancialDebtToAssetsRatio = 4_109

资产负债率 (单位:0.001% 倍率:100000)



PropertyFinancialReturnToNetAssetsRatio = 4_110

净资产收益率 (单位:0.001% 倍率:100000)



PropertyFinancialEbitda = 4_201

盈利能力因子

税息折旧及摊销前利润 (单位:0.001元 倍率:1000)



PropertyFinancialRoic = 4_202

投入资本回报率 (单位:0.001% 倍率:100000)



PropertyFinancialEbitMargin = 4_203

EBIT利润率 (单位:0.001% 倍率:100000)



PropertyFinancialEbitdaMargin = 4_204

EBITDA利润率 (单位:0.001% 倍率:100000)



PropertyFinancialFinancialCostRate = 4_205

财务成本率 (单位:0.001% 倍率:100000)



PropertyFinancialEbitTtm = 4_206

息税前利润(TTM) (单位:0.001元 倍率:1000)



PropertyFinancialOperatingProfitTtm = 4_207

营业利润(TTM) (单位:0.001元 倍率:1000)



PropertyFinancialShareholdersProfitTtm = 4_208

归属于母公司的净利润(TTM) (单位:0.001元 倍率:1000)



PropertyFinancialRoaTtm = 4_209

资产回报率(TTM) (单位:0.001% 倍率:100000)



PropertyFinancialOperatingMarginTtm = 4_210

营业利润率(TTM) (单位:0.001% 倍率:100000)



PropertyFinancialNetProfitCashCoverTtm = 4_211

盈利中的现金收入比例(TTM) (单位:0.001% 倍率:100000)



PropertyFinancialRdExpenseRatio = 4_212

研发费用率(单位:0.001% 倍率:100000)



PropertyFinancialSellingExpenseRatio = 4_213

销售费用率(单位:0.001% 倍率:100000)



PropertyFinancialManageExpenseRatio = 4_214

管理费用率(单位:0.001% 倍率:100000)



PropertyFinancialOperatingProfitRate = 4_215

经营利润率(单位:0.001% 倍率:100000)



PropertyFinancialProfitBeforeTaxRate = 4_216

税前利润率(单位:0.001% 倍率:100000)



PropertyFinancialDividendsTtm = 4_217

股息TTM(单位:0.001 倍率:1000)



PropertyFinancialDividendsLfy = 4_218

股息LFY(单位:0.001 倍率:1000)



PropertyFinancialDividendsTtmRatio = 4_219

股息率TTM(单位:0.001% 倍率:100000)



PropertyFinancialDividendsLfyRatio = 4_220

股息率LFY(单位:0.001% 倍率:100000)



PropertyFinancialCurrentRatio = 4_301

偿债能力因子

流动比率 (单位:0.001% 倍率:100000)



PropertyFinancialQuickRatio = 4_302

速动比率 (单位:0.001% 倍率:100000)



PropertyFinancialLongTermDebtShareholdersRatio = 4_303

长期负债股东权益比率(单位:0.001% 倍率:100000)



PropertyFinancialFinancialLeverage = 4_304

财务杠杆(单位:0.001% 倍率:100000)



PropertyFinancialInterestBearingDebtRatio = 4_305

有息负债率(单位:0.001% 倍率:100000)



PropertyFinancialCashAndCashEquivalents = 4_401

清债能力因子

现金和现金等价 (单位:0.001元 倍率:1000)



PropertyFinancialCurrentAssetRatio = 4_402

流动资产率 (单位:0.001% 倍率:100000)



PropertyFinancialCurrentDebtRatio = 4_403

流动负债率 (单位:0.001% 倍率:100000)



PropertyFinancialEquityMultiplier = 4_404

权益乘数 (单位:0.001% 倍率:100000)



PropertyFinancialPropertyRatio = 4_405

产权比率 (单位:0.001% 倍率:100000)



PropertyFinancialAccountsReceviable = 4_501

运营能力因子

应收帐款净额 (单位:0.001元 倍率:1000)



PropertyFinancialTotalAssetTurnover = 4_502

总资产周转率 (单位:0.001% 倍率:100000)



PropertyFinancialFixedAssetTurnover = 4_503

固定资产周转率 (单位:0.001% 倍率:100000)



PropertyFinancialInventoryTurnover = 4_504

存货周转率 (单位:0.001% 倍率:100000)



PropertyFinancialOperatingCashFlowTtm = 4_505

经营活动现金流(TTM) (单位:0.001元 倍率:1000)



PropertyFinancialMoneyTurnoverCycle = 4_506

资金周转周期(天)(单位:0.001,倍率:1000)



PropertyFinancialAccountsReceivableRate = 4_507

应收帐款周转率(次)(单位:0.001,倍率:1000)



PropertyFinancialFreeCashFlowIncomeRatio = 4_508

自由现金流与收入比率(单位:0.001% 倍率:100000)



PropertyFinancialFreeCashFlowParentCompanyNetProfitRatio = 4_509

自由现金流与母公司净利润比率(单位:0.001% 倍率:100000)



PropertyFinancialTurnoverRateCurrentAssetsRatio = 4_510

流动资产周转率(次)(单位:0.001,倍率:1000)



PropertyFinancialEbitGrowthRate = 4_601

成长能力

EBIT同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialOperatingProfitGrowthRate = 4_602

营业利润同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialTotalAssetsGrowthRate = 4_603

总资产同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialProfitToShareholdersGrowthRate = 4_604

归母净利润同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialProfitBeforeTaxGrowthRate = 4_605

总利润同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialEpsGrowthRate = 4_606

EPS同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialRoeGrowthRate = 4_607

ROE同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialRoicGrowthRate = 4_608

ROIC同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialNocfGrowthRate = 4_609

经营现金流同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialNocfPerShareGrowthRate = 4_610

每股经营现金流同比增长率 (单位:0.001% 倍率:100000)



PropertyFinancialOperatingRevenueCashCover = 4_701

现金流

经营现金收入比 (单位:0.001% 倍率:100000)



PropertyFinancialOperatingProfitToTotalProfit = 4_702

营业利润占比 (单位:0.001% 倍率:100000)



PropertyFinancialBasicEps = 4_801

市场表现

基本每股收益 (单位:0.001元 倍率:1000)



PropertyFinancialDilutedEps = 4_802

稀释每股收益 (单位:0.001元 倍率:1000)



PropertyFinancialNocfPerShare = 4_803

每股经营现金净流量 (单位:0.001元 倍率:1000)



PropertyFinancialTotalShare = 4_901

基础量价因子

总股数 (单位:1股 倍率:1)



PropertyFinancialFloatShare = 4_902

流通股数 (单位:1股 倍率:1)



PropertyFinancialFloatMarketCap = 4_903

流通市值 (单位:0.001元 倍率:1000)



PropertyFinancialPsTtm = 4_904

市销率(TTM) (单位:0.001% 倍率:100000)



PropertyFinancialPriceCashFlowRatioTtm = 4_905

市现率(TTM) (单位:0.001% 倍率:100000)

Implementations

Source

impl PropertyNameFinancial

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PropertyNameFinancial.

pub fn from_i32(value: i32) -> Option<PropertyNameFinancial>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a PropertyNameFinancial, or None if value is not a valid variant.

Source

impl PropertyNameFinancial

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.