#[repr(i32)]pub enum Term {
Unknown = 0,
Q1 = 1,
Q2 = 2,
Q3 = 3,
Q4 = 4,
Q6 = 6,
Q9 = 9,
QLatest = 10,
Annual = 100,
}Variants
Unknown = 0
未知
Q1 = 1
Q1报
Q2 = 2
Q2报
Q3 = 3
Q3报
Q4 = 4
Q4报
Q6 = 6
中报(累积报)
Q9 = 9
三季报(累积报)
QLatest = 10
最新单季报
Annual = 100
年报FY
Implementations
Sourceimpl Term
impl Term
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.