pub struct ScreenQueries {Show 16 fields
pub market: Option<i32>,
pub exchanges: Vec<u64>,
pub categories: Vec<u64>,
pub simple_property_queries: Vec<QueryPropertySimple>,
pub cumulative_property_queries: Vec<QueryPropertyCumulative>,
pub financial_property_queries: Vec<QueryPropertyFinancial>,
pub indicator_positional_queries: Vec<QueryIndicatorPositional>,
pub indicator_pattern_queries: Vec<QueryIndicatorPattern>,
pub featured_property_queries: Vec<QueryPropertyFeatured>,
pub broker_holdings_queries: Vec<QueryPropertyBroker>,
pub kline_pattern_queries: Vec<QueryKlinePattern>,
pub has_adr: Option<bool>,
pub has_option: Option<bool>,
pub has_warrant: Option<bool>,
pub has_future: Option<bool>,
pub has_ah_stock: Option<bool>,
}Expand description
筛选查询过滤器
Fields
market: Option<i32>市场
exchanges: Vec<u64>交易所过滤器
categories: Vec<u64>板块
simple_property_queries: Vec<QueryPropertySimple>简单行情过滤器
cumulative_property_queries: Vec<QueryPropertyCumulative>累计值行情过滤器
financial_property_queries: Vec<QueryPropertyFinancial>财务指标过滤器
indicator_positional_queries: Vec<QueryIndicatorPositional>指标相对位置过滤器
indicator_pattern_queries: Vec<QueryIndicatorPattern>形态过滤器
featured_property_queries: Vec<QueryPropertyFeatured>特色指标过滤器
broker_holdings_queries: Vec<QueryPropertyBroker>经纪商持股过滤器
kline_pattern_queries: Vec<QueryKlinePattern>K线形态过滤器
has_adr: Option<bool>有关联adr标的(需要该条件筛选才设置)
has_option: Option<bool>含期权标的(需要该条件筛选才设置)
has_warrant: Option<bool>含窝轮标的(需要改条件筛选才设置)
has_future: Option<bool>含期货标的(需要该条件筛选才设置)
has_ah_stock: Option<bool>有关联AH股的标的(需要该条件筛选才设置)
Implementations
Sourceimpl ScreenQueries
impl ScreenQueries
Sourcepub fn market(&self) -> Market
pub fn market(&self) -> Market
Returns the enum value of market, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_market(&mut self, value: Market)
pub fn set_market(&mut self, value: Market)
Sets market to the provided enum value.
Sourcepub fn has_adr(&self) -> bool
pub fn has_adr(&self) -> bool
Returns the value of has_adr, or the default value if has_adr is unset.
Sourcepub fn has_option(&self) -> bool
pub fn has_option(&self) -> bool
Returns the value of has_option, or the default value if has_option is unset.
Sourcepub fn has_warrant(&self) -> bool
pub fn has_warrant(&self) -> bool
Returns the value of has_warrant, or the default value if has_warrant is unset.
Sourcepub fn has_future(&self) -> bool
pub fn has_future(&self) -> bool
Returns the value of has_future, or the default value if has_future is unset.
Sourcepub fn has_ah_stock(&self) -> bool
pub fn has_ah_stock(&self) -> bool
Returns the value of has_ah_stock, or the default value if has_ah_stock is unset.