pub struct PropertyBasic {
pub name: Option<i32>,
}Expand description
—————–Property Definitions—————–
Fields
name: Option<i32>Implementations
Sourceimpl PropertyBasic
impl PropertyBasic
Sourcepub fn name(&self) -> PropertyNameBasic
pub fn name(&self) -> PropertyNameBasic
Returns the enum value of name, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_name(&mut self, value: PropertyNameBasic)
pub fn set_name(&mut self, value: PropertyNameBasic)
Sets name to the provided enum value.