pub struct PropertyCumulative {
pub name: Option<i32>,
pub days: Option<u32>,
pub period_average: Option<i32>,
}Fields
name: Option<i32>days: Option<u32>period_average: Option<i32>周期平均
Implementations
Sourceimpl PropertyCumulative
impl PropertyCumulative
Sourcepub fn name(&self) -> PropertyNameCumulative
pub fn name(&self) -> PropertyNameCumulative
Returns the enum value of name, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_name(&mut self, value: PropertyNameCumulative)
pub fn set_name(&mut self, value: PropertyNameCumulative)
Sets name to the provided enum value.
Sourcepub fn period_average(&self) -> i32
pub fn period_average(&self) -> i32
Returns the value of period_average, or the default value if period_average is unset.