PropertyFeatured

Struct PropertyFeatured 

pub struct PropertyFeatured {
    pub name: Option<i32>,
    pub period: Option<i32>,
    pub range_period: Option<i32>,
}

Fields

name: Option<i32>

枚举如上Featured所示

period: Option<i32>

K线周期,用于指标解读

range_period: Option<i32>

范围周期(用于公司估值)枚举如上RangePeriod所示

Implementations

Source

impl PropertyFeatured

pub fn name(&self) -> i32

Returns the value of name, or the default value if name is unset.

pub fn period(&self) -> Period

Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.

pub fn set_period(&mut self, value: Period)

Sets period to the provided enum value.

pub fn range_period(&self) -> i32

Returns the value of range_period, or the default value if range_period is unset.