pub struct PropertyFinancial {
pub name: Option<i32>,
pub term: Option<i32>,
pub duration: Option<i64>,
pub year: Option<i32>,
pub period_average: Option<i32>,
}Fields
name: Option<i32>term: Option<i32>duration: Option<i64>可选时间跨度(范围[1, 9], 成长能力因子专用)
year: Option<i32>年份(2020/2019/…)
period_average: Option<i32>周期平均
Implementations
Sourceimpl PropertyFinancial
impl PropertyFinancial
Sourcepub fn name(&self) -> PropertyNameFinancial
pub fn name(&self) -> PropertyNameFinancial
Returns the enum value of name, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_name(&mut self, value: PropertyNameFinancial)
pub fn set_name(&mut self, value: PropertyNameFinancial)
Sets name to the provided enum value.
Sourcepub fn term(&self) -> Term
pub fn term(&self) -> Term
Returns the enum value of term, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn duration(&self) -> i64
pub fn duration(&self) -> i64
Returns the value of duration, or the default value if duration is unset.
Sourcepub fn period_average(&self) -> i32
pub fn period_average(&self) -> i32
Returns the value of period_average, or the default value if period_average is unset.