PropertyIndicator

Struct PropertyIndicator 

pub struct PropertyIndicator {
    pub name: Option<i32>,
    pub period: Option<i32>,
    pub indicator_params: Vec<i64>,
}

Fields

name: Option<i32>period: Option<i32>indicator_params: Vec<i64>

动态参数(如MA6,设置6即可;BOLL(15,3),则按顺序设置15, 3;KDJ(9,4,4),则按顺序设置9,4,4)

Implementations

Source

impl PropertyIndicator

pub fn name(&self) -> Indicator

Returns the enum value of name, or the default if the field is unset or set to an invalid enum value.

pub fn set_name(&mut self, value: Indicator)

Sets name to the provided enum value.

pub fn period(&self) -> Period

Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.

pub fn set_period(&mut self, value: Period)

Sets period to the provided enum value.