pub struct PropertySimple {
pub name: Option<i32>,
}Fields
name: Option<i32>Implementations
Sourceimpl PropertySimple
impl PropertySimple
Sourcepub fn name(&self) -> PropertyNameSimple
pub fn name(&self) -> PropertyNameSimple
Returns the enum value of name, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_name(&mut self, value: PropertyNameSimple)
pub fn set_name(&mut self, value: PropertyNameSimple)
Sets name to the provided enum value.