pub struct QueryIndicatorPattern {
pub pattern: i32,
pub period: i32,
pub continuous_period: Option<i32>,
}Expand description
指标样式查询
Fields
pattern: i32period: i32continuous_period: Option<i32>连续周期
Implementations
Sourceimpl QueryIndicatorPattern
impl QueryIndicatorPattern
Sourcepub fn pattern(&self) -> Pattern
pub fn pattern(&self) -> Pattern
Returns the enum value of pattern, or the default if the field is set to an invalid enum value.
Sourcepub fn set_pattern(&mut self, value: Pattern)
pub fn set_pattern(&mut self, value: Pattern)
Sets pattern to the provided enum value.
Sourcepub fn period(&self) -> Period
pub fn period(&self) -> Period
Returns the enum value of period, or the default if the field is set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: Period)
pub fn set_period(&mut self, value: Period)
Sets period to the provided enum value.
Sourcepub fn continuous_period(&self) -> i32
pub fn continuous_period(&self) -> i32
Returns the value of continuous_period, or the default value if continuous_period is unset.