pub struct QueryKlinePattern {
pub kline_pattern: Option<i32>,
pub period: Option<i32>,
pub continuous_period: Option<i32>,
}Fields
kline_pattern: Option<i32>period: Option<i32>continuous_period: Option<i32>连续周期
Implementations
Sourceimpl QueryKlinePattern
impl QueryKlinePattern
Sourcepub fn kline_pattern(&self) -> KlinePattern
pub fn kline_pattern(&self) -> KlinePattern
Returns the enum value of kline_pattern, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_kline_pattern(&mut self, value: KlinePattern)
pub fn set_kline_pattern(&mut self, value: KlinePattern)
Sets kline_pattern to the provided enum value.
Sourcepub fn period(&self) -> Period
pub fn period(&self) -> Period
Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: Period)
pub fn set_period(&mut self, value: Period)
Sets period to the provided enum value.
Sourcepub fn continuous_period(&self) -> i32
pub fn continuous_period(&self) -> i32
Returns the value of continuous_period, or the default value if continuous_period is unset.