pub struct RetrieveRequest {
pub stock_ids: Vec<u64>,
pub basic_properties: Vec<PropertyBasic>,
pub simple_properties: Vec<PropertySimple>,
pub cumulative_properties: Vec<PropertyCumulative>,
pub financial_properties: Vec<PropertyFinancial>,
pub indicator_properties: Vec<PropertyIndicator>,
pub featured_properties: Vec<PropertyFeatured>,
pub broker_properties: Vec<PropertyBroker>,
}Expand description
客户端命令号:9011
Fields
stock_ids: Vec<u64>basic_properties: Vec<PropertyBasic>simple_properties: Vec<PropertySimple>cumulative_properties: Vec<PropertyCumulative>financial_properties: Vec<PropertyFinancial>indicator_properties: Vec<PropertyIndicator>featured_properties: Vec<PropertyFeatured>broker_properties: Vec<PropertyBroker>Trait Implementations
Sourceimpl Clone for RetrieveRequest
impl Clone for RetrieveRequest
Sourcefn clone(&self) -> RetrieveRequest
fn clone(&self) -> RetrieveRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetrieveRequest
impl Debug for RetrieveRequest
Sourceimpl Default for RetrieveRequest
impl Default for RetrieveRequest
Sourceimpl Message for RetrieveRequest
impl Message for RetrieveRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RetrieveRequest
impl PartialEq for RetrieveRequest
impl StructuralPartialEq for RetrieveRequest