pub struct ScreenRequest {Show 20 fields
pub market: i32,
pub exchanges: Vec<u64>,
pub categories: Vec<u64>,
pub watchlist_stock_ids: Vec<u64>,
pub use_watchlist_stocks: Option<bool>,
pub has_adr: Option<bool>,
pub has_option: Option<bool>,
pub has_warrant: Option<bool>,
pub has_future: Option<bool>,
pub has_ah_stock: Option<bool>,
pub simple_property_queries: Vec<QueryPropertySimple>,
pub cumulative_property_queries: Vec<QueryPropertyCumulative>,
pub financial_property_queries: Vec<QueryPropertyFinancial>,
pub indicator_positional_queries: Vec<QueryIndicatorPositional>,
pub indicator_pattern_queries: Vec<QueryIndicatorPattern>,
pub featured_property_queries: Vec<QueryPropertyFeatured>,
pub broker_holdings_queries: Vec<QueryPropertyBroker>,
pub kline_pattern_queries: Vec<QueryKlinePattern>,
pub limit: Option<u32>,
pub sort: Option<Sort>,
}Expand description
客户端命令号:9010
Fields
market: i32市场
exchanges: Vec<u64>交易所过滤器
categories: Vec<u64>板块
watchlist_stock_ids: Vec<u64>自定义的股票名单列表
use_watchlist_stocks: Option<bool>使用自选股
has_adr: Option<bool>有关联adr标的(需要该条件筛选才设置)
has_option: Option<bool>含期权标的(需要该条件筛选才设置)
has_warrant: Option<bool>含窝轮标的(需要该条件筛选才设置)
has_future: Option<bool>含期货标的(需要该条件筛选才设置)
has_ah_stock: Option<bool>有关联AH股的标的(需要该条件筛选才设置)
simple_property_queries: Vec<QueryPropertySimple>简单行情过滤器
cumulative_property_queries: Vec<QueryPropertyCumulative>累计值行情过滤器
financial_property_queries: Vec<QueryPropertyFinancial>财务指标过滤器
indicator_positional_queries: Vec<QueryIndicatorPositional>指标相对位置过滤器
indicator_pattern_queries: Vec<QueryIndicatorPattern>形态过滤器
featured_property_queries: Vec<QueryPropertyFeatured>特色指标过滤器
broker_holdings_queries: Vec<QueryPropertyBroker>经纪商持股过滤器
kline_pattern_queries: Vec<QueryKlinePattern>K线形态过滤器
limit: Option<u32>选出股票个数限制,不传代表不限制
sort: Option<Sort>排序字段
Implementations
Sourceimpl ScreenRequest
impl ScreenRequest
Sourcepub fn market(&self) -> Market
pub fn market(&self) -> Market
Returns the enum value of market, or the default if the field is set to an invalid enum value.
Sourcepub fn set_market(&mut self, value: Market)
pub fn set_market(&mut self, value: Market)
Sets market to the provided enum value.
Sourcepub fn use_watchlist_stocks(&self) -> bool
pub fn use_watchlist_stocks(&self) -> bool
Returns the value of use_watchlist_stocks, or the default value if use_watchlist_stocks is unset.
Sourcepub fn has_adr(&self) -> bool
pub fn has_adr(&self) -> bool
Returns the value of has_adr, or the default value if has_adr is unset.
Sourcepub fn has_option(&self) -> bool
pub fn has_option(&self) -> bool
Returns the value of has_option, or the default value if has_option is unset.
Sourcepub fn has_warrant(&self) -> bool
pub fn has_warrant(&self) -> bool
Returns the value of has_warrant, or the default value if has_warrant is unset.
Sourcepub fn has_future(&self) -> bool
pub fn has_future(&self) -> bool
Returns the value of has_future, or the default value if has_future is unset.
Sourcepub fn has_ah_stock(&self) -> bool
pub fn has_ah_stock(&self) -> bool
Returns the value of has_ah_stock, or the default value if has_ah_stock is unset.