pub struct Sort {
pub direction: i32,
pub basic_property: Option<PropertyBasic>,
pub simple_property: Option<PropertySimple>,
pub cumulative_property: Option<PropertyCumulative>,
pub financial_property: Option<PropertyFinancial>,
pub indicator_property: Option<PropertyIndicator>,
pub featured_property: Option<PropertyFeatured>,
pub broker_property: Option<PropertyBroker>,
}Expand description
basic_property, simple_property, cumulative_property, financial_property, indicator_property,featured_property, property_broker 选一
Fields
direction: i32basic_property: Option<PropertyBasic>simple_property: Option<PropertySimple>cumulative_property: Option<PropertyCumulative>financial_property: Option<PropertyFinancial>indicator_property: Option<PropertyIndicator>featured_property: Option<PropertyFeatured>broker_property: Option<PropertyBroker>Implementations
Sourceimpl Sort
impl Sort
Sourcepub fn direction(&self) -> SortDirection
pub fn direction(&self) -> SortDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: SortDirection)
pub fn set_direction(&mut self, value: SortDirection)
Sets direction to the provided enum value.