TickItem

Struct TickItem 

pub struct TickItem {
    pub tick_key: Option<u64>,
    pub type: Option<i32>,
    pub exchange_data_time_ms: Option<u64>,
    pub price: Option<u64>,
    pub volume: Option<u64>,
    pub trade_type: Option<String>,
    pub server_recv_from_exchange_time_ms: Option<i64>,
    pub price_last_close: Option<u64>,
    pub ticker_type: Option<u32>,
}
逐笔项

Fields

tick_key: Option<u64>

唯一标志,用于去重

type: Option<i32>

逐笔类型,枚举TickItemType

exchange_data_time_ms: Option<u64>

成交时间,毫秒

price: Option<u64>

成交价[放大10^9倍]

volume: Option<u64>

成交量(1股)

trade_type: Option<String>

成交类型(一个英文字母的ASCII码),UI直接展示

server_recv_from_exchange_time_ms: Option<i64>

富途服务器从交易所收到数据的时间. server重启时该字段为空,client使用前要判空

price_last_close: Option<u64>

用于判断涨跌色的基准价格[放大10^9倍],对盘中逐笔表示昨收,对盘前盘后逐笔表示计算盘前、盘后涨跌幅的基础价格

ticker_type: Option<u32>

逐笔类型,参考TickPeriodType

Implementations

Source

impl TickItem

pub fn tick_key(&self) -> u64

Returns the value of tick_key, or the default value if tick_key is unset.

pub fn type(&self) -> i32

Returns the value of type, or the default value if type is unset.

pub fn exchange_data_time_ms(&self) -> u64

Returns the value of exchange_data_time_ms, or the default value if exchange_data_time_ms is unset.

pub fn price(&self) -> u64

Returns the value of price, or the default value if price is unset.

pub fn volume(&self) -> u64

Returns the value of volume, or the default value if volume is unset.

pub fn trade_type(&self) -> &str

Returns the value of trade_type, or the default value if trade_type is unset.

pub fn server_recv_from_exchange_time_ms(&self) -> i64

Returns the value of server_recv_from_exchange_time_ms, or the default value if server_recv_from_exchange_time_ms is unset.

pub fn price_last_close(&self) -> u64

Returns the value of price_last_close, or the default value if price_last_close is unset.

pub fn ticker_type(&self) -> u32

Returns the value of ticker_type, or the default value if ticker_type is unset.