#[repr(i32)]pub enum TradeAuthProtocolCmd {
CmdTradePswdAuth = 2_900,
CmdTradeTokenAuth = 2_901,
CmdTradeSwapCipher = 2_902,
CmdUniqTradePswdAuth = 2_904,
CmdUniqTradeTokenAuth = 2_905,
CmdGetBioTradeSig = 2_906,
CmdBioTradeAuth = 2_907,
CmdBioTradeClose = 2_908,
}Variants
CmdTradePswdAuth = 2_900
交易密码鉴权
CmdTradeTokenAuth = 2_901
交易token鉴权
CmdTradeSwapCipher = 2_902
交易交换票据
CmdUniqTradePswdAuth = 2_904
通用交易密码验证(多个业务账户共一个交易密码),开启指纹解锁交易功能
CmdUniqTradeTokenAuth = 2_905
通用交易密码验证交易token
CmdGetBioTradeSig = 2_906
获取指纹解锁交易需要的凭证
CmdBioTradeAuth = 2_907
指纹解锁交易
CmdBioTradeClose = 2_908
关闭指纹解锁交易功能
Implementations
Sourceimpl TradeAuthProtocolCmd
impl TradeAuthProtocolCmd
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of TradeAuthProtocolCmd.
Sourcepub fn from_i32(value: i32) -> Option<TradeAuthProtocolCmd>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TradeAuthProtocolCmd>
Converts an i32 to a TradeAuthProtocolCmd, or None if value is not a valid variant.
Sourceimpl TradeAuthProtocolCmd
impl TradeAuthProtocolCmd
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.