FutureDetailInfo

Struct FutureDetailInfo 

pub struct FutureDetailInfo {
Show 18 fields pub name: Option<String>, pub symbol: Option<String>, pub last_trade_date: Option<u32>, pub underlying_stock_id: Option<i64>, pub show_variety: Option<String>, pub exchange: Option<String>, pub category: Option<String>, pub scale: Option<i32>, pub scale_unit: Option<String>, pub currency: Option<String>, pub minimum_variation_value: Option<f64>, pub minimum_variation_unit: Option<String>, pub price_quotation: Option<String>, pub contract_value: Option<String>, pub trade_time_detail_list: Vec<TradetimeDetail>, pub time_zone: Option<String>, pub specification_url: Option<String>, pub security_id: Option<u64>,
}
期货合约具体数据

Fields

name: Option<String>

合约名称

symbol: Option<String>

合约代码

last_trade_date: Option<u32>

最后交易日(时间戳)

underlying_stock_id: Option<i64>

标的ID

show_variety: Option<String>

标的名称

exchange: Option<String>

交易所

category: Option<String>

合约类型

scale: Option<i32>

合约规模

scale_unit: Option<String>

合约规模的单位

currency: Option<String>

报价货币

minimum_variation_value: Option<f64>

最小变动值

minimum_variation_unit: Option<String>

最小变动值的单位

price_quotation: Option<String>

报价单位(港股期货)

contract_value: Option<String>

合约价值(美股期货)

trade_time_detail_list: Vec<TradetimeDetail>

具体交易时间区间数值列表

time_zone: Option<String>

所在时区

specification_url: Option<String>

交易所规格

security_id: Option<u64>

期货ID

Implementations

Source

impl FutureDetailInfo

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn last_trade_date(&self) -> u32

Returns the value of last_trade_date, or the default value if last_trade_date is unset.

pub fn underlying_stock_id(&self) -> i64

Returns the value of underlying_stock_id, or the default value if underlying_stock_id is unset.

pub fn show_variety(&self) -> &str

Returns the value of show_variety, or the default value if show_variety is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn category(&self) -> &str

Returns the value of category, or the default value if category is unset.

pub fn scale(&self) -> i32

Returns the value of scale, or the default value if scale is unset.

pub fn scale_unit(&self) -> &str

Returns the value of scale_unit, or the default value if scale_unit is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn minimum_variation_value(&self) -> f64

Returns the value of minimum_variation_value, or the default value if minimum_variation_value is unset.

pub fn minimum_variation_unit(&self) -> &str

Returns the value of minimum_variation_unit, or the default value if minimum_variation_unit is unset.

pub fn price_quotation(&self) -> &str

Returns the value of price_quotation, or the default value if price_quotation is unset.

pub fn contract_value(&self) -> &str

Returns the value of contract_value, or the default value if contract_value is unset.

pub fn time_zone(&self) -> &str

Returns the value of time_zone, or the default value if time_zone is unset.

pub fn specification_url(&self) -> &str

Returns the value of specification_url, or the default value if specification_url is unset.

pub fn security_id(&self) -> u64

Returns the value of security_id, or the default value if security_id is unset.