TradetimeDetail

Struct TradetimeDetail 

pub struct TradetimeDetail {
    pub begin: Option<i32>,
    pub end: Option<i32>,
}
具体交易时间数值区间

Fields

begin: Option<i32>

开始时间(分钟)如 17:00 = 17 * 60, 17:00(T-1) = -17 * 60

end: Option<i32>

结束时间(分钟)形式如上

Implementations

Source

impl TradetimeDetail

pub fn begin(&self) -> i32

Returns the value of begin, or the default value if begin is unset.

pub fn end(&self) -> i32

Returns the value of end, or the default value if end is unset.