#[repr(i32)]pub enum AccGrantCategory {
OrdinaryAcc = 0,
EntrustAcc = 1,
ManageAcc = 2,
}Expand description
账户在机构授权场景下细分的类型 历史债,这里设计的不好,比较难理解,建议参考介绍文档看一下
Variants
OrdinaryAcc = 0
非挂靠账户
EntrustAcc = 1
委托账户(委托方视角下委托方挂靠在机构下的账户)
ManageAcc = 2
管理账户(机构方视角下委托方挂靠在机构下的账户)
Implementations
Sourceimpl AccGrantCategory
impl AccGrantCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.