#[repr(i32)]pub enum AuthorizeStatus {
Unauthorized = 0,
AuthorizationInProgress = 1,
Authorized = 2,
CancelAuthorized = 3,
}Expand description
富途HK港股BCAN状态
Variants
Implementations
Sourceimpl AuthorizeStatus
impl AuthorizeStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.