#[repr(i32)]pub enum BrokerId {
Show 13 variants
Futu = 1_001,
FutuMoomoo = 1_007,
FutuSg = 1_008,
FutuAu = 1_009,
FutuCrypto = 1_010,
FutuSgCrypto = 1_011,
FutuJp = 1_012,
FutuAuCrypto = 1_013,
FutuHkCrypto = 1_015,
FutuMy = 1_017,
FutuCa = 1_019,
Futc = 1_021,
AirstarSec = 1_022,
}Expand description
券商ID
Variants
Futu = 1_001
富途香港
FutuMoomoo = 1_007
富途美分
FutuSg = 1_008
富途新加坡
FutuAu = 1_009
富途澳洲
FutuCrypto = 1_010
富途数字货币(美国)
FutuSgCrypto = 1_011
富途数字货币(新加坡)
FutuJp = 1_012
富途日本
FutuAuCrypto = 1_013
富途数字货币(澳洲)
FutuHkCrypto = 1_015
富途数字货币(香港)
FutuMy = 1_017
富途马来西亚
FutuCa = 1_019
富途加拿大
Futc = 1_021
FUTC
AirstarSec = 1_022
天星证券
Implementations
Sourceimpl BrokerId
impl BrokerId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.