#[repr(i32)]pub enum GrantState {
GsNone = 0,
GsGrant = 1,
GsAccept = 2,
}Expand description
授权状态(废弃,以前富途HK交易社会化特性引入的) 目前2008/2282/2298接口都写死“未授权0“
Variants
Implementations
Sourceimpl GrantState
impl GrantState
Sourceimpl GrantState
impl GrantState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.