#[repr(i32)]pub enum MarketId {
HkSec = 0,
UsSec = 1,
ASec = 2,
AConn = 3,
Futures = 4,
}Expand description
市场ID(不用关注,仅2008接口market_id取值参考) 这里的取值和后端的取值不一样,例如港股后端取值为1,这里是0
Variants
Implementations
Sourceimpl MarketId
impl MarketId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.