#[repr(i32)]pub enum MixedState {
MsNone = 0,
MsApply = 1,
MsOpening = 2,
MsNormal = 3,
MsTrdForbid = 4,
MsLgnForbid = 5,
MsNotOpen = 6,
MsRdsNeeded = 7,
}Expand description
混合状态
Variants
MsNone = 0
未开户
MsApply = 1
请求开户
MsOpening = 2
即将开通
MsNormal = 3
正常(已开户)
MsTrdForbid = 4
禁止交易
MsLgnForbid = 5
禁止登录
MsNotOpen = 6
交易未开启
MsRdsNeeded = 7
需要风批
Implementations
Sourceimpl MixedState
impl MixedState
Sourceimpl MixedState
impl MixedState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.