#[repr(i32)]pub enum Role {
Ordinary = 0,
Master = 1,
}Expand description
账户在机构场景下细分的类型 历史债,这里设计的不好,其实账户是不是主账户,协议里面用一个bool类型就够了,
Variants
Implementations
Sourceimpl Role
impl Role
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.