#[repr(i32)]pub enum TradeMarket {
Show 17 variants
Hk = 1,
Us = 2,
Hkcc = 4,
Futures = 5,
Sg = 6,
Crypto = 7,
Au = 8,
Forex = 9,
Bond = 10,
My = 11,
Ca = 12,
HkFund = 13,
Fund = 14,
Jp = 15,
StructuredNotes = 16,
UsFund = 23,
SgFund = 24,
}Expand description
交易市场,2282/2298接口的enable_market参考该取值
Variants
Hk = 1
港股股票
Us = 2
美股股票
Hkcc = 4
港股A股通
Futures = 5
期货市场
Sg = 6
新加坡股票
Crypto = 7
数字货币
Au = 8
澳股股票
Forex = 9
杠杆式外汇市场
Bond = 10
债券
My = 11
马股
Ca = 12
加股
HkFund = 13
港币基金
Fund = 14
基金(合并原13,23,24)
Jp = 15
日股
StructuredNotes = 16
结构化票据
UsFund = 23
美元基金
SgFund = 24
新元基金
Implementations
Sourceimpl TradeMarket
impl TradeMarket
Sourceimpl TradeMarket
impl TradeMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.