#[repr(i32)]pub enum TrdPswdMode {
TpmUnified = 0,
TpmIsolated = 1,
}Expand description
交易密码模式(不用关注,仅2008协议依赖) 并且当前2008接口都写死“统一密码0“
Variants
Implementations
Sourceimpl TrdPswdMode
impl TrdPswdMode
Sourceimpl TrdPswdMode
impl TrdPswdMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.