SubAccount

Struct SubAccount 

pub struct SubAccount {
    pub id: Option<u64>,
    pub type: Option<u32>,
    pub state: Option<u32>,
    pub jp_info: Option<JpInfo>,
}
子账户(第三层)

Fields

id: Option<u64>

子账户ID(在同个账户下,每个子账户ID唯一)

type: Option<u32>

子账户类型,取值参考SubAccountType枚举

state: Option<u32>

子账户状态,取值参考SubAccountState枚举

jp_info: Option<JpInfo>

jp特定信息

Implementations

Source

impl SubAccount

pub fn id(&self) -> u64

Returns the value of id, or the default value if id is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn state(&self) -> u32

Returns the value of state, or the default value if state is unset.