UniversalAccount

Struct UniversalAccount 

pub struct UniversalAccount {
Show 13 fields pub id: Option<u64>, pub uid: Option<u64>, pub card_number: Option<String>, pub sec_account: Option<Account>, pub futures_account: Option<Account>, pub crypto_account: Option<Account>, pub acc_diy_name: Option<String>, pub acc_bussiness_name: Vec<AccBusinessName>, pub role: Option<u32>, pub acc_grant_category: Option<u32>, pub forex_account: Option<Account>, pub settlement_type: Option<u32>, pub name_info: Option<NameInfo>,
}
综合账户(第一层)

Fields

id: Option<u64>

综合账户ID,唯一标识一个综合账户(跨券商唯一)

uid: Option<u64>

用户ID(账户归属人ID)

card_number: Option<String>

综合账户16位卡号

sec_account: Option<Account>

证券账户,marketID:6,取值参考AccountMarket枚举

futures_account: Option<Account>

期货账户,marketID:5,取值参考AccountMarket枚举

crypto_account: Option<Account>

数字货币账户,marketID:7,取值参考AccountMarket枚举

acc_diy_name: Option<String>

综合账户自定义名称(可以考虑废弃,后端无数据)

acc_bussiness_name: Vec<AccBusinessName>

ESOP专有账户名称(可以考虑废弃,后端无数据)

role: Option<u32>

取值参考Role枚举

acc_grant_category: Option<u32>

取值参考AccGrantCategory枚举(考虑废弃,难理解,扩展性差)

forex_account: Option<Account>

外汇账户,marketID:9,取值参考AccountMarket枚举

settlement_type: Option<u32>

交收模式,取值参考SettlementType枚举

name_info: Option<NameInfo>

综合账户名称信息

Implementations

Source

impl UniversalAccount

pub fn id(&self) -> u64

Returns the value of id, or the default value if id is unset.

pub fn uid(&self) -> u64

Returns the value of uid, or the default value if uid is unset.

pub fn card_number(&self) -> &str

Returns the value of card_number, or the default value if card_number is unset.

pub fn acc_diy_name(&self) -> &str

Returns the value of acc_diy_name, or the default value if acc_diy_name is unset.

pub fn role(&self) -> u32

Returns the value of role, or the default value if role is unset.

pub fn acc_grant_category(&self) -> u32

Returns the value of acc_grant_category, or the default value if acc_grant_category is unset.

pub fn settlement_type(&self) -> u32

Returns the value of settlement_type, or the default value if settlement_type is unset.