#[repr(i32)]pub enum IssuerAgency {
Show 29 variants
Bc = 1,
Bi = 2,
Bp = 3,
Cs = 4,
Ct = 5,
Db = 6,
Dc = 7,
Ea = 8,
Gs = 9,
Hs = 10,
Jp = 11,
Kc = 12,
Mb = 13,
Mc = 14,
Ml = 15,
Nm = 16,
Rb = 17,
Rs = 18,
Sc = 19,
Sg = 20,
Ub = 21,
Ht = 22,
Vt = 23,
Ms = 24,
Gj = 25,
Xz = 26,
Hu = 27,
Ks = 28,
Ci = 29,
}Expand description
发行商
Variants
Bc = 1
巴克莱银行
Bi = 2
中银
Bp = 3
法巴
Cs = 4
瑞信
Ct = 5
花旗
Db = 6
德银
Dc = 7
大和
Ea = 8
东亚
Gs = 9
高盛
Hs = 10
汇丰
Jp = 11
摩通
Kc = 12
比联
Mb = 13
麦银
Mc = 14
?
Ml = 15
美林
Nm = 16
野村
Rb = 17
荷合
Rs = 18
苏皇
Sc = 19
渣打
Sg = 20
法兴
Ub = 21
瑞银
Ht = 22
海通
Vt = 23
瑞通
Ms = 24
摩利
Gj = 25
国君
Xz = 26
星展
Hu = 27
华泰
Ks = 28
韩投
Ci = 29
信证
Implementations
Sourceimpl IssuerAgency
impl IssuerAgency
Sourceimpl IssuerAgency
impl IssuerAgency
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.