#[repr(i32)]pub enum WarrantStatus {
StatusNormal = 0,
StatusCommon = 1,
StatusStop = 2,
StatusListing = 3,
}Variants
StatusNormal = 0
正常状态
StatusCommon = 1
正常状态(历史问题,这个也是代表终止交易)
StatusStop = 2
终止交易(牛熊被回收,权证过期), 1和2都表示终止交易
StatusListing = 3
待上市
Implementations
Sourceimpl WarrantStatus
impl WarrantStatus
Sourceimpl WarrantStatus
impl WarrantStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.