StrikeDateItem

Struct StrikeDateItem 

pub struct StrikeDateItem {
    pub strike_date: Option<u32>,
    pub expiration: Option<u32>,
    pub suffix: Option<String>,
    pub left_day: Option<i32>,
}

Fields

strike_date: Option<u32>

行权日时间戳

expiration: Option<u32>

到期类型

suffix: Option<String>

行权日后缀

left_day: Option<i32>

剩余时间

Implementations

Source

impl StrikeDateItem

pub fn strike_date(&self) -> u32

Returns the value of strike_date, or the default value if strike_date is unset.

pub fn expiration(&self) -> u32

Returns the value of expiration, or the default value if expiration is unset.

pub fn suffix(&self) -> &str

Returns the value of suffix, or the default value if suffix is unset.

pub fn left_day(&self) -> i32

Returns the value of left_day, or the default value if left_day is unset.