OptionChainReq

Struct OptionChainReq 

pub struct OptionChainReq {
    pub stock_id: Option<u64>,
    pub strike_date: Option<u32>,
    pub option_type: Option<u32>,
    pub sort_type: Option<u32>,
    pub sort_id: Option<u32>,
    pub from: Option<u32>,
    pub count: Option<u32>,
}
请求期权链。CMD=6312

Fields

stock_id: Option<u64>

标的正股的股票ID

strike_date: Option<u32>

行权日

option_type: Option<u32>

期权类型,参考OPTION_TYPE

sort_type: Option<u32>

排序方式,参考SORT_TYPE

sort_id: Option<u32>

排序字段, 参考SORT_ID

from: Option<u32>count: Option<u32>

从第from条记录开始,返回count条记录

Implementations

Source

impl OptionChainReq

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn strike_date(&self) -> u32

Returns the value of strike_date, or the default value if strike_date is unset.

pub fn option_type(&self) -> u32

Returns the value of option_type, or the default value if option_type is unset.

pub fn sort_type(&self) -> u32

Returns the value of sort_type, or the default value if sort_type is unset.

pub fn sort_id(&self) -> u32

Returns the value of sort_id, or the default value if sort_id is unset.

pub fn from(&self) -> u32

Returns the value of from, or the default value if from is unset.

pub fn count(&self) -> u32

Returns the value of count, or the default value if count is unset.