DividendItem

Struct DividendItem 

pub struct DividendItem {
    pub info_pub_date: Option<String>,
    pub dividend: Option<String>,
    pub ex_date: Option<String>,
    pub payable_date: Option<String>,
    pub fiscal_year: Option<String>,
    pub type: Option<String>,
    pub dividend_total: Option<i64>,
    pub dividend_currency: Option<String>,
    pub ex_date_timestamp: Option<i64>,
    pub payable_date_timestamp: Option<i64>,
    pub info_pub_date_timestamp: Option<i64>,
}

Fields

info_pub_date: Option<String>dividend: Option<String>ex_date: Option<String>payable_date: Option<String>fiscal_year: Option<String>type: Option<String>dividend_total: Option<i64>dividend_currency: Option<String>ex_date_timestamp: Option<i64>payable_date_timestamp: Option<i64>info_pub_date_timestamp: Option<i64>

Implementations

Source

impl DividendItem

pub fn info_pub_date(&self) -> &str

Returns the value of info_pub_date, or the default value if info_pub_date is unset.

pub fn dividend(&self) -> &str

Returns the value of dividend, or the default value if dividend is unset.

pub fn ex_date(&self) -> &str

Returns the value of ex_date, or the default value if ex_date is unset.

pub fn payable_date(&self) -> &str

Returns the value of payable_date, or the default value if payable_date is unset.

pub fn fiscal_year(&self) -> &str

Returns the value of fiscal_year, or the default value if fiscal_year is unset.

pub fn type(&self) -> &str

Returns the value of type, or the default value if type is unset.

pub fn dividend_total(&self) -> i64

Returns the value of dividend_total, or the default value if dividend_total is unset.

pub fn dividend_currency(&self) -> &str

Returns the value of dividend_currency, or the default value if dividend_currency is unset.

pub fn ex_date_timestamp(&self) -> i64

Returns the value of ex_date_timestamp, or the default value if ex_date_timestamp is unset.

pub fn payable_date_timestamp(&self) -> i64

Returns the value of payable_date_timestamp, or the default value if payable_date_timestamp is unset.

pub fn info_pub_date_timestamp(&self) -> i64

Returns the value of info_pub_date_timestamp, or the default value if info_pub_date_timestamp is unset.