InnerOrder

Struct InnerOrder 

pub struct InnerOrder {
Show 27 fields pub account_id: Option<u64>, pub cid: Option<u64>, pub order_id: Option<String>, pub cl_ord_id: Option<String>, pub orig_cl_ord_id: Option<String>, pub symbol: Option<SymbolPair>, pub exchange: Option<String>, pub security_type: Option<u32>, pub side: Option<u32>, pub order_qty: Option<String>, pub price: Option<String>, pub cum_qty: Option<String>, pub avg_px: Option<String>, pub ord_type: Option<u32>, pub tif: Option<u32>, pub ord_status: Option<u32>, pub leaves_qty: Option<String>, pub currency: Option<String>, pub out_session: Option<String>, pub create_time: Option<i64>, pub update_time: Option<i64>, pub order_show_id: Option<String>, pub trade_date: Option<u32>, pub is_close: Option<bool>, pub stock_id: Option<u64>, pub transaction_category: Option<u32>, pub order_id_up: Option<String>,
}

Fields

account_id: Option<u64>

订单的下游账户ID

cid: Option<u64>

customer_id

order_id: Option<String>

订单ID - 内部, 生命周期内维持不变

cl_ord_id: Option<String>

cl_ord_id - 内部

orig_cl_ord_id: Option<String>

废弃 orig_cl_ord_id - 内部

symbol: Option<SymbolPair>exchange: Option<String>

交易所

security_type: Option<u32>

详见trade_cmn.SecurityType定义

side: Option<u32>

详见trade_cmn.CryptoSide定义

order_qty: Option<String>

订单数量

price: Option<String>

订单价格

cum_qty: Option<String>

已成交数量

avg_px: Option<String>

成交平均价格

ord_type: Option<u32>

详见trade_cmn.CryptoOrdType定义

tif: Option<u32>

详见trade_cmn.CryptoTimeInForce定义

ord_status: Option<u32>

详见trade_cmn.CryptoOrderStatus定义

leaves_qty: Option<String>

剩余未成交数量

currency: Option<String>

报价货币

out_session: Option<String>

Outbound Session(outbound地址)

create_time: Option<i64>update_time: Option<i64>order_show_id: Option<String>

客户端展示的订单id

trade_date: Option<u32>

废弃 交易日

is_close: Option<bool>

订单是否已完结

stock_id: Option<u64>transaction_category: Option<u32>

交易类型,详见trade_cmn.TransactionCategory

order_id_up: Option<String>

上游订单 id

Implementations

Source

impl InnerOrder

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn cl_ord_id(&self) -> &str

Returns the value of cl_ord_id, or the default value if cl_ord_id is unset.

pub fn orig_cl_ord_id(&self) -> &str

Returns the value of orig_cl_ord_id, or the default value if orig_cl_ord_id is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn order_qty(&self) -> &str

Returns the value of order_qty, or the default value if order_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn avg_px(&self) -> &str

Returns the value of avg_px, or the default value if avg_px is unset.

pub fn ord_type(&self) -> u32

Returns the value of ord_type, or the default value if ord_type is unset.

pub fn tif(&self) -> u32

Returns the value of tif, or the default value if tif is unset.

pub fn ord_status(&self) -> u32

Returns the value of ord_status, or the default value if ord_status is unset.

pub fn leaves_qty(&self) -> &str

Returns the value of leaves_qty, or the default value if leaves_qty is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn out_session(&self) -> &str

Returns the value of out_session, or the default value if out_session is unset.

pub fn create_time(&self) -> i64

Returns the value of create_time, or the default value if create_time is unset.

pub fn update_time(&self) -> i64

Returns the value of update_time, or the default value if update_time is unset.

pub fn order_show_id(&self) -> &str

Returns the value of order_show_id, or the default value if order_show_id is unset.

pub fn trade_date(&self) -> u32

Returns the value of trade_date, or the default value if trade_date is unset.

pub fn is_close(&self) -> bool

Returns the value of is_close, or the default value if is_close is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn transaction_category(&self) -> u32

Returns the value of transaction_category, or the default value if transaction_category is unset.

pub fn order_id_up(&self) -> &str

Returns the value of order_id_up, or the default value if order_id_up is unset.