OrderFill

Struct OrderFill 

pub struct OrderFill {
Show 15 fields pub cid: Option<u64>, pub account_id: Option<u64>, pub order_id: Option<String>, pub fill_id: Option<String>, pub side: Option<u32>, pub symbol_pair: Option<SymbolPair>, pub security_type: Option<u32>, pub last_px: Option<String>, pub last_qty: Option<String>, pub last_fill_amount: Option<String>, pub order_time: Option<i64>, pub transact_time: Option<i64>, pub fee_info_list: Vec<FillFeeItem>, pub trade_date: Option<u32>, pub clearing_date: Option<u32>,
}

Fields

cid: Option<u64>

customer_id

account_id: Option<u64>

账户短ID

order_id: Option<String>

订单ID - 内部

fill_id: Option<String>

成交ID

side: Option<u32>

详见trade_cmn.Side

symbol_pair: Option<SymbolPair>

交易对信息

security_type: Option<u32>

详见trade_cmn.SecurityType定义

last_px: Option<String>

本次成交价格

last_qty: Option<String>

本次成交数量

last_fill_amount: Option<String>

本次成交金额=本次成交数量*本次成交价格,截断保留两位

order_time: Option<i64>

订单时间

transact_time: Option<i64>

成交时间,微秒

fee_info_list: Vec<FillFeeItem>

扣费信息

trade_date: Option<u32>

交易日

clearing_date: Option<u32>

结算日

Implementations

Source

impl OrderFill

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn fill_id(&self) -> &str

Returns the value of fill_id, or the default value if fill_id is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn last_px(&self) -> &str

Returns the value of last_px, or the default value if last_px is unset.

pub fn last_qty(&self) -> &str

Returns the value of last_qty, or the default value if last_qty is unset.

pub fn last_fill_amount(&self) -> &str

Returns the value of last_fill_amount, or the default value if last_fill_amount is unset.

pub fn order_time(&self) -> i64

Returns the value of order_time, or the default value if order_time is unset.

pub fn transact_time(&self) -> i64

Returns the value of transact_time, or the default value if transact_time is unset.

pub fn trade_date(&self) -> u32

Returns the value of trade_date, or the default value if trade_date is unset.

pub fn clearing_date(&self) -> u32

Returns the value of clearing_date, or the default value if clearing_date is unset.