QueryManualOrderReq

Struct QueryManualOrderReq 

pub struct QueryManualOrderReq {
    pub cid: Option<u64>,
    pub symbol: Option<String>,
    pub side: Option<u32>,
    pub manual_ord_type: Option<u32>,
    pub status: Option<u32>,
    pub begin_input_time: Option<i64>,
    pub end_input_time: Option<i64>,
    pub pagination: Option<Pagination>,
    pub creator_name: Option<String>,
}
查询人工单

Fields

cid: Option<u64>

customer_id

symbol: Option<String>

symbol,eg. BTC/USD

side: Option<u32>

详见公共协议cryptotrade_cmn.OrderSide

manual_ord_type: Option<u32>

人工单类型,详见公共协议cryptotrade_cmn.ManualOrdType

status: Option<u32>

人工单状态,详见公共协议cryptotrade_cmn.ManualOrdStatus

begin_input_time: Option<i64>

查询起始时间

end_input_time: Option<i64>

查询结束时间,不填默认当前时间

pagination: Option<Pagination>

分页信息,page_size 最大 20

creator_name: Option<String>

操作人名字

Implementations

Source

impl QueryManualOrderReq

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn manual_ord_type(&self) -> u32

Returns the value of manual_ord_type, or the default value if manual_ord_type is unset.

pub fn status(&self) -> u32

Returns the value of status, or the default value if status is unset.

pub fn begin_input_time(&self) -> i64

Returns the value of begin_input_time, or the default value if begin_input_time is unset.

pub fn end_input_time(&self) -> i64

Returns the value of end_input_time, or the default value if end_input_time is unset.

pub fn creator_name(&self) -> &str

Returns the value of creator_name, or the default value if creator_name is unset.