ReportInfo

Struct ReportInfo 

pub struct ReportInfo {
Show 28 fields pub router_exchange: Option<String>, pub exec_type: Option<String>, pub symbol: Option<String>, pub symbol_base: Option<String>, pub symbol_quote: Option<String>, pub exec_id: Option<String>, pub account: Option<String>, pub order_id_up: Option<String>, pub cl_ord_id: Option<String>, pub orig_cl_ord_id: Option<String>, pub order_qty: Option<String>, pub last_qty: Option<String>, pub cum_qty: Option<String>, pub leaves_qty: Option<String>, pub price: Option<String>, pub last_px: Option<String>, pub avg_px: Option<String>, pub ord_status: Option<String>, pub ord_type: Option<String>, pub side: Option<String>, pub text: Option<String>, pub tif: Option<String>, pub transact_time: Option<u64>, pub report_type: Option<String>, pub order_id: Option<String>, pub account_id: Option<u64>, pub cid: Option<u64>, pub last_mkt: Option<String>,
}

Fields

router_exchange: Option<String>

上游交易所

exec_type: Option<String>

执行报告类型

symbol: Option<String>symbol_base: Option<String>symbol_quote: Option<String>exec_id: Option<String>

执行报告 id

account: Option<String>

上游account id

order_id_up: Option<String>

上游订单 id

cl_ord_id: Option<String>orig_cl_ord_id: Option<String>order_qty: Option<String>

订单数量

last_qty: Option<String>

本次成交量

cum_qty: Option<String>

累计成交量

leaves_qty: Option<String>

未成交量

price: Option<String>last_px: Option<String>avg_px: Option<String>ord_status: Option<String>

订单状态,fix 枚举:0-新订单,1-部分成交,2-完全成交,4-已撤销,8-已拒绝,C-已过期

ord_type: Option<String>

订单类型,fix 枚举:1-市价单,2-限价单

side: Option<String>

买卖方向,fix 枚举:1-买,2-卖

text: Option<String>tif: Option<String>

fix 枚举:0-当日有效,1-Good Till Cancel撤销前有效

transact_time: Option<u64>

上游报告处理(创建)时间,微秒

report_type: Option<String>

报告类型 OrderFill-成交报告,OrderNew-下单成功报告,OrderReject-下单拒绝报告(执行报告中的拒绝),OrderCancel-撤单报告,CancelReject-撤单拒绝报告,SessionReject-会话拒绝报告,Expired-过期报告,Unknown-未知报

order_id: Option<String>

内部订单id

account_id: Option<u64>

账户长ID

cid: Option<u64>

customer id

last_mkt: Option<String>

成交的执行市场原始值

Implementations

Source

impl ReportInfo

pub fn router_exchange(&self) -> &str

Returns the value of router_exchange, or the default value if router_exchange is unset.

pub fn exec_type(&self) -> &str

Returns the value of exec_type, or the default value if exec_type is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn symbol_base(&self) -> &str

Returns the value of symbol_base, or the default value if symbol_base is unset.

pub fn symbol_quote(&self) -> &str

Returns the value of symbol_quote, or the default value if symbol_quote is unset.

pub fn exec_id(&self) -> &str

Returns the value of exec_id, or the default value if exec_id is unset.

pub fn account(&self) -> &str

Returns the value of account, or the default value if account is unset.

pub fn order_id_up(&self) -> &str

Returns the value of order_id_up, or the default value if order_id_up is unset.

pub fn cl_ord_id(&self) -> &str

Returns the value of cl_ord_id, or the default value if cl_ord_id is unset.

pub fn orig_cl_ord_id(&self) -> &str

Returns the value of orig_cl_ord_id, or the default value if orig_cl_ord_id is unset.

pub fn order_qty(&self) -> &str

Returns the value of order_qty, or the default value if order_qty is unset.

pub fn last_qty(&self) -> &str

Returns the value of last_qty, or the default value if last_qty is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn leaves_qty(&self) -> &str

Returns the value of leaves_qty, or the default value if leaves_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn last_px(&self) -> &str

Returns the value of last_px, or the default value if last_px is unset.

pub fn avg_px(&self) -> &str

Returns the value of avg_px, or the default value if avg_px is unset.

pub fn ord_status(&self) -> &str

Returns the value of ord_status, or the default value if ord_status is unset.

pub fn ord_type(&self) -> &str

Returns the value of ord_type, or the default value if ord_type is unset.

pub fn side(&self) -> &str

Returns the value of side, or the default value if side is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn tif(&self) -> &str

Returns the value of tif, or the default value if tif is unset.

pub fn transact_time(&self) -> u64

Returns the value of transact_time, or the default value if transact_time is unset.

pub fn report_type(&self) -> &str

Returns the value of report_type, or the default value if report_type is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn last_mkt(&self) -> &str

Returns the value of last_mkt, or the default value if last_mkt is unset.