pub struct CryptoFill {
pub order_id: Option<String>,
pub fill_id: Option<String>,
pub symbol_pair: Option<SymbolPair>,
pub exchange: Option<String>,
pub side: Option<u32>,
pub quantity: Option<String>,
pub price: Option<String>,
pub amount: Option<String>,
pub fill_time: Option<i64>,
pub market: Option<u32>,
pub security_type: Option<u32>,
}Fields
order_id: Option<String>订单id
fill_id: Option<String>成交id
symbol_pair: Option<SymbolPair>交易对信息
exchange: Option<String>交易所
side: Option<u32>详见公共协议cryptotrade_cmn的Side
quantity: Option<String>本次次成交数量
price: Option<String>本次成交价格
amount: Option<String>本次总成交金额
fill_time: Option<i64>成交时间
market: Option<u32>详见公共协议cryptotrade_cmn的StockMarket
security_type: Option<u32>详见公共协议cryptotrade_cmn的SecurityType
Implementations
Sourceimpl CryptoFill
impl CryptoFill
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn fill_id(&self) -> &str
pub fn fill_id(&self) -> &str
Returns the value of fill_id, or the default value if fill_id is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn amount(&self) -> &str
pub fn amount(&self) -> &str
Returns the value of amount, or the default value if amount is unset.
Sourcepub fn fill_time(&self) -> i64
pub fn fill_time(&self) -> i64
Returns the value of fill_time, or the default value if fill_time is unset.
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn security_type(&self) -> u32
pub fn security_type(&self) -> u32
Returns the value of security_type, or the default value if security_type is unset.