FillLog

Struct FillLog 

pub struct FillLog {
    pub fill_id: Option<String>,
    pub order_id: Option<String>,
    pub account_id: Option<u64>,
    pub cid: Option<u64>,
    pub create_time: Option<i64>,
    pub side: Option<u32>,
    pub coin: Option<String>,
    pub currency: Option<String>,
    pub last_qty: Option<String>,
    pub last_px: Option<String>,
    pub last_amount: Option<String>,
    pub router_exchange: Option<u32>,
}

Fields

fill_id: Option<String>

成交ID(对应DB的exec_id)

order_id: Option<String>

内部订单ID

account_id: Option<u64>

订单账户ID

cid: Option<u64>

custome_id

create_time: Option<i64>

发生时间戳,微妙

side: Option<u32>

详见公共协议cryptotrade_cmn的Side

coin: Option<String>

交易对的基础资产,如BTC、ETH

currency: Option<String>

交易对的计价资产,如USD,SGD

last_qty: Option<String>

本次成交数量

last_px: Option<String>

本次成交价格

last_amount: Option<String>

本次成交金额

router_exchange: Option<u32>

详见公共协议cryptotrade_cmn的RouterExchange

Implementations

Source

impl FillLog

pub fn fill_id(&self) -> &str

Returns the value of fill_id, or the default value if fill_id is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn create_time(&self) -> i64

Returns the value of create_time, or the default value if create_time is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn coin(&self) -> &str

Returns the value of coin, or the default value if coin is unset.

pub fn currency(&self) -> &str

Returns the value of currency, or the default value if currency is unset.

pub fn last_qty(&self) -> &str

Returns the value of last_qty, or the default value if last_qty is unset.

pub fn last_px(&self) -> &str

Returns the value of last_px, or the default value if last_px is unset.

pub fn last_amount(&self) -> &str

Returns the value of last_amount, or the default value if last_amount is unset.

pub fn router_exchange(&self) -> u32

Returns the value of router_exchange, or the default value if router_exchange is unset.