InnerFill

Struct InnerFill 

pub struct InnerFill {
Show 30 fields pub header: Option<InnerHeader>, pub account: Option<String>, pub order_id: Option<String>, pub order_id_up: Option<String>, pub cl_ord_id: Option<String>, pub cl_ord_id_up: Option<String>, pub orig_cl_ord_id: Option<String>, pub orig_cl_ord_id_up: Option<String>, pub exec_id: Option<String>, pub exec_id_up: Option<String>, pub secondary_exec_id_up: Option<String>, pub msg_type: Option<u32>, pub exec_type: Option<u32>, pub order_qty: Option<String>, pub last_qty: Option<String>, pub cum_qty: Option<String>, pub leaves_qty: Option<String>, pub price: Option<String>, pub last_px: Option<String>, pub avg_px: Option<String>, pub symbol: Option<SymbolPair>, pub ord_status: Option<u32>, pub ord_type: Option<u32>, pub side: Option<u32>, pub tif: Option<u32>, pub transact_time: Option<i64>, pub text: Option<String>, pub trade_date: Option<u32>, pub clearing_date: Option<u32>, pub fill_id: Option<String>,
}

Fields

header: Option<InnerHeader>account: Option<String>

上游账户,非客户端账户

order_id: Option<String>

订单ID - 内部

order_id_up: Option<String>

订单ID - 上游

cl_ord_id: Option<String>

cl_ord_id - 内部

cl_ord_id_up: Option<String>
👎Deprecated

cl_ord_id - 上游,废弃,不建议使用

orig_cl_ord_id: Option<String>
👎Deprecated

orig_cl_ord_id - 内部,废弃,不建议使用

orig_cl_ord_id_up: Option<String>
👎Deprecated

orig_cl_ord_id - 上游,废弃,不建议使用

exec_id: Option<String>
👎Deprecated

报告ID - 内部,废弃,不建议使用

exec_id_up: Option<String>
👎Deprecated

报告ID - 上游,废弃,不建议使用

secondary_exec_id_up: Option<String>
👎Deprecated

成交ID - 上游,废弃,不建议使用

msg_type: Option<u32>
👎Deprecated

详见trade_cmn.FixMsgType定义,废弃,不建议使用

exec_type: Option<u32>
👎Deprecated

详见trade_cmn.FixExecType定义,废弃,不建议使用

order_qty: Option<String>

订单数量

last_qty: Option<String>

本次成交数量

cum_qty: Option<String>

累计成交数量

leaves_qty: Option<String>

剩余未成交数量

price: Option<String>

订单价格

last_px: Option<String>

本次成交价格

avg_px: Option<String>

成交平均价格

symbol: Option<SymbolPair>ord_status: Option<u32>
👎Deprecated

详见trade_cmn.FixOrdStatus定义,废弃,不建议使用

ord_type: Option<u32>
👎Deprecated

详见trade_cmn.CryptoOrderType定义,废弃,不建议使用

side: Option<u32>

详见trade_cmn.CryptoSide定义

tif: Option<u32>

详见trade_cmn.CryptoTimeInForce定义

transact_time: Option<i64>

报告时间

text: Option<String>

报告附加信息

trade_date: Option<u32>

交易日

clearing_date: Option<u32>

结算日

fill_id: Option<String>

成交ID - 内部

Implementations

Source

impl InnerFill

pub fn account(&self) -> &str

Returns the value of account, or the default value if account is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn order_id_up(&self) -> &str

Returns the value of order_id_up, or the default value if order_id_up is unset.

pub fn cl_ord_id(&self) -> &str

Returns the value of cl_ord_id, or the default value if cl_ord_id is unset.

pub fn cl_ord_id_up(&self) -> &str

Returns the value of cl_ord_id_up, or the default value if cl_ord_id_up is unset.

pub fn orig_cl_ord_id(&self) -> &str

Returns the value of orig_cl_ord_id, or the default value if orig_cl_ord_id is unset.

pub fn orig_cl_ord_id_up(&self) -> &str

Returns the value of orig_cl_ord_id_up, or the default value if orig_cl_ord_id_up is unset.

pub fn exec_id(&self) -> &str

Returns the value of exec_id, or the default value if exec_id is unset.

pub fn exec_id_up(&self) -> &str

Returns the value of exec_id_up, or the default value if exec_id_up is unset.

pub fn secondary_exec_id_up(&self) -> &str

Returns the value of secondary_exec_id_up, or the default value if secondary_exec_id_up is unset.

pub fn msg_type(&self) -> u32

Returns the value of msg_type, or the default value if msg_type is unset.

pub fn exec_type(&self) -> u32

Returns the value of exec_type, or the default value if exec_type is unset.

pub fn order_qty(&self) -> &str

Returns the value of order_qty, or the default value if order_qty is unset.

pub fn last_qty(&self) -> &str

Returns the value of last_qty, or the default value if last_qty is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn leaves_qty(&self) -> &str

Returns the value of leaves_qty, or the default value if leaves_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn last_px(&self) -> &str

Returns the value of last_px, or the default value if last_px is unset.

pub fn avg_px(&self) -> &str

Returns the value of avg_px, or the default value if avg_px is unset.

pub fn ord_status(&self) -> u32

Returns the value of ord_status, or the default value if ord_status is unset.

pub fn ord_type(&self) -> u32

Returns the value of ord_type, or the default value if ord_type is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn tif(&self) -> u32

Returns the value of tif, or the default value if tif is unset.

pub fn transact_time(&self) -> i64

Returns the value of transact_time, or the default value if transact_time is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn trade_date(&self) -> u32

Returns the value of trade_date, or the default value if trade_date is unset.

pub fn clearing_date(&self) -> u32

Returns the value of clearing_date, or the default value if clearing_date is unset.

pub fn fill_id(&self) -> &str

Returns the value of fill_id, or the default value if fill_id is unset.