OrderOpLog

Struct OrderOpLog 

pub struct OrderOpLog {
    pub cl_ord_id: Option<String>,
    pub order_id: Option<String>,
    pub account_id: Option<u64>,
    pub cid: Option<u64>,
    pub create_time: Option<i64>,
    pub op: Option<u32>,
    pub input_source: Option<u32>,
}

Fields

cl_ord_id: Option<String>

内部订单请求ID(下改撤不同)

order_id: Option<String>

内部订单ID

account_id: Option<u64>

订单账户ID

cid: Option<u64>

custome_id

create_time: Option<i64>

发生时间戳,微妙

op: Option<u32>

详见公共协议cryptotrade_cmn的OrderOpType

input_source: Option<u32>

订单操作来源,详见公共协议cryptotrade_cmn的InputSource

Implementations

Source

impl OrderOpLog

pub fn cl_ord_id(&self) -> &str

Returns the value of cl_ord_id, or the default value if cl_ord_id is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn cid(&self) -> u64

Returns the value of cid, or the default value if cid is unset.

pub fn create_time(&self) -> i64

Returns the value of create_time, or the default value if create_time is unset.

pub fn op(&self) -> u32

Returns the value of op, or the default value if op is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.