RoaOrder

Struct RoaOrder 

pub struct RoaOrder {
Show 20 fields pub order_id: Option<String>, pub symbol_pair: Option<SymbolPair>, pub side: Option<u32>, pub order_qty: Option<String>, pub price: Option<String>, pub order_amount: Option<String>, pub cum_qty: Option<String>, pub avg_px: Option<String>, pub fill_amount: Option<String>, pub ord_type: Option<u32>, pub time_in_force: Option<u32>, pub create_time: Option<i64>, pub update_time: Option<i64>, pub ord_status: Option<u32>, pub input_source: Option<u32>, pub operator_id: Option<u64>, pub operator_name: Option<String>, pub cancel_source: Option<u32>, pub order_show_id: Option<String>, pub cancel_time: Option<i64>,
}

Fields

order_id: Option<String>

订单号, 生命周期内维持不变

symbol_pair: Option<SymbolPair>

交易对信息

side: Option<u32>

详见公共协议cryptotrade_cmn的Side

order_qty: Option<String>

订单数量

price: Option<String>

订单价格

order_amount: Option<String>

订单金额

cum_qty: Option<String>

已成交数量

avg_px: Option<String>

成交平均价格

fill_amount: Option<String>

成交金额

ord_type: Option<u32>

详见公共协议cryptotrade_cmn的CryptoOrderType

time_in_force: Option<u32>

详见公共协议cryptotrade_cmn的TimeInForce

create_time: Option<i64>

订单创建时间,微妙

update_time: Option<i64>

订单更新时间,微妙

ord_status: Option<u32>

详见公共协议cryptotrade_cmn的CryptoOrderStatus

input_source: Option<u32>

订单下单来源,详见公共协议cryptotrade_cmn的InputSource

operator_id: Option<u64>

下单人ID

operator_name: Option<String>

下单人名称(ROA下单的才有值,客户端下单的没有值)

cancel_source: Option<u32>

订单撤单(成功)来源,详见公共协议cryptotrade_cmn的InputSourceType

order_show_id: Option<String>

客户端展示的订单id

cancel_time: Option<i64>

订单撤单成功操作的发起时间

Implementations

Source

impl RoaOrder

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn order_qty(&self) -> &str

Returns the value of order_qty, or the default value if order_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn order_amount(&self) -> &str

Returns the value of order_amount, or the default value if order_amount is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn avg_px(&self) -> &str

Returns the value of avg_px, or the default value if avg_px is unset.

pub fn fill_amount(&self) -> &str

Returns the value of fill_amount, or the default value if fill_amount is unset.

pub fn ord_type(&self) -> u32

Returns the value of ord_type, or the default value if ord_type is unset.

pub fn time_in_force(&self) -> u32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn create_time(&self) -> i64

Returns the value of create_time, or the default value if create_time is unset.

pub fn update_time(&self) -> i64

Returns the value of update_time, or the default value if update_time is unset.

pub fn ord_status(&self) -> u32

Returns the value of ord_status, or the default value if ord_status is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.

pub fn operator_id(&self) -> u64

Returns the value of operator_id, or the default value if operator_id is unset.

pub fn operator_name(&self) -> &str

Returns the value of operator_name, or the default value if operator_name is unset.

pub fn cancel_source(&self) -> u32

Returns the value of cancel_source, or the default value if cancel_source is unset.

pub fn order_show_id(&self) -> &str

Returns the value of order_show_id, or the default value if order_show_id is unset.

pub fn cancel_time(&self) -> i64

Returns the value of cancel_time, or the default value if cancel_time is unset.