pub struct MainIncomeRsp {
pub ret_code: Option<i32>,
pub stock_id: Option<u64>,
pub response_type: Option<i32>,
pub period: Option<String>,
pub main_income_item: Vec<MainIncomeItem>,
pub currency: Option<String>,
pub screen_dates: Vec<ScreenDate>,
pub currency_code: Option<String>,
}Fields
ret_code: Option<i32>stock_id: Option<u64>response_type: Option<i32>period: Option<String>main_income_item: Vec<MainIncomeItem>currency: Option<String>screen_dates: Vec<ScreenDate>currency_code: Option<String>Implementations
Sourceimpl MainIncomeRsp
impl MainIncomeRsp
Sourcepub fn ret_code(&self) -> i32
pub fn ret_code(&self) -> i32
Returns the value of ret_code, or the default value if ret_code is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn response_type(&self) -> i32
pub fn response_type(&self) -> i32
Returns the value of response_type, or the default value if response_type is unset.
Sourcepub fn period(&self) -> &str
pub fn period(&self) -> &str
Returns the value of period, or the default value if period is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn currency_code(&self) -> &str
pub fn currency_code(&self) -> &str
Returns the value of currency_code, or the default value if currency_code is unset.