MarketTradeStatus

Enum MarketTradeStatus 

#[repr(i32)]
pub enum MarketTradeStatus {
Show 37 variants EMtsNone = 0, EMtsAuction = 1, EMtsWaitopen = 2, EMtsMorning = 3, EMtsLunchbreak = 4, EMtsAfternoon = 5, EMtsDayclose = 6, EMtsMaauction = 7, EMtsUsBeforeBegin = 8, EMtsUsBeforeEnd = 9, EMtsUsAfterBegin = 10, EMtsUsAfterEnd = 11, EMtsFutuSwitchDate = 12, EMtsFutureNight = 13, EMtsFutureNightEnd = 14, EMtsFutureDay = 15, EMtsFutureDayBreak = 16, EMtsFutureDayClose = 17, EMtsFutureDayWait = 18, EMtsHkCas = 19, EMtsFutureNightWait = 20, EMtsFutureAfternoon = 21, EMtsUsFutureSwitchDate = 22, EMtsUsFutureOpen = 23, EMtsUsFutureBreak = 24, EMtsUsFutureBreakOver = 25, EMtsUsFutureClose = 26, EMtsStibAfterhoursWait = 27, EMtsStibAfterhoursBegin = 28, EMtsStibAfterhoursEnd = 29, EMtsCloseAuction = 30, EMtsAfternoonEnd = 31, EMtsNight = 32, EMtsOvernightBegin = 33, EMtsOvernightEnd = 34, EMtsTradeAtLast = 35, EMtsTradeAuction = 36,
}

Variants



EMtsNone = 0



EMtsAuction = 1

盘前竞价



EMtsWaitopen = 2

等待开盘



EMtsMorning = 3

上午开盘



EMtsLunchbreak = 4

午间休盘



EMtsAfternoon = 5

下午开盘



EMtsDayclose = 6

收盘



EMtsMaauction = 7



EMtsUsBeforeBegin = 8

美股的盘前开始



EMtsUsBeforeEnd = 9

美股的盘前结束



EMtsUsAfterBegin = 10

美股的盘后开始



EMtsUsAfterEnd = 11

美股的盘后结束



EMtsFutuSwitchDate = 12

富途的切换交易状态,专门用来只是切一下交易日



EMtsFutureNight = 13

13~18是期货日市夜市的市场状态

夜市开盘



EMtsFutureNightEnd = 14

夜市收盘



EMtsFutureDay = 15

日市开盘



EMtsFutureDayBreak = 16

日市休市



EMtsFutureDayClose = 17

收盘



EMtsFutureDayWait = 18

日市等待开盘



EMtsHkCas = 19

港股盘后竞价



EMtsFutureNightWait = 20

夜市等待开盘



EMtsFutureAfternoon = 21

期货下午开盘



EMtsUsFutureSwitchDate = 22

美国期货新增加状态

期货切交易日



EMtsUsFutureOpen = 23

期货开盘(不分早晚市)



EMtsUsFutureBreak = 24

期货中盘休息



EMtsUsFutureBreakOver = 25

期货休息后开盘



EMtsUsFutureClose = 26

期货收盘



EMtsStibAfterhoursWait = 27

科创板新增状态

科创板的盘后撮合时段(15:00-15:05)



EMtsStibAfterhoursBegin = 28

科创板的盘后交易开始(15:05-15:30)



EMtsStibAfterhoursEnd = 29

科创板的盘后交易结束(15:30之后)



EMtsCloseAuction = 30

收市竞价



EMtsAfternoonEnd = 31

已收盘



EMtsNight = 32

交易中



EMtsOvernightBegin = 33

夜盘开始



EMtsOvernightEnd = 34

夜盘结束



EMtsTradeAtLast = 35

收盘前成交(在交易时间表内)



EMtsTradeAuction = 36

收盘前的竞价 (在交易时间表内)

Implementations

Source

impl MarketTradeStatus

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of MarketTradeStatus.

pub fn from_i32(value: i32) -> Option<MarketTradeStatus>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a MarketTradeStatus, or None if value is not a valid variant.

Source

impl MarketTradeStatus

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.