NTradeDateRsp

Struct NTradeDateRsp 

pub struct NTradeDateRsp {
    pub code: Option<i32>,
    pub msg: Option<String>,
    pub date_key: Option<u32>,
    pub market_id: Option<i32>,
    pub day_infos: Vec<DayInfo>,
    pub time_date: Option<u32>,
}
查询某个市场,指定交易日的前/后N交易日。应答消息

Fields

code: Option<i32>

请求返回码,0表示成功,其它表示失败

msg: Option<String>

请求返回的message

date_key: Option<u32>

请求指定date_key前/后第N个交易日的时间戳

market_id: Option<i32>

请求指定的市场

day_infos: Vec<DayInfo>

包含请求指定date_key的后n个交易日的完整列表

time_date: Option<u32>

请求指定date_key前/后第N个交易日的日期YYYYMMDD,例如20210207

Implementations

Source

impl NTradeDateRsp

pub fn code(&self) -> i32

Returns the value of code, or the default value if code is unset.

pub fn msg(&self) -> &str

Returns the value of msg, or the default value if msg is unset.

pub fn date_key(&self) -> u32

Returns the value of date_key, or the default value if date_key is unset.

pub fn market_id(&self) -> i32

Returns the value of market_id, or the default value if market_id is unset.

pub fn time_date(&self) -> u32

Returns the value of time_date, or the default value if time_date is unset.