#[repr(i32)]pub enum MsgCategory {
Pricewarn = 1,
MsgNetworkDebug = 2,
MsgPortfolioAdjust = 3,
MsgIpoTradingInform = 4,
MsgIndicatorWarn = 5,
OptionMoveWarn = 6,
}Expand description
消息类型
Variants
Pricewarn = 1
到价提醒
MsgNetworkDebug = 2
Web网络状态监测
MsgPortfolioAdjust = 3
投资组合调仓提醒
MsgIpoTradingInform = 4
新股开盘提醒
MsgIndicatorWarn = 5
技术指标提醒
OptionMoveWarn = 6
期权异动提醒
Implementations
Sourceimpl MsgCategory
impl MsgCategory
Sourceimpl MsgCategory
impl MsgCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.