PriceWarnDetailMsg

Struct PriceWarnDetailMsg 

pub struct PriceWarnDetailMsg {
    pub key: Option<u64>,
    pub type: Option<u32>,
    pub set_value: Option<i64>,
    pub present_value: Option<i64>,
}
到价提醒消息详情

Fields

key: Option<u64>

提醒配置唯一标识

type: Option<u32>

提醒类型(参考 FTCmd6806-6810.proto: WarnType)

set_value: Option<i64>

提醒设置值

present_value: Option<i64>

当前实际值

Implementations

Source

impl PriceWarnDetailMsg

pub fn key(&self) -> u64

Returns the value of key, or the default value if key is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn set_value(&self) -> i64

Returns the value of set_value, or the default value if set_value is unset.

pub fn present_value(&self) -> i64

Returns the value of present_value, or the default value if present_value is unset.