PriceWarnMsg

Struct PriceWarnMsg 

pub struct PriceWarnMsg {
    pub stock_id: Option<u64>,
    pub price: Option<u32>,
    pub price_change_ratio: Option<i64>,
    pub msg_content: Option<String>,
    pub msg_content_tc: Option<String>,
    pub msg_content_en: Option<String>,
    pub note: Option<String>,
    pub market_status: Option<i32>,
    pub warn_detail: Option<PriceWarnDetailMsg>,
}
到价提醒类-消息定义

Fields

stock_id: Option<u64>

股票ID

price: Option<u32>

消息当时的低精度股票价格(真实价格*1e3)

price_change_ratio: Option<i64>

消息当时的股票涨跌幅。精确到0.001%, 1000表示1%

msg_content: Option<String>

消息内容,简体中文

msg_content_tc: Option<String>

消息内容,繁体中文

msg_content_en: Option<String>

消息内容,英文

note: Option<String>

用户设置的备注

market_status: Option<i32>

市场状态,参考MarketStatus

warn_detail: Option<PriceWarnDetailMsg>

提醒内容详细值

Implementations

Source

impl PriceWarnMsg

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn price(&self) -> u32

Returns the value of price, or the default value if price is unset.

pub fn price_change_ratio(&self) -> i64

Returns the value of price_change_ratio, or the default value if price_change_ratio is unset.

pub fn msg_content(&self) -> &str

Returns the value of msg_content, or the default value if msg_content is unset.

pub fn msg_content_tc(&self) -> &str

Returns the value of msg_content_tc, or the default value if msg_content_tc is unset.

pub fn msg_content_en(&self) -> &str

Returns the value of msg_content_en, or the default value if msg_content_en is unset.

pub fn note(&self) -> &str

Returns the value of note, or the default value if note is unset.

pub fn market_status(&self) -> i32

Returns the value of market_status, or the default value if market_status is unset.