#[repr(i32)]pub enum AccountMarket {
Hk = 1,
Us = 2,
UsOption = 3,
Hkcc = 4,
Futures = 5,
Universal = 6,
Crypto = 7,
Forex = 9,
HkBond = 13,
UsBond = 23,
}Variants
Hk = 1
港股账户
Us = 2
美股账户
UsOption = 3
美股期权账户
Hkcc = 4
港股A股通账户
Futures = 5
期货账户
Universal = 6
证券全能账户
Crypto = 7
数字货币账户
Forex = 9
外汇
HkBond = 13
港币债券账户
UsBond = 23
美元债券账户
Implementations
Sourceimpl AccountMarket
impl AccountMarket
Sourceimpl AccountMarket
impl AccountMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.