#[repr(i32)]pub enum AccountState {
NotOpen = 0,
Opening = 1,
PreOpened = 2,
Opened = 3,
TradeForbidding = 4,
LoginForbidding = 5,
TradeNotOpen = 6,
NeedRiskDisclosure = 7,
}Variants
NotOpen = 0
未开户
Opening = 1
开户处理中
PreOpened = 2
已预开户
Opened = 3
已正式开通
TradeForbidding = 4
禁止交易
LoginForbidding = 5
禁止登陆
TradeNotOpen = 6
交易未开启
NeedRiskDisclosure = 7
需要风批
Implementations
Sourceimpl AccountState
impl AccountState
Sourceimpl AccountState
impl AccountState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.