#[repr(i32)]pub enum AssetCategory {
Unknown = 0,
DomesticStocks = 1,
ForeignStocks = 2,
}Expand description
同一账户下资产/风控数据维度的分类(目前只有JP信用/衍生品账户使用)
Variants
Implementations
Sourceimpl AssetCategory
impl AssetCategory
Sourceimpl AssetCategory
impl AssetCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.