#[repr(i32)]pub enum Currency {
Show 57 variants
Hkd = 1,
Usd = 2,
Cnh = 3,
Jpy = 4,
Sgd = 5,
Aed = 6,
Ats = 7,
Aud = 8,
Bdt = 9,
Bec = 10,
Bel = 11,
Bhd = 12,
Bnd = 13,
Brc = 14,
Buk = 15,
Cad = 16,
Chf = 17,
Cny = 18,
Cyp = 19,
Dem = 20,
Dkk = 21,
Ecu = 22,
Esp = 23,
Eur = 24,
Fim = 25,
Fjd = 26,
Frf = 27,
Gbp = 28,
Idr = 29,
Iep = 30,
Inr = 31,
Itl = 32,
Kes = 33,
Krw = 34,
Kwd = 35,
Lbp = 36,
Lkr = 37,
Mop = 38,
Mur = 39,
Mxn = 40,
Myr = 41,
Ngn = 42,
Nlg = 43,
Nok = 44,
Nzd = 45,
Omr = 46,
Php = 47,
Pkr = 48,
Pte = 49,
Qar = 50,
Sar = 51,
Scr = 52,
Sdr = 53,
Sek = 54,
Sll = 55,
Thb = 56,
Zar = 57,
}Variants
Hkd = 1
用到时请加注释,注明是哪种货币
港币
Usd = 2
美元
Cnh = 3
离岸人民币
Jpy = 4
日元
Sgd = 5
新币
Aed = 6
Ats = 7
Aud = 8
澳元
Bdt = 9
Bec = 10
Bel = 11
Bhd = 12
Bnd = 13
Brc = 14
Buk = 15
Cad = 16
Chf = 17
Cny = 18
Cyp = 19
Dem = 20
Dkk = 21
Ecu = 22
Esp = 23
Eur = 24
Fim = 25
Fjd = 26
Frf = 27
Gbp = 28
Idr = 29
Iep = 30
Inr = 31
Itl = 32
Kes = 33
Krw = 34
Kwd = 35
Lbp = 36
Lkr = 37
Mop = 38
Mur = 39
Mxn = 40
Myr = 41
Ngn = 42
Nlg = 43
Nok = 44
Nzd = 45
Omr = 46
Php = 47
Pkr = 48
Pte = 49
Qar = 50
Sar = 51
Scr = 52
Sdr = 53
Sek = 54
Sll = 55
Thb = 56
Zar = 57
Implementations
Sourceimpl Currency
impl Currency
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.