#[repr(i32)]pub enum Market {
Show 14 variants
HkStock = 1,
UsStock = 2,
UsOption = 3,
HkccStock = 4,
Futures = 5,
SgStock = 6,
CryptoCurrency = 7,
AuStock = 8,
Forex = 9,
My = 11,
Ca = 12,
HkBond = 13,
Jp = 15,
UsBond = 23,
}Variants
HkStock = 1
港股股票
UsStock = 2
美股股票
UsOption = 3
美股期权
HkccStock = 4
港股A股通
Futures = 5
期货市场
SgStock = 6
新加坡市场
CryptoCurrency = 7
数字币市场
AuStock = 8
澳股
Forex = 9
外汇
My = 11
马股
Ca = 12
加股
HkBond = 13
港币债券
Jp = 15
日股
UsBond = 23
美元债券
Implementations
Sourceimpl Market
impl Market
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.