#[repr(i32)]pub enum OrderTimeInForce {
TimeDay = 0,
TimeGtc = 1,
TimeGtd = 2,
TimeFok = 3,
TimeIoc = 4,
}Expand description
订单期限
Variants
TimeDay = 0
当日有效
TimeGtc = 1
撤单前有效,最多持续90自然日
TimeGtd = 2
指定日期前有效
TimeFok = 3
全部成交或取消
TimeIoc = 4
立即或取消(可部分成交,剩余交易量取消)
Implementations
Sourceimpl OrderTimeInForce
impl OrderTimeInForce
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.