#[repr(i32)]pub enum Side {
Buy = 1,
Sell = 2,
SellShort = 3,
BuyBack = 4,
}Expand description
交易方向
- 客户端下单时, 只需要传buy和sell
- server返回的数据, 会有sell_short, buy, sell
- buy_back, server使用
Variants
Implementations
Sourceimpl Side
impl Side
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.