#[repr(i32)]pub enum TradingPeriod {
BeforeTradePeriod = 1,
AfterTradePeriod = 2,
}Expand description
订单所属时段(该字段是非交易时段使用,只识别正常交易时段的前后)
Variants
Implementations
Sourceimpl TradingPeriod
impl TradingPeriod
Sourceimpl TradingPeriod
impl TradingPeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.