CashDynamicInfo

Struct CashDynamicInfo 

pub struct CashDynamicInfo {
Show 25 fields pub max_power_long: Option<String>, pub max_power_short: Option<String>, pub drawable: Option<String>, pub total_asset: Option<String>, pub mv: Option<String>, pub long_mv: Option<String>, pub short_mv: Option<String>, pub loan_max: Option<String>, pub debit_recover: Option<String>, pub margin_call_balance: Option<String>, pub margin_call_balance_ratio: Option<String>, pub margin_call_recover: Option<String>, pub risk_level: Option<u32>, pub absolute_safe_mcb_ratio: Option<String>, pub margin_call: Option<String>, pub cash_drawable: Option<String>, pub risk_status: Option<u32>, pub pdt_seq: Vec<i32>, pub is_pdt: Option<bool>, pub beginning_dtbp: Option<String>, pub remaining_dtbp: Option<String>, pub cash_in_credit: Option<String>, pub risk_status_client: Option<i32>, pub unrealized_profit: Option<String>, pub realized_profit: Option<String>,
}

Fields

max_power_long: Option<String>

最大做多购买力

max_power_short: Option<String>

最大做空购买力

drawable: Option<String>

最大可提金额

total_asset: Option<String>

资产净值

mv: Option<String>

持仓市值

long_mv: Option<String>

多头持仓市值

short_mv: Option<String>

空头持仓市值

loan_max: Option<String>

最高借贷额

debit_recover: Option<String>

追收金额

margin_call_balance: Option<String>

MarginCall保证金剩余

margin_call_balance_ratio: Option<String>

过夜风控比例

margin_call_recover: Option<String>

追缴保证金

risk_level: Option<u32>

风险等级, 取值参考 CltRiskLevel

absolute_safe_mcb_ratio: Option<String>

RiskLevel==ABSOLUTE_SAFE时, 客户端需用来展示的固定过夜风控比例

margin_call: Option<String>

MarginCall保证金

cash_drawable: Option<String>

现金可提金额

risk_status: Option<u32>

账户状态码, 10:安全1, 20:安全2, 30:安全3,

pdt_seq: Vec<i32>

41:较低4.1, 42:较低4.2, 51:中等5.1, 52:中等5.2, 61:偏高6.1, 62:偏高6.2, 70:预警7, 81:危险8.1, 82:危险8.2, 91:危险9.1, 92:危险9.2, 93:危险9.3, 其它值,暂定为安全1

日内交易序列,【美分】目前适用

is_pdt: Option<bool>

是否PDT用户

beginning_dtbp: Option<String>

日内交易购买力,is_pdt==true时才有

remaining_dtbp: Option<String>

剩余日内交易购买力,is_pdt==true时才有

cash_in_credit: Option<String>

入金授信开仓上限

risk_status_client: Option<i32>

账户风险状态码,客户端专用

unrealized_profit: Option<String>

未实现盈亏

realized_profit: Option<String>

已实现盈亏

Implementations

Source

impl CashDynamicInfo

pub fn max_power_long(&self) -> &str

Returns the value of max_power_long, or the default value if max_power_long is unset.

pub fn max_power_short(&self) -> &str

Returns the value of max_power_short, or the default value if max_power_short is unset.

pub fn drawable(&self) -> &str

Returns the value of drawable, or the default value if drawable is unset.

pub fn total_asset(&self) -> &str

Returns the value of total_asset, or the default value if total_asset is unset.

pub fn mv(&self) -> &str

Returns the value of mv, or the default value if mv is unset.

pub fn long_mv(&self) -> &str

Returns the value of long_mv, or the default value if long_mv is unset.

pub fn short_mv(&self) -> &str

Returns the value of short_mv, or the default value if short_mv is unset.

pub fn loan_max(&self) -> &str

Returns the value of loan_max, or the default value if loan_max is unset.

pub fn debit_recover(&self) -> &str

Returns the value of debit_recover, or the default value if debit_recover is unset.

pub fn margin_call_balance(&self) -> &str

Returns the value of margin_call_balance, or the default value if margin_call_balance is unset.

pub fn margin_call_balance_ratio(&self) -> &str

Returns the value of margin_call_balance_ratio, or the default value if margin_call_balance_ratio is unset.

pub fn margin_call_recover(&self) -> &str

Returns the value of margin_call_recover, or the default value if margin_call_recover is unset.

pub fn risk_level(&self) -> u32

Returns the value of risk_level, or the default value if risk_level is unset.

pub fn absolute_safe_mcb_ratio(&self) -> &str

Returns the value of absolute_safe_mcb_ratio, or the default value if absolute_safe_mcb_ratio is unset.

pub fn margin_call(&self) -> &str

Returns the value of margin_call, or the default value if margin_call is unset.

pub fn cash_drawable(&self) -> &str

Returns the value of cash_drawable, or the default value if cash_drawable is unset.

pub fn risk_status(&self) -> u32

Returns the value of risk_status, or the default value if risk_status is unset.

pub fn is_pdt(&self) -> bool

Returns the value of is_pdt, or the default value if is_pdt is unset.

pub fn beginning_dtbp(&self) -> &str

Returns the value of beginning_dtbp, or the default value if beginning_dtbp is unset.

pub fn remaining_dtbp(&self) -> &str

Returns the value of remaining_dtbp, or the default value if remaining_dtbp is unset.

pub fn cash_in_credit(&self) -> &str

Returns the value of cash_in_credit, or the default value if cash_in_credit is unset.

pub fn risk_status_client(&self) -> i32

Returns the value of risk_status_client, or the default value if risk_status_client is unset.

pub fn unrealized_profit(&self) -> &str

Returns the value of unrealized_profit, or the default value if unrealized_profit is unset.

pub fn realized_profit(&self) -> &str

Returns the value of realized_profit, or the default value if realized_profit is unset.