CashStaticInfo

Struct CashStaticInfo 

pub struct CashStaticInfo {
    pub balance: Option<String>,
    pub hold: Option<String>,
}

Fields

balance: Option<String>

现金结余

hold: Option<String>

冻结资金

Implementations

Source

impl CashStaticInfo

pub fn balance(&self) -> &str

Returns the value of balance, or the default value if balance is unset.

pub fn hold(&self) -> &str

Returns the value of hold, or the default value if hold is unset.