CltActionOrderConfirm

Struct CltActionOrderConfirm 

pub struct CltActionOrderConfirm {
    pub order_id: Option<String>,
    pub title: Option<String>,
    pub content: Option<String>,
    pub confirm_button_title: Option<String>,
    pub cancel_button_title: Option<String>,
    pub confirm_type: Option<u32>,
    pub exchange_code: Option<u32>,
    pub exchange: Option<String>,
}

Fields

order_id: Option<String>

订单id

title: Option<String>

显示弹窗标题文案

content: Option<String>

显示弹窗内容文案

confirm_button_title: Option<String>

显示确认按钮文案

cancel_button_title: Option<String>

显示取消按钮文案

confirm_type: Option<u32>

确认类型,订单确认时使用服务器返回的这个值

exchange_code: Option<u32>

期货上游交易所代码

exchange: Option<String>

Implementations

Source

impl CltActionOrderConfirm

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn content(&self) -> &str

Returns the value of content, or the default value if content is unset.

pub fn confirm_button_title(&self) -> &str

Returns the value of confirm_button_title, or the default value if confirm_button_title is unset.

pub fn cancel_button_title(&self) -> &str

Returns the value of cancel_button_title, or the default value if cancel_button_title is unset.

pub fn confirm_type(&self) -> u32

Returns the value of confirm_type, or the default value if confirm_type is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.