pub struct FuturePowerInfo {
pub currency: Option<u32>,
pub available: Option<String>,
pub max_buypower: Option<String>,
}Expand description
期货账户购买力信息
Fields
currency: Option<u32>货币单位, 取值参考Currency
available: Option<String>可用资金
max_buypower: Option<String>最大购买力
Implementations
Sourceimpl FuturePowerInfo
impl FuturePowerInfo
Sourcepub fn currency(&self) -> u32
pub fn currency(&self) -> u32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn available(&self) -> &str
pub fn available(&self) -> &str
Returns the value of available, or the default value if available is unset.
Sourcepub fn max_buypower(&self) -> &str
pub fn max_buypower(&self) -> &str
Returns the value of max_buypower, or the default value if max_buypower is unset.