SimpleOrder

Struct SimpleOrder 

pub struct SimpleOrder {
Show 15 fields pub side: Option<u32>, pub market: Option<u32>, pub symbol: Option<String>, pub order_id: Option<String>, pub type: Option<u32>, pub qty: Option<String>, pub cum_qty: Option<String>, pub price: Option<String>, pub avg_fill_price: Option<String>, pub exchange: Option<String>, pub create_time: Option<u64>, pub status: Option<u32>, pub trading_period: Option<u32>, pub input_source: Option<u32>, pub round_timestamp: Option<i64>,
}

Fields

side: Option<u32>

取值参考 Side

market: Option<u32>

取值参考 Market

symbol: Option<String>

股票代码

order_id: Option<String>

订单号, 生命周期内维持不变

type: Option<u32>

取值参考 OrderType

qty: Option<String>

订单股数

cum_qty: Option<String>

总已成交股数

price: Option<String>

订单价格

avg_fill_price: Option<String>

订单平均成交价

exchange: Option<String>create_time: Option<u64>

单位微秒

status: Option<u32>

取值参考 OrderStatus

trading_period: Option<u32>

订单所属时段,取值参考 TradingPeriod

input_source: Option<u32>

input_source

round_timestamp: Option<i64>

圆整后的时间戳,优先使用这个,create_time+trading_period供旧客户端使用

Implementations

Source

impl SimpleOrder

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn market(&self) -> u32

Returns the value of market, or the default value if market is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn avg_fill_price(&self) -> &str

Returns the value of avg_fill_price, or the default value if avg_fill_price is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn create_time(&self) -> u64

Returns the value of create_time, or the default value if create_time is unset.

pub fn status(&self) -> u32

Returns the value of status, or the default value if status is unset.

pub fn trading_period(&self) -> u32

Returns the value of trading_period, or the default value if trading_period is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.

pub fn round_timestamp(&self) -> i64

Returns the value of round_timestamp, or the default value if round_timestamp is unset.