pub struct SimpleOrderFill {
pub side: Option<u32>,
pub market: Option<u32>,
pub symbol: Option<String>,
pub order_id: Option<String>,
pub id: Option<String>,
pub qty: Option<String>,
pub price: Option<String>,
pub create_time: Option<u64>,
pub trading_period: Option<u32>,
pub exchange: Option<String>,
pub input_source: Option<u32>,
pub round_timestamp: Option<i64>,
}Fields
side: Option<u32>取值参考 Side
market: Option<u32>取值参考 Market
symbol: Option<String>股票代码
order_id: Option<String>订单id
id: Option<String>成交id
qty: Option<String>成交股数
price: Option<String>成交价格
create_time: Option<u64>单位微秒, 成交创建时间
trading_period: Option<u32>订单所属时段,取值参考 TradingPeriod
exchange: Option<String>input_source: Option<u32>input_source
round_timestamp: Option<i64>圆整后的时间戳,优先使用这个,create_time+trading_period供旧客户端使用
Implementations
Sourceimpl SimpleOrderFill
impl SimpleOrderFill
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn create_time(&self) -> u64
pub fn create_time(&self) -> u64
Returns the value of create_time, or the default value if create_time is unset.
Sourcepub fn trading_period(&self) -> u32
pub fn trading_period(&self) -> u32
Returns the value of trading_period, or the default value if trading_period is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn input_source(&self) -> u32
pub fn input_source(&self) -> u32
Returns the value of input_source, or the default value if input_source is unset.
Sourcepub fn round_timestamp(&self) -> i64
pub fn round_timestamp(&self) -> i64
Returns the value of round_timestamp, or the default value if round_timestamp is unset.