SupAccountBasicInfo

Struct SupAccountBasicInfo 

pub struct SupAccountBasicInfo {
    pub account_id: Option<u64>,
    pub account_card_no: Option<String>,
    pub intra_account_id: Option<u32>,
    pub nn_uid: Option<u64>,
    pub trade_account: Option<String>,
    pub real_name: Option<String>,
    pub is_online: Option<bool>,
    pub state: Option<u32>,
    pub type: Option<u32>,
    pub id_card: Option<String>,
}

Fields

account_id: Option<u64>

业务账户ID

account_card_no: Option<String>

业务账户卡号, 用于展示

intra_account_id: Option<u32>

内部业务账户ID, 用于展示

nn_uid: Option<u64>

用户牛牛号

trade_account: Option<String>

账户名

real_name: Option<String>

真是姓名

is_online: Option<bool>

是否在线

state: Option<u32>

账户状态, 取值参考 AccountState

type: Option<u32>

账户类型, 取值参考 AccountType

id_card: Option<String>

身份证号码

Implementations

Source

impl SupAccountBasicInfo

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn account_card_no(&self) -> &str

Returns the value of account_card_no, or the default value if account_card_no is unset.

pub fn intra_account_id(&self) -> u32

Returns the value of intra_account_id, or the default value if intra_account_id is unset.

pub fn nn_uid(&self) -> u64

Returns the value of nn_uid, or the default value if nn_uid is unset.

pub fn trade_account(&self) -> &str

Returns the value of trade_account, or the default value if trade_account is unset.

pub fn real_name(&self) -> &str

Returns the value of real_name, or the default value if real_name is unset.

pub fn is_online(&self) -> bool

Returns the value of is_online, or the default value if is_online is unset.

pub fn state(&self) -> u32

Returns the value of state, or the default value if state is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn id_card(&self) -> &str

Returns the value of id_card, or the default value if id_card is unset.