SupMarginInfo

Struct SupMarginInfo 

pub struct SupMarginInfo {
Show 15 fields pub long_power: Option<String>, pub short_power: Option<String>, pub balance: Option<String>, pub mv: Option<String>, pub elv: Option<String>, pub im: Option<String>, pub mcm: Option<String>, pub mm: Option<String>, pub im_balance: Option<String>, pub mcm_balance: Option<String>, pub mm_balance: Option<String>, pub im_recover: Option<String>, pub elv_mv_ratio: Option<f64>, pub risk_level: Option<u32>, pub margin_call_days: Option<i32>,
}

Fields

long_power: Option<String>short_power: Option<String>balance: Option<String>mv: Option<String>elv: Option<String>im: Option<String>mcm: Option<String>mm: Option<String>im_balance: Option<String>

可用资金

mcm_balance: Option<String>

margin_call剩余

mm_balance: Option<String>

剩余流动性

im_recover: Option<String>

追收保证金

elv_mv_ratio: Option<f64>

净资产市值占比

risk_level: Option<u32>

风险级别类型, 取值参考 SupRiskLevel

margin_call_days: Option<i32>

产生margin_call持续天数

Implementations

Source

impl SupMarginInfo

pub fn long_power(&self) -> &str

Returns the value of long_power, or the default value if long_power is unset.

pub fn short_power(&self) -> &str

Returns the value of short_power, or the default value if short_power is unset.

pub fn balance(&self) -> &str

Returns the value of balance, or the default value if balance is unset.

pub fn mv(&self) -> &str

Returns the value of mv, or the default value if mv is unset.

pub fn elv(&self) -> &str

Returns the value of elv, or the default value if elv is unset.

pub fn im(&self) -> &str

Returns the value of im, or the default value if im is unset.

pub fn mcm(&self) -> &str

Returns the value of mcm, or the default value if mcm is unset.

pub fn mm(&self) -> &str

Returns the value of mm, or the default value if mm is unset.

pub fn im_balance(&self) -> &str

Returns the value of im_balance, or the default value if im_balance is unset.

pub fn mcm_balance(&self) -> &str

Returns the value of mcm_balance, or the default value if mcm_balance is unset.

pub fn mm_balance(&self) -> &str

Returns the value of mm_balance, or the default value if mm_balance is unset.

pub fn im_recover(&self) -> &str

Returns the value of im_recover, or the default value if im_recover is unset.

pub fn elv_mv_ratio(&self) -> f64

Returns the value of elv_mv_ratio, or the default value if elv_mv_ratio is unset.

pub fn risk_level(&self) -> u32

Returns the value of risk_level, or the default value if risk_level is unset.

pub fn margin_call_days(&self) -> i32

Returns the value of margin_call_days, or the default value if margin_call_days is unset.