pub struct TradeStatisticInfo {
pub date: Option<f64>,
pub open_balance: Option<String>,
pub open_mv: Option<String>,
pub order_fill_cnt: Option<String>,
pub turnover: Option<String>,
pub profit: Option<String>,
pub profit_ratio: Option<String>,
}Fields
date: Option<f64>时间戳,单位秒
open_balance: Option<String>开盘前现金结余
open_mv: Option<String>开盘前股票市值
order_fill_cnt: Option<String>今日成交笔数
turnover: Option<String>今日成交总额
profit: Option<String>今日总盈亏
profit_ratio: Option<String>今日盈亏比例
Implementations
Sourceimpl TradeStatisticInfo
impl TradeStatisticInfo
Sourcepub fn open_balance(&self) -> &str
pub fn open_balance(&self) -> &str
Returns the value of open_balance, or the default value if open_balance is unset.
Sourcepub fn open_mv(&self) -> &str
pub fn open_mv(&self) -> &str
Returns the value of open_mv, or the default value if open_mv is unset.
Sourcepub fn order_fill_cnt(&self) -> &str
pub fn order_fill_cnt(&self) -> &str
Returns the value of order_fill_cnt, or the default value if order_fill_cnt is unset.
Sourcepub fn turnover(&self) -> &str
pub fn turnover(&self) -> &str
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn profit(&self) -> &str
pub fn profit(&self) -> &str
Returns the value of profit, or the default value if profit is unset.
Sourcepub fn profit_ratio(&self) -> &str
pub fn profit_ratio(&self) -> &str
Returns the value of profit_ratio, or the default value if profit_ratio is unset.