pub struct GetOptionSpreadListReq {
pub strategy: Option<i32>,
pub stock_id: Option<u64>,
pub strike_date: Option<u64>,
pub expiration: Option<u32>,
pub strike_date_item: Vec<NewStrikeDateItem>,
}Expand description
CMD 6735: 查询期权策略有效价差列表。
Fields
strategy: Option<i32>stock_id: Option<u64>strike_date: Option<u64>expiration: Option<u32>strike_date_item: Vec<NewStrikeDateItem>Implementations
Sourceimpl GetOptionSpreadListReq
impl GetOptionSpreadListReq
Sourcepub fn strategy(&self) -> i32
pub fn strategy(&self) -> i32
Returns the value of strategy, or the default value if strategy is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn strike_date(&self) -> u64
pub fn strike_date(&self) -> u64
Returns the value of strike_date, or the default value if strike_date is unset.
Sourcepub fn expiration(&self) -> u32
pub fn expiration(&self) -> u32
Returns the value of expiration, or the default value if expiration is unset.