pub struct OrderCloseInfo {
pub strategy: Option<i32>,
pub order_side: Option<i32>,
pub quantity: Option<String>,
}Fields
strategy: Option<i32>order_side: Option<i32>quantity: Option<String>Implementations
Sourceimpl OrderCloseInfo
impl OrderCloseInfo
Sourcepub fn strategy(&self) -> OptionStrategyType
pub fn strategy(&self) -> OptionStrategyType
Returns the enum value of strategy, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_strategy(&mut self, value: OptionStrategyType)
pub fn set_strategy(&mut self, value: OptionStrategyType)
Sets strategy to the provided enum value.
Sourcepub fn order_side(&self) -> OrderSide
pub fn order_side(&self) -> OrderSide
Returns the enum value of order_side, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_order_side(&mut self, value: OrderSide)
pub fn set_order_side(&mut self, value: OrderSide)
Sets order_side to the provided enum value.