pub struct BatchQueryOrderFeeRsp {
pub err_code: i32,
pub err_msg: String,
pub latest_date: i32,
pub total: u32,
pub page_index: u32,
pub page_size: u32,
pub order_fee_list: Vec<OrderFee>,
}Fields
err_code: i320成功,其他失败
err_msg: String错误信息
latest_date: i32svr中关于该market的最新入库订单日期
total: u32满足要求的订单数量
page_index: u32从0开始
page_size: u32默认1000
order_fee_list: Vec<OrderFee>Trait Implementations
Sourceimpl Clone for BatchQueryOrderFeeRsp
impl Clone for BatchQueryOrderFeeRsp
Sourcefn clone(&self) -> BatchQueryOrderFeeRsp
fn clone(&self) -> BatchQueryOrderFeeRsp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchQueryOrderFeeRsp
impl Debug for BatchQueryOrderFeeRsp
Sourceimpl Default for BatchQueryOrderFeeRsp
impl Default for BatchQueryOrderFeeRsp
Sourceimpl Message for BatchQueryOrderFeeRsp
impl Message for BatchQueryOrderFeeRsp
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BatchQueryOrderFeeRsp
impl PartialEq for BatchQueryOrderFeeRsp
impl StructuralPartialEq for BatchQueryOrderFeeRsp