BatchCloseInfo

Struct BatchCloseInfo 

pub struct BatchCloseInfo {
    pub order_type: Option<u32>,
    pub order_side: Option<u32>,
    pub symbol: Option<String>,
    pub exchange_code: Option<u32>,
    pub qty: Option<String>,
    pub security_type: Option<u32>,
    pub enable_ba_trade: Option<u32>,
    pub time_in_force: Option<u32>,
    pub price_type: Option<u32>,
    pub exchange: Option<String>,
}

Fields

order_type: Option<u32>

取值参考 OrderType,若填充的是市价单,品种不支持的由svr转成限价单

order_side: Option<u32>

取值参考 Side,客户端填充SIDE_BUY或SIDE_SELL,SIDE_BUY的svr会自动转为SIDE_BUY_BACK

symbol: Option<String>exchange_code: Option<u32>

期货所属交易所代码, 从行情获得,【期货】必填

qty: Option<String>

下单数量

security_type: Option<u32>

指定交易品种

enable_ba_trade: Option<u32>

【美股】是否允许盘前盘后时段生效;【港股】是否允许盘前竞价提交。港美股填允许,A股通新股填不允许。取值参考EnableBATradeType

time_in_force: Option<u32>

订单期限,取值参考OrderTimeInForce

price_type: Option<u32>

对价或最新价格,取值参考 PriceType, 目前期货/股票平仓用到

exchange: Option<String>

交易所

Implementations

Source

impl BatchCloseInfo

pub fn order_type(&self) -> u32

Returns the value of order_type, or the default value if order_type is unset.

pub fn order_side(&self) -> u32

Returns the value of order_side, or the default value if order_side is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn enable_ba_trade(&self) -> u32

Returns the value of enable_ba_trade, or the default value if enable_ba_trade is unset.

pub fn time_in_force(&self) -> u32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn price_type(&self) -> u32

Returns the value of price_type, or the default value if price_type is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.