HistoryOrderListReq

Struct HistoryOrderListReq 

pub struct HistoryOrderListReq {
Show 20 fields pub msg_header: Option<MsgHeader>, pub page_flag: Option<String>, pub symbol: Option<String>, pub time_begin: Option<u64>, pub time_end: Option<u64>, pub page_size: Option<u32>, pub side: Option<u32>, pub order_flag: Option<u32>, pub security_type: Vec<u32>, pub order_type: Vec<u32>, pub trade_type: Vec<u32>, pub order_status: Vec<u32>, pub query_word: Option<String>, pub ex_destination: Option<u32>, pub for_trigger: Option<u32>, pub market: Vec<u32>, pub date_begin: Option<u32>, pub date_end: Option<u32>, pub currency: Vec<i32>, pub show_related_order: Option<bool>,
}
历史查询单独协议处理 原因: 历史数据以后会单独存储, 可能查询耗时会更长, 当前活跃订单需要快速查询 repeated字段不填表示全选, 目前产品不能多选, 所以后台实现只读第一个, 为兼容以后可能改为多选特设为repeated字段

Fields

msg_header: Option<MsgHeader>page_flag: Option<String>

空, 表示从头开始, 否则使用返回server返回的page_flag

symbol: Option<String>

获取指定symbol的订单列表, 不指定->获取全部

time_begin: Option<u64>

time_begin < time_end, 单位微秒

time_end: Option<u64>page_size: Option<u32>

分页大小,如果不传的话,返回默认个数50

side: Option<u32>

取值参考odr_sys_cmn.Side

order_flag: Option<u32>

deprecated, 不传默认是所有订单,0也表示所有历史订单,1表示有成交的订单, 新的客户端使用order_status。

security_type: Vec<u32>

路由用途, 目前没用

order_type: Vec<u32>

HistoryOrderType

trade_type: Vec<u32>

HistoryTradeType

order_status: Vec<u32>

HistoryOrderStatus 替代order_flag字段。

query_word: Option<String>

模糊查询

ex_destination: Option<u32>

根据期货市场过滤,空或者0-不过滤、205-港期、206-CME。参考odr_sys_cmn.ExDestination

for_trigger: Option<u32>

0: 拉普通单,2:拉普通单+扩展订单(止损、止盈等)

market: Vec<u32>

筛选查询订单所属市场

date_begin: Option<u32>

开始日期 例:2021年1月1日填充 20210101

date_end: Option<u32>

结束日期 例:2021年1月1日填充 20210101

currency: Vec<i32>

货币单位,取值看odr_sys_cmn.Currency

show_related_order: Option<bool>

是否返回订单组的其他关联订单,不传则默认(为true)要返回

Implementations

Source

impl HistoryOrderListReq

pub fn page_flag(&self) -> &str

Returns the value of page_flag, or the default value if page_flag is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn time_begin(&self) -> u64

Returns the value of time_begin, or the default value if time_begin is unset.

pub fn time_end(&self) -> u64

Returns the value of time_end, or the default value if time_end is unset.

pub fn page_size(&self) -> u32

Returns the value of page_size, or the default value if page_size is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn order_flag(&self) -> u32

Returns the value of order_flag, or the default value if order_flag is unset.

pub fn query_word(&self) -> &str

Returns the value of query_word, or the default value if query_word is unset.

pub fn ex_destination(&self) -> u32

Returns the value of ex_destination, or the default value if ex_destination is unset.

pub fn for_trigger(&self) -> u32

Returns the value of for_trigger, or the default value if for_trigger is unset.

pub fn date_begin(&self) -> u32

Returns the value of date_begin, or the default value if date_begin is unset.

pub fn date_end(&self) -> u32

Returns the value of date_end, or the default value if date_end is unset.

Returns the value of show_related_order, or the default value if show_related_order is unset.