MaxBuySellReq

Struct MaxBuySellReq 

pub struct MaxBuySellReq {
Show 18 fields pub msg_header: Option<MsgHeader>, pub order_type: Option<u32>, pub symbol: Option<String>, pub price: Option<String>, pub order_id: Option<String>, pub is_odd_lot: Option<bool>, pub exchange_code: Option<u32>, pub scene_type: Option<i32>, pub force_pull: Option<bool>, pub exchange: Option<String>, pub nn_uid: Option<u64>, pub order_trade_time_type: Option<u32>, pub crypto_base_info: Option<CryptoBaseInfo>, pub quantity: Option<String>, pub is_cash_order: Option<bool>, pub position_id: Option<String>, pub long_sub_acct_id: Option<u64>, pub short_sub_acct_id: Option<u64>,
}
最大可买可卖接口已转交给风控

Fields

msg_header: Option<MsgHeader>order_type: Option<u32>

取值参考 OrderType

symbol: Option<String>

futu_symbol 如:AAPL、HSI2311。对于港股A股客户端及PCROA为00700、000100

price: Option<String>order_id: Option<String>

如果是改单, 需要填入order_id

is_odd_lot: Option<bool>

A股, 港股, 是否碎股

exchange_code: Option<u32>

期货所属交易所代码, 从行情获得,改单不需要填,【期货】【全能账户】尽量填(改单不需要填)

scene_type: Option<i32>

请求触发场景,取值参考 SceneType

force_pull: Option<bool>

是否强制拉取,强制拉取的请求不做流控

exchange: Option<String>

从行情获得,【期货】【全能账户】优先填(改单不需要填)。

nn_uid: Option<u64>

exchange和exchange_code至少保证填一个 exchange和exchange_code尽量两个都填,此时以exchange为准

牛牛号(授权账号 要传最终的父账号 例子:A牛牛号授权的B牛牛号,要传A牛牛号)

order_trade_time_type: Option<u32>

订单交易时段类型,参考OrderTradeTimeType,美股优先级高于odr_enable_ba_trade与hk_enable_ba_trade

crypto_base_info: Option<CryptoBaseInfo>

数字货币相关信息

quantity: Option<String>

交易数量

is_cash_order: Option<bool>
是否金额单
position_id: Option<String>

jp 两融场景 持仓id ;jp 日股期权,平仓需要传

long_sub_acct_id: Option<u64>

jp信用:long 子账户id ;用于开仓 计算 买开数量

short_sub_acct_id: Option<u64>

jp信用:short 子账户id; 用于开仓 计算 卖开sellShort数量

Implementations

Source

impl MaxBuySellReq

pub fn order_type(&self) -> u32

Returns the value of order_type, or the default value if order_type is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn is_odd_lot(&self) -> bool

Returns the value of is_odd_lot, or the default value if is_odd_lot is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn scene_type(&self) -> i32

Returns the value of scene_type, or the default value if scene_type is unset.

pub fn force_pull(&self) -> bool

Returns the value of force_pull, or the default value if force_pull is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn nn_uid(&self) -> u64

Returns the value of nn_uid, or the default value if nn_uid is unset.

pub fn order_trade_time_type(&self) -> u32

Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.

pub fn quantity(&self) -> &str

Returns the value of quantity, or the default value if quantity is unset.

pub fn is_cash_order(&self) -> bool

Returns the value of is_cash_order, or the default value if is_cash_order is unset.

pub fn position_id(&self) -> &str

Returns the value of position_id, or the default value if position_id is unset.

pub fn long_sub_acct_id(&self) -> u64

Returns the value of long_sub_acct_id, or the default value if long_sub_acct_id is unset.

pub fn short_sub_acct_id(&self) -> u64

Returns the value of short_sub_acct_id, or the default value if short_sub_acct_id is unset.