ReversingTradeReq

Struct ReversingTradeReq 

pub struct ReversingTradeReq {
    pub msg_header: Option<MsgHeader>,
    pub order_type: Option<u32>,
    pub order_side: Option<u32>,
    pub symbol: Option<String>,
    pub qty: Option<String>,
    pub price: Option<String>,
    pub text: Option<String>,
    pub exchange_code: Option<u32>,
    pub price_type: Option<u32>,
    pub first_order_price_type: Option<u32>,
    pub exchange: Option<String>,
}
反手

Fields

msg_header: Option<MsgHeader>order_type: Option<u32>

取值参考 OrderType

order_side: Option<u32>

取值参考 Side

symbol: Option<String>qty: Option<String>

普通单下单数量

price: Option<String>

普通单下单价格,客户端未填svr会根据first_order_price_type取价格 (市价单、竞价市价单不填)

text: Option<String>

可见字符, 最长100字节, server不根据此字段做任何逻辑, 只存储+校验

exchange_code: Option<u32>

期货所属交易所代码, 从行情获得,【期货】必填

price_type: Option<u32>

对价或最新价格,第2比订单下单需要使用,取值参考 PriceType

first_order_price_type: Option<u32>

第1比订单下单的价格类型,对价或最新价格,取值参考 PriceType

exchange: Option<String>

Implementations

Source

impl ReversingTradeReq

pub fn order_type(&self) -> u32

Returns the value of order_type, or the default value if order_type is unset.

pub fn order_side(&self) -> u32

Returns the value of order_side, or the default value if order_side is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn price_type(&self) -> u32

Returns the value of price_type, or the default value if price_type is unset.

pub fn first_order_price_type(&self) -> u32

Returns the value of first_order_price_type, or the default value if first_order_price_type is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.