RoaRiskAccount

Struct RoaRiskAccount 

pub struct RoaRiskAccount {
    pub nn_uid: Option<u64>,
    pub account_id: Option<u64>,
    pub is_unified: Option<u32>,
    pub order_type: Option<i32>,
    pub symbol: Option<String>,
    pub exchange_code: Option<i32>,
    pub exchange: Option<String>,
}
风控账户信息

Fields

nn_uid: Option<u64>

统一大账户ID,表示平大账号下所有子账号的订单。is_unified非0有效

account_id: Option<u64>

独立子账户ID,非统一大账户时需要。包含market的。is_unified为0有效

is_unified: Option<u32>

选择上面两个账号。非0:大账户,0:独立账户

order_type: Option<i32>

1=限价单,2=竞价单

symbol: Option<String>exchange_code: Option<i32>

交易所代码,跟symbol关联指定唯一股票/合约。详情参考行情market_id.h

exchange: Option<String>

股票所属交易所

Implementations

Source

impl RoaRiskAccount

pub fn nn_uid(&self) -> u64

Returns the value of nn_uid, or the default value if nn_uid is unset.

pub fn account_id(&self) -> u64

Returns the value of account_id, or the default value if account_id is unset.

pub fn is_unified(&self) -> u32

Returns the value of is_unified, or the default value if is_unified is unset.

pub fn order_type(&self) -> i32

Returns the value of order_type, or the default value if order_type is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn exchange_code(&self) -> i32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.