pub struct RollingPstnReq {
pub msg_header: Option<MsgHeader>,
pub order_type: Option<u32>,
pub order_side: Option<u32>,
pub symbol: Option<String>,
pub qty: Option<String>,
pub price: Option<String>,
pub text: Option<String>,
pub exchange_code: Option<u32>,
pub rolling_pstn_info: Option<RollingPstnInfo>,
pub exchange: Option<String>,
}Fields
msg_header: Option<MsgHeader>order_type: Option<u32>取值参考 OrderType
order_side: Option<u32>取值参考 Side
symbol: Option<String>qty: Option<String>普通单下单数量
price: Option<String>普通单下单价格,如果客户端不填svr会取对手价 (市价单、竞价市价单不填)
text: Option<String>可见字符, 最长100字节, server不根据此字段做任何逻辑, 只存储+校验
exchange_code: Option<u32>期货所属交易所代码, 从行情获得,【期货】必填
rolling_pstn_info: Option<RollingPstnInfo>移仓相关信息
exchange: Option<String>Implementations
Sourceimpl RollingPstnReq
impl RollingPstnReq
Sourcepub fn order_type(&self) -> u32
pub fn order_type(&self) -> u32
Returns the value of order_type, or the default value if order_type is unset.
Sourcepub fn order_side(&self) -> u32
pub fn order_side(&self) -> u32
Returns the value of order_side, or the default value if order_side is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn exchange_code(&self) -> u32
pub fn exchange_code(&self) -> u32
Returns the value of exchange_code, or the default value if exchange_code is unset.