pub struct InstitutionHolderRsp {
pub ret_code: Option<i32>,
pub stock_id: Option<u64>,
pub market: Option<i32>,
pub message: Option<String>,
pub update_time: Option<u64>,
pub institution_holder_item: Vec<InstitutionHolderItem>,
pub have_more: Option<u64>,
}Fields
ret_code: Option<i32>stock_id: Option<u64>market: Option<i32>message: Option<String>update_time: Option<u64>institution_holder_item: Vec<InstitutionHolderItem>have_more: Option<u64>Implementations
Sourceimpl InstitutionHolderRsp
impl InstitutionHolderRsp
Sourcepub fn ret_code(&self) -> i32
pub fn ret_code(&self) -> i32
Returns the value of ret_code, or the default value if ret_code is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn market(&self) -> i32
pub fn market(&self) -> i32
Returns the value of market, or the default value if market is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn update_time(&self) -> u64
pub fn update_time(&self) -> u64
Returns the value of update_time, or the default value if update_time is unset.