OwnershipDetailReq

Struct OwnershipDetailReq 

pub struct OwnershipDetailReq {
    pub stock_id: Option<u64>,
    pub market: Option<i32>,
    pub request_type: Option<i32>,
    pub start: Option<i32>,
    pub num: Option<i32>,
    pub sort_column: Option<i32>,
    pub sort_type: Option<i32>,
    pub include_request_types: Vec<i32>,
    pub exclude_request_types: Vec<i32>,
    pub period_id: Option<i32>,
    pub owner_object_id: Option<i32>,
    pub key_word: Option<String>,
}

Fields

stock_id: Option<u64>market: Option<i32>request_type: Option<i32>start: Option<i32>num: Option<i32>sort_column: Option<i32>sort_type: Option<i32>include_request_types: Vec<i32>exclude_request_types: Vec<i32>period_id: Option<i32>owner_object_id: Option<i32>key_word: Option<String>

Implementations

Source

impl OwnershipDetailReq

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn market(&self) -> i32

Returns the value of market, or the default value if market is unset.

pub fn request_type(&self) -> i32

Returns the value of request_type, or the default value if request_type is unset.

pub fn start(&self) -> i32

Returns the value of start, or the default value if start is unset.

pub fn num(&self) -> i32

Returns the value of num, or the default value if num is unset.

pub fn sort_column(&self) -> i32

Returns the value of sort_column, or the default value if sort_column is unset.

pub fn sort_type(&self) -> i32

Returns the value of sort_type, or the default value if sort_type is unset.

pub fn period_id(&self) -> i32

Returns the value of period_id, or the default value if period_id is unset.

pub fn owner_object_id(&self) -> i32

Returns the value of owner_object_id, or the default value if owner_object_id is unset.

pub fn key_word(&self) -> &str

Returns the value of key_word, or the default value if key_word is unset.