pub struct OwnershipDetailRsp {
pub ret_code: Option<i32>,
pub stock_id: Option<u64>,
pub market: Option<i32>,
pub response_type: Option<i32>,
pub message: Option<String>,
pub update_time: Option<u64>,
pub ownership_detail_item: Vec<OwnershipDetailItem>,
pub total_num: Option<u64>,
pub owner_object_id: Option<i32>,
}Fields
ret_code: Option<i32>stock_id: Option<u64>market: Option<i32>response_type: Option<i32>message: Option<String>update_time: Option<u64>ownership_detail_item: Vec<OwnershipDetailItem>total_num: Option<u64>owner_object_id: Option<i32>Implementations
Sourceimpl OwnershipDetailRsp
impl OwnershipDetailRsp
Sourcepub fn ret_code(&self) -> i32
pub fn ret_code(&self) -> i32
Returns the value of ret_code, or the default value if ret_code is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn market(&self) -> i32
pub fn market(&self) -> i32
Returns the value of market, or the default value if market is unset.
Sourcepub fn response_type(&self) -> i32
pub fn response_type(&self) -> i32
Returns the value of response_type, or the default value if response_type is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn update_time(&self) -> u64
pub fn update_time(&self) -> u64
Returns the value of update_time, or the default value if update_time is unset.
Sourcepub fn total_num(&self) -> u64
pub fn total_num(&self) -> u64
Returns the value of total_num, or the default value if total_num is unset.
Sourcepub fn owner_object_id(&self) -> i32
pub fn owner_object_id(&self) -> i32
Returns the value of owner_object_id, or the default value if owner_object_id is unset.