#[repr(i32)]pub enum AuthStateDiffReason {
ERsnNone = 0,
ERsnIpAreaNotMatch = 1,
ERsnMultiClt = 2,
ERsnCltReq = 3,
ERsnGetCardFail = 4,
}Expand description
客户拥有的权限和本次登录权限不一致的原因
Variants
ERsnNone = 0
ERsnIpAreaNotMatch = 1
登录区域限制
ERsnMultiClt = 2
多终端登录
ERsnCltReq = 3
客户端主动请求低权限
ERsnGetCardFail = 4
获取免费行情卡失败
Implementations
Sourceimpl AuthStateDiffReason
impl AuthStateDiffReason
Sourcepub fn from_i32(value: i32) -> Option<AuthStateDiffReason>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<AuthStateDiffReason>
Converts an i32 to a AuthStateDiffReason, or None if value is not a valid variant.
Sourceimpl AuthStateDiffReason
impl AuthStateDiffReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.