#[repr(i32)]pub enum CltQut {
HkLv2 = 1,
HkBmp = 2,
HkLv1 = 3,
HkSf = 4,
UsOvernigthNone = 0,
}Expand description
客户端使用的行情权限取值
Variants
Implementations
Sourceimpl CltQut
impl CltQut
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.