#[repr(i32)]pub enum CommonCltQut {
None = 0,
Delay = 1,
Rt = 2,
Lv2 = 3,
Lv3 = 4,
}Expand description
后续新增权限位使用公共结构体
Variants
Implementations
Sourceimpl CommonCltQut
impl CommonCltQut
Sourceimpl CommonCltQut
impl CommonCltQut
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.