#[repr(i32)]pub enum HighQtaAuthType {
ExerciseProbabilityOfOption = 1,
PlDiagramOfCombinedOption = 2,
StockFinanciAlanalysis = 3,
KlineShape = 4,
FeaturedIndicatorScreener = 5,
VolatilityAnalysisOfOption = 6,
}Variants
ExerciseProbabilityOfOption = 1
期权行权概率权限
PlDiagramOfCombinedOption = 2
期权损益图(组合)
StockFinanciAlanalysis = 3
个股财务解读
KlineShape = 4
K线形态
FeaturedIndicatorScreener = 5
特色选股
VolatilityAnalysisOfOption = 6
期权波动率分析
Implementations
Sourceimpl HighQtaAuthType
impl HighQtaAuthType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.