#[repr(i32)]pub enum UsAuthRule {
EUsAuthRuleDefault = 1,
EUsAuthRulePaidUtp = 2,
EUsAuthRuleOtherUtp = 3,
}Expand description
美股权限分配所依赖的策略
Variants
Implementations
Sourceimpl UsAuthRule
impl UsAuthRule
Sourceimpl UsAuthRule
impl UsAuthRule
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.