RatingDetail

Struct RatingDetail 

pub struct RatingDetail {
    pub stock_id: Option<u64>,
    pub rating: Option<i32>,
    pub total: Option<i32>,
    pub strong_buy: Option<i32>,
    pub hold: Option<i32>,
    pub sell: Option<i32>,
    pub update_time: Option<i64>,
    pub buy: Option<i32>,
    pub underperform: Option<i32>,
}

Fields

stock_id: Option<u64>rating: Option<i32>total: Option<i32>strong_buy: Option<i32>hold: Option<i32>sell: Option<i32>update_time: Option<i64>buy: Option<i32>underperform: Option<i32>

Implementations

Source

impl RatingDetail

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn rating(&self) -> i32

Returns the value of rating, or the default value if rating is unset.

pub fn total(&self) -> i32

Returns the value of total, or the default value if total is unset.

pub fn strong_buy(&self) -> i32

Returns the value of strong_buy, or the default value if strong_buy is unset.

pub fn hold(&self) -> i32

Returns the value of hold, or the default value if hold is unset.

pub fn sell(&self) -> i32

Returns the value of sell, or the default value if sell is unset.

pub fn update_time(&self) -> i64

Returns the value of update_time, or the default value if update_time is unset.

pub fn buy(&self) -> i32

Returns the value of buy, or the default value if buy is unset.

pub fn underperform(&self) -> i32

Returns the value of underperform, or the default value if underperform is unset.