#[repr(i32)]pub enum Market {
Hk = 1,
Us = 2,
HkccStock = 4,
Future = 5,
Sg = 6,
Fx = 9,
Hkfund = 13,
Usfund = 23,
}Expand description
交易市场
Variants
Hk = 1
港股市场
Us = 2
美股市场
HkccStock = 4
A 股通市场
Future = 5
期货市场
Sg = 6
新加坡市场
Fx = 9
外汇
Hkfund = 13
港币基金
Usfund = 23
美元基金
Implementations
Sourceimpl Market
impl Market
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.