pub struct Detail {
pub title: Option<String>,
pub value: Option<String>,
pub url: Option<String>,
pub old_value: Option<String>,
pub icon_url_id: Option<String>,
pub type_id: Option<u32>,
}Fields
title: Option<String>key
value: Option<String>项目值
url: Option<String>外部超链接
old_value: Option<String>原始项目值
icon_url_id: Option<String>icon 超链接 id
type_id: Option<u32>客户端上报类型 id
Implementations
Sourceimpl Detail
impl Detail
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the value of value, or the default value if value is unset.
Sourcepub fn old_value(&self) -> &str
pub fn old_value(&self) -> &str
Returns the value of old_value, or the default value if old_value is unset.
Sourcepub fn icon_url_id(&self) -> &str
pub fn icon_url_id(&self) -> &str
Returns the value of icon_url_id, or the default value if icon_url_id is unset.