pub struct GetCashLogReq {Show 14 fields
pub market: Option<u32>,
pub account_id: Option<u64>,
pub biz_group_id: Option<u32>,
pub in_out: Option<u32>,
pub begin_time: Option<u64>,
pub end_time: Option<u64>,
pub need_stock_name: Option<bool>,
pub log_id: Option<String>,
pub max_cnt: Option<u32>,
pub keyword: Option<String>,
pub biz_sub_group_id: Option<u32>,
pub currency: Option<String>,
pub symbol: Option<String>,
pub stock_id: Option<u64>,
}Expand description
获取资金流水 - 请求 (cmd: 3000)
Fields
market: Option<u32>Market enum
account_id: Option<u64>账户业务 id
biz_group_id: Option<u32>业务类型 id (默认全部)
in_out: Option<u32>资金流向 Side enum
begin_time: Option<u64>起始时间 (epoch 秒)
end_time: Option<u64>结束时间 (epoch 秒)
need_stock_name: Option<bool>是否返回股票名称
log_id: Option<String>上次返回的 next_log_id (cursor)
max_cnt: Option<u32>本次返回最多条数
keyword: Option<String>搜索关键词
biz_sub_group_id: Option<u32>二级业务类型 id (有此则忽略 biz_group_id)
currency: Option<String>货币代码 (CNY/HKD/USD/JPY/SGD)
symbol: Option<String>股票代码 (e.g. AAPL.US, 00700.HK)
stock_id: Option<u64>行情 stock_id (优先级最高)
Implementations
Sourceimpl GetCashLogReq
impl GetCashLogReq
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn biz_group_id(&self) -> u32
pub fn biz_group_id(&self) -> u32
Returns the value of biz_group_id, or the default value if biz_group_id is unset.
Sourcepub fn in_out(&self) -> u32
pub fn in_out(&self) -> u32
Returns the value of in_out, or the default value if in_out is unset.
Sourcepub fn begin_time(&self) -> u64
pub fn begin_time(&self) -> u64
Returns the value of begin_time, or the default value if begin_time is unset.
Sourcepub fn end_time(&self) -> u64
pub fn end_time(&self) -> u64
Returns the value of end_time, or the default value if end_time is unset.
Sourcepub fn need_stock_name(&self) -> bool
pub fn need_stock_name(&self) -> bool
Returns the value of need_stock_name, or the default value if need_stock_name is unset.
Sourcepub fn log_id(&self) -> &str
pub fn log_id(&self) -> &str
Returns the value of log_id, or the default value if log_id is unset.
Sourcepub fn max_cnt(&self) -> u32
pub fn max_cnt(&self) -> u32
Returns the value of max_cnt, or the default value if max_cnt is unset.
Sourcepub fn keyword(&self) -> &str
pub fn keyword(&self) -> &str
Returns the value of keyword, or the default value if keyword is unset.
Sourcepub fn biz_sub_group_id(&self) -> u32
pub fn biz_sub_group_id(&self) -> u32
Returns the value of biz_sub_group_id, or the default value if biz_sub_group_id is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.