pub struct ComboMaxBuySellReq {
pub client_account_id: Option<u64>,
pub items: Vec<ComboItem>,
pub quantity: Option<String>,
pub price: Option<String>,
pub side: Option<u32>,
pub order_id: Option<String>,
pub strategy_id: Option<u32>,
pub rollover_combo_id: Option<String>,
pub sub_account_id: Option<u64>,
pub notice_type: Option<u32>,
pub check_risk_increase: Option<bool>,
}Expand description
C++ 10.7: backend CMD 2297 ComboMaxBuySellReq.
Fields
client_account_id: Option<u64>items: Vec<ComboItem>quantity: Option<String>price: Option<String>side: Option<u32>order_id: Option<String>strategy_id: Option<u32>rollover_combo_id: Option<String>sub_account_id: Option<u64>notice_type: Option<u32>check_risk_increase: Option<bool>Implementations
Sourceimpl ComboMaxBuySellReq
impl ComboMaxBuySellReq
Sourcepub fn client_account_id(&self) -> u64
pub fn client_account_id(&self) -> u64
Returns the value of client_account_id, or the default value if client_account_id is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn strategy_id(&self) -> u32
pub fn strategy_id(&self) -> u32
Returns the value of strategy_id, or the default value if strategy_id is unset.
Sourcepub fn rollover_combo_id(&self) -> &str
pub fn rollover_combo_id(&self) -> &str
Returns the value of rollover_combo_id, or the default value if rollover_combo_id is unset.
Sourcepub fn sub_account_id(&self) -> u64
pub fn sub_account_id(&self) -> u64
Returns the value of sub_account_id, or the default value if sub_account_id is unset.
Sourcepub fn notice_type(&self) -> u32
pub fn notice_type(&self) -> u32
Returns the value of notice_type, or the default value if notice_type is unset.
Sourcepub fn check_risk_increase(&self) -> bool
pub fn check_risk_increase(&self) -> bool
Returns the value of check_risk_increase, or the default value if check_risk_increase is unset.