pub struct ComboMaxBuySellRsp {Show 19 fields
pub result: Option<i32>,
pub err_msg: Option<String>,
pub power: Option<String>,
pub power_auto_transfer: Option<String>,
pub overnight_power: Option<String>,
pub power_used: Option<String>,
pub overnight_power_used: Option<String>,
pub closeable_quantity: Option<String>,
pub pre_margin: Vec<OrderPreMarginV2Item>,
pub show_closeable_quantity: Option<bool>,
pub available_settled_cash: Option<String>,
pub required_im_long: Option<String>,
pub required_im_short: Option<String>,
pub cash_power: Option<String>,
pub cash_power_auto_transfer: Option<String>,
pub combo_order_im: Option<String>,
pub risk_increase_info: Option<RiskIncreaseInfo>,
pub is_high_leverage_user: Option<bool>,
pub auto_transfer_enable: Option<bool>,
}Expand description
C++ 10.7: backend CMD 2297 ComboMaxBuySellRsp.
Fields
result: Option<i32>err_msg: Option<String>power: Option<String>power_auto_transfer: Option<String>overnight_power: Option<String>power_used: Option<String>overnight_power_used: Option<String>closeable_quantity: Option<String>pre_margin: Vec<OrderPreMarginV2Item>show_closeable_quantity: Option<bool>available_settled_cash: Option<String>required_im_long: Option<String>required_im_short: Option<String>cash_power: Option<String>cash_power_auto_transfer: Option<String>combo_order_im: Option<String>risk_increase_info: Option<RiskIncreaseInfo>is_high_leverage_user: Option<bool>auto_transfer_enable: Option<bool>Implementations
Sourceimpl ComboMaxBuySellRsp
impl ComboMaxBuySellRsp
Sourcepub fn result(&self) -> i32
pub fn result(&self) -> i32
Returns the value of result, or the default value if result is unset.
Sourcepub fn err_msg(&self) -> &str
pub fn err_msg(&self) -> &str
Returns the value of err_msg, or the default value if err_msg is unset.
Sourcepub fn power(&self) -> &str
pub fn power(&self) -> &str
Returns the value of power, or the default value if power is unset.
Sourcepub fn power_used(&self) -> &str
pub fn power_used(&self) -> &str
Returns the value of power_used, or the default value if power_used is unset.
Sourcepub fn closeable_quantity(&self) -> &str
pub fn closeable_quantity(&self) -> &str
Returns the value of closeable_quantity, or the default value if closeable_quantity is unset.
Sourcepub fn show_closeable_quantity(&self) -> bool
pub fn show_closeable_quantity(&self) -> bool
Returns the value of show_closeable_quantity, or the default value if show_closeable_quantity is unset.
Sourcepub fn available_settled_cash(&self) -> &str
pub fn available_settled_cash(&self) -> &str
Returns the value of available_settled_cash, or the default value if available_settled_cash is unset.
Sourcepub fn required_im_long(&self) -> &str
pub fn required_im_long(&self) -> &str
Returns the value of required_im_long, or the default value if required_im_long is unset.
Sourcepub fn required_im_short(&self) -> &str
pub fn required_im_short(&self) -> &str
Returns the value of required_im_short, or the default value if required_im_short is unset.
Sourcepub fn cash_power(&self) -> &str
pub fn cash_power(&self) -> &str
Returns the value of cash_power, or the default value if cash_power is unset.
Sourcepub fn combo_order_im(&self) -> &str
pub fn combo_order_im(&self) -> &str
Returns the value of combo_order_im, or the default value if combo_order_im is unset.
Sourcepub fn overnight_power(&self) -> &str
pub fn overnight_power(&self) -> &str
Returns the value of overnight_power, or the default value if overnight_power is unset.
Sourcepub fn overnight_power_used(&self) -> &str
pub fn overnight_power_used(&self) -> &str
Returns the value of overnight_power_used, or the default value if overnight_power_used is unset.
Sourcepub fn is_high_leverage_user(&self) -> bool
pub fn is_high_leverage_user(&self) -> bool
Returns the value of is_high_leverage_user, or the default value if is_high_leverage_user is unset.
Sourcepub fn power_auto_transfer(&self) -> &str
pub fn power_auto_transfer(&self) -> &str
Returns the value of power_auto_transfer, or the default value if power_auto_transfer is unset.
Sourcepub fn cash_power_auto_transfer(&self) -> &str
pub fn cash_power_auto_transfer(&self) -> &str
Returns the value of cash_power_auto_transfer, or the default value if cash_power_auto_transfer is unset.
Sourcepub fn auto_transfer_enable(&self) -> bool
pub fn auto_transfer_enable(&self) -> bool
Returns the value of auto_transfer_enable, or the default value if auto_transfer_enable is unset.