MarginInfo

Struct MarginInfo 

pub struct MarginInfo {
Show 39 fields pub long_power: Option<String>, pub short_power: Option<String>, pub balance: Option<String>, pub market_value: Option<String>, pub elv: Option<String>, pub im: Option<String>, pub mcm: Option<String>, pub mm: Option<String>, pub im_balance: Option<String>, pub mcm_balance: Option<String>, pub mm_balance: Option<String>, pub im_recover: Option<String>, pub alerter_margin: Option<String>, pub alerter_margin_balance: Option<String>, pub elv_mv_ratio: Option<f64>, pub risk_level_type: Option<u32>, pub margin_call_days: Option<i32>, pub risk_status: Option<i32>, pub risk_status_client: Option<i32>, pub pstn_ratio: Option<String>, pub lever_multi: Option<String>, pub mm_balance_ratio: Option<String>, pub ibp: Option<String>, pub original_client_level: Option<u32>, pub original_risk_factor_client: Option<u32>, pub original_risk_level: Option<u32>, pub original_risk_status: Option<i32>, pub real_loan: Option<String>, pub loan_ratio: Option<String>, pub margin_value: Option<String>, pub margin_ratio: Option<String>, pub margin_init_ratio: Option<String>, pub margin_warn_ratio: Option<String>, pub margin_cover_ratio: Option<String>, pub regt_call_amount: Option<String>, pub is_high_leverage_user: Option<bool>, pub overnight_im: Option<String>, pub overnight_mm: Option<String>, pub overnight_mm_balance: Option<String>,
}
MarginInfo 全字段对齐 mobile risk_user_account_info.proto.

Fields

long_power: Option<String>

多头购买力

short_power: Option<String>

空头购买力

balance: Option<String>

账户余额

market_value: Option<String>

持仓市值

elv: Option<String>

账户净值 (当前权益)

im: Option<String>

当前初始保证金

mcm: Option<String>

margin call 保证金

mm: Option<String>

当前维持保证金

im_balance: Option<String>

初始保证金剩余额度

mcm_balance: Option<String>

margin call 保证金剩余额度

mm_balance: Option<String>

剩余流动性 (elv - mm)

im_recover: Option<String>

追缴保证金

alerter_margin: Option<String>

预警保证金

alerter_margin_balance: Option<String>

预警保证金剩余额度

elv_mv_ratio: Option<f64>

资产 / 市值 比例 (杠杆指标)

risk_level_type: Option<u32>

风险等级: SAFE=0 / MARGIN_CALL=1 / FORCE_CLOSE=2 / ALERT=3

margin_call_days: Option<i32>

连续 margin call 天数

risk_status: Option<i32>

账户状态码: 10/20/30=安全 / 41/42=较低 / 51/52=中等 / 61/62=偏高 / 70=预警 / 81-93=危险

risk_status_client: Option<i32>

客户端风险状态码

pstn_ratio: Option<String>

持仓占比

lever_multi: Option<String>

杠杆倍数

mm_balance_ratio: Option<String>

强平比例

ibp: Option<String>

入金授信购买力

original_client_level: Option<u32>

透传监察字段

original_risk_factor_client: Option<u32>

透传监察字段

original_risk_level: Option<u32>

透传监察字段

original_risk_status: Option<i32>

透传监察字段

real_loan: Option<String>

HK-specific (US/CN_AH 通常返空字符串)

实际借贷额, min(balance, 0)

loan_ratio: Option<String>

账户授信比

margin_value: Option<String>

港股股票保证金

margin_ratio: Option<String>

港股账户保证金比例

margin_init_ratio: Option<String>

初始保证金线

margin_warn_ratio: Option<String>

保证金警戒线

margin_cover_ratio: Option<String>

保证金平仓线

regt_call_amount: Option<String>

Reg-T call amount

is_high_leverage_user: Option<bool>

是否日内证券高杠杆客户组

overnight_im: Option<String>

隔夜初始保证金

overnight_mm: Option<String>

隔夜维持保证金

overnight_mm_balance: Option<String>

隔夜剩余流动性

Implementations

Source

impl MarginInfo

pub fn long_power(&self) -> &str

Returns the value of long_power, or the default value if long_power is unset.

pub fn short_power(&self) -> &str

Returns the value of short_power, or the default value if short_power is unset.

pub fn balance(&self) -> &str

Returns the value of balance, or the default value if balance is unset.

pub fn market_value(&self) -> &str

Returns the value of market_value, or the default value if market_value is unset.

pub fn elv(&self) -> &str

Returns the value of elv, or the default value if elv is unset.

pub fn im(&self) -> &str

Returns the value of im, or the default value if im is unset.

pub fn mcm(&self) -> &str

Returns the value of mcm, or the default value if mcm is unset.

pub fn mm(&self) -> &str

Returns the value of mm, or the default value if mm is unset.

pub fn im_balance(&self) -> &str

Returns the value of im_balance, or the default value if im_balance is unset.

pub fn mcm_balance(&self) -> &str

Returns the value of mcm_balance, or the default value if mcm_balance is unset.

pub fn mm_balance(&self) -> &str

Returns the value of mm_balance, or the default value if mm_balance is unset.

pub fn im_recover(&self) -> &str

Returns the value of im_recover, or the default value if im_recover is unset.

pub fn alerter_margin(&self) -> &str

Returns the value of alerter_margin, or the default value if alerter_margin is unset.

pub fn alerter_margin_balance(&self) -> &str

Returns the value of alerter_margin_balance, or the default value if alerter_margin_balance is unset.

pub fn elv_mv_ratio(&self) -> f64

Returns the value of elv_mv_ratio, or the default value if elv_mv_ratio is unset.

pub fn risk_level_type(&self) -> u32

Returns the value of risk_level_type, or the default value if risk_level_type is unset.

pub fn margin_call_days(&self) -> i32

Returns the value of margin_call_days, or the default value if margin_call_days is unset.

pub fn risk_status(&self) -> i32

Returns the value of risk_status, or the default value if risk_status is unset.

pub fn risk_status_client(&self) -> i32

Returns the value of risk_status_client, or the default value if risk_status_client is unset.

pub fn pstn_ratio(&self) -> &str

Returns the value of pstn_ratio, or the default value if pstn_ratio is unset.

pub fn lever_multi(&self) -> &str

Returns the value of lever_multi, or the default value if lever_multi is unset.

pub fn mm_balance_ratio(&self) -> &str

Returns the value of mm_balance_ratio, or the default value if mm_balance_ratio is unset.

pub fn ibp(&self) -> &str

Returns the value of ibp, or the default value if ibp is unset.

pub fn original_client_level(&self) -> u32

Returns the value of original_client_level, or the default value if original_client_level is unset.

pub fn original_risk_factor_client(&self) -> u32

Returns the value of original_risk_factor_client, or the default value if original_risk_factor_client is unset.

pub fn original_risk_level(&self) -> u32

Returns the value of original_risk_level, or the default value if original_risk_level is unset.

pub fn original_risk_status(&self) -> i32

Returns the value of original_risk_status, or the default value if original_risk_status is unset.

pub fn real_loan(&self) -> &str

Returns the value of real_loan, or the default value if real_loan is unset.

pub fn loan_ratio(&self) -> &str

Returns the value of loan_ratio, or the default value if loan_ratio is unset.

pub fn margin_value(&self) -> &str

Returns the value of margin_value, or the default value if margin_value is unset.

pub fn margin_ratio(&self) -> &str

Returns the value of margin_ratio, or the default value if margin_ratio is unset.

pub fn margin_init_ratio(&self) -> &str

Returns the value of margin_init_ratio, or the default value if margin_init_ratio is unset.

pub fn margin_warn_ratio(&self) -> &str

Returns the value of margin_warn_ratio, or the default value if margin_warn_ratio is unset.

pub fn margin_cover_ratio(&self) -> &str

Returns the value of margin_cover_ratio, or the default value if margin_cover_ratio is unset.

pub fn regt_call_amount(&self) -> &str

Returns the value of regt_call_amount, or the default value if regt_call_amount is unset.

pub fn is_high_leverage_user(&self) -> bool

Returns the value of is_high_leverage_user, or the default value if is_high_leverage_user is unset.

pub fn overnight_im(&self) -> &str

Returns the value of overnight_im, or the default value if overnight_im is unset.

pub fn overnight_mm(&self) -> &str

Returns the value of overnight_mm, or the default value if overnight_mm is unset.

pub fn overnight_mm_balance(&self) -> &str

Returns the value of overnight_mm_balance, or the default value if overnight_mm_balance is unset.