#[repr(i32)]pub enum OrderStatus {
PengdingNew = 1,
New = 2,
PartialFill = 3,
Fill = 4,
Cancelled = 5,
Rejected = 6,
PartialFillCancelled = 7,
Disable = 101,
WaitingNew = 102,
FillCancelled = 103,
Delete = 104,
}Variants
PengdingNew = 1
提交中
New = 2
已提交,等待成交
PartialFill = 3
部分成交
Fill = 4
全部成交
Cancelled = 5
全部已撤单,无成交
Rejected = 6
下单失败,服务拒绝
PartialFillCancelled = 7
部分成交,剩余已撤销
Disable = 101
已失效
WaitingNew = 102
等待提交
FillCancelled = 103
成交被撤销
Delete = 104
已删除
Implementations
Sourceimpl OrderStatus
impl OrderStatus
Sourceimpl OrderStatus
impl OrderStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.