Order

Struct Order 

pub struct Order {
Show 60 fields pub side: Option<u32>, pub market: Option<u32>, pub symbol: Option<String>, pub stock_name: Option<String>, pub order_id: Option<String>, pub type: Option<u32>, pub qty: Option<String>, pub cum_qty: Option<String>, pub leave_qty: Option<String>, pub price: Option<String>, pub avg_fill_price: Option<String>, pub creator_id_type: Option<u32>, pub creator_id: Option<u64>, pub nn_uid: Option<u64>, pub intra_account_id: Option<u64>, pub last_err_msg: Option<String>, pub create_time: Option<u64>, pub update_time: Option<u64>, pub status: Option<u32>, pub lot_type: Option<u32>, pub version: Option<u32>, pub currency: Option<u32>, pub sup: Option<OrderSup>, pub expire_time: Option<u64>, pub text: Option<String>, pub client_type: Option<u32>, pub client_version: Option<u32>, pub last_err: Option<i32>, pub security_type: Option<u32>, pub dark_pool: Option<u32>, pub order_show_type: Option<u32>, pub exdestination: Option<u32>, pub notice_msg: Option<String>, pub trigger_info: Option<TriggerInfo>, pub ba_trade_notice_msg: Option<String>, pub exchange_code: Option<u32>, pub group_id: Option<String>, pub relation_type: Option<i32>, pub notice_action: Option<OrderNoticeAction>, pub aux_price: Option<String>, pub disable_auto_short: Option<bool>, pub exec_time: Option<u64>, pub price_type: Option<u32>, pub order_show_id: Option<String>, pub fill_amount: Option<String>, pub order_amount: Option<String>, pub input_source: Option<u32>, pub exchange: Option<String>, pub algo_info: Option<AlgoInfo>, pub parent_order_id: Option<String>, pub order_group_id: Option<String>, pub group_type: Option<u32>, pub account_market: Option<u32>, pub multi_leg_info: Option<MultiLegInfo>, pub batch_id: Option<String>, pub forex_addition: Option<ForexAddition>, pub fix_session_id: Option<String>, pub bond_info: Option<BondInfo>, pub third_party_bcan: Option<String>, pub sub_account: Option<u32>,
}

Fields

side: Option<u32>

取值参考 Side

market: Option<u32>

取值参考 Market

symbol: Option<String>stock_name: Option<String>order_id: Option<String>

订单号, 生命周期内维持不变

type: Option<u32>

取值参考 OrderType

qty: Option<String>cum_qty: Option<String>

总已成交股数

leave_qty: Option<String>price: Option<String>avg_fill_price: Option<String>creator_id_type: Option<u32>

取值参考 CreatorIDType

creator_id: Option<u64>nn_uid: Option<u64>

该订单属于哪个牛牛号

intra_account_id: Option<u64>

注意跟clt传给server的不同

last_err_msg: Option<String>

废弃!!!使用notice_action返回信息展示

create_time: Option<u64>

单位微秒

update_time: Option<u64>

单位微秒

status: Option<u32>

取值参考 OrderStatus

lot_type: Option<u32>

取值参考 LotType

version: Option<u32>

版本号, 用来判断clt跟server的order是否同步

currency: Option<u32>

取值参考 Currency

sup: Option<OrderSup>expire_time: Option<u64>

真实订单过期时间戳(客户端暂时用不到这个,预留未来使用), 单位微秒

text: Option<String>

可见字符, 最长100字节, server不根据此字段做任何逻辑, 只存储+校验

client_type: Option<u32>

客户类型

client_version: Option<u32>

客户版本

last_err: Option<i32>

错误码

security_type: Option<u32>

交易品种 取值参考SecurityType

dark_pool: Option<u32>

暗盘类型,0:非暗盘 1:暗盘 else:暗盘

order_show_type: Option<u32>

订单显示标识,客户端根据这个字段决定在哪个列表显示,取值参考OrderShowType

exdestination: Option<u32>

上游券商 取值参考ExDestination

notice_msg: Option<String>

废弃!!!使用notice_action返回信息展示

trigger_info: Option<TriggerInfo>

废弃!!!

ba_trade_notice_msg: Option<String>

美股允许盘前盘后提示

exchange_code: Option<u32>

期货所属交易所代码

group_id: Option<String>

订单组id(期货快捷交易专用)

relation_type: Option<i32>

订单关系, 取值参考RelationType

notice_action: Option<OrderNoticeAction>

订单状态提醒

aux_price: Option<String>

止损价差

disable_auto_short: Option<bool>

是否禁止转方向(卖单->卖空 or 买单转buyback)

exec_time: Option<u64>

执行时间,触发时间,=0 表示监控中

price_type: Option<u32>

对价或最新价格,取值参考 PriceType, 目前期货条件单平仓用到

order_show_id: Option<String>

客户端展示的订单id

fill_amount: Option<String>

成交额,拉取历史订单使用

order_amount: Option<String>

订单金额

input_source: Option<u32>

请求源,OrderQueryService使用,客户端用于判断属于普通订单或者行权/指派订单,取值参考InputSourceType

exchange: Option<String>

股票所属交易所

algo_info: Option<AlgoInfo>

算法参数信息

parent_order_id: Option<String>

组订单父订单的order_id

order_group_id: Option<String>

组订单的group_id

group_type: Option<u32>

订单组类型,参考GroupType

account_market: Option<u32>

全能账户所属市场为6,其余同market

multi_leg_info: Option<MultiLegInfo>

多退订单组合信息

batch_id: Option<String>

批次id

forex_addition: Option<ForexAddition>

外汇订单字段

fix_session_id: Option<String>bond_info: Option<BondInfo>

债券相关信息

third_party_bcan: Option<String>

外部券商bcan 格式[CE_ID].[NUMBER] xxxxxx.123

sub_account: Option<u32>

【日本券商】口座, 见账户侧协议中Tags枚举(acc_info.proto)

Implementations

Source

impl Order

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn market(&self) -> u32

Returns the value of market, or the default value if market is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn order_id(&self) -> &str

Returns the value of order_id, or the default value if order_id is unset.

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn cum_qty(&self) -> &str

Returns the value of cum_qty, or the default value if cum_qty is unset.

pub fn leave_qty(&self) -> &str

Returns the value of leave_qty, or the default value if leave_qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn avg_fill_price(&self) -> &str

Returns the value of avg_fill_price, or the default value if avg_fill_price is unset.

pub fn creator_id_type(&self) -> u32

Returns the value of creator_id_type, or the default value if creator_id_type is unset.

pub fn creator_id(&self) -> u64

Returns the value of creator_id, or the default value if creator_id is unset.

pub fn nn_uid(&self) -> u64

Returns the value of nn_uid, or the default value if nn_uid is unset.

pub fn intra_account_id(&self) -> u64

Returns the value of intra_account_id, or the default value if intra_account_id is unset.

pub fn last_err_msg(&self) -> &str

Returns the value of last_err_msg, or the default value if last_err_msg is unset.

pub fn create_time(&self) -> u64

Returns the value of create_time, or the default value if create_time is unset.

pub fn update_time(&self) -> u64

Returns the value of update_time, or the default value if update_time is unset.

pub fn status(&self) -> u32

Returns the value of status, or the default value if status is unset.

pub fn lot_type(&self) -> u32

Returns the value of lot_type, or the default value if lot_type is unset.

pub fn version(&self) -> u32

Returns the value of version, or the default value if version is unset.

pub fn currency(&self) -> u32

Returns the value of currency, or the default value if currency is unset.

pub fn expire_time(&self) -> u64

Returns the value of expire_time, or the default value if expire_time is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn client_type(&self) -> u32

Returns the value of client_type, or the default value if client_type is unset.

pub fn client_version(&self) -> u32

Returns the value of client_version, or the default value if client_version is unset.

pub fn last_err(&self) -> i32

Returns the value of last_err, or the default value if last_err is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn dark_pool(&self) -> u32

Returns the value of dark_pool, or the default value if dark_pool is unset.

pub fn order_show_type(&self) -> u32

Returns the value of order_show_type, or the default value if order_show_type is unset.

pub fn exdestination(&self) -> u32

Returns the value of exdestination, or the default value if exdestination is unset.

pub fn notice_msg(&self) -> &str

Returns the value of notice_msg, or the default value if notice_msg is unset.

pub fn ba_trade_notice_msg(&self) -> &str

Returns the value of ba_trade_notice_msg, or the default value if ba_trade_notice_msg is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn group_id(&self) -> &str

Returns the value of group_id, or the default value if group_id is unset.

pub fn relation_type(&self) -> i32

Returns the value of relation_type, or the default value if relation_type is unset.

pub fn aux_price(&self) -> &str

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn disable_auto_short(&self) -> bool

Returns the value of disable_auto_short, or the default value if disable_auto_short is unset.

pub fn exec_time(&self) -> u64

Returns the value of exec_time, or the default value if exec_time is unset.

pub fn price_type(&self) -> u32

Returns the value of price_type, or the default value if price_type is unset.

pub fn order_show_id(&self) -> &str

Returns the value of order_show_id, or the default value if order_show_id is unset.

pub fn fill_amount(&self) -> &str

Returns the value of fill_amount, or the default value if fill_amount is unset.

pub fn order_amount(&self) -> &str

Returns the value of order_amount, or the default value if order_amount is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn parent_order_id(&self) -> &str

Returns the value of parent_order_id, or the default value if parent_order_id is unset.

pub fn order_group_id(&self) -> &str

Returns the value of order_group_id, or the default value if order_group_id is unset.

pub fn group_type(&self) -> u32

Returns the value of group_type, or the default value if group_type is unset.

pub fn account_market(&self) -> u32

Returns the value of account_market, or the default value if account_market is unset.

pub fn batch_id(&self) -> &str

Returns the value of batch_id, or the default value if batch_id is unset.

pub fn fix_session_id(&self) -> &str

Returns the value of fix_session_id, or the default value if fix_session_id is unset.

pub fn third_party_bcan(&self) -> &str

Returns the value of third_party_bcan, or the default value if third_party_bcan is unset.

pub fn sub_account(&self) -> u32

Returns the value of sub_account, or the default value if sub_account is unset.