HistoryOrderListReq

Struct HistoryOrderListReq 

pub struct HistoryOrderListReq {
Show 20 fields pub msg_header: Option<MsgHeader>, pub page_flag: Option<String>, pub symbol: Option<String>, pub time_begin: Option<u64>, pub time_end: Option<u64>, pub page_size: Option<u32>, pub side: Option<u32>, pub order_flag: Option<u32>, pub security_type: Vec<u32>, pub order_type: Vec<u32>, pub trade_type: Vec<u32>, pub order_status: Vec<u32>, pub query_word: Option<String>, pub ex_destination: Option<u32>, pub for_trigger: Option<u32>, pub market: Vec<u32>, pub date_begin: Option<u32>, pub date_end: Option<u32>, pub currency: Vec<i32>, pub show_related_order: Option<bool>,
}

Fields

msg_header: Option<MsgHeader>page_flag: Option<String>symbol: Option<String>time_begin: Option<u64>time_end: Option<u64>page_size: Option<u32>side: Option<u32>order_flag: Option<u32>security_type: Vec<u32>order_type: Vec<u32>trade_type: Vec<u32>order_status: Vec<u32>query_word: Option<String>ex_destination: Option<u32>for_trigger: Option<u32>market: Vec<u32>date_begin: Option<u32>date_end: Option<u32>currency: Vec<i32>show_related_order: Option<bool>

Implementations

Source

impl HistoryOrderListReq

pub fn page_flag(&self) -> &str

Returns the value of page_flag, or the default value if page_flag is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn time_begin(&self) -> u64

Returns the value of time_begin, or the default value if time_begin is unset.

pub fn time_end(&self) -> u64

Returns the value of time_end, or the default value if time_end is unset.

pub fn page_size(&self) -> u32

Returns the value of page_size, or the default value if page_size is unset.

pub fn side(&self) -> u32

Returns the value of side, or the default value if side is unset.

pub fn order_flag(&self) -> u32

Returns the value of order_flag, or the default value if order_flag is unset.

pub fn query_word(&self) -> &str

Returns the value of query_word, or the default value if query_word is unset.

pub fn ex_destination(&self) -> u32

Returns the value of ex_destination, or the default value if ex_destination is unset.

pub fn for_trigger(&self) -> u32

Returns the value of for_trigger, or the default value if for_trigger is unset.

pub fn date_begin(&self) -> u32

Returns the value of date_begin, or the default value if date_begin is unset.

pub fn date_end(&self) -> u32

Returns the value of date_end, or the default value if date_end is unset.

Returns the value of show_related_order, or the default value if show_related_order is unset.