pub struct MaxBuySellReq {Show 18 fields
pub msg_header: Option<MsgHeader>,
pub order_type: Option<u32>,
pub symbol: Option<String>,
pub price: Option<String>,
pub order_id: Option<String>,
pub is_odd_lot: Option<bool>,
pub exchange_code: Option<u32>,
pub scene_type: Option<i32>,
pub force_pull: Option<bool>,
pub exchange: Option<String>,
pub nn_uid: Option<u64>,
pub order_trade_time_type: Option<u32>,
pub crypto_base_info: Option<CryptoBaseInfo>,
pub quantity: Option<String>,
pub is_cash_order: Option<bool>,
pub position_id: Option<String>,
pub long_sub_acct_id: Option<u64>,
pub short_sub_acct_id: Option<u64>,
}Expand description
最大可买可卖接口。C++ sim 分支使用 sim_order_sys_interface::MaxBuySellReq 并通过 NNProto_Trd_Base::GetCmdID(4713) 发 CMD 14713。 Ref:
- /Users/leaf/ai-lab/o-src/FutuOpenD/Src/NNProtoFile/Server/PB/Trade/sim_odr_sys_interface.proto:356-416
- /Users/leaf/ai-lab/o-src/FutuOpenD/Src/NNProtoCenter/Trade/NNProto_Trd_MaxQty.cpp:97-105
Fields
msg_header: Option<MsgHeader>order_type: Option<u32>symbol: Option<String>price: Option<String>order_id: Option<String>is_odd_lot: Option<bool>exchange_code: Option<u32>scene_type: Option<i32>force_pull: Option<bool>exchange: Option<String>nn_uid: Option<u64>order_trade_time_type: Option<u32>crypto_base_info: Option<CryptoBaseInfo>quantity: Option<String>is_cash_order: Option<bool>position_id: Option<String>long_sub_acct_id: Option<u64>short_sub_acct_id: Option<u64>Implementations
Sourceimpl MaxBuySellReq
impl MaxBuySellReq
Sourcepub fn order_type(&self) -> u32
pub fn order_type(&self) -> u32
Returns the value of order_type, or the default value if order_type is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn is_odd_lot(&self) -> bool
pub fn is_odd_lot(&self) -> bool
Returns the value of is_odd_lot, or the default value if is_odd_lot is unset.
Sourcepub fn exchange_code(&self) -> u32
pub fn exchange_code(&self) -> u32
Returns the value of exchange_code, or the default value if exchange_code is unset.
Sourcepub fn scene_type(&self) -> i32
pub fn scene_type(&self) -> i32
Returns the value of scene_type, or the default value if scene_type is unset.
Sourcepub fn force_pull(&self) -> bool
pub fn force_pull(&self) -> bool
Returns the value of force_pull, or the default value if force_pull is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn nn_uid(&self) -> u64
pub fn nn_uid(&self) -> u64
Returns the value of nn_uid, or the default value if nn_uid is unset.
Sourcepub fn order_trade_time_type(&self) -> u32
pub fn order_trade_time_type(&self) -> u32
Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn is_cash_order(&self) -> bool
pub fn is_cash_order(&self) -> bool
Returns the value of is_cash_order, or the default value if is_cash_order is unset.
Sourcepub fn position_id(&self) -> &str
pub fn position_id(&self) -> &str
Returns the value of position_id, or the default value if position_id is unset.
Sourcepub fn long_sub_acct_id(&self) -> u64
pub fn long_sub_acct_id(&self) -> u64
Returns the value of long_sub_acct_id, or the default value if long_sub_acct_id is unset.
Sourcepub fn short_sub_acct_id(&self) -> u64
pub fn short_sub_acct_id(&self) -> u64
Returns the value of short_sub_acct_id, or the default value if short_sub_acct_id is unset.