OrderNewReq

Struct OrderNewReq 

pub struct OrderNewReq {
Show 40 fields pub msg_header: Option<MsgHeader>, pub order_type: Option<u32>, pub order_side: Option<u32>, pub symbol: Option<String>, pub qty: Option<String>, pub price: Option<String>, pub expire_time: Option<u64>, pub text: Option<String>, pub lot_type: Option<u32>, pub security_type: Option<u32>, pub trigger_type: Option<u32>, pub pdt_confirmed: Option<bool>, pub trigger_risk_check: Option<bool>, pub odr_enable_ba_trade: Option<bool>, pub exchange_code: Option<u32>, pub time_in_force: Option<u32>, pub pdt_protection: Option<bool>, pub price_type: Option<u32>, pub disable_auto_short: Option<bool>, pub tickets: Option<Tickets>, pub hk_enable_ba_trade: Option<u32>, pub price_protect: Option<bool>, pub exchange: Option<String>, pub trigger_info: Option<TriggerInfo>, pub aux_price: Option<String>, pub trail_type: Option<u32>, pub trail_percent: Option<String>, pub trail_price: Option<String>, pub algo_info: Option<AlgoInfo>, pub input_source: Option<u32>, pub dt_call_confirmed: Option<bool>, pub order_trade_time_type: Option<u32>, pub fixed_side: Option<bool>, pub cash_order_qty: Option<String>, pub position_id: Option<String>, pub margin_trade_info: Option<MarginTradeInfo>, pub force_routing: Option<String>, pub batch_risk_confirm_code: Vec<u32>, pub combo_id: Option<String>, pub owner_broker_id: Option<String>,
}

Fields

msg_header: Option<MsgHeader>order_type: Option<u32>order_side: Option<u32>symbol: Option<String>qty: Option<String>price: Option<String>expire_time: Option<u64>text: Option<String>lot_type: Option<u32>security_type: Option<u32>trigger_type: Option<u32>pdt_confirmed: Option<bool>trigger_risk_check: Option<bool>odr_enable_ba_trade: Option<bool>exchange_code: Option<u32>time_in_force: Option<u32>pdt_protection: Option<bool>price_type: Option<u32>disable_auto_short: Option<bool>tickets: Option<Tickets>hk_enable_ba_trade: Option<u32>price_protect: Option<bool>exchange: Option<String>trigger_info: Option<TriggerInfo>aux_price: Option<String>trail_type: Option<u32>trail_percent: Option<String>trail_price: Option<String>algo_info: Option<AlgoInfo>input_source: Option<u32>dt_call_confirmed: Option<bool>order_trade_time_type: Option<u32>fixed_side: Option<bool>cash_order_qty: Option<String>position_id: Option<String>margin_trade_info: Option<MarginTradeInfo>force_routing: Option<String>batch_risk_confirm_code: Vec<u32>combo_id: Option<String>owner_broker_id: Option<String>

Implementations

Source

impl OrderNewReq

pub fn order_type(&self) -> u32

Returns the value of order_type, or the default value if order_type is unset.

pub fn order_side(&self) -> u32

Returns the value of order_side, or the default value if order_side is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn expire_time(&self) -> u64

Returns the value of expire_time, or the default value if expire_time is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn lot_type(&self) -> u32

Returns the value of lot_type, or the default value if lot_type is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn trigger_type(&self) -> u32

Returns the value of trigger_type, or the default value if trigger_type is unset.

pub fn pdt_confirmed(&self) -> bool

Returns the value of pdt_confirmed, or the default value if pdt_confirmed is unset.

pub fn trigger_risk_check(&self) -> bool

Returns the value of trigger_risk_check, or the default value if trigger_risk_check is unset.

pub fn odr_enable_ba_trade(&self) -> bool

Returns the value of odr_enable_ba_trade, or the default value if odr_enable_ba_trade is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn time_in_force(&self) -> u32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn pdt_protection(&self) -> bool

Returns the value of pdt_protection, or the default value if pdt_protection is unset.

pub fn price_type(&self) -> u32

Returns the value of price_type, or the default value if price_type is unset.

pub fn disable_auto_short(&self) -> bool

Returns the value of disable_auto_short, or the default value if disable_auto_short is unset.

pub fn hk_enable_ba_trade(&self) -> u32

Returns the value of hk_enable_ba_trade, or the default value if hk_enable_ba_trade is unset.

pub fn price_protect(&self) -> bool

Returns the value of price_protect, or the default value if price_protect is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn aux_price(&self) -> &str

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn trail_type(&self) -> u32

Returns the value of trail_type, or the default value if trail_type is unset.

pub fn trail_percent(&self) -> &str

Returns the value of trail_percent, or the default value if trail_percent is unset.

pub fn trail_price(&self) -> &str

Returns the value of trail_price, or the default value if trail_price is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.

pub fn dt_call_confirmed(&self) -> bool

Returns the value of dt_call_confirmed, or the default value if dt_call_confirmed is unset.

pub fn order_trade_time_type(&self) -> u32

Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.

pub fn fixed_side(&self) -> bool

Returns the value of fixed_side, or the default value if fixed_side is unset.

pub fn cash_order_qty(&self) -> &str

Returns the value of cash_order_qty, or the default value if cash_order_qty is unset.

pub fn position_id(&self) -> &str

Returns the value of position_id, or the default value if position_id is unset.

pub fn force_routing(&self) -> &str

Returns the value of force_routing, or the default value if force_routing is unset.

pub fn combo_id(&self) -> &str

Returns the value of combo_id, or the default value if combo_id is unset.

pub fn owner_broker_id(&self) -> &str

Returns the value of owner_broker_id, or the default value if owner_broker_id is unset.