#[repr(i32)]pub enum RetCode {
RetSucc = 0,
RetNoStock = 1,
RetDealtError = 2,
RetNoLinkId = 3,
RetOverLimit = 4,
RetErrSymbol = 5,
RetEmptyStock = 6,
}Variants
RetSucc = 0
成功
RetNoStock = 1
找不到股票
RetDealtError = 2
处理失败
RetNoLinkId = 3
没有正股
RetOverLimit = 4
超出请求上限
RetErrSymbol = 5
请求股票不正确
RetEmptyStock = 6
请求列表为空
Implementations
Sourceimpl RetCode
impl RetCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.