CryptoResultInfo

Struct CryptoResultInfo 

pub struct CryptoResultInfo {
Show 21 fields pub ret: Option<i32>, pub stock_id: Option<u64>, pub symbol: Option<String>, pub display_symbol: Option<String>, pub instrument_type: Option<i32>, pub sub_instrument_type: Option<i32>, pub market_code: Option<u32>, pub sc_name: Option<String>, pub tc_name: Option<String>, pub name: Option<String>, pub spread_table_code: Option<u32>, pub no_search: Option<i32>, pub no_subscription: Option<bool>, pub cc_origin: Option<String>, pub cc_destination: Option<String>, pub crypto_exchange: Option<String>, pub code_item: Option<SrcCodeItem>, pub instrument_type_v2: Option<i32>, pub sub_instrument_type_v2: Option<i32>, pub delisting_flag: Option<u32>, pub region: Option<String>,
}
Ref:

  • o-src/FutuOpenD/Src/NNProtoFile/Server/PB/Quote/stock_information.proto:404-478
  • o-src/moomoo/…/Proto/Quote/api_stock_information.proto:405-479

Fields

ret: Option<i32>stock_id: Option<u64>symbol: Option<String>display_symbol: Option<String>instrument_type: Option<i32>sub_instrument_type: Option<i32>market_code: Option<u32>sc_name: Option<String>tc_name: Option<String>name: Option<String>spread_table_code: Option<u32>no_search: Option<i32>no_subscription: Option<bool>cc_origin: Option<String>cc_destination: Option<String>crypto_exchange: Option<String>code_item: Option<SrcCodeItem>instrument_type_v2: Option<i32>sub_instrument_type_v2: Option<i32>delisting_flag: Option<u32>region: Option<String>

Implementations

Source

impl CryptoResultInfo

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn display_symbol(&self) -> &str

Returns the value of display_symbol, or the default value if display_symbol is unset.

pub fn instrument_type(&self) -> i32

Returns the value of instrument_type, or the default value if instrument_type is unset.

pub fn sub_instrument_type(&self) -> i32

Returns the value of sub_instrument_type, or the default value if sub_instrument_type is unset.

pub fn market_code(&self) -> u32

Returns the value of market_code, or the default value if market_code is unset.

pub fn sc_name(&self) -> &str

Returns the value of sc_name, or the default value if sc_name is unset.

pub fn tc_name(&self) -> &str

Returns the value of tc_name, or the default value if tc_name is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn spread_table_code(&self) -> u32

Returns the value of spread_table_code, or the default value if spread_table_code is unset.

Returns the value of no_search, or the default value if no_search is unset.

pub fn no_subscription(&self) -> bool

Returns the value of no_subscription, or the default value if no_subscription is unset.

pub fn cc_origin(&self) -> &str

Returns the value of cc_origin, or the default value if cc_origin is unset.

pub fn cc_destination(&self) -> &str

Returns the value of cc_destination, or the default value if cc_destination is unset.

pub fn crypto_exchange(&self) -> &str

Returns the value of crypto_exchange, or the default value if crypto_exchange is unset.

pub fn instrument_type_v2(&self) -> i32

Returns the value of instrument_type_v2, or the default value if instrument_type_v2 is unset.

pub fn sub_instrument_type_v2(&self) -> i32

Returns the value of sub_instrument_type_v2, or the default value if sub_instrument_type_v2 is unset.

pub fn delisting_flag(&self) -> u32

Returns the value of delisting_flag, or the default value if delisting_flag is unset.

pub fn region(&self) -> &str

Returns the value of region, or the default value if region is unset.