FutureResultInfo

Struct FutureResultInfo 

pub struct FutureResultInfo {
Show 19 fields pub ret: Option<i32>, pub symbol: Option<String>, pub sc_name: Option<String>, pub tc_name: Option<String>, pub name: Option<String>, pub last_trade_date: Option<i64>, pub stock_id: Option<u64>, pub instrument_type: Option<i32>, pub market_code: Option<u32>, pub lot_size: Option<u32>, pub spread_table_code: Option<u32>, pub sub_instrument_type: Option<i32>, pub display_symbol: Option<String>, pub no_search: Option<i32>, pub code_item: Option<SrcCodeItem>, pub instrument_type_v2: Option<i32>, pub sub_instrument_type_v2: Option<i32>, pub delisting_flag: Option<u32>, pub listed_exchange: Option<String>,
}
Ref:

  • o-src/FutuOpenD/Src/NNProtoFile/Server/PB/Quote/stock_information.proto:347-402
  • o-src/moomoo/…/Proto/Quote/api_stock_information.proto:347-403

Fields

ret: Option<i32>symbol: Option<String>sc_name: Option<String>tc_name: Option<String>name: Option<String>last_trade_date: Option<i64>stock_id: Option<u64>instrument_type: Option<i32>market_code: Option<u32>lot_size: Option<u32>spread_table_code: Option<u32>sub_instrument_type: Option<i32>display_symbol: Option<String>no_search: Option<i32>code_item: Option<SrcCodeItem>instrument_type_v2: Option<i32>sub_instrument_type_v2: Option<i32>delisting_flag: Option<u32>listed_exchange: Option<String>

Implementations

Source

impl FutureResultInfo

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn sc_name(&self) -> &str

Returns the value of sc_name, or the default value if sc_name is unset.

pub fn tc_name(&self) -> &str

Returns the value of tc_name, or the default value if tc_name is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn last_trade_date(&self) -> i64

Returns the value of last_trade_date, or the default value if last_trade_date is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn instrument_type(&self) -> i32

Returns the value of instrument_type, or the default value if instrument_type is unset.

pub fn market_code(&self) -> u32

Returns the value of market_code, or the default value if market_code is unset.

pub fn lot_size(&self) -> u32

Returns the value of lot_size, or the default value if lot_size is unset.

pub fn spread_table_code(&self) -> u32

Returns the value of spread_table_code, or the default value if spread_table_code is unset.

pub fn sub_instrument_type(&self) -> i32

Returns the value of sub_instrument_type, or the default value if sub_instrument_type is unset.

pub fn display_symbol(&self) -> &str

Returns the value of display_symbol, or the default value if display_symbol is unset.

Returns the value of no_search, or the default value if no_search is unset.

pub fn instrument_type_v2(&self) -> i32

Returns the value of instrument_type_v2, or the default value if instrument_type_v2 is unset.

pub fn sub_instrument_type_v2(&self) -> i32

Returns the value of sub_instrument_type_v2, or the default value if sub_instrument_type_v2 is unset.

pub fn delisting_flag(&self) -> u32

Returns the value of delisting_flag, or the default value if delisting_flag is unset.

pub fn listed_exchange(&self) -> &str

Returns the value of listed_exchange, or the default value if listed_exchange is unset.