StockInfoItem

Struct StockInfoItem 

pub struct StockInfoItem {
    pub ret: Option<i32>,
    pub stock_id: Option<u64>,
    pub symbol: Option<String>,
    pub name: Option<String>,
    pub market: Option<u32>,
    pub lot_size: Option<u32>,
    pub instrument_type: Option<u32>,
}
v1.4.38 最小 subset:只含 stock_id / code / name / lot_size,填进 static_cache 够用

Fields

ret: Option<i32>stock_id: Option<u64>symbol: Option<String>name: Option<String>market: Option<u32>lot_size: Option<u32>instrument_type: Option<u32>

…剩余字段跳过,字段号在 proto 里定好留出空间

Implementations

Source

impl StockInfoItem

pub fn ret(&self) -> i32

Returns the value of ret, or the default value if ret is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn market(&self) -> u32

Returns the value of market, or the default value if market is unset.

pub fn lot_size(&self) -> u32

Returns the value of lot_size, or the default value if lot_size is unset.

pub fn instrument_type(&self) -> u32

Returns the value of instrument_type, or the default value if instrument_type is unset.