#[repr(i32)]pub enum CashFlowPeriod {
Day = 1,
Week = 2,
Month = 3,
Quarter = 4,
}Expand description
资金流向周期类型
Variants
Implementations
Sourceimpl CashFlowPeriod
impl CashFlowPeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.