Featured

#[repr(i32)]
pub enum Featured {
Show 104 variants ChipsProfitRatio = 5_101, ChipsIntervalCoincidence = 5_102, ShortPositionTotal = 5_110, FinancialPositionTotal = 5_111, ShortLastWeekDiff = 5_112, FinancialLastWeekDiff = 5_113, FinancingShortRatio = 5_114, LendingFeePerShare = 5_115, CoverDays = 5_116, IndicatorAnalysisStatus = 5_201, IndicatorPearsonCorrelation = 5_202, IndicatorBeta = 5_203, StockTradeIndexHp = 5_211, StockSearchIndexHp = 5_212, StockNewsIndexHp = 5_213, StockAverageIndexHp = 5_214, StockTradeIndexHpRank = 5_215, StockSearchIndexHpRank = 5_216, StockNewsIndexHpRank = 5_217, StockAverageIndexHpRank = 5_218, StockTradeHpRankComparedWithPre = 5_219, StockSearchHpRankComparedWithPre = 5_220, StockNewsHpRankComparedWithPre = 5_221, StockAverageHpRankComparedWithPre = 5_222, PublicOpinionIndexStatus = 5_301, IfisPerformanceAnnouncementDate = 5_310, IfisPerformanceRevisedRateSales = 5_311, IfisPerformanceRevisedRateOp = 5_312, IfisPerformanceRevisedRateRp = 5_313, IfisPerformanceRevisedRateNp = 5_314, InstStockOwnershipInstitutionRatio = 5_320, InstInstitutionStockOwnershipRatio = 5_321, InstIsInstitutionHold = 5_322, InstStockOwnershipValue = 5_323, InstStockOwnershipSharesChg = 5_324, InstStockOwnershipHoldingStockRadio = 5_325, InstStockOwnershipHoldingStockChgRadio = 5_326, InstStockOwnershipHoldingChgType = 5_327, InstStockOwnershipHoldingDate = 5_328, EmployeeNum = 5_330, EmployeeNumGrowth = 5_331, AnalysisLevelStatus = 5_401, AnalystInstRatingChange = 5_402, AnalystTargetPrice = 5_403, AnalystTargetPriceRate = 5_404, MorningstarFairValue = 5_405, MorningstarFairValueRate = 5_406, MorningstarStarRating = 5_407, MorningstarEconomicMoat = 5_408, MorningstarUncertainty = 5_409, MorningstarFinancialHealth = 5_410, CompanyValuationOverHistPercentilePb = 5_501, CompanyValuationOverHistPercentilePe = 5_502, CompanyValuationOverHistPercentilePs = 5_503, CompanyValuationIndustryRankPb = 5_504, CompanyValuetionIndustryRankPe = 5_505, CompanyValuetionIndustryRankPs = 5_506, CompanyValuationMarketRankPb = 5_507, CompanyValuationMarketRankPe = 5_508, CompanyValuationMarketRankPs = 5_509, IsLongMargin = 5_600, IsShortMargin = 5_601, InitialLongMarginRatio = 5_602, InitialShortMarginRatio = 5_603, ShortFeeRate = 5_604, IsCollateralSecurity = 5_605, CollateralRatio = 5_606, IsShareholderPerks = 5_700, ShareholderPerksRequiredVal = 5_701, ShareholderPerksStMonths = 5_702, ShareholderPerksYield = 5_703, ShareholderPerksTotalYield = 5_704, ShareholderPerksCategories = 5_705, ShareholderPerksHasStMonth = 5_706, ShareholderPerksHasCategory = 5_707, PayoutRatioLfy = 5_800, DistributionFrequency = 5_801, MaxDividendGrowYear = 5_802, PubDateTimestamp = 5_803, PubDateDays = 5_804, NextRecordDateTimestamp = 5_805, NextRecordDateDays = 5_806, NextExDateTimestamp = 5_807, NextExDateDays = 5_808, NextDividendPayableDateTimestamp = 5_809, NextDividendPayableDateDays = 5_810, IncreaseRate = 5_811, AverageDividendYield = 5_812, ToyokeizaiForecastDividendRatio = 5_813, AuFrankingDividendTaxPeriod = 5_814, AuFrankingDividendYieldTaxPeriod = 5_815, AuFrankingFranking = 5_816, AuFrankingFrankingCredit = 5_817, AuFrankingGrossDividendYield = 5_818, AuFrankingDividendTaxRate = 5_819, CashFlowTotalNetIn = 5_900, CashFlowMainNetIn = 5_901, CashFlowTotalNetInCount = 5_902, CashFlowTotalNetOutCount = 5_903, CashFlowMainNetInCount = 5_904, CashFlowMainNetOutCount = 5_905, HkConnectCashFlowNetIn = 5_906, HkConnectCashFlowNetInCount = 5_907, HkConnectCashFlowNetOutCount = 5_908,
}
特色指标

Variants



ChipsProfitRatio = 5_101

筹码

筹码获利比例 (单位:0.001% 倍率:100000)



ChipsIntervalCoincidence = 5_102

筹码区间重合度 (单位:0.001% 倍率:100000)



ShortPositionTotal = 5_110

卖空数据(日股)

卖空持仓量,倍率1



FinancialPositionTotal = 5_111

融资持仓量,倍率1



ShortLastWeekDiff = 5_112

卖空净增仓(前周比),倍率1



FinancialLastWeekDiff = 5_113

融资净增仓(前周比),倍率1



FinancingShortRatio = 5_114

融资/卖空 倍数,倍率1e3



LendingFeePerShare = 5_115

借贷费用(逆日步)(每股费用),倍率1e3



CoverDays = 5_116

回补天数,倍率1e3



IndicatorAnalysisStatus = 5_201

指标解读

指标解读状态(单位:0.001 倍率:1000)



IndicatorPearsonCorrelation = 5_202

行情指标

皮尔逊相关系数,参数:板块ID(单位:1 倍率:1e5)



IndicatorBeta = 5_203

贝塔系数,参数:板块ID(单位:1 倍率:1e5)



StockTradeIndexHp = 5_211

股票热度

交易热度(倍率:1e5)



StockSearchIndexHp = 5_212

搜索热度(倍率:1e5)



StockNewsIndexHp = 5_213

资讯热度(倍率:1e5)



StockAverageIndexHp = 5_214

综合热度(倍率:1e5)



StockTradeIndexHpRank = 5_215

交易热度排名(倍率:1)



StockSearchIndexHpRank = 5_216

搜索热度排名(倍率:1)



StockNewsIndexHpRank = 5_217

资讯热度排名(倍率:1)



StockAverageIndexHpRank = 5_218

综合热度排名(倍率:1)



StockTradeHpRankComparedWithPre = 5_219

交易热度排名较上次增减(倍率:1)



StockSearchHpRankComparedWithPre = 5_220

搜索热度排名较上次增减(倍率:1)



StockNewsHpRankComparedWithPre = 5_221

资讯热度排名较上次增减(倍率:1)



StockAverageHpRankComparedWithPre = 5_222

综合热度排名较上次增减(倍率:1)



PublicOpinionIndexStatus = 5_301

舆情指数

舆情指数状态(单位:0.001 倍率:1000)



IfisPerformanceAnnouncementDate = 5_310

IFIS

业绩公告日(时间戳)(单位:1 倍率:1)



IfisPerformanceRevisedRateSales = 5_311

营业收入业绩修正率(单位:1 倍率:1e5)



IfisPerformanceRevisedRateOp = 5_312

营业利润业绩修正率(单位:1 倍率:1e5)



IfisPerformanceRevisedRateRp = 5_313

经常利润业绩修正率(单位:1 倍率:1e5)



IfisPerformanceRevisedRateNp = 5_314

归普净利润业绩修正率(单位:1 倍率:1e5)



InstStockOwnershipInstitutionRatio = 5_320

机构持股

个股机构持股比例(单位:1 倍率:1e5)



InstInstitutionStockOwnershipRatio = 5_321

机构持股个股比例,参数机构ID(单位:1 倍率:1e5)



InstIsInstitutionHold = 5_322

是否机构持股,参数机构ID(单位:1 倍率:1)



InstStockOwnershipValue = 5_323

机构持股市值(单位:1 倍率:1e3)



InstStockOwnershipSharesChg = 5_324

机构持股数变化(单位:1 倍率:1e5)



InstStockOwnershipHoldingStockRadio = 5_325

机构持股比率(单位:1 倍率:1e5)



InstStockOwnershipHoldingStockChgRadio = 5_326

机构持股变化比率(单位:1 倍率:1e5)



InstStockOwnershipHoldingChgType = 5_327

机构持股变化类型(单位:1 倍率:1)



InstStockOwnershipHoldingDate = 5_328

机构持股日期(单位:1 倍率:1)



EmployeeNum = 5_330

经营效率-员工数

员工人数(单位:1,倍率:1)



EmployeeNumGrowth = 5_331

员工人数增长率(参数:RecentDuration)(单位:1 倍率:100000)



AnalysisLevelStatus = 5_401

分析师评级 & 晨星评级

分析师评级状态(单位:0.001 倍率:1000)



AnalystInstRatingChange = 5_402

分析师评级-机构评级变动,参数(RecentDuration, RatingChangeType)(单位:1 倍率:1)



AnalystTargetPrice = 5_403

分析师评级-目标价(单位:1 倍率:1e9)



AnalystTargetPriceRate = 5_404

分析师评级(目标价-当前价)/当前价(单位:1 倍率:1e5)



MorningstarFairValue = 5_405

晨星公允价值(单位:1 倍率:1e9)



MorningstarFairValueRate = 5_406

晨星公允价值(目标价-当前价)/当前价(单位:1 倍率:1e5)



MorningstarStarRating = 5_407

晨星星级评级(单位:1 倍率:1)



MorningstarEconomicMoat = 5_408

晨星评级护城河(单位:1 倍率:1),参考EconomicMoatType



MorningstarUncertainty = 5_409

晨星评级不确定性(单位:1 倍率:1)



MorningstarFinancialHealth = 5_410

晨星评级财务健康(单位:1 倍率:1)



CompanyValuationOverHistPercentilePb = 5_501

公司估值

PB高于历史百分位 (单位:0.001% 倍率:100000)



CompanyValuationOverHistPercentilePe = 5_502

PE高于历史百分位 (单位:0.001% 倍率:100000)



CompanyValuationOverHistPercentilePs = 5_503

PS高于历史百分位 (单位:0.001% 倍率:100000)



CompanyValuationIndustryRankPb = 5_504

PB估值行业排行(单位:1 倍率:1)



CompanyValuetionIndustryRankPe = 5_505

PE估值行业排行(单位:1 倍率:1)



CompanyValuetionIndustryRankPs = 5_506

PS估值行业排行(单位:1 倍率:1)



CompanyValuationMarketRankPb = 5_507

PB估值市场排行(单位:1 倍率:1)



CompanyValuationMarketRankPe = 5_508

PE估值市场排行(单位:1 倍率:1)



CompanyValuationMarketRankPs = 5_509

PS估值市场排行(单位:1 倍率:1)



IsLongMargin = 5_600

融资融券

指定券商下是否允许融资,参数券商id



IsShortMargin = 5_601

指定券商下是否允许融券,参数券商id



InitialLongMarginRatio = 5_602

指定券商下融资初始保证金比率,参数券商id, 倍率1e6



InitialShortMarginRatio = 5_603

指定券商下卖空初始保证金比率,参数券商id, 倍率1e6



ShortFeeRate = 5_604

指定券商下卖空费率,参数券商id, 倍率1e6



IsCollateralSecurity = 5_605

指定券商下是否可抵押证券,参数券商id



CollateralRatio = 5_606

指定券商下可抵押证券抵押比例,参数券商id, 倍率1e6



IsShareholderPerks = 5_700

股东优待

是否支持股东优待



ShareholderPerksRequiredVal = 5_701

股东优待最低购买金额, 倍率1e6



ShareholderPerksStMonths = 5_702

股东优待股权登记月(单位:1 倍率:1)



ShareholderPerksYield = 5_703

股东优待总收益率, 倍率1e6



ShareholderPerksTotalYield = 5_704

股东优待总收益率, 倍率1e6



ShareholderPerksCategories = 5_705

股东优待分类(单位:1 倍率:1)



ShareholderPerksHasStMonth = 5_706

是否包含股东优待股权登记月,参数股权登记月(单位:1 倍率:1)



ShareholderPerksHasCategory = 5_707

是否包含股东优待分类,参数股东优待分类(单位:1 倍率:1)



PayoutRatioLfy = 5_800

股息率

股息支付率LFY(单位:1 倍率:1e5)



DistributionFrequency = 5_801

派息频率,返回结果,参数:1:年派,2:半年派,3:季派,4:月派



MaxDividendGrowYear = 5_802

股息最大增长年数(单位:1 倍率:1)



PubDateTimestamp = 5_803

公告日, 时间戳(按照东8区抓换)(单位:1 倍率:1)



PubDateDays = 5_804

公告日, 天数(单位:1 倍率:1)



NextRecordDateTimestamp = 5_805

下次股权登记日, 时间戳(单位:1 倍率:1)



NextRecordDateDays = 5_806

下次股权登记日, 天数转换(单位:1 倍率:1)



NextExDateTimestamp = 5_807

下次除权除息日, 时间戳(单位:1 倍率:1)



NextExDateDays = 5_808

下次除权除息日, 天数(单位:1 倍率:1)



NextDividendPayableDateTimestamp = 5_809

下次派息日, 时间戳(单位:1 倍率:1)



NextDividendPayableDateDays = 5_810

下次派息日, 天数(单位:1 倍率:1)



IncreaseRate = 5_811

增派率, 参数:1-一年增派率, 3-三年增派率, 5-五年增派率(单位:1 倍率:1e5)



AverageDividendYield = 5_812

平均股息率,参数:3-三年平均股息率, 5-五年平均股息率(单位:1 倍率:1e5)



ToyokeizaiForecastDividendRatio = 5_813

东洋预测股息率

东洋预测股息率(单位:1 倍率:1e5)



AuFrankingDividendTaxPeriod = 5_814

AU Franking

AU Franking 最近计税周期股息(单位:1 倍率:1e5)



AuFrankingDividendYieldTaxPeriod = 5_815

AU Franking 最近计税周期股息率(单位:1 倍率:1e5)



AuFrankingFranking = 5_816

AU Franking 抵免税率(最近一个计税周期)(单位:1 倍率:1e5)



AuFrankingFrankingCredit = 5_817

AU Franking 抵免税额(最近一个计税周期)(单位:1 倍率:1e5)



AuFrankingGrossDividendYield = 5_818

AU Franking 毛利股息率(最近一个计算周期)(单位:1 倍率:1e5)



AuFrankingDividendTaxRate = 5_819

AU Franking 公司税率(最新一次派息)(单位:1 倍率:1e5)



CashFlowTotalNetIn = 5_900

资金流向

整体净流入,参数:CashFlowPeriod(单位: 1 倍率:1e3)



CashFlowMainNetIn = 5_901

主力大单净流入,参数:CashFlowPeriod(单位: 1 倍率:1e3)



CashFlowTotalNetInCount = 5_902

整体净流入次数,参数:CashFlowPeriod(单位: 1 倍率:1)



CashFlowTotalNetOutCount = 5_903

整体净流出次数,参数:CashFlowPeriod(单位: 1 倍率:1)



CashFlowMainNetInCount = 5_904

主力大单净流入次数,参数:CashFlowPeriod(单位: 1 倍率:1)



CashFlowMainNetOutCount = 5_905

主力大单净流出次数,参数:CashFlowPeriod(单位: 1 倍率:1)



HkConnectCashFlowNetIn = 5_906

资金流向-港股通

港股通净流入,参数:CashFlowPeriod(单位: 1 倍率:1e3)



HkConnectCashFlowNetInCount = 5_907

港股通净流入次数,参数:CashFlowPeriod,目前仅支持日维度 CASH_FLOW_PERIOD_DAY(单位: 1 倍率:1)



HkConnectCashFlowNetOutCount = 5_908

港股通净流出次数,参数:CashFlowPeriod,目前仅支持日维度 CASH_FLOW_PERIOD_DAY(单位: 1 倍率:1)

Implementations

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of Featured.

pub fn from_i32(value: i32) -> Option<Featured>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a Featured, or None if value is not a valid variant.

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.