#[repr(i32)]pub enum FutureDuration {
FutureUnknown = 0,
FutureNext1Day = 1,
FutureNext1Week = 2,
FutureNext2Week = 3,
FutureNext1Month = 4,
FutureNext2Month = 5,
}Expand description
未来N天
Variants
FutureUnknown = 0
未知选项
FutureNext1Day = 1
未来1天
FutureNext1Week = 2
未来1周
FutureNext2Week = 3
未来2周
FutureNext1Month = 4
未来1月
FutureNext2Month = 5
未来2月
Implementations
Sourceimpl FutureDuration
impl FutureDuration
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.