#[repr(i32)]pub enum KlineShape {
Type = 6_200,
RiseProb = 6_201,
AfterSelectedChg = 6_202,
SelectedTime = 6_203,
SupportLevel = 6_204,
PressureLevel = 6_205,
}Variants
Type = 6_200
K线形态 (单位:1 倍率:1)
RiseProb = 6_201
上涨概率/下跌概率 (单位:0.001% 倍率:100000)
AfterSelectedChg = 6_202
入选后涨跌幅 (单位:0.001% 倍率:100000)
SelectedTime = 6_203
入选时间 (单位:1 倍率:1)
SupportLevel = 6_204
支撑位 (单位:0.000000001元,倍率:10e9)
PressureLevel = 6_205
压力位 (单位:0.000000001元,倍率:10e9)
Implementations
Sourceimpl KlineShape
impl KlineShape
Sourceimpl KlineShape
impl KlineShape
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.