#[repr(i32)]pub enum Option {
StockIv = 1_000,
StockIvRank = 1_001,
StockIvPercentile = 1_002,
StockEarningsIvCrush = 1_003,
StockIvChg = 1_004,
StockIvChgRatio = 1_005,
StockHv = 1_006,
StockIvMinusHv = 1_007,
StockIvDivisionHv = 1_008,
StockOptionVol = 1_009,
StockOptionOpenIn = 1_010,
}Variants
StockIv = 1_000
期权
正股 iv, 倍率1e6
StockIvRank = 1_001
正股 iv 排名, 倍率1e6
StockIvPercentile = 1_002
正股 iv 百分位, 倍率1e6
StockEarningsIvCrush = 1_003
财报发布日iv,带财报周期参数, 倍率1e6
StockIvChg = 1_004
正股 iv 涨跌, 倍率1e6
StockIvChgRatio = 1_005
股票 iv 变化率, 倍率1e6
StockHv = 1_006
正股HV,带周期参数, 倍率1e6
StockIvMinusHv = 1_007
正股iv减hv,不带参数,默认30天, 倍率1e6
StockIvDivisionHv = 1_008
正股iv/hv,不带参数,默认30天, 倍率1e6
StockOptionVol = 1_009
期权成交量, 倍率1
StockOptionOpenIn = 1_010
期权总持仓, 倍率1
Implementations
Sourceimpl Option
impl Option
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.