#[repr(i32)]pub enum OptionHvRangePeriod {
OptionHvRangeOneMonth = 0,
OptionHvRangeTwoMonth = 1,
OptionHvRangeThreeMonth = 2,
OptionHvRangeFourMonth = 3,
OptionHvRangeOneYear = 4,
}Variants
OptionHvRangeOneMonth = 0
30天
OptionHvRangeTwoMonth = 1
60天
OptionHvRangeThreeMonth = 2
90天
OptionHvRangeFourMonth = 3
120天
OptionHvRangeOneYear = 4
365天
Implementations
Sourceimpl OptionHvRangePeriod
impl OptionHvRangePeriod
Sourcepub fn from_i32(value: i32) -> Option<OptionHvRangePeriod>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OptionHvRangePeriod>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OptionHvRangePeriod, or None if value is not a valid variant.
Sourceimpl OptionHvRangePeriod
impl OptionHvRangePeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.