#[repr(i32)]pub enum PropertyNameFinancial {
Show 131 variants
PropertyFinancialUnknown = 0,
PropertyFinancialNetProfit = 4_101,
PropertyFinancialNetProfitGrowth = 4_102,
PropertyFinancialGrossProfit = 4_103,
PropertyFinancialGrossProfitGrowth = 4_104,
PropertyFinancialRevenue = 4_105,
PropertyFinancialRevenueGrowth = 4_106,
PropertyFinancialNetProfitRatio = 4_107,
PropertyFinancialGrossProfitRatio = 4_108,
PropertyFinancialDebtToAssetsRatio = 4_109,
PropertyFinancialReturnToNetAssetsRatio = 4_110,
PropertyFinancialReleasedDate = 4_111,
PropertyFinancialEbitda = 4_201,
PropertyFinancialRoic = 4_202,
PropertyFinancialEbitMargin = 4_203,
PropertyFinancialEbitdaMargin = 4_204,
PropertyFinancialFinancialCostRate = 4_205,
PropertyFinancialEbitTtm = 4_206,
PropertyFinancialOperatingProfitTtm = 4_207,
PropertyFinancialShareholdersProfitTtm = 4_208,
PropertyFinancialRoaTtm = 4_209,
PropertyFinancialOperatingMarginTtm = 4_210,
PropertyFinancialNetProfitCashCoverTtm = 4_211,
PropertyFinancialRdExpenseRatio = 4_212,
PropertyFinancialSellingExpenseRatio = 4_213,
PropertyFinancialManageExpenseRatio = 4_214,
PropertyFinancialOperatingProfitRate = 4_215,
PropertyFinancialProfitBeforeTaxRate = 4_216,
PropertyFinancialDividendsTtm = 4_217,
PropertyFinancialDividendsLfy = 4_218,
PropertyFinancialDividendsTtmRatio = 4_219,
PropertyFinancialDividendsLfyRatio = 4_220,
PropertyFinancialCurrentRatio = 4_301,
PropertyFinancialQuickRatio = 4_302,
PropertyFinancialLongTermDebtShareholdersRatio = 4_303,
PropertyFinancialFinancialLeverage = 4_304,
PropertyFinancialInterestBearingDebtRatio = 4_305,
PropertyFinancialCashAndCashEquivalents = 4_401,
PropertyFinancialCurrentAssetRatio = 4_402,
PropertyFinancialCurrentDebtRatio = 4_403,
PropertyFinancialEquityMultiplier = 4_404,
PropertyFinancialPropertyRatio = 4_405,
PropertyFinancialAccountsReceviable = 4_501,
PropertyFinancialTotalAssetTurnover = 4_502,
PropertyFinancialFixedAssetTurnover = 4_503,
PropertyFinancialInventoryTurnover = 4_504,
PropertyFinancialOperatingCashFlowTtm = 4_505,
PropertyFinancialMoneyTurnoverCycle = 4_506,
PropertyFinancialAccountsReceivableRate = 4_507,
PropertyFinancialFreeCashFlowIncomeRatio = 4_508,
PropertyFinancialFreeCashFlowParentCompanyNetProfitRatio = 4_509,
PropertyFinancialTurnoverRateCurrentAssetsRatio = 4_510,
PropertyFinancialIncomePerCapita = 4_511,
PropertyFinancialProfitPerCapita = 4_512,
PropertyFinancialNetProfitPerCapita = 4_513,
PropertyFinancialEbitGrowthRate = 4_601,
PropertyFinancialOperatingProfitGrowthRate = 4_602,
PropertyFinancialTotalAssetsGrowthRate = 4_603,
PropertyFinancialProfitToShareholdersGrowthRate = 4_604,
PropertyFinancialProfitBeforeTaxGrowthRate = 4_605,
PropertyFinancialEpsGrowthRate = 4_606,
PropertyFinancialRoeGrowthRate = 4_607,
PropertyFinancialRoicGrowthRate = 4_608,
PropertyFinancialNocfGrowthRate = 4_609,
PropertyFinancialNocfPerShareGrowthRate = 4_610,
PropertyFinancialRevenueCagr = 4_611,
PropertyFinancialGrossProfitCagr = 4_612,
PropertyFinancialEbitdaCagr = 4_613,
PropertyFinancialEbitCagr = 4_614,
PropertyFinancialNetProfitCagr = 4_615,
PropertyFinancialStockholderProfitCagr = 4_616,
PropertyFinancialNetMarginCagr = 4_617,
PropertyFinancialOperatingProfitCagr = 4_618,
PropertyFinancialFreeCashCagr = 4_619,
PropertyFinancialTotalAssetsCagr = 4_620,
PropertyFinancialBasicEpsCagr = 4_621,
PropertyFinancialRoaCagr = 4_622,
PropertyFinancialRoeCagr = 4_623,
PropertyFinancialRoicCagr = 4_624,
PropertyFinancialDividendCagr = 4_625,
PropertyFinancialFreeCashFlowGrowthRate = 4_626,
PropertyFinancialOperatingRevenueCashCover = 4_701,
PropertyFinancialOperatingProfitToTotalProfit = 4_702,
PropertyFinancialFreeCashFlow = 4_703,
PropertyFinancialBasicEps = 4_801,
PropertyFinancialDilutedEps = 4_802,
PropertyFinancialNocfPerShare = 4_803,
PropertyFinancialTotalShare = 4_901,
PropertyFinancialFloatShare = 4_902,
PropertyFinancialFloatMarketCap = 4_903,
PropertyFinancialPsTtm = 4_904,
PropertyFinancialPriceCashFlowRatioTtm = 4_905,
PropertyFinancialSurpriseEpsReleasedDate = 4_906,
PropertyFinancialSurpriseRevenueReleasedDate = 4_907,
PropertyFinancialSurpriseEbitReleasedDate = 4_908,
PropertyFinancialSurpriseActualEps = 4_909,
PropertyFinancialSurpriseActualRevenue = 4_910,
PropertyFinancialSurpriseActualEbit = 4_911,
PropertyFinancialSurpriseEstimateEps = 4_912,
PropertyFinancialSurpriseEstimateRevenue = 4_913,
PropertyFinancialSurpriseEstimateEbit = 4_914,
PropertyFinancialSurpriseEpsBeatRatio = 4_915,
PropertyFinancialSurpriseRevenueBeatRatio = 4_916,
PropertyFinancialSurpriseEbitBeatRatio = 4_917,
PropertyFinancialSurpriseEpsYoy = 4_918,
PropertyFinancialSurpriseRevenueYoy = 4_919,
PropertyFinancialSurpriseEbitYoy = 4_920,
PropertyFinancialSurpriseEpsYoyGrowth = 4_921,
PropertyFinancialSurpriseRevenueYoyGrowth = 4_922,
PropertyFinancialSurpriseEbitYoyGrowth = 4_923,
PropertyFinancialSurpriseEpsTerm = 4_924,
PropertyFinancialSurpriseRevenueTerm = 4_925,
PropertyFinancialSurpriseEbitTerm = 4_926,
PropertyFinancialSurpriseEpsEarningDayChg = 4_927,
PropertyFinancialSurpriseRevenueEarningDayChg = 4_928,
PropertyFinancialSurpriseEbitEarningDayChg = 4_929,
PropertyFinancialSurpriseEpsPostEarningDayChg = 4_930,
PropertyFinancialSurpriseRevenuePostEarningDayChg = 4_931,
PropertyFinancialSurpriseEbitPostEarningDayChg = 4_932,
PropertyFinancialSurpriseEpsDetailPostPeriod = 4_933,
PropertyFinancialSurpriseRevenueDetailPostPeriod = 4_934,
PropertyFinancialSurpriseEbitDetailPostPeriod = 4_935,
PropertyFinancialSurpriseEpsEarningDayChgV2 = 4_936,
PropertyFinancialSurpriseRevenueEarningDayChgV2 = 4_937,
PropertyFinancialSurpriseEbitEarningDayChgV2 = 4_938,
PropertyFinancialSurpriseEpsReleasedDateV2 = 4_939,
PropertyFinancialSurpriseRevenueReleasedDateV2 = 4_940,
PropertyFinancialSurpriseEbitReleasedDateV2 = 4_941,
PropertyFinancialSurpriseEpsDetailPostPeriodV2 = 4_942,
PropertyFinancialSurpriseRevenueDetailPostPeriodV2 = 4_943,
PropertyFinancialSurpriseEbitDetailPostPeriodV2 = 4_944,
}Variants
PropertyFinancialUnknown = 0
基本财务因子
未知
PropertyFinancialNetProfit = 4_101
净利润 (单位:0.001元 倍率:1000)
PropertyFinancialNetProfitGrowth = 4_102
净利润增长率 (单位:0.001% 倍率:100000)
PropertyFinancialGrossProfit = 4_103
毛利润 (单位:0.001元 倍率:1000)
PropertyFinancialGrossProfitGrowth = 4_104
毛利润增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRevenue = 4_105
营业额 (单位:0.001元 倍率:1000)
PropertyFinancialRevenueGrowth = 4_106
营业额增长率 (单位:0.001% 倍率:100000)
PropertyFinancialNetProfitRatio = 4_107
净利率 (单位:0.001% 倍率:100000)
PropertyFinancialGrossProfitRatio = 4_108
毛利率 (单位:0.001% 倍率:100000)
PropertyFinancialDebtToAssetsRatio = 4_109
资产负债率 (单位:0.001% 倍率:100000)
PropertyFinancialReturnToNetAssetsRatio = 4_110
净资产收益率 (单位:0.001% 倍率:100000)
PropertyFinancialReleasedDate = 4_111
财报日期(时间戳-秒)(单位:1,倍率:1)
PropertyFinancialEbitda = 4_201
盈利能力因子
税息折旧及摊销前利润 (单位:0.001元 倍率:1000)
PropertyFinancialRoic = 4_202
投入资本回报率 (单位:0.001% 倍率:100000)
PropertyFinancialEbitMargin = 4_203
EBIT利润率 (单位:0.001% 倍率:100000)
PropertyFinancialEbitdaMargin = 4_204
EBITDA利润率 (单位:0.001% 倍率:100000)
PropertyFinancialFinancialCostRate = 4_205
财务成本率 (单位:0.001% 倍率:100000)
PropertyFinancialEbitTtm = 4_206
息税前利润(TTM) (单位:0.001元 倍率:1000)
PropertyFinancialOperatingProfitTtm = 4_207
营业利润(TTM) (单位:0.001元 倍率:1000)
归属于母公司的净利润(TTM) (单位:0.001元 倍率:1000)
PropertyFinancialRoaTtm = 4_209
资产回报率(TTM) (单位:0.001% 倍率:100000)
PropertyFinancialOperatingMarginTtm = 4_210
营业利润率(TTM) (单位:0.001% 倍率:100000)
PropertyFinancialNetProfitCashCoverTtm = 4_211
盈利中的现金收入比例(TTM) (单位:0.001% 倍率:100000)
PropertyFinancialRdExpenseRatio = 4_212
研发费用率(单位:0.001% 倍率:100000)
PropertyFinancialSellingExpenseRatio = 4_213
销售费用率(单位:0.001% 倍率:100000)
PropertyFinancialManageExpenseRatio = 4_214
管理费用率(单位:0.001% 倍率:100000)
PropertyFinancialOperatingProfitRate = 4_215
经营利润率(单位:0.001% 倍率:100000)
PropertyFinancialProfitBeforeTaxRate = 4_216
税前利润率(单位:0.001% 倍率:100000)
PropertyFinancialDividendsTtm = 4_217
股息TTM(单位:0.001 倍率:1000)
PropertyFinancialDividendsLfy = 4_218
股息LFY(单位:0.001 倍率:1000)
PropertyFinancialDividendsTtmRatio = 4_219
股息率TTM(单位:0.001% 倍率:100000)
PropertyFinancialDividendsLfyRatio = 4_220
股息率LFY(单位:0.001% 倍率:100000)
PropertyFinancialCurrentRatio = 4_301
偿债能力因子
流动比率 (单位:0.001% 倍率:100000)
PropertyFinancialQuickRatio = 4_302
速动比率 (单位:0.001% 倍率:100000)
长期负债股东权益比率(单位:0.001% 倍率:100000)
PropertyFinancialFinancialLeverage = 4_304
财务杠杆(单位:0.001% 倍率:100000)
PropertyFinancialInterestBearingDebtRatio = 4_305
有息负债率(单位:0.001% 倍率:100000)
PropertyFinancialCashAndCashEquivalents = 4_401
清债能力因子
现金和现金等价 (单位:0.001元 倍率:1000)
PropertyFinancialCurrentAssetRatio = 4_402
流动资产率 (单位:0.001% 倍率:100000)
PropertyFinancialCurrentDebtRatio = 4_403
流动负债率 (单位:0.001% 倍率:100000)
PropertyFinancialEquityMultiplier = 4_404
权益乘数 (单位:0.001% 倍率:100000)
PropertyFinancialPropertyRatio = 4_405
产权比率 (单位:0.001% 倍率:100000)
PropertyFinancialAccountsReceviable = 4_501
运营能力因子
应收帐款净额 (单位:0.001元 倍率:1000)
PropertyFinancialTotalAssetTurnover = 4_502
总资产周转率 (单位:0.001% 倍率:100000)
PropertyFinancialFixedAssetTurnover = 4_503
固定资产周转率 (单位:0.001% 倍率:100000)
PropertyFinancialInventoryTurnover = 4_504
存货周转率 (单位:0.001% 倍率:100000)
PropertyFinancialOperatingCashFlowTtm = 4_505
经营活动现金流(TTM) (单位:0.001元 倍率:1000)
PropertyFinancialMoneyTurnoverCycle = 4_506
资金周转周期(天)(单位:0.001,倍率:1000)
PropertyFinancialAccountsReceivableRate = 4_507
应收帐款周转率(次)(单位:0.001,倍率:1000)
PropertyFinancialFreeCashFlowIncomeRatio = 4_508
自由现金流与收入比率(单位:0.001% 倍率:100000)
PropertyFinancialFreeCashFlowParentCompanyNetProfitRatio = 4_509
自由现金流与母公司净利润比率(单位:0.001% 倍率:100000)
PropertyFinancialTurnoverRateCurrentAssetsRatio = 4_510
流动资产周转率(次)(单位:0.001,倍率:1000)
PropertyFinancialIncomePerCapita = 4_511
人均营收(参数:Term)(单位:1 倍率:1000)
PropertyFinancialProfitPerCapita = 4_512
人均营业利润(参数:Term)(单位:1 倍率:1000)
PropertyFinancialNetProfitPerCapita = 4_513
人均净利润(参数:Term)(单位:1 倍率:1000)
PropertyFinancialEbitGrowthRate = 4_601
成长能力
EBIT同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialOperatingProfitGrowthRate = 4_602
营业利润同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialTotalAssetsGrowthRate = 4_603
总资产同比增长率 (单位:0.001% 倍率:100000)
归母净利润同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialProfitBeforeTaxGrowthRate = 4_605
总利润同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialEpsGrowthRate = 4_606
EPS同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRoeGrowthRate = 4_607
ROE同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRoicGrowthRate = 4_608
ROIC同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialNocfGrowthRate = 4_609
经营现金流同比增长率 (单位:0.001% 倍率:100000)
每股经营现金流同比增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRevenueCagr = 4_611
总收入复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialGrossProfitCagr = 4_612
毛利润复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialEbitdaCagr = 4_613
EBITDA复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialEbitCagr = 4_614
EBIT复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialNetProfitCagr = 4_615
净利润复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialStockholderProfitCagr = 4_616
归属于普通股利润复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialNetMarginCagr = 4_617
归母净利润 复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialOperatingProfitCagr = 4_618
营业利润复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialFreeCashCagr = 4_619
自由现金流复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialTotalAssetsCagr = 4_620
总资产复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialBasicEpsCagr = 4_621
EPS复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRoaCagr = 4_622
ROA复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRoeCagr = 4_623
ROE复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialRoicCagr = 4_624
ROIC复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialDividendCagr = 4_625
股息复合年均增长率 (单位:0.001% 倍率:100000)
PropertyFinancialFreeCashFlowGrowthRate = 4_626
自由现金流同比增长率 (单位:0.001% 倀率:1e5)
PropertyFinancialOperatingRevenueCashCover = 4_701
现金流
经营现金收入比 (单位:0.001% 倍率:100000)
PropertyFinancialOperatingProfitToTotalProfit = 4_702
营业利润占比 (单位:0.001% 倍率:100000)
PropertyFinancialFreeCashFlow = 4_703
自由现金流 (单位:1 倍率:1e3)
PropertyFinancialBasicEps = 4_801
市场表现
基本每股收益 (单位:0.001元 倍率:1000)
PropertyFinancialDilutedEps = 4_802
稀释每股收益 (单位:0.001元 倍率:1000)
每股经营现金净流量 (单位:0.001元 倍率:1000)
基础量价因子
总股数 (单位:1股 倍率:1)
流通股数 (单位:1股 倍率:1)
PropertyFinancialFloatMarketCap = 4_903
流通市值 (单位:0.001元 倍率:1000)
PropertyFinancialPsTtm = 4_904
市销率(TTM) (单位:0.001% 倍率:100000)
PropertyFinancialPriceCashFlowRatioTtm = 4_905
市现率(TTM) (单位:0.001% 倍率:100000)
PropertyFinancialSurpriseEpsReleasedDate = 4_906
财务超预期
财报EPS发布日,时间戳(秒)
PropertyFinancialSurpriseRevenueReleasedDate = 4_907
财报REVENUE发布日,时间戳(秒)
PropertyFinancialSurpriseEbitReleasedDate = 4_908
财报EBIT发布日,时间戳(秒)
PropertyFinancialSurpriseActualEps = 4_909
真实值eps,倍数1e4
PropertyFinancialSurpriseActualRevenue = 4_910
真实值revenue,倍数1e4
PropertyFinancialSurpriseActualEbit = 4_911
真实值ebit,倍数1e4
PropertyFinancialSurpriseEstimateEps = 4_912
预测值eps,倍数1e4
PropertyFinancialSurpriseEstimateRevenue = 4_913
预测值revenue,倍数1e4
PropertyFinancialSurpriseEstimateEbit = 4_914
预测值ebit,倍数1e4
PropertyFinancialSurpriseEpsBeatRatio = 4_915
超预期比例eps,倍数1e5
PropertyFinancialSurpriseRevenueBeatRatio = 4_916
超预期比例revenue,倍数1e5
PropertyFinancialSurpriseEbitBeatRatio = 4_917
超预期比例ebit,倍数1e5
PropertyFinancialSurpriseEpsYoy = 4_918
去年同期eps,倍数1e4
PropertyFinancialSurpriseRevenueYoy = 4_919
去年同期revenue,倍数1e4
PropertyFinancialSurpriseEbitYoy = 4_920
去年同期ebit,倍数1e4
PropertyFinancialSurpriseEpsYoyGrowth = 4_921
同比增长率eps,倍数1e5
PropertyFinancialSurpriseRevenueYoyGrowth = 4_922
同比增长率revenue,倍数1e5
PropertyFinancialSurpriseEbitYoyGrowth = 4_923
同比增长率ebit,倍数1e5
PropertyFinancialSurpriseEpsTerm = 4_924
eps财报周期,2024/FY 2024/Q1 2024/H1
PropertyFinancialSurpriseRevenueTerm = 4_925
revenue财报周期,2024/FY 2024/Q1 2024/H1
PropertyFinancialSurpriseEbitTerm = 4_926
eps财报周期,2024/FY 2024/Q1 2024/H1
PropertyFinancialSurpriseEpsEarningDayChg = 4_927
eps财报日涨跌幅,倍数1e5
PropertyFinancialSurpriseRevenueEarningDayChg = 4_928
revenue财报日涨跌幅,倍数1e5
PropertyFinancialSurpriseEbitEarningDayChg = 4_929
ebit财报日涨跌幅,倍数1e5
PropertyFinancialSurpriseEpsPostEarningDayChg = 4_930
eps财报第二日涨跌幅,倍数1e5
PropertyFinancialSurpriseRevenuePostEarningDayChg = 4_931
revenue财报第二日涨跌幅,倍数1e5
PropertyFinancialSurpriseEbitPostEarningDayChg = 4_932
ebit财报第二日涨跌幅,倍数1e5
PropertyFinancialSurpriseEpsDetailPostPeriod = 4_933
eps财报具体时间,返回值参见SURPRISE_POST_PERIOD
PropertyFinancialSurpriseRevenueDetailPostPeriod = 4_934
revenue财报具体时间,返回值参见SURPRISE_POST_PERIOD
PropertyFinancialSurpriseEbitDetailPostPeriod = 4_935
eps财报具体时间,返回值参见SURPRISE_POST_PERIOD
PropertyFinancialSurpriseEpsEarningDayChgV2 = 4_936
EPS财报日涨跌幅v2(倍数: 1e5)
PropertyFinancialSurpriseRevenueEarningDayChgV2 = 4_937
REVENUE财报日涨跌幅v2(倍数: 1e5)
PropertyFinancialSurpriseEbitEarningDayChgV2 = 4_938
EBIT财报日涨跌幅v2(倍数: 1e5)
PropertyFinancialSurpriseEpsReleasedDateV2 = 4_939
EPS财报发布日v2,时间戳
PropertyFinancialSurpriseRevenueReleasedDateV2 = 4_940
REVENUE财报发布日v2,时间戳
PropertyFinancialSurpriseEbitReleasedDateV2 = 4_941
EBIT财报发布日v2,时间戳
PropertyFinancialSurpriseEpsDetailPostPeriodV2 = 4_942
EPS财报发布具体时间v2,返回值参见SURPRISE_POST_PERIOD
PropertyFinancialSurpriseRevenueDetailPostPeriodV2 = 4_943
REVENUE财报发布具体时间v2,返回值参见SURPRISE_POST_PERIOD
PropertyFinancialSurpriseEbitDetailPostPeriodV2 = 4_944
EBIT财报发布具体时间v2,返回值参见SURPRISE_POST_PERIOD
Implementations
Sourceimpl PropertyNameFinancial
impl PropertyNameFinancial
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of PropertyNameFinancial.
Sourcepub fn from_i32(value: i32) -> Option<PropertyNameFinancial>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PropertyNameFinancial>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PropertyNameFinancial, or None if value is not a valid variant.
Sourceimpl PropertyNameFinancial
impl PropertyNameFinancial
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.