#[repr(i32)]pub enum SimpleField {
Market = 1,
Exchange = 2,
IndexId = 3,
UseWatchlistStocks = 4,
HasAdr = 5,
HasOption = 6,
HasWarrant = 7,
HasFuture = 8,
HasAhStock = 9,
IsIslamicStock = 10,
NorthBoundId = 11,
MmExclusiveId = 12,
}Expand description
简单字段
Variants
Market = 1
市场(取值如上枚举Market)(目前仅支持填单个市场)
Exchange = 2
交易所/上市地(多个 交易所/上市地 与老筛选协议保存一致,是 并集 关系)
IndexId = 3
指数ID(多个 指数ID 与老协议保持一致,是 并集 关系)
UseWatchlistStocks = 4
是否使用自选股(0: 不用自选股,1: 使用自选股)
HasAdr = 5
是否有关联adr标的(0: 筛选没有关联adr的股票,1: 筛选有关联adr的股票)
HasOption = 6
是否含期权标的(0: 筛选不含期权的股票,1: 筛选含期权的股票)
HasWarrant = 7
是否含窝轮标的(0: 筛选不含窝轮的股票,1: 筛选含有窝轮的股票)
HasFuture = 8
是否含期货标的(0: 筛选不含期货的股票,1: 筛选含期货的股票)
HasAhStock = 9
是否有关联AH股的标的(0: 筛选没有关联AH股的股票,筛选有关联AH股的股票)
IsIslamicStock = 10
是否回教股(0: 筛选非回教股,1:筛选回教股)
NorthBoundId = 11
北向板块ID(支持沪股通、深股通)
MmExclusiveId = 12
Moomoo独家股票板块ID(参数板块ID)
Implementations
Sourceimpl SimpleField
impl SimpleField
Sourceimpl SimpleField
impl SimpleField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.