#[repr(i32)]pub enum SurprisePostPeriod {
Regular = 0,
Before = 1,
After = 2,
IntradayTrading = 3,
}Expand description
超预期财报发布时段
Variants
Implementations
Sourceimpl SurprisePostPeriod
impl SurprisePostPeriod
Sourcepub fn from_i32(value: i32) -> Option<SurprisePostPeriod>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SurprisePostPeriod>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SurprisePostPeriod, or None if value is not a valid variant.
Sourceimpl SurprisePostPeriod
impl SurprisePostPeriod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.