pub struct PropertyFeatured {
pub name: Option<i32>,
pub period: Option<i32>,
pub range_period: Option<i32>,
pub first_custom_param: Option<i64>,
}Fields
name: Option<i32>枚举如上Featured所示
period: Option<i32>K线周期,用于指标解读
range_period: Option<i32>first_custom_param: Option<i64>范围周期: 1、用于公司估值,枚举参考RangePeriod 2、用于IFIS业绩修正,枚举参考RecentDuration 3、用于FEATURED_ANALYST_INST_RATING_CHANGE分析师机构评级变动,枚举参考RecentDuration 4、用于FEATURED_EMPLOYEE_NUM_GROWTH员工人数增长率,枚举参考RecentDuration,近支持近1年、3年、5年
通用自定义参数1,目前支持单选参数: 1、比如CashFlowPeriod周期枚举 2、FEATURED_DISTRIBUTION_FREQUENCY参数枚举 3、评级变动类型枚举RatingChangeType 4、行情指标FEATURED_INDICATOR_PEARSON_CORRELATION、FEATURED_INDICATOR_BETA填对应的板块ID 5、FEATURED_INST_INSTITUTION_STOCK_OWNERSHIP_RATIO参数,机构ID
Implementations
Sourceimpl PropertyFeatured
impl PropertyFeatured
Sourcepub fn period(&self) -> Period
pub fn period(&self) -> Period
Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: Period)
pub fn set_period(&mut self, value: Period)
Sets period to the provided enum value.
Sourcepub fn range_period(&self) -> i32
pub fn range_period(&self) -> i32
Returns the value of range_period, or the default value if range_period is unset.
Sourcepub fn first_custom_param(&self) -> i64
pub fn first_custom_param(&self) -> i64
Returns the value of first_custom_param, or the default value if first_custom_param is unset.