pub struct PropertyOption {
pub name: Option<i32>,
pub param: Option<Param>,
pub period: Option<i32>,
}Fields
name: Option<i32>枚举如上 Option 所示
param: Option<Param>指标StockEarningsIVCrush参数
period: Option<i32>指标StockHV参数
Implementations
Sourceimpl PropertyOption
impl PropertyOption
Sourcepub fn period(&self) -> OptionHvRangePeriod
pub fn period(&self) -> OptionHvRangePeriod
Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: OptionHvRangePeriod)
pub fn set_period(&mut self, value: OptionHvRangePeriod)
Sets period to the provided enum value.