QueryPropertyFinancial

Struct QueryPropertyFinancial 

pub struct QueryPropertyFinancial {
    pub property: PropertyFinancial,
    pub lower: Option<Bounary>,
    pub upper: Option<Bounary>,
    pub continuous_period: Option<i32>,
    pub unit: Option<i32>,
    pub testa: Option<i32>,
    pub testb: Option<i32>,
}

Fields

property: PropertyFinancial

财务属性查询

lower: Option<Bounary>

区间下限

upper: Option<Bounary>

区间上限

continuous_period: Option<i32>

连续周期

unit: Option<i32>

数值单位:由客户端语言决定单位,单位仅用于展示,不影响lower和upper的具体数值,不影响选股器筛选结果

参考unit_lvl

testa: Option<i32>
👎Deprecated

废弃

testb: Option<i32>
👎Deprecated

Implementations

Source

impl QueryPropertyFinancial

pub fn continuous_period(&self) -> i32

Returns the value of continuous_period, or the default value if continuous_period is unset.

pub fn testa(&self) -> i32

Returns the value of testa, or the default value if testa is unset.

pub fn testb(&self) -> i32

Returns the value of testb, or the default value if testb is unset.

pub fn unit(&self) -> i32

Returns the value of unit, or the default value if unit is unset.