#[repr(i32)]pub enum AuthState {
Show 19 variants
UnknownAuth = 0,
StockHkLv2 = 1,
StockHkBmp = 2,
StockUsUtp = 3,
StockUsBasic = 4,
StockCnLv2 = 5,
StockSgRealtime = 6,
StockSgBmp = 7,
StockCnDelay = 8,
StockCaRealtime = 9,
StockCaDelay = 10,
StockAuRealtime = 13,
StockAuDelay = 14,
StockCnbjshow = 15,
StockCnbjFilter = 16,
StockJaRealtime = 17,
StockJaDelay = 18,
StockMyRealtime = 19,
StockMyDelay = 20,
}Variants
UnknownAuth = 0
以下为权限定义
StockHkLv2 = 1
港股实时权限
StockHkBmp = 2
港股bmp权限
StockUsUtp = 3
美股utp权限
StockUsBasic = 4
美股基本权限
StockCnLv2 = 5
A股实时权限
StockSgRealtime = 6
新加坡股票实时权限
StockSgBmp = 7
新加坡股票bmp权限
StockCnDelay = 8
A股延时权限
StockCaRealtime = 9
加拿大股票实时权限
StockCaDelay = 10
加拿大股票延时权限
StockAuRealtime = 13
澳大利亚股票实时权限
StockAuDelay = 14
澳大利亚股票延时权限
StockCnbjshow = 15
展示北交所
StockCnbjFilter = 16
屏蔽北交所
StockJaRealtime = 17
日本股票实时权限
StockJaDelay = 18
日本股票延时权限
StockMyRealtime = 19
马来西亚股票实时权限
StockMyDelay = 20
马来西亚股票延时权限
Implementations
Sourceimpl AuthState
impl AuthState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.