pub struct Item {
pub stock_id: Option<u64>,
pub valuation_type: Option<i32>,
pub interval_type: Option<i32>,
pub valuation_data: Option<ValuationData>,
pub plate_statistics: Option<PlateStatistics>,
pub plate_data: Option<PlateData>,
pub market_statistics: Option<MarketStatistics>,
pub valuation_percentile: Option<u64>,
}Fields
stock_id: Option<u64>valuation_type: Option<i32>interval_type: Option<i32>valuation_data: Option<ValuationData>plate_statistics: Option<PlateStatistics>plate_data: Option<PlateData>market_statistics: Option<MarketStatistics>valuation_percentile: Option<u64>Implementations
Sourceimpl Item
impl Item
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn valuation_type(&self) -> ValuationType
pub fn valuation_type(&self) -> ValuationType
Returns the enum value of valuation_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_valuation_type(&mut self, value: ValuationType)
pub fn set_valuation_type(&mut self, value: ValuationType)
Sets valuation_type to the provided enum value.
Sourcepub fn interval_type(&self) -> IntervalType
pub fn interval_type(&self) -> IntervalType
Returns the enum value of interval_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_interval_type(&mut self, value: IntervalType)
pub fn set_interval_type(&mut self, value: IntervalType)
Sets interval_type to the provided enum value.
Sourcepub fn valuation_percentile(&self) -> u64
pub fn valuation_percentile(&self) -> u64
Returns the value of valuation_percentile, or the default value if valuation_percentile is unset.