pub struct GetDetailResponse {
pub result: Option<i32>,
pub items: Vec<Item>,
pub last_update_time: Option<u64>,
}Fields
result: Option<i32>items: Vec<Item>last_update_time: Option<u64>Implementations
Sourceimpl GetDetailResponse
impl GetDetailResponse
Sourcepub fn result(&self) -> Result
pub fn result(&self) -> Result
Returns the enum value of result, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_result(&mut self, value: Result)
pub fn set_result(&mut self, value: Result)
Sets result to the provided enum value.
Sourcepub fn last_update_time(&self) -> u64
pub fn last_update_time(&self) -> u64
Returns the value of last_update_time, or the default value if last_update_time is unset.