#[repr(i32)]pub enum CryptoCltActionType {
CCltActionTypeUnspecified = 0,
CCltActionTypeUpdateCipher = 1,
CCltActionTypeOpenUrl = 2,
}Variants
CCltActionTypeUnspecified = 0
取srpc头里的code和msg
CCltActionTypeUpdateCipher = 1
需要引导客户更新cipher
CCltActionTypeOpenUrl = 2
需要引导客户打开URL
Implementations
Sourceimpl CryptoCltActionType
impl CryptoCltActionType
Sourcepub fn from_i32(value: i32) -> Option<CryptoCltActionType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CryptoCltActionType>
Converts an i32 to a CryptoCltActionType, or None if value is not a valid variant.
Sourceimpl CryptoCltActionType
impl CryptoCltActionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.