#[repr(i32)]pub enum CryptoNoticeType {
CNoticeTypeOrderUnspecified = 0,
CNoticeTypeOrderUpdate = 1,
CNoticeTypeOrderFillUpdate = 2,
CNoticeTypeOrderOpResult = 3,
}Variants
CNoticeTypeOrderUnspecified = 0
CNoticeTypeOrderUpdate = 1
订单更新
CNoticeTypeOrderFillUpdate = 2
成交更新
CNoticeTypeOrderOpResult = 3
订单操作结果通知,也就是下改撤操作结果通知
Implementations
Sourceimpl CryptoNoticeType
impl CryptoNoticeType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.