#[repr(i32)]pub enum CryptoOrderStatus {
COrderStatusUnspecified = 0,
COrderStatusProcessing = 1,
COrderStatusPending = 2,
COrderStatusPartial = 3,
COrderStatusDone = 4,
COrderStatusCanceled = 5,
COrderStatusRejected = 6,
COrderStatusPartialAndCancel = 7,
COrderStatusInvalid = 101,
COrderStatusPendingSubmissing = 102,
COrderStatusDoneButCancelled = 103,
COrderStatusDeleted = 104,
}Expand description
订单状态(客户端/ROA展示用)
Variants
COrderStatusUnspecified = 0
COrderStatusProcessing = 1
交易svr处理中(提交中)
COrderStatusPending = 2
已提交,等待成交
COrderStatusPartial = 3
部分成交
COrderStatusDone = 4
完全成交
COrderStatusCanceled = 5
订单被撤销,无成交
COrderStatusRejected = 6
订单被拒绝(下单失败,服务拒绝)
COrderStatusPartialAndCancel = 7
部分成交后,剩余部分被撤销
COrderStatusInvalid = 101
超过有效期(已失效)
COrderStatusPendingSubmissing = 102
等待提交至上游
COrderStatusDoneButCancelled = 103
订单成交后被上游回滚撤销(成交被撤销)
COrderStatusDeleted = 104
客户端删除订单,不展示
Implementations
Sourceimpl CryptoOrderStatus
impl CryptoOrderStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.