#[repr(i32)]pub enum CryptoSimpleOrderStatus {
CSimpleOrderStatusUnspecified = 0,
CSimpleOrderStatusFilled = 1,
CSimpleOrderStatusCanceled = 2,
CSimpleOrderStatusFailed = 3,
CSimpleOrderStatusSubmitting = 4,
CSimpleOrderStatusPending = 5,
CSimpleOrderStatusDeactivated = 6,
}Expand description
简单订单状态
Variants
CSimpleOrderStatusUnspecified = 0
CSimpleOrderStatusFilled = 1
已成交(done)
CSimpleOrderStatusCanceled = 2
已撤销(canceled、partial and cancel、done but cancelled)
CSimpleOrderStatusFailed = 3
下单失败(rejected)
CSimpleOrderStatusSubmitting = 4
待提交(processing、pending submitting)
CSimpleOrderStatusPending = 5
待成交(pending、partial)
CSimpleOrderStatusDeactivated = 6
已失效(invalid)
Implementations
Sourceimpl CryptoSimpleOrderStatus
impl CryptoSimpleOrderStatus
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of CryptoSimpleOrderStatus.
Sourcepub fn from_i32(value: i32) -> Option<CryptoSimpleOrderStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CryptoSimpleOrderStatus>
Converts an i32 to a CryptoSimpleOrderStatus, or None if value is not a valid variant.
Sourceimpl CryptoSimpleOrderStatus
impl CryptoSimpleOrderStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.