#[repr(i32)]pub enum FeeType {
Unspecified = 0,
Commission = 1,
PlatformFee = 2,
Gst = 3,
SettlementInstruction = 4,
Trading = 5,
WithholdingFee = 6,
}Expand description
费用类型
Variants
Unspecified = 0
Commission = 1
佣金
PlatformFee = 2
平台使用费
Gst = 3
GST-消费税
SettlementInstruction = 4
清结算费
Trading = 5
交易佣金
WithholdingFee = 6
mci-withholding-fee 身份未验证收取的税费
Implementations
Sourceimpl FeeType
impl FeeType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.