#[repr(i32)]pub enum FixExecType {
Show 14 variants
Unspecified = 0,
New = 1,
PartialFill = 2,
Fill = 3,
Canceled = 4,
Replaced = 5,
PendingNew = 6,
PendingCancel = 7,
PendingReplace = 8,
Rejected = 9,
Suspended = 10,
Expired = 11,
Restated = 12,
Trade = 13,
}Expand description
FIX协议的报告执行类型
Variants
Unspecified = 0
New = 1
新订单
PartialFill = 2
订单部分成交
Fill = 3
订单全部成交
Canceled = 4
订单被撤销
Replaced = 5
订单被替换
PendingNew = 6
订单等待提交
PendingCancel = 7
订单等待撤销
PendingReplace = 8
订单等待替换
Rejected = 9
订单被拒绝
Suspended = 10
订单被暂停
Expired = 11
订单过期
Restated = 12
订单被重置
Trade = 13
订单成交(部分成交或全部成交)
Implementations
Sourceimpl FixExecType
impl FixExecType
Sourceimpl FixExecType
impl FixExecType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.