#[repr(i32)]pub enum FixMsgType {
Unspecified = 0,
New = 1,
Replace = 2,
Cancel = 3,
ExecutionReport = 4,
CxlRejectReport = 5,
RejectReport = 6,
BusinessReject = 7,
Heartbeat = 8,
}Expand description
FIX协议的消息类型
Variants
Unspecified = 0
New = 1
下单
Replace = 2
改单
Cancel = 3
撤单
ExecutionReport = 4
执行报告
CxlRejectReport = 5
改撤单的拒绝报告
RejectReport = 6
拒绝报告
BusinessReject = 7
业务规则拒绝
Heartbeat = 8
心跳
Implementations
Sourceimpl FixMsgType
impl FixMsgType
Sourceimpl FixMsgType
impl FixMsgType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.