#[repr(i32)]pub enum InputSourceType {
Unspecified = 0,
Client = 1,
Roa = 2,
Manual = 3,
}Expand description
订单操作来源
Variants
Implementations
Sourceimpl InputSourceType
impl InputSourceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.