#[repr(i32)]pub enum ManualOrdStatus {
Unspecified = 0,
Wait = 1,
Failed = 2,
PendingReview = 3,
Approved = 4,
Rejected = 5,
Executed = 6,
Withdrawn = 7,
}Expand description
人工单状态
Variants
Unspecified = 0
未知状态
Wait = 1
等待创建
Failed = 2
创建失败
PendingReview = 3
等待审批
Approved = 4
审批通过
Rejected = 5
已拒绝
Executed = 6
已生效
Withdrawn = 7
已撤销
Implementations
Sourceimpl ManualOrdStatus
impl ManualOrdStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.