#[repr(i32)]pub enum OrderOpType {
Unspecified = 0,
New = 1,
Cancel = 2,
Replace = 3,
}Expand description
订单操作类型
Variants
Implementations
Sourceimpl OrderOpType
impl OrderOpType
Sourceimpl OrderOpType
impl OrderOpType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.