#[repr(i32)]pub enum SecurityType {
Unknown = 0,
Common = 1,
Option = 2,
Fund = 3,
Futures = 4,
Bond = 5,
Crypto = 6,
Multileg = 7,
Forex = 8,
StructuredNote = 9,
}Expand description
复用证券
Variants
Unknown = 0
未知类型
Common = 1
正股、窝轮、ETF等
Option = 2
期权(美股期权、港股期权)
Fund = 3
富途的基金(如现金宝)
Futures = 4
期货
Bond = 5
债券
Crypto = 6
数字币订单
Multileg = 7
多腿订单, 下多腿订单的时候一定要填这个值
Forex = 8
外汇
StructuredNote = 9
结构化票据
Implementations
Sourceimpl SecurityType
impl SecurityType
Sourceimpl SecurityType
impl SecurityType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.