#[repr(i32)]pub enum StockMarket {
Crypto = 7,
}Expand description
复用证券(也叫trade market)
Variants
Crypto = 7
数字货币市场
Implementations
Sourceimpl StockMarket
impl StockMarket
Sourceimpl StockMarket
impl StockMarket
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.