CryptoCltActionOpenUrl

Struct CryptoCltActionOpenUrl 

pub struct CryptoCltActionOpenUrl {
    pub title: Option<String>,
    pub content: Option<String>,
    pub confirm_button_title: Option<String>,
    pub target: Option<u32>,
    pub cancel_button_title: Option<String>,
}

Fields

title: Option<String>

显示弹窗标题文案

content: Option<String>

显示弹窗内容文案

confirm_button_title: Option<String>

显示确认按钮文案

target: Option<u32>

跳转的url地址

cancel_button_title: Option<String>

显示取消按钮文案

Implementations

Source

impl CryptoCltActionOpenUrl

pub fn title(&self) -> &str

Returns the value of title, or the default value if title is unset.

pub fn content(&self) -> &str

Returns the value of content, or the default value if content is unset.

pub fn confirm_button_title(&self) -> &str

Returns the value of confirm_button_title, or the default value if confirm_button_title is unset.

pub fn target(&self) -> u32

Returns the value of target, or the default value if target is unset.

pub fn cancel_button_title(&self) -> &str

Returns the value of cancel_button_title, or the default value if cancel_button_title is unset.