pub struct UsShortDailyInfo {
pub timestamp: Option<u64>,
pub total_shares_short: Option<u64>,
pub nasdaq_shares_short: Option<u64>,
pub nyse_shares_short: Option<u64>,
pub short_percent: Option<u32>,
pub volume: Option<u64>,
pub close_price: Option<i64>,
pub last_close_price: Option<i64>,
pub daily_trade_avg_ratio: Option<i32>,
}Fields
timestamp: Option<u64>short_percent: Option<u32>volume: Option<u64>close_price: Option<i64>last_close_price: Option<i64>daily_trade_avg_ratio: Option<i32>Implementations
Sourceimpl UsShortDailyInfo
impl UsShortDailyInfo
Sourcepub fn timestamp(&self) -> u64
pub fn timestamp(&self) -> u64
Returns the value of timestamp, or the default value if timestamp is unset.
Returns the value of total_shares_short, or the default value if total_shares_short is unset.
Returns the value of nasdaq_shares_short, or the default value if nasdaq_shares_short is unset.
Returns the value of nyse_shares_short, or the default value if nyse_shares_short is unset.
Sourcepub fn short_percent(&self) -> u32
pub fn short_percent(&self) -> u32
Returns the value of short_percent, or the default value if short_percent is unset.
Sourcepub fn volume(&self) -> u64
pub fn volume(&self) -> u64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn close_price(&self) -> i64
pub fn close_price(&self) -> i64
Returns the value of close_price, or the default value if close_price is unset.
Sourcepub fn last_close_price(&self) -> i64
pub fn last_close_price(&self) -> i64
Returns the value of last_close_price, or the default value if last_close_price is unset.
Sourcepub fn daily_trade_avg_ratio(&self) -> i32
pub fn daily_trade_avg_ratio(&self) -> i32
Returns the value of daily_trade_avg_ratio, or the default value if daily_trade_avg_ratio is unset.