#[repr(i32)]pub enum ResultCode {
Success = 0,
ServerErr = 1,
ParamErr = 2,
ExcessMaxLimitErr = 3,
GroupNameLenExcess = 4,
InvalidUserId = 5,
IllegalOpearteSystemGroup = 6,
GroupNoExist = 7,
GroupListDiffer = 8,
SecListDiffer = 9,
}Variants
Success = 0
成功
ServerErr = 1
ParamErr = 2
请求参数有误
ExcessMaxLimitErr = 3
超过最大限制,添加分组、自选会出现错误
GroupNameLenExcess = 4
分组名超过最大限制50
InvalidUserId = 5
错误user_id
IllegalOpearteSystemGroup = 6
非法操作系统分组(1、系统分组删除改名;2、全部分组隐藏;3、往非全部、特别关心的系统分组添加自选)
GroupNoExist = 7
GroupListDiffer = 8
分组列表不一致,需要重新拉取
SecListDiffer = 9
自选列表不一致,需要重新拉取
Implementations
Sourceimpl ResultCode
impl ResultCode
Sourceimpl ResultCode
impl ResultCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.