#[repr(i32)]pub enum SystemGroupType {
Show 16 variants
All = 1_000,
Cn = 899,
Hk = 898,
Us = 897,
Position = 896,
UsOpt = 895,
Focus = 894,
HkOpt = 893,
Future = 892,
Forex = 891,
Fund = 890,
Option = 889,
Bond = 888,
Sg = 887,
Index = 886,
Crypto = 885,
}Variants
All = 1_000
全部分组
Cn = 899
沪深
Hk = 898
港股
Us = 897
美股
Position = 896
持仓
UsOpt = 895
美股期权
Focus = 894
特别关注
HkOpt = 893
港股期权
Future = 892
期货
Forex = 891
外汇
Fund = 890
基金
Option = 889
期权
Bond = 888
债券
Sg = 887
新加坡
Index = 886
指数
Crypto = 885
数字货币
Implementations
Sourceimpl SystemGroupType
impl SystemGroupType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.