FieldId

#[repr(i32)]
pub enum FieldId {
Show 49 variants Unknown = 0, Code = 1, Name = 2, IssuerId = 4, StockOwner = 5, WarrantType = 6, ConversionRatio = 7, CurrentPrice = 8, StreetRatio = 9, Volume = 10, MaturityDate = 11, StrikePrice = 12, Premium = 13, RecoveryPrice = 14, ImpliedVolatility = 15, LeverageRatio = 16, PriceRecoveryRatio = 17, Delta = 18, Status = 19, IpoTime = 20, BuyVol = 21, SellVol = 22, EffectiveLeverage = 23, LastClosePrice = 24, Turnover = 25, SellPrice = 26, BuyPrice = 27, HighPrice = 28, LowPrice = 29, RatioItmOtm = 30, BreakEvenPoint = 31, AmplitudePrice = 32, ScoreFaxing = 33, LastTradeDate = 34, StreetVolume = 35, LotSize = 36, IssueSize = 37, IpoPrice = 38, LowerStrikePrice = 39, UpperStrikePrice = 40, IwPriceStatus = 41, Sensitivity = 42, ConversionPrice = 43, ChangeRate = 44, ChangeValue = 45, Score = 51, FilterNoTradeStatus = 52, CurrencyCode = 53, StockOwnerPrice = 54,
}
FieldId 筛选字段id( 筛选未使用 表示调用方未使用到该筛选项(会返回数据并显示),增量需求要使用该筛选项 需知会@timingxu 并验证下)

Variants



Unknown = 0

默认值,未用



Code = 1

【筛选项】股票/证券代码,文本型 (筛选未使用)



Name = 2

【筛选项】股票名称,文本型 (筛选未使用)



IssuerId = 4

【筛选项】发行商id,数值型



StockOwner = 5

【筛选项】正股id,数值型



WarrantType = 6

【筛选项】窝轮类型,枚举查看 WarrantType,数值型



ConversionRatio = 7

【筛选区间】换股比率,放大10^3



CurrentPrice = 8

【筛选区间】当前价,放大10^3



StreetRatio = 9

【筛选区间】街货占比,放大10^3



Volume = 10

【筛选区间】成交量



MaturityDate = 11

【筛选区间】到期日,时间戳(秒)



StrikePrice = 12

【筛选区间】行使价,放大10^3



Premium = 13

【筛选区间】溢价,放大10^5 ,可为负值



RecoveryPrice = 14

【筛选区间】收回价,放大10^3



ImpliedVolatility = 15

【筛选区间】引伸波幅,,放大10^2



LeverageRatio = 16

【筛选区间】杠杆比率,放大10^3



PriceRecoveryRatio = 17

【筛选区间】正股距收回价% 1001000



Delta = 18

【筛选区间】对冲值,放大10^3



Status = 19

【筛选项】轮证状态,数值型



IpoTime = 20

【筛选区间】上市时间,时间戳(秒)



BuyVol = 21

【筛选区间】买量



SellVol = 22

【筛选区间】卖量



EffectiveLeverage = 23

【筛选区间】有效杠杆,放大10^3



LastClosePrice = 24

【筛选区间】昨收价,放大10^3 (筛选未使用)



Turnover = 25

【筛选区间】成交额



SellPrice = 26

【筛选区间】卖价,放大10^3 (筛选未使用)



BuyPrice = 27

【筛选区间】买价,放大10^3 (筛选未使用)



HighPrice = 28

【筛选区间】最高价,放大10^3 (筛选未使用)



LowPrice = 29

【筛选区间】最低价,放大10^3 (筛选未使用)



RatioItmOtm = 30

【筛选区间】价内/价外,放大10^5,可为负值



BreakEvenPoint = 31

【筛选区间】打和点,放大10^5 (筛选未使用)



AmplitudePrice = 32

【筛选区间】振幅,放大10^5 (筛选未使用)



ScoreFaxing = 33

【筛选区间】法兴评分,放大10^5 (筛选未使用)



LastTradeDate = 34

【筛选区间】最后交易日,时间戳(秒) (筛选未使用)



StreetVolume = 35

【筛选区间】街货量 (筛选未使用)



LotSize = 36

【筛选区间】每手股数 (筛选未使用)



IssueSize = 37

【筛选区间】发行量 (筛选未使用)



IpoPrice = 38

【筛选区间】发行价,放大10^3 (筛选未使用)



LowerStrikePrice = 39

【筛选区间】下限价,放大10^3 (筛选未使用)



UpperStrikePrice = 40

【筛选区间】上限价,放大10^3 (筛选未使用)



IwPriceStatus = 41

【筛选项】界内/界外 (筛选未使用)



Sensitivity = 42

【筛选区间】敏感度,放大10^3 (筛选未使用)



ConversionPrice = 43

【筛选区间】换股价 (筛选未使用)



ChangeRate = 44

【筛选区间】涨跌幅,放大10^3



ChangeValue = 45

【筛选区间】涨跌额



Score = 51

【筛选区间】warrant评分,放大10^5 (筛选未使用)



FilterNoTradeStatus = 52

【筛选项】过滤掉上市后无成交窝轮,0:不过滤 1:过滤 数值型



CurrencyCode = 53

【筛选项】币种,数值型 (筛选未使用)



StockOwnerPrice = 54

【筛选区间】正股价格,放大10^3 (筛选未使用)

Implementations

Source

impl FieldId

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of FieldId.

pub fn from_i32(value: i32) -> Option<FieldId>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a FieldId, or None if value is not a valid variant.

Source

impl FieldId

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.