pub struct EmptyDesiredMarket {
pub mkt_type: u8,
pub is_depth: bool,
}Expand description
Explicit backend market group for an empty CMD6211 set-state request.
Empty requests are used when the last desired item in a market bucket is
removed. They still must carry the original backend route market in protocol
header reserved[0]; routeMarketID=0 is rejected by backend.
Fields
mkt_type: u8is_depth: boolTrait Implementations
Sourceimpl Clone for EmptyDesiredMarket
impl Clone for EmptyDesiredMarket
Sourcefn clone(&self) -> EmptyDesiredMarket
fn clone(&self) -> EmptyDesiredMarket
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmptyDesiredMarket
impl Debug for EmptyDesiredMarket
Sourceimpl Hash for EmptyDesiredMarket
impl Hash for EmptyDesiredMarket
Sourceimpl Ord for EmptyDesiredMarket
impl Ord for EmptyDesiredMarket
Sourcefn cmp(&self, other: &EmptyDesiredMarket) -> Ordering
fn cmp(&self, other: &EmptyDesiredMarket) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EmptyDesiredMarket
impl PartialEq for EmptyDesiredMarket
Sourceimpl PartialOrd for EmptyDesiredMarket
impl PartialOrd for EmptyDesiredMarket
impl Copy for EmptyDesiredMarket
impl Eq for EmptyDesiredMarket
impl StructuralPartialEq for EmptyDesiredMarket