crypto_trade_push_runtime_spec

Function crypto_trade_push_runtime_spec 

pub fn crypto_trade_push_runtime_spec(
    operation: CryptoTradeOperation,
) -> Option<CommandSpec>
Return the unified inbound contract for a crypto trade push.

This inventory is separate from crypto_trade_runtime_spec so these broker pushes can be audited without becoming executable requests.