Struct CryptoTradeCommandSpec
pub struct CryptoTradeCommandSpec {
pub operation: CryptoTradeOperation,
pub cmd: u16,
pub body: CryptoTradeBodyProto,
pub channel: TradeBackendChannel,
}Fields
operation: CryptoTradeOperationcmd: u16body: CryptoTradeBodyProtochannel: TradeBackendChannelImplementations
impl CryptoTradeCommandSpec
impl CryptoTradeCommandSpec
pub const fn wire_format(self) -> WireFormatKind
pub const fn wire_format(self) -> WireFormatKind
C++ currently marks every crypto trade command as encrypted with
security data. Keeping this on the crypto registry avoids making an
inbound push executable through outbound CommandRuntime.