pub struct AccCashInfo {
pub currency: Option<String>,
pub balance: Option<String>,
pub cash_drawable: Option<String>,
pub cash_buypower: Option<String>,
pub hold: Option<String>,
pub available: Option<String>,
}Expand description
账户现金信息
Fields
currency: Option<String>币种无关字段(如果后续有和多币种相关的字段,添加CurrencyData结构,和资金、持仓结构保持一致)
标准货币代码,参考ISO_4217,目前支持币种如HKD, USD,CNH,SGD,JPY
balance: Option<String>现金结余
cash_drawable: Option<String>现金可提金额
cash_buypower: Option<String>现金购买力
hold: Option<String>现金冻结
available: Option<String>现金可用
Implementations
Sourceimpl AccCashInfo
impl AccCashInfo
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn balance(&self) -> &str
pub fn balance(&self) -> &str
Returns the value of balance, or the default value if balance is unset.
Sourcepub fn cash_drawable(&self) -> &str
pub fn cash_drawable(&self) -> &str
Returns the value of cash_drawable, or the default value if cash_drawable is unset.
Sourcepub fn cash_buypower(&self) -> &str
pub fn cash_buypower(&self) -> &str
Returns the value of cash_buypower, or the default value if cash_buypower is unset.