pub struct PositionPl {
pub market: Option<u32>,
pub account_id: Option<u64>,
pub futu_symbol: Option<String>,
pub long_short: Option<String>,
pub exchange: Option<String>,
pub currency: Option<String>,
pub buy_avg_price: Option<String>,
pub realized_profit: Option<String>,
}Fields
market: Option<u32>市场ID,见Market枚举
account_id: Option<u64>业务ID
futu_symbol: Option<String>股票代码,比如700、BABA
long_short: Option<String>仓位类型,LONG/SHORT
exchange: Option<String>交易所,期货用
currency: Option<String>币种,比如HKD、USD
buy_avg_price: Option<String>平均成本价(平均买入价)
realized_profit: Option<String>已实现盈亏
Implementations
Sourceimpl PositionPl
impl PositionPl
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn futu_symbol(&self) -> &str
pub fn futu_symbol(&self) -> &str
Returns the value of futu_symbol, or the default value if futu_symbol is unset.
Sourcepub fn long_short(&self) -> &str
pub fn long_short(&self) -> &str
Returns the value of long_short, or the default value if long_short is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn buy_avg_price(&self) -> &str
pub fn buy_avg_price(&self) -> &str
Returns the value of buy_avg_price, or the default value if buy_avg_price is unset.
Sourcepub fn realized_profit(&self) -> &str
pub fn realized_profit(&self) -> &str
Returns the value of realized_profit, or the default value if realized_profit is unset.