pub struct AccFundInfo {Show 70 fields
pub currency: Option<u32>,
pub total_asset: Option<String>,
pub hold: Option<String>,
pub available: Option<String>,
pub initial_margin: Option<String>,
pub maintenance_margin: Option<String>,
pub max_power_long: Option<String>,
pub max_power_short: Option<String>,
pub drawable: Option<String>,
pub mv: Option<String>,
pub long_mv: Option<String>,
pub short_mv: Option<String>,
pub loan_max: Option<String>,
pub debit_recover: Option<String>,
pub margin_call_balance: Option<String>,
pub margin_call_balance_ratio: Option<String>,
pub margin_call_recover: Option<String>,
pub risk_level: Option<u32>,
pub absolute_safe_mcb_ratio: Option<String>,
pub margin_call: Option<String>,
pub risk_status: Option<u32>,
pub pdt_seq: Vec<i32>,
pub is_pdt: Option<bool>,
pub beginning_dtbp: Option<String>,
pub remaining_dtbp: Option<String>,
pub unrealized_profit: Option<String>,
pub realized_profit: Option<String>,
pub cash_in_credit: Option<String>,
pub dt_call_amount: Option<String>,
pub risk_status_client: Option<i32>,
pub net_cash_power: Option<String>,
pub pending_asset: Option<String>,
pub dt_status: Option<i32>,
pub fund_cashing: Option<bool>,
pub fund_market_value: Option<String>,
pub temp_available_fund_credit: Option<String>,
pub average_profit: Option<String>,
pub diluted_profit: Option<String>,
pub lever_multi: Option<String>,
pub mm_balance_ratio: Option<String>,
pub mm_balance: Option<String>,
pub stock_market: Option<u32>,
pub client_level: Option<u32>,
pub remaining_general_nisa_limit: Option<String>,
pub margin_requirement: Option<String>,
pub remaining_tsumitate_nisa_limit: Option<String>,
pub premium_option_mv: Option<String>,
pub swap: Option<String>,
pub accumulated_incomes: Option<String>,
pub fund_value: Option<String>,
pub custody_balance: Option<String>,
pub available_custody_balance: Option<String>,
pub custody_to_hold_balance: Option<String>,
pub crypto_available: Option<String>,
pub crypto_hold: Option<String>,
pub virtual_limit: Option<String>,
pub remaining_virtual_limit: Option<String>,
pub virtual_limit_state: Option<u32>,
pub elv: Option<String>,
pub buy_power: Option<String>,
pub im: Option<String>,
pub im_ratio: Option<String>,
pub margin_total: Option<String>,
pub margin_cash_total: Option<String>,
pub margin_position_total: Option<String>,
pub withdrawable: Option<String>,
pub accrued_fee: Option<String>,
pub position_im: Option<String>,
pub position_mm: Option<String>,
pub position_sem: Option<String>,
}Expand description
账户资金信息
Fields
currency: Option<u32>货币类型,取值参考 Currency 枚举
total_asset: Option<String>资产净值
hold: Option<String>冻结资金
available: Option<String>可用资金
initial_margin: Option<String>初始保证金
maintenance_margin: Option<String>维持保证金
max_power_long: Option<String>最大做多购买力
max_power_short: Option<String>最大做空购买力
drawable: Option<String>现金可提,和AccCashInfo.cash_drawable一致
mv: Option<String>持仓市值
long_mv: Option<String>多头持仓市值
short_mv: Option<String>空头持仓市值
loan_max: Option<String>最高借贷额
debit_recover: Option<String>追收金额
margin_call_balance: Option<String>MarginCall保证金剩余
margin_call_balance_ratio: Option<String>过夜风控比例
margin_call_recover: Option<String>追缴保证金
risk_level: Option<u32>已废弃,风控监察不会返回,新客户端不使用这个字段
absolute_safe_mcb_ratio: Option<String>RiskLevel==ABSOLUTE_SAFE时, 客户端需用来展示的固定过夜风控比例
margin_call: Option<String>MarginCall保证金
risk_status: Option<u32>需要找风控拿最新的状态码
pdt_seq: Vec<i32>日内交易序列,【美分】目前适用
is_pdt: Option<bool>是否PDT用户
beginning_dtbp: Option<String>日内交易购买力,is_pdt==true时才有
remaining_dtbp: Option<String>剩余日内交易购买力,is_pdt==true时才有
unrealized_profit: Option<String>未实现盈亏
realized_profit: Option<String>已实现盈亏
cash_in_credit: Option<String>入金授信开仓上限,目前只有期货用到
dt_call_amount: Option<String>客户当前由于日内交易的代缴金额
risk_status_client: Option<i32>账户风险状态码,客户端专用
net_cash_power: Option<String>A=1,非常安全 A=2,安全 A=3,较安全 A=4,较低风险 A=5,中等风险 A=6,偏高风险 A=7,预警 A=8,危险 A=9,危险
净现金购买力
pending_asset: Option<String>在途资产净值
dt_status: Option<i32>日内交易状态
fund_cashing: Option<bool>是否采用现金宝现金化,账户为融资账户且现金化开关打开时,该字段为true
fund_market_value: Option<String>证券账户关联的基金账户的现金宝市值
temp_available_fund_credit: Option<String>临时可用基金授信
average_profit: Option<String>累计持仓盈亏(股票)/收益(基金)
diluted_profit: Option<String>累计持仓盈亏(股票)/收益(基金)
lever_multi: Option<String>杠杆倍数
mm_balance_ratio: Option<String>强平比例
mm_balance: Option<String>剩余流动性 elv-mm
stock_market: Option<u32>交易市场 仅diff_market_fund_info_list用到
client_level: Option<u32>(透传风控监察协议0xb8f3)客户端级别类型 0-3定义见 risk_factor_parser.ClientLevel,目前客户端展示的是这个字段
remaining_general_nisa_limit: Option<String>一般nisa子账户的剩余限额
margin_requirement: Option<String>保证金(现金账户)
remaining_tsumitate_nisa_limit: Option<String>储蓄nisa子账户的剩余限额
70~79 号段为期货专用
权利金期权市值
swap: Option<String>80~99号段为杠杆式外汇专用
隔夜利息
accumulated_incomes: Option<String>100~199号段为基金专用
账户级累计收益
fund_value: Option<String>基金持仓市值
custody_balance: Option<String>200~299号数字货币专用
数字货币托管钱包资产
available_custody_balance: Option<String>数字货币托管钱包可用资产
custody_to_hold_balance: Option<String>数字货币托管钱包冻结资产
crypto_available: Option<String>数字货币可用资产
crypto_hold: Option<String>数字货币冻结资产
virtual_limit: Option<String>虚拟资产持仓限额,decimal类型
remaining_virtual_limit: Option<String>虚拟资产剩余持仓限额,不小于0,decimal类型
virtual_limit_state: Option<u32>虚拟资产持仓限额状态,取值枚举见【VIRTUAL_LIMIT_STATE】
elv: Option<String>300~349为JP信用/衍生品账户专用
收入保证金总额(受入保証金合計)
buy_power: Option<String>信用账户最大购买力(新规建余力)
im: Option<String>保证金占用总额(必要保証金)
im_ratio: Option<String>委托保证金率(委託保證金率)
margin_total: Option<String>差额保证金总额(差入保証金合計)
margin_cash_total: Option<String>保证金现金总额(保証金現金合計)
margin_position_total: Option<String>保证金证券总额(代用有価証券合計)
withdrawable: Option<String>信用账户可振替到现物账户的金额(振替(引出)余力)
accrued_fee: Option<String>应计费用,持仓的应计费用汇总
position_im: Option<String>必要保证金(initial margin),JP衍生品账户专用
position_mm: Option<String>维持保证金(maintenance margin),JP衍生品账户专用
position_sem: Option<String>最低维持证据金(soft edge margin),JP衍生品账户专用
Implementations
Sourceimpl AccFundInfo
impl AccFundInfo
Sourcepub fn currency(&self) -> u32
pub fn currency(&self) -> u32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn total_asset(&self) -> &str
pub fn total_asset(&self) -> &str
Returns the value of total_asset, or the default value if total_asset is unset.
Sourcepub fn available(&self) -> &str
pub fn available(&self) -> &str
Returns the value of available, or the default value if available is unset.
Sourcepub fn initial_margin(&self) -> &str
pub fn initial_margin(&self) -> &str
Returns the value of initial_margin, or the default value if initial_margin is unset.
Sourcepub fn maintenance_margin(&self) -> &str
pub fn maintenance_margin(&self) -> &str
Returns the value of maintenance_margin, or the default value if maintenance_margin is unset.
Sourcepub fn max_power_long(&self) -> &str
pub fn max_power_long(&self) -> &str
Returns the value of max_power_long, or the default value if max_power_long is unset.
Sourcepub fn max_power_short(&self) -> &str
pub fn max_power_short(&self) -> &str
Returns the value of max_power_short, or the default value if max_power_short is unset.
Sourcepub fn drawable(&self) -> &str
pub fn drawable(&self) -> &str
Returns the value of drawable, or the default value if drawable is unset.
Sourcepub fn long_mv(&self) -> &str
pub fn long_mv(&self) -> &str
Returns the value of long_mv, or the default value if long_mv is unset.
Sourcepub fn short_mv(&self) -> &str
pub fn short_mv(&self) -> &str
Returns the value of short_mv, or the default value if short_mv is unset.
Sourcepub fn loan_max(&self) -> &str
pub fn loan_max(&self) -> &str
Returns the value of loan_max, or the default value if loan_max is unset.
Sourcepub fn debit_recover(&self) -> &str
pub fn debit_recover(&self) -> &str
Returns the value of debit_recover, or the default value if debit_recover is unset.
Sourcepub fn margin_call_balance(&self) -> &str
pub fn margin_call_balance(&self) -> &str
Returns the value of margin_call_balance, or the default value if margin_call_balance is unset.
Sourcepub fn margin_call_balance_ratio(&self) -> &str
pub fn margin_call_balance_ratio(&self) -> &str
Returns the value of margin_call_balance_ratio, or the default value if margin_call_balance_ratio is unset.
Sourcepub fn margin_call_recover(&self) -> &str
pub fn margin_call_recover(&self) -> &str
Returns the value of margin_call_recover, or the default value if margin_call_recover is unset.
Sourcepub fn risk_level(&self) -> u32
pub fn risk_level(&self) -> u32
Returns the value of risk_level, or the default value if risk_level is unset.
Sourcepub fn absolute_safe_mcb_ratio(&self) -> &str
pub fn absolute_safe_mcb_ratio(&self) -> &str
Returns the value of absolute_safe_mcb_ratio, or the default value if absolute_safe_mcb_ratio is unset.
Sourcepub fn margin_call(&self) -> &str
pub fn margin_call(&self) -> &str
Returns the value of margin_call, or the default value if margin_call is unset.
Sourcepub fn risk_status(&self) -> u32
pub fn risk_status(&self) -> u32
Returns the value of risk_status, or the default value if risk_status is unset.
Sourcepub fn is_pdt(&self) -> bool
pub fn is_pdt(&self) -> bool
Returns the value of is_pdt, or the default value if is_pdt is unset.
Sourcepub fn beginning_dtbp(&self) -> &str
pub fn beginning_dtbp(&self) -> &str
Returns the value of beginning_dtbp, or the default value if beginning_dtbp is unset.
Sourcepub fn remaining_dtbp(&self) -> &str
pub fn remaining_dtbp(&self) -> &str
Returns the value of remaining_dtbp, or the default value if remaining_dtbp is unset.
Sourcepub fn unrealized_profit(&self) -> &str
pub fn unrealized_profit(&self) -> &str
Returns the value of unrealized_profit, or the default value if unrealized_profit is unset.
Sourcepub fn realized_profit(&self) -> &str
pub fn realized_profit(&self) -> &str
Returns the value of realized_profit, or the default value if realized_profit is unset.
Sourcepub fn cash_in_credit(&self) -> &str
pub fn cash_in_credit(&self) -> &str
Returns the value of cash_in_credit, or the default value if cash_in_credit is unset.
Sourcepub fn dt_call_amount(&self) -> &str
pub fn dt_call_amount(&self) -> &str
Returns the value of dt_call_amount, or the default value if dt_call_amount is unset.
Sourcepub fn risk_status_client(&self) -> i32
pub fn risk_status_client(&self) -> i32
Returns the value of risk_status_client, or the default value if risk_status_client is unset.
Sourcepub fn net_cash_power(&self) -> &str
pub fn net_cash_power(&self) -> &str
Returns the value of net_cash_power, or the default value if net_cash_power is unset.
Sourcepub fn pending_asset(&self) -> &str
pub fn pending_asset(&self) -> &str
Returns the value of pending_asset, or the default value if pending_asset is unset.
Sourcepub fn dt_status(&self) -> i32
pub fn dt_status(&self) -> i32
Returns the value of dt_status, or the default value if dt_status is unset.
Sourcepub fn fund_cashing(&self) -> bool
pub fn fund_cashing(&self) -> bool
Returns the value of fund_cashing, or the default value if fund_cashing is unset.
Sourcepub fn fund_market_value(&self) -> &str
pub fn fund_market_value(&self) -> &str
Returns the value of fund_market_value, or the default value if fund_market_value is unset.
Sourcepub fn temp_available_fund_credit(&self) -> &str
pub fn temp_available_fund_credit(&self) -> &str
Returns the value of temp_available_fund_credit, or the default value if temp_available_fund_credit is unset.
Sourcepub fn average_profit(&self) -> &str
pub fn average_profit(&self) -> &str
Returns the value of average_profit, or the default value if average_profit is unset.
Sourcepub fn diluted_profit(&self) -> &str
pub fn diluted_profit(&self) -> &str
Returns the value of diluted_profit, or the default value if diluted_profit is unset.
Sourcepub fn lever_multi(&self) -> &str
pub fn lever_multi(&self) -> &str
Returns the value of lever_multi, or the default value if lever_multi is unset.
Sourcepub fn mm_balance_ratio(&self) -> &str
pub fn mm_balance_ratio(&self) -> &str
Returns the value of mm_balance_ratio, or the default value if mm_balance_ratio is unset.
Sourcepub fn mm_balance(&self) -> &str
pub fn mm_balance(&self) -> &str
Returns the value of mm_balance, or the default value if mm_balance is unset.
Sourcepub fn stock_market(&self) -> u32
pub fn stock_market(&self) -> u32
Returns the value of stock_market, or the default value if stock_market is unset.
Sourcepub fn client_level(&self) -> u32
pub fn client_level(&self) -> u32
Returns the value of client_level, or the default value if client_level is unset.
Sourcepub fn remaining_general_nisa_limit(&self) -> &str
pub fn remaining_general_nisa_limit(&self) -> &str
Returns the value of remaining_general_nisa_limit, or the default value if remaining_general_nisa_limit is unset.
Sourcepub fn margin_requirement(&self) -> &str
pub fn margin_requirement(&self) -> &str
Returns the value of margin_requirement, or the default value if margin_requirement is unset.
Sourcepub fn remaining_tsumitate_nisa_limit(&self) -> &str
pub fn remaining_tsumitate_nisa_limit(&self) -> &str
Returns the value of remaining_tsumitate_nisa_limit, or the default value if remaining_tsumitate_nisa_limit is unset.
Returns the value of premium_option_mv, or the default value if premium_option_mv is unset.
Sourcepub fn accumulated_incomes(&self) -> &str
pub fn accumulated_incomes(&self) -> &str
Returns the value of accumulated_incomes, or the default value if accumulated_incomes is unset.
Sourcepub fn fund_value(&self) -> &str
pub fn fund_value(&self) -> &str
Returns the value of fund_value, or the default value if fund_value is unset.
Sourcepub fn custody_balance(&self) -> &str
pub fn custody_balance(&self) -> &str
Returns the value of custody_balance, or the default value if custody_balance is unset.
Sourcepub fn available_custody_balance(&self) -> &str
pub fn available_custody_balance(&self) -> &str
Returns the value of available_custody_balance, or the default value if available_custody_balance is unset.
Sourcepub fn custody_to_hold_balance(&self) -> &str
pub fn custody_to_hold_balance(&self) -> &str
Returns the value of custody_to_hold_balance, or the default value if custody_to_hold_balance is unset.
Sourcepub fn crypto_available(&self) -> &str
pub fn crypto_available(&self) -> &str
Returns the value of crypto_available, or the default value if crypto_available is unset.
Sourcepub fn crypto_hold(&self) -> &str
pub fn crypto_hold(&self) -> &str
Returns the value of crypto_hold, or the default value if crypto_hold is unset.
Sourcepub fn virtual_limit(&self) -> &str
pub fn virtual_limit(&self) -> &str
Returns the value of virtual_limit, or the default value if virtual_limit is unset.
Sourcepub fn remaining_virtual_limit(&self) -> &str
pub fn remaining_virtual_limit(&self) -> &str
Returns the value of remaining_virtual_limit, or the default value if remaining_virtual_limit is unset.
Sourcepub fn virtual_limit_state(&self) -> u32
pub fn virtual_limit_state(&self) -> u32
Returns the value of virtual_limit_state, or the default value if virtual_limit_state is unset.
Sourcepub fn buy_power(&self) -> &str
pub fn buy_power(&self) -> &str
Returns the value of buy_power, or the default value if buy_power is unset.
Sourcepub fn im_ratio(&self) -> &str
pub fn im_ratio(&self) -> &str
Returns the value of im_ratio, or the default value if im_ratio is unset.
Sourcepub fn margin_total(&self) -> &str
pub fn margin_total(&self) -> &str
Returns the value of margin_total, or the default value if margin_total is unset.
Sourcepub fn margin_cash_total(&self) -> &str
pub fn margin_cash_total(&self) -> &str
Returns the value of margin_cash_total, or the default value if margin_cash_total is unset.
Sourcepub fn margin_position_total(&self) -> &str
pub fn margin_position_total(&self) -> &str
Returns the value of margin_position_total, or the default value if margin_position_total is unset.
Sourcepub fn withdrawable(&self) -> &str
pub fn withdrawable(&self) -> &str
Returns the value of withdrawable, or the default value if withdrawable is unset.
Sourcepub fn accrued_fee(&self) -> &str
pub fn accrued_fee(&self) -> &str
Returns the value of accrued_fee, or the default value if accrued_fee is unset.
Sourcepub fn position_im(&self) -> &str
pub fn position_im(&self) -> &str
Returns the value of position_im, or the default value if position_im is unset.
Sourcepub fn position_mm(&self) -> &str
pub fn position_mm(&self) -> &str
Returns the value of position_mm, or the default value if position_mm is unset.
Sourcepub fn position_sem(&self) -> &str
pub fn position_sem(&self) -> &str
Returns the value of position_sem, or the default value if position_sem is unset.