pub struct IncomeWithBondRsp {Show 19 fields
pub result: Option<i32>,
pub err_msg: Option<String>,
pub market_value: Option<String>,
pub today_incomes: Option<String>,
pub position_incomes: Option<String>,
pub notification: Option<Notification>,
pub quantity: Option<String>,
pub cost: Option<String>,
pub expired_time: Option<u64>,
pub next_dividend_time: Option<u64>,
pub dividend_type: Option<u32>,
pub accrued_interest: Option<String>,
pub dividend_option: Option<u32>,
pub notice: Option<Notice>,
pub notice_list: Vec<Notice>,
pub ccy: Option<String>,
pub coupon_cash: Option<String>,
pub position_cost: Option<String>,
pub price: Option<String>,
}Fields
result: Option<i32>err_msg: Option<String>market_value: Option<String>持仓总市值
today_incomes: Option<String>position_incomes: Option<String>notification: Option<Notification>废弃, 用 notice_list
quantity: Option<String>cost: Option<String>expired_time: Option<u64>到期时间戳 (0=未知)
next_dividend_time: Option<u64>dividend_type: Option<u32>0=不派息, 1=每年1次, 2=每年2次, 3=每年4次, 4=每月1次, 5=5年1次, 6=2年1次
accrued_interest: Option<String>dividend_option: Option<u32>1=固定, 2=不固定
notice: Option<Notice>废弃, 用 notice_list
notice_list: Vec<Notice>ccy: Option<String>coupon_cash: Option<String>已获利息
position_cost: Option<String>持仓成本
price: Option<String>中间价 (without accrued)
Implementations
Sourceimpl IncomeWithBondRsp
impl IncomeWithBondRsp
Sourcepub fn result(&self) -> i32
pub fn result(&self) -> i32
Returns the value of result, or the default value if result is unset.
Sourcepub fn err_msg(&self) -> &str
pub fn err_msg(&self) -> &str
Returns the value of err_msg, or the default value if err_msg is unset.
Sourcepub fn market_value(&self) -> &str
pub fn market_value(&self) -> &str
Returns the value of market_value, or the default value if market_value is unset.
Sourcepub fn today_incomes(&self) -> &str
pub fn today_incomes(&self) -> &str
Returns the value of today_incomes, or the default value if today_incomes is unset.
Sourcepub fn position_incomes(&self) -> &str
pub fn position_incomes(&self) -> &str
Returns the value of position_incomes, or the default value if position_incomes is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn expired_time(&self) -> u64
pub fn expired_time(&self) -> u64
Returns the value of expired_time, or the default value if expired_time is unset.
Sourcepub fn next_dividend_time(&self) -> u64
pub fn next_dividend_time(&self) -> u64
Returns the value of next_dividend_time, or the default value if next_dividend_time is unset.
Sourcepub fn dividend_type(&self) -> u32
pub fn dividend_type(&self) -> u32
Returns the value of dividend_type, or the default value if dividend_type is unset.
Sourcepub fn accrued_interest(&self) -> &str
pub fn accrued_interest(&self) -> &str
Returns the value of accrued_interest, or the default value if accrued_interest is unset.
Sourcepub fn dividend_option(&self) -> u32
pub fn dividend_option(&self) -> u32
Returns the value of dividend_option, or the default value if dividend_option is unset.
Sourcepub fn coupon_cash(&self) -> &str
pub fn coupon_cash(&self) -> &str
Returns the value of coupon_cash, or the default value if coupon_cash is unset.
Sourcepub fn position_cost(&self) -> &str
pub fn position_cost(&self) -> &str
Returns the value of position_cost, or the default value if position_cost is unset.