pub struct GetCashLogReq {Show 15 fields
pub market: Option<u32>,
pub account_id: Option<u64>,
pub broker_id: Option<u32>,
pub long_account_id: Option<u64>,
pub biz_group_id: Option<u32>,
pub in_out: Option<u32>,
pub begin_time: Option<u64>,
pub end_time: Option<u64>,
pub log_id: Option<String>,
pub max_cnt: Option<u32>,
pub keyword: Option<String>,
pub biz_sub_group_id: Option<u32>,
pub currency: Option<String>,
pub stock_id: Option<u64>,
pub time_location: Option<String>,
}Expand description
获取资金流水 - 请求
Fields
market: Option<u32>市场,见Market枚举
account_id: Option<u64>账户业务ID
broker_id: Option<u32>券商ID
long_account_id: Option<u64>长账户ID (优先使用长ID,若为空则使用三元组(market,account_id, broker_id))
biz_group_id: Option<u32>业务类型ID,默认全部
in_out: Option<u32>资金流向,默认全部,1为入,2为出
begin_time: Option<u64>起始时间,时间戳,单位秒
end_time: Option<u64>结束时间,时间戳,单位秒
log_id: Option<String>本次请求的log_id,首次请求时不填,后面填上次返回的next_log_id(若有)
max_cnt: Option<u32>本次返回最多条数,不填由server默认返回30
keyword: Option<String>搜索的关键词,不填写则不搜索,支持如ETH、ET、THUSD、ETHUSD的搜索
biz_sub_group_id: Option<u32>二级业务类型ID,可不填,填写后将忽略biz_group_id
currency: Option<String>货币代码,可不填。离岸人民币:CNY,港币:HKD,美元:USD,日币:JPY,新币:SGD ..等。综合账户填了currency才会有汇总的in out
stock_id: Option<u64>支持按stock_id搜索,支持如ETH、ET、THUSD、ETHUSD的stock_id。在stock_id和keyword都填的情况下,优先用stock_id
time_location: Option<String>流水创建时间所在时区,使用TimeZone identifier格式,如“Asia/Shanghai“,不填使用默认时区
Implementations
Sourceimpl GetCashLogReq
impl GetCashLogReq
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn biz_group_id(&self) -> u32
pub fn biz_group_id(&self) -> u32
Returns the value of biz_group_id, or the default value if biz_group_id is unset.
Sourcepub fn in_out(&self) -> u32
pub fn in_out(&self) -> u32
Returns the value of in_out, or the default value if in_out is unset.
Sourcepub fn begin_time(&self) -> u64
pub fn begin_time(&self) -> u64
Returns the value of begin_time, or the default value if begin_time is unset.
Sourcepub fn end_time(&self) -> u64
pub fn end_time(&self) -> u64
Returns the value of end_time, or the default value if end_time is unset.
Sourcepub fn log_id(&self) -> &str
pub fn log_id(&self) -> &str
Returns the value of log_id, or the default value if log_id is unset.
Sourcepub fn max_cnt(&self) -> u32
pub fn max_cnt(&self) -> u32
Returns the value of max_cnt, or the default value if max_cnt is unset.
Sourcepub fn keyword(&self) -> &str
pub fn keyword(&self) -> &str
Returns the value of keyword, or the default value if keyword is unset.
Sourcepub fn biz_sub_group_id(&self) -> u32
pub fn biz_sub_group_id(&self) -> u32
Returns the value of biz_sub_group_id, or the default value if biz_sub_group_id is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn broker_id(&self) -> u32
pub fn broker_id(&self) -> u32
Returns the value of broker_id, or the default value if broker_id is unset.
Sourcepub fn long_account_id(&self) -> u64
pub fn long_account_id(&self) -> u64
Returns the value of long_account_id, or the default value if long_account_id is unset.
Sourcepub fn time_location(&self) -> &str
pub fn time_location(&self) -> &str
Returns the value of time_location, or the default value if time_location is unset.