pub struct PositionLog {Show 20 fields
pub id: Option<u64>,
pub log_id: Option<u64>,
pub process_date: Option<u32>,
pub account_id: Option<u64>,
pub market: Option<u32>,
pub broker_id: Option<u32>,
pub symbol: Option<String>,
pub long_short: Option<String>,
pub exchange: Option<String>,
pub currency: Option<String>,
pub buy_quantity: Option<String>,
pub buy_cost: Option<String>,
pub sell_quantity: Option<String>,
pub sell_income: Option<String>,
pub change_after: Option<String>,
pub settle_date: Option<u32>,
pub biz_type_id: Option<u32>,
pub biz_flow_id: Option<String>,
pub created_time: Option<u64>,
pub version: Option<i64>,
}Fields
id: Option<u64>持仓流水id
log_id: Option<u64>变更流水id
process_date: Option<u32>变更所属周期,记账日
account_id: Option<u64>账户号码
market: Option<u32>所属市场
broker_id: Option<u32>券商id
symbol: Option<String>股票代码
long_short: Option<String>多空类型,LONG为多,SHORT为空
exchange: Option<String>交易所
currency: Option<String>货币代码,比如HKD、USD
buy_quantity: Option<String>买入数量
buy_cost: Option<String>买入支出
sell_quantity: Option<String>卖出数量
sell_income: Option<String>卖出收入
change_after: Option<String>变更后余额
settle_date: Option<u32>交收日(0:立即交收, 99999999:结算后交收)
biz_type_id: Option<u32>变更类型id
biz_flow_id: Option<String>业务系统流水id
created_time: Option<u64>流水生成时间
version: Option<i64>变更后的实时资产version
Implementations
Sourceimpl PositionLog
impl PositionLog
Sourcepub fn process_date(&self) -> u32
pub fn process_date(&self) -> u32
Returns the value of process_date, or the default value if process_date is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn broker_id(&self) -> u32
pub fn broker_id(&self) -> u32
Returns the value of broker_id, or the default value if broker_id is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn long_short(&self) -> &str
pub fn long_short(&self) -> &str
Returns the value of long_short, or the default value if long_short is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn buy_quantity(&self) -> &str
pub fn buy_quantity(&self) -> &str
Returns the value of buy_quantity, or the default value if buy_quantity is unset.
Sourcepub fn buy_cost(&self) -> &str
pub fn buy_cost(&self) -> &str
Returns the value of buy_cost, or the default value if buy_cost is unset.
Sourcepub fn sell_quantity(&self) -> &str
pub fn sell_quantity(&self) -> &str
Returns the value of sell_quantity, or the default value if sell_quantity is unset.
Sourcepub fn sell_income(&self) -> &str
pub fn sell_income(&self) -> &str
Returns the value of sell_income, or the default value if sell_income is unset.
Sourcepub fn change_after(&self) -> &str
pub fn change_after(&self) -> &str
Returns the value of change_after, or the default value if change_after is unset.
Sourcepub fn settle_date(&self) -> u32
pub fn settle_date(&self) -> u32
Returns the value of settle_date, or the default value if settle_date is unset.
Sourcepub fn biz_type_id(&self) -> u32
pub fn biz_type_id(&self) -> u32
Returns the value of biz_type_id, or the default value if biz_type_id is unset.
Sourcepub fn biz_flow_id(&self) -> &str
pub fn biz_flow_id(&self) -> &str
Returns the value of biz_flow_id, or the default value if biz_flow_id is unset.
Sourcepub fn created_time(&self) -> u64
pub fn created_time(&self) -> u64
Returns the value of created_time, or the default value if created_time is unset.