pub struct CashAsset {
pub currency: Option<String>,
pub quantity: Option<String>,
pub available: Option<String>,
pub hold: Option<String>,
pub drawable: Option<String>,
pub buy_power: Option<String>,
}Fields
currency: Option<String>货币单位
quantity: Option<String>数量
available: Option<String>可用
hold: Option<String>冻结
drawable: Option<String>可提
buy_power: Option<String>购买力
Implementations
Sourceimpl CashAsset
impl CashAsset
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn available(&self) -> &str
pub fn available(&self) -> &str
Returns the value of available, or the default value if available is unset.