pub struct CoinAsset {
pub symbol: Option<String>,
pub long_short: Option<String>,
pub quantity: Option<String>,
pub available_quantity: Option<String>,
pub quantity_on_hold: Option<String>,
}Fields
symbol: Option<String>币种单位
long_short: Option<String>多空类型,LONG为多,SHORT为空
quantity: Option<String>总持股数量
available_quantity: Option<String>可用数量
quantity_on_hold: Option<String>被挂起(冻结)的数量
Implementations
Sourceimpl CoinAsset
impl CoinAsset
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn long_short(&self) -> &str
pub fn long_short(&self) -> &str
Returns the value of long_short, or the default value if long_short is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn available_quantity(&self) -> &str
pub fn available_quantity(&self) -> &str
Returns the value of available_quantity, or the default value if available_quantity is unset.
Sourcepub fn quantity_on_hold(&self) -> &str
pub fn quantity_on_hold(&self) -> &str
Returns the value of quantity_on_hold, or the default value if quantity_on_hold is unset.