pub struct CurrencyAsset {
pub currency: Option<String>,
pub total_asset: Option<String>,
pub balance: Option<String>,
pub available: Option<String>,
pub total_holds: Option<String>,
pub drawable: Option<String>,
pub cash_buypower: Option<String>,
}Fields
currency: Option<String>货币单位
total_asset: Option<String>资产净值(未使用&暂不支持)
balance: Option<String>现金结余
available: Option<String>可用资金
total_holds: Option<String>总冻结资金
drawable: Option<String>可提
cash_buypower: Option<String>现金购买力
Implementations
Sourceimpl CurrencyAsset
impl CurrencyAsset
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn total_asset(&self) -> &str
pub fn total_asset(&self) -> &str
Returns the value of total_asset, or the default value if total_asset is unset.
Sourcepub fn balance(&self) -> &str
pub fn balance(&self) -> &str
Returns the value of balance, or the default value if balance is unset.
Sourcepub fn available(&self) -> &str
pub fn available(&self) -> &str
Returns the value of available, or the default value if available is unset.
Sourcepub fn total_holds(&self) -> &str
pub fn total_holds(&self) -> &str
Returns the value of total_holds, or the default value if total_holds is unset.
Sourcepub fn drawable(&self) -> &str
pub fn drawable(&self) -> &str
Returns the value of drawable, or the default value if drawable is unset.
Sourcepub fn cash_buypower(&self) -> &str
pub fn cash_buypower(&self) -> &str
Returns the value of cash_buypower, or the default value if cash_buypower is unset.