#[repr(i32)]pub enum ErrNo {
Show 38 variants
Success = 0,
RiskMin = -50_000,
RiskMax = -52_000,
ChangeAssetFail = -50_001,
UserLockConflict = -50_002,
ServerInternal = -50_003,
BadRequest = -50_004,
AcctInconsistency = -50_005,
FindOrderFail = -50_101,
OrderHasFinished = -50_102,
InvalidReplaceQuantity = -50_103,
ExecLogDuplicate = -50_104,
RmOrderDuplicate = -50_105,
RmOrderFillDuplicate = -50_106,
NotEnoughHoldQuantity = -50_201,
FindHoldFail = -50_202,
HoldAlreadeyCancel = -50_203,
HoldEffectInconsistent = -50_204,
HoldAlreadeyEffect = -50_205,
HoldUpdateInconsistent = -50_206,
AlreadyHold = -50_207,
HoldInfoDuplicate = -50_208,
NotEnoughCashPower = -50_301,
NotEnoughLongCoin = -50_302,
ExceedingAuthority = -50_303,
UserNotEnableMarket = -50_304,
RestrAcctBiz = -50_305,
CrossTrading = -50_306,
TradeLowerLimit = -50_307,
TradeHigherLimit = -50_308,
TradeAmountLowerLimit = -50_309,
TradeAmountHigherLimit = -50_310,
TradePriceLowerLimit = -50_311,
TradePriceHigherLimit = -50_312,
TradePositionLimitExceed = -50_313,
NotPiUser = -50_314,
NotQuoteData = 550_000_055,
ReportFillTooMuchQuantity = -50_401,
}Expand description
错误码相关 风控错误码 业务错误码
Variants
Success = 0
成功
RiskMin = -50_000
风控最小错误码
RiskMax = -52_000
风控最小错误码
ChangeAssetFail = -50_001
通用
资产变更失败
UserLockConflict = -50_002
用户锁定失败
ServerInternal = -50_003
后端服务内部错误
BadRequest = -50_004
参数错误
AcctInconsistency = -50_005
账户不一致
FindOrderFail = -50_101
订单相关
查找订单失败
OrderHasFinished = -50_102
订单已完结
InvalidReplaceQuantity = -50_103
改单数量不合法,低于已成交订单数量
ExecLogDuplicate = -50_104
执行日志重复
RmOrderDuplicate = -50_105
冻结订单重复
RmOrderFillDuplicate = -50_106
订单成交记录重复
NotEnoughHoldQuantity = -50_201
冻结相关
冻结数量不足
FindHoldFail = -50_202
查找冻结信息失败
HoldAlreadeyCancel = -50_203
冻结信息已解冻
HoldEffectInconsistent = -50_204
冻结和冻结生效时信息不一致(数量、标的等)
HoldAlreadeyEffect = -50_205
冻结信息已生效
HoldUpdateInconsistent = -50_206
冻结信息更新与原信息不一致(只支持变更数量)
AlreadyHold = -50_207
该apply_id已经冻结,不可重复冻结
HoldInfoDuplicate = -50_208
冻结记录重复
NotEnoughCashPower = -50_301
规则相关
现金购买力不足
NotEnoughLongCoin = -50_302
数字币多头持仓不足
ExceedingAuthority = -50_303
未授权,账户无权限操作此账户该行为(通常为机构户操作零售户)
UserNotEnableMarket = -50_304
用户未开通市场权限
RestrAcctBiz = -50_305
账户限制规则限制该行为
CrossTrading = -50_306
交叉交易限制
TradeLowerLimit = -50_307
订单低于最小委托数量
TradeHigherLimit = -50_308
订单高于最大委托数量
TradeAmountLowerLimit = -50_309
订单金额低于最小委托金额
TradeAmountHigherLimit = -50_310
订单金额高于最大委托金额
TradePriceLowerLimit = -50_311
订单价格低于最小委托价格
TradePriceHigherLimit = -50_312
订单价格高于最大委托价格
TradePositionLimitExceed = -50_313
超出持仓限额
NotPiUser = -50_314
非PI用户
NotQuoteData = 550_000_055
无行情数据(买1/卖1/市场价) 【返回给交易错误码,交易在请求体返回客户端。存在弹窗文案】
ReportFillTooMuchQuantity = -50_401
报告相关
成交数量不合法。 成交后成交量大于订单总量
Implementations
Sourceimpl ErrNo
impl ErrNo
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.