pub struct NotifyMsg {
pub notice_header: Option<NoticeHeader>,
pub notice_type: Option<i32>,
pub sub_notice_type: Option<i32>,
}Fields
notice_header: Option<NoticeHeader>参考 NoticeHeader
notice_type: Option<i32>参考 NoticeType
sub_notice_type: Option<i32>参考 SubNoticeType
Implementations
Sourceimpl NotifyMsg
impl NotifyMsg
Sourcepub fn notice_type(&self) -> NoticeType
pub fn notice_type(&self) -> NoticeType
Returns the enum value of notice_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_notice_type(&mut self, value: NoticeType)
pub fn set_notice_type(&mut self, value: NoticeType)
Sets notice_type to the provided enum value.
Sourcepub fn sub_notice_type(&self) -> SubNoticeType
pub fn sub_notice_type(&self) -> SubNoticeType
Returns the enum value of sub_notice_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_sub_notice_type(&mut self, value: SubNoticeType)
pub fn set_sub_notice_type(&mut self, value: SubNoticeType)
Sets sub_notice_type to the provided enum value.