pub struct OrderPreMarginV2Req {Show 13 fields
pub nn_uid: Option<u64>,
pub account_id: Option<u64>,
pub stock_info: Option<ClientStockInfo>,
pub order_side: Option<u32>,
pub quantity: Option<String>,
pub price: Option<String>,
pub order_type: Option<u32>,
pub order_id: Option<String>,
pub order_trade_time_type: Option<u32>,
pub check_risk_increase: Option<bool>,
pub sub_account_id: Option<u64>,
pub cash_order_qty: Option<String>,
pub position_id: Option<String>,
}Fields
nn_uid: Option<u64>account_id: Option<u64>stock_info: Option<ClientStockInfo>order_side: Option<u32>quantity: Option<String>price: Option<String>order_type: Option<u32>order_id: Option<String>order_trade_time_type: Option<u32>check_risk_increase: Option<bool>sub_account_id: Option<u64>cash_order_qty: Option<String>position_id: Option<String>Implementations
Sourceimpl OrderPreMarginV2Req
impl OrderPreMarginV2Req
Sourcepub fn nn_uid(&self) -> u64
pub fn nn_uid(&self) -> u64
Returns the value of nn_uid, or the default value if nn_uid is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn order_side(&self) -> u32
pub fn order_side(&self) -> u32
Returns the value of order_side, or the default value if order_side is unset.
Sourcepub fn quantity(&self) -> &str
pub fn quantity(&self) -> &str
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn order_type(&self) -> u32
pub fn order_type(&self) -> u32
Returns the value of order_type, or the default value if order_type is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn order_trade_time_type(&self) -> u32
pub fn order_trade_time_type(&self) -> u32
Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.
Sourcepub fn check_risk_increase(&self) -> bool
pub fn check_risk_increase(&self) -> bool
Returns the value of check_risk_increase, or the default value if check_risk_increase is unset.
Sourcepub fn sub_account_id(&self) -> u64
pub fn sub_account_id(&self) -> u64
Returns the value of sub_account_id, or the default value if sub_account_id is unset.
Sourcepub fn cash_order_qty(&self) -> &str
pub fn cash_order_qty(&self) -> &str
Returns the value of cash_order_qty, or the default value if cash_order_qty is unset.
Sourcepub fn position_id(&self) -> &str
pub fn position_id(&self) -> &str
Returns the value of position_id, or the default value if position_id is unset.