IpoListReq

pub struct IpoListReq {
    pub market: Option<i32>,
    pub request_type: Option<i32>,
    pub language: Option<i32>,
}
请求IPO股票列表, CMD=6956

Fields

market: Option<i32>

市场, 参考MARKET

request_type: Option<i32>

请求类型, 参考REQUEST_TYPE

language: Option<i32>

当前语言,参考LANGUAGE

Implementations

Source

impl IpoListReq

pub fn market(&self) -> i32

Returns the value of market, or the default value if market is unset.

pub fn request_type(&self) -> i32

Returns the value of request_type, or the default value if request_type is unset.

pub fn language(&self) -> i32

Returns the value of language, or the default value if language is unset.