pub struct IpoListReq {
pub market: Option<i32>,
pub request_type: Option<i32>,
pub language: Option<i32>,
pub particular_date: Option<String>,
pub broker: Option<i32>,
pub broker_type_list: Vec<i32>,
pub broker_id_list: Vec<i32>,
pub broker_id: Option<i32>,
}Expand description
请求IPO股票列表, CMD=6956
Fields
market: Option<i32>市场, 参考MARKET
request_type: Option<i32>请求类型, 参考REQUEST_TYPE
language: Option<i32>当前语言,参考LANGUAGE
particular_date: Option<String>已弃用,请勿使用
broker: Option<i32>打新券商类型,参考BROKER_TYPE
broker_type_list: Vec<i32>打新券商类型列表
broker_id_list: Vec<i32>主推通用券商id列表
broker_id: Option<i32>单券商id
Implementations
Sourceimpl IpoListReq
impl IpoListReq
Sourcepub fn market(&self) -> i32
pub fn market(&self) -> i32
Returns the value of market, or the default value if market is unset.
Sourcepub fn request_type(&self) -> i32
pub fn request_type(&self) -> i32
Returns the value of request_type, or the default value if request_type is unset.
Sourcepub fn language(&self) -> i32
pub fn language(&self) -> i32
Returns the value of language, or the default value if language is unset.
Sourcepub fn particular_date(&self) -> &str
pub fn particular_date(&self) -> &str
Returns the value of particular_date, or the default value if particular_date is unset.