UsIpoListItem

Struct UsIpoListItem 

pub struct UsIpoListItem {
    pub stock_id: Option<u64>,
    pub stock_name: Option<String>,
    pub code: Option<String>,
    pub ipo_price_range: Option<String>,
    pub shares: Option<String>,
    pub expected_ipo_date: Option<String>,
    pub ipo_price_low: Option<u32>,
    pub ipo_price_high: Option<u32>,
    pub ipo_date_timestamp: Option<u64>,
    pub shares_num: Option<i64>,
}

Fields

stock_id: Option<u64>

股票内部ID

stock_name: Option<String>

股票名称(简体)

code: Option<String>

股票代码, 例如“AAPL“

ipo_price_range: Option<String>

发行价区间, 例如“12.00~14.00“

shares: Option<String>

发行量

expected_ipo_date: Option<String>

预计上市日

ipo_price_low: Option<u32>

发行价区间,下界,保留两位精度,即1234表示12.34

ipo_price_high: Option<u32>

发行价区间,上界,保留两位精度,即1234表示12.34

ipo_date_timestamp: Option<u64>

预计上市日, 时间戳

shares_num: Option<i64>

发行量,数值格式

Implementations

Source

impl UsIpoListItem

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn stock_name(&self) -> &str

Returns the value of stock_name, or the default value if stock_name is unset.

pub fn code(&self) -> &str

Returns the value of code, or the default value if code is unset.

pub fn ipo_price_range(&self) -> &str

Returns the value of ipo_price_range, or the default value if ipo_price_range is unset.

pub fn shares(&self) -> &str

Returns the value of shares, or the default value if shares is unset.

pub fn expected_ipo_date(&self) -> &str

Returns the value of expected_ipo_date, or the default value if expected_ipo_date is unset.

pub fn ipo_price_low(&self) -> u32

Returns the value of ipo_price_low, or the default value if ipo_price_low is unset.

pub fn ipo_price_high(&self) -> u32

Returns the value of ipo_price_high, or the default value if ipo_price_high is unset.

pub fn ipo_date_timestamp(&self) -> u64

Returns the value of ipo_date_timestamp, or the default value if ipo_date_timestamp is unset.

pub fn shares_num(&self) -> i64

Returns the value of shares_num, or the default value if shares_num is unset.