pub struct DealStatistics {Show 16 fields
pub price_open: Option<i64>,
pub price_highest: Option<i64>,
pub price_lowest: Option<i64>,
pub volume: Option<i64>,
pub volume_sold: Option<i64>,
pub volume_bought: Option<i64>,
pub turnover: Option<i64>,
pub ratio_volume: Option<i64>,
pub ratio_turnover: Option<i64>,
pub amplitude_price: Option<i64>,
pub price_average: Option<i64>,
pub change_speed_price: Option<i64>,
pub ratio_bid_ask: Option<i64>,
pub kcb_stock_static: Option<CnkcbAfterDealStatistics>,
pub volume_precision: Option<u32>,
pub statistics_24h: Option<Statistics24H>,
}Expand description
成交统计,订阅位:SBIT_DEAL_STATISTICS
Fields
price_open: Option<i64>开盘价
price_highest: Option<i64>最高价
price_lowest: Option<i64>最低价
volume: Option<i64>成交量,精度见 volume_precision (crypto)
volume_sold: Option<i64>内盘/总卖量(仅A股)
volume_bought: Option<i64>外盘/总买量(仅A股)
turnover: Option<i64>成交额
ratio_volume: Option<i64>量比,[放大10^3倍],前端展示值
ratio_turnover: Option<i64>换手率,[放大10^5倍],前端展示百分比
amplitude_price: Option<i64>振幅,[放大10^5倍],前端展示百分比
price_average: Option<i64>平均价
change_speed_price: Option<i64>涨跌速率,[放大10^5倍],前端展示百分比
ratio_bid_ask: Option<i64>委比,[放大10^5倍],前端展示百分比。本为摆盘信息,放入成交统计分类是为了降低推送频率。
kcb_stock_static: Option<CnkcbAfterDealStatistics>科创板股票得盘后信息
volume_precision: Option<u32>v1.4.110 final E.5 P1#1: 补 field 15-16 对齐 C++ Quote/FTCmdStockQuoteCoverageData.proto:359-360 crypto 成交量精度 (volume 实际单位 = volume / 10^volume_precision) + 24H 滚动统计.
成交量精度n, 对 volume 放大了 10^n 次方
statistics_24h: Option<Statistics24H>24H 统计信息
Implementations
Sourceimpl DealStatistics
impl DealStatistics
Sourcepub fn price_open(&self) -> i64
pub fn price_open(&self) -> i64
Returns the value of price_open, or the default value if price_open is unset.
Sourcepub fn price_highest(&self) -> i64
pub fn price_highest(&self) -> i64
Returns the value of price_highest, or the default value if price_highest is unset.
Sourcepub fn price_lowest(&self) -> i64
pub fn price_lowest(&self) -> i64
Returns the value of price_lowest, or the default value if price_lowest is unset.
Sourcepub fn volume(&self) -> i64
pub fn volume(&self) -> i64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn volume_sold(&self) -> i64
pub fn volume_sold(&self) -> i64
Returns the value of volume_sold, or the default value if volume_sold is unset.
Sourcepub fn volume_bought(&self) -> i64
pub fn volume_bought(&self) -> i64
Returns the value of volume_bought, or the default value if volume_bought is unset.
Sourcepub fn turnover(&self) -> i64
pub fn turnover(&self) -> i64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn ratio_volume(&self) -> i64
pub fn ratio_volume(&self) -> i64
Returns the value of ratio_volume, or the default value if ratio_volume is unset.
Sourcepub fn ratio_turnover(&self) -> i64
pub fn ratio_turnover(&self) -> i64
Returns the value of ratio_turnover, or the default value if ratio_turnover is unset.
Sourcepub fn amplitude_price(&self) -> i64
pub fn amplitude_price(&self) -> i64
Returns the value of amplitude_price, or the default value if amplitude_price is unset.
Sourcepub fn price_average(&self) -> i64
pub fn price_average(&self) -> i64
Returns the value of price_average, or the default value if price_average is unset.
Sourcepub fn change_speed_price(&self) -> i64
pub fn change_speed_price(&self) -> i64
Returns the value of change_speed_price, or the default value if change_speed_price is unset.
Sourcepub fn ratio_bid_ask(&self) -> i64
pub fn ratio_bid_ask(&self) -> i64
Returns the value of ratio_bid_ask, or the default value if ratio_bid_ask is unset.
Sourcepub fn volume_precision(&self) -> u32
pub fn volume_precision(&self) -> u32
Returns the value of volume_precision, or the default value if volume_precision is unset.