pub struct HkWarrantCbbc {Show 25 fields
pub type: Option<i32>,
pub issued_shares: Option<i64>,
pub price_underlying: Option<i64>,
pub price_strike: Option<i64>,
pub premium: Option<i64>,
pub ratio_entitlement: Option<i64>,
pub price_entitlement: Option<i64>,
pub leverage: Option<i64>,
pub volume_street: Option<i64>,
pub ratio_street: Option<i64>,
pub ratio_itm_otm: Option<i64>,
pub price_break_even_point: Option<i64>,
pub delta: Option<i64>,
pub expiry_date_time_s: Option<i64>,
pub last_trading_date_time_s: Option<i64>,
pub score_faxing: Option<i32>,
pub issuer_code: Option<String>,
pub price_call: Option<i64>,
pub ratio_price_call: Option<i64>,
pub implied_volatility: Option<i64>,
pub effective_leverage: Option<i64>,
pub upper_price: Option<i64>,
pub lower_price: Option<i64>,
pub in_or_out: Option<i64>,
pub sensitivity: Option<i32>,
}Expand description
港股窝轮牛熊 (窝轮/衍生權證 + 牛熊證) 窝轮/衍生權證 Derivative Warrants 牛熊證 Callable Bull/Bear Contracts (CBBC) HKWarrantCBBC包含两类品种的字段,单类品种特有的字段会在注释中明确标识([Warrant]或[CBBC]),共用的字段没有特殊标识。
Fields
type: Option<i32>窝轮类型,枚举HKWarrantCBBCType
发行量(股)
price_underlying: Option<i64>正股价格
price_strike: Option<i64>行使价
溢价,[放大10^5倍],前端展示百分比
ratio_entitlement: Option<i64>换股比率/行使比率,[放大10^3倍],前端展示值
price_entitlement: Option<i64>换股价
leverage: Option<i64>杠杆比率(倍),[放大10^3倍],前端展示值
volume_street: Option<i64>街货量
ratio_street: Option<i64>街货比,[放大10^5倍],前端展示百分比
ratio_itm_otm: Option<i64>价内/价外比例,[放大10^5倍],前端展示百分比 In The Money(ITM)/Out Of The Money(OTM)
price_break_even_point: Option<i64>打和点
delta: Option<i64>对冲值,[放大10^3倍],前端展示值
expiry_date_time_s: Option<i64>到期日
last_trading_date_time_s: Option<i64>最后交易日
score_faxing: Option<i32>法兴评分
issuer_code: Option<String>发行人代码
price_call: Option<i64>[CBBC]收回价
ratio_price_call: Option<i64>[CBBC]距收回价比例,[放大10^5倍],前端展示百分比
implied_volatility: Option<i64>[Warrant]引伸波幅,[放大10^3倍],前端展示值。前端显示示例:协议值是12345,前端展示为12.345,不显示百分号%。
effective_leverage: Option<i64>[Warrant]有效杠杆,[放大10^3倍],前端展示值
upper_price: Option<i64>上限价。目前用于界内证
lower_price: Option<i64>下限价。目前用于界内证
in_or_out: Option<i64>界内还是界外。目前用于界内证。取值参考:HKInWarrantStatus
sensitivity: Option<i32>敏感度,[放大10^3倍],前端展示值
Implementations
Sourceimpl HkWarrantCbbc
impl HkWarrantCbbc
Returns the value of issued_shares, or the default value if issued_shares is unset.
Sourcepub fn price_underlying(&self) -> i64
pub fn price_underlying(&self) -> i64
Returns the value of price_underlying, or the default value if price_underlying is unset.
Sourcepub fn price_strike(&self) -> i64
pub fn price_strike(&self) -> i64
Returns the value of price_strike, or the default value if price_strike is unset.
Returns the value of premium, or the default value if premium is unset.
Sourcepub fn ratio_entitlement(&self) -> i64
pub fn ratio_entitlement(&self) -> i64
Returns the value of ratio_entitlement, or the default value if ratio_entitlement is unset.
Sourcepub fn price_entitlement(&self) -> i64
pub fn price_entitlement(&self) -> i64
Returns the value of price_entitlement, or the default value if price_entitlement is unset.
Sourcepub fn leverage(&self) -> i64
pub fn leverage(&self) -> i64
Returns the value of leverage, or the default value if leverage is unset.
Sourcepub fn volume_street(&self) -> i64
pub fn volume_street(&self) -> i64
Returns the value of volume_street, or the default value if volume_street is unset.
Sourcepub fn ratio_street(&self) -> i64
pub fn ratio_street(&self) -> i64
Returns the value of ratio_street, or the default value if ratio_street is unset.
Sourcepub fn ratio_itm_otm(&self) -> i64
pub fn ratio_itm_otm(&self) -> i64
Returns the value of ratio_itm_otm, or the default value if ratio_itm_otm is unset.
Sourcepub fn price_break_even_point(&self) -> i64
pub fn price_break_even_point(&self) -> i64
Returns the value of price_break_even_point, or the default value if price_break_even_point is unset.
Sourcepub fn expiry_date_time_s(&self) -> i64
pub fn expiry_date_time_s(&self) -> i64
Returns the value of expiry_date_time_s, or the default value if expiry_date_time_s is unset.
Sourcepub fn last_trading_date_time_s(&self) -> i64
pub fn last_trading_date_time_s(&self) -> i64
Returns the value of last_trading_date_time_s, or the default value if last_trading_date_time_s is unset.
Sourcepub fn score_faxing(&self) -> i32
pub fn score_faxing(&self) -> i32
Returns the value of score_faxing, or the default value if score_faxing is unset.
Sourcepub fn issuer_code(&self) -> &str
pub fn issuer_code(&self) -> &str
Returns the value of issuer_code, or the default value if issuer_code is unset.
Sourcepub fn price_call(&self) -> i64
pub fn price_call(&self) -> i64
Returns the value of price_call, or the default value if price_call is unset.
Sourcepub fn ratio_price_call(&self) -> i64
pub fn ratio_price_call(&self) -> i64
Returns the value of ratio_price_call, or the default value if ratio_price_call is unset.
Sourcepub fn implied_volatility(&self) -> i64
pub fn implied_volatility(&self) -> i64
Returns the value of implied_volatility, or the default value if implied_volatility is unset.
Sourcepub fn effective_leverage(&self) -> i64
pub fn effective_leverage(&self) -> i64
Returns the value of effective_leverage, or the default value if effective_leverage is unset.
Sourcepub fn upper_price(&self) -> i64
pub fn upper_price(&self) -> i64
Returns the value of upper_price, or the default value if upper_price is unset.
Sourcepub fn lower_price(&self) -> i64
pub fn lower_price(&self) -> i64
Returns the value of lower_price, or the default value if lower_price is unset.
Sourcepub fn in_or_out(&self) -> i64
pub fn in_or_out(&self) -> i64
Returns the value of in_or_out, or the default value if in_or_out is unset.
Sourcepub fn sensitivity(&self) -> i32
pub fn sensitivity(&self) -> i32
Returns the value of sensitivity, or the default value if sensitivity is unset.