#[repr(i32)]pub enum KlinePattern {
Show 20 variants
TripleBottom = 7_101,
HornBottom = 7_102,
DoubleBottom = 7_103,
HeadAndSholdersBottom = 7_104,
BullishSymmetricalTriangle = 7_105,
BullishFlag = 7_106,
BullishContinuousDiamond = 7_107,
ArcBottom = 7_108,
BullishSustainedWedge = 7_109,
BullishContinuousTriangle = 7_110,
HornTop = 7_201,
BearishSustainedWedge = 7_202,
BearishContinuousTriangle = 7_203,
DoubleTop = 7_204,
BearishSymmetricalTriangle = 7_205,
BearishFlag = 7_206,
HeadAndShouldersTop = 7_207,
TripleTop = 7_208,
BearishContinuousDiamond = 7_209,
ArcTop = 7_210,
}Expand description
K线形态
Variants
TripleBottom = 7_101
三重底
HornBottom = 7_102
喇叭底
DoubleBottom = 7_103
W型底
HeadAndSholdersBottom = 7_104
头肩底
BullishSymmetricalTriangle = 7_105
看涨对称三角形
BullishFlag = 7_106
看涨旗形
BullishContinuousDiamond = 7_107
看涨持续菱形
ArcBottom = 7_108
圆弧底
BullishSustainedWedge = 7_109
看涨持续楔形
BullishContinuousTriangle = 7_110
看涨持续三角形
HornTop = 7_201
喇叭顶
BearishSustainedWedge = 7_202
看跌持续楔形
BearishContinuousTriangle = 7_203
看跌持续三角形
DoubleTop = 7_204
M型顶
BearishSymmetricalTriangle = 7_205
看跌对称三角形
BearishFlag = 7_206
看跌旗形
HeadAndShouldersTop = 7_207
头肩顶
TripleTop = 7_208
三重顶
BearishContinuousDiamond = 7_209
看跌持续菱形
ArcTop = 7_210
圆弧顶
Implementations
Sourceimpl KlinePattern
impl KlinePattern
Sourceimpl KlinePattern
impl KlinePattern
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.