#[repr(i32)]pub enum PropertyNameSimple {
Show 43 variants
PropertySimpleUnknown = 0,
PropertySimpleBusinessLongMarginAllowed = 2_101,
PropertySimpleBusinessLongMarginMortgageRate = 2_102,
PropertySimpleBusinessShortMarginAllowed = 2_103,
PropertySimpleBusinessShortMarginInterestRate = 2_104,
PropertySimpleBusinessLongMarginBailRate = 2_105,
PropertySimpleBusinessShortMarginBailRate = 2_106,
PropertySimpleQuotePrice = 2_201,
PropertySimpleQuotePriceTodayOpen = 2_202,
PropertySimpleQuotePriceLastClose = 2_203,
PropertySimpleQuotePriceTodayHigh = 2_204,
PropertySimpleQuotePriceTodayLow = 2_205,
PropertySimpleQuotePriceChangeRate = 2_206,
PropertySimpleQuotePriceBid = 2_207,
PropertySimpleQuotePriceAsk = 2_208,
PropertySimpleQuotePriceTo52weekHighRatio = 2_209,
PropertySimpleQuotePriceTo52weekLowRatio = 2_210,
PropertySimpleQuotePriceTodayHighTo52weekHighRatio = 2_211,
PropertySimpleQuotePriceTodayLowTo52weekLowRatio = 2_212,
PropertySimpleQuotePriceChangeIn5min = 2_213,
PropertySimpleQuotePriceChangeFromBeginningOfThisYear = 2_214,
PropertySimpleQuoteVolumeBid = 2_215,
PropertySimpleQuoteVolumeAsk = 2_216,
PropertySimpleQuoteVolumeRatio = 2_217,
PropertySimpleQuoteBidAskRatio = 2_218,
PropertySimpleQuoteLotPrice = 2_219,
PropertySimpleInfoMarketCapital = 2_301,
PropertySimpleInfoPeAnnual = 2_302,
PropertySimpleInfoPeTtm = 2_303,
PropertySimpleInfoPb = 2_304,
PropertySimpleInfoDividendRatio = 2_305,
PropertySimpleInfoListedDate = 2_306,
PropertySimpleInfoListedDays = 2_307,
PropertySimpleQuoteBeforePrice = 2_401,
PropertySimpleQuoteBeforePriceChange = 2_402,
PropertySimpleQuoteBeforePriceChangePercentage = 2_403,
PropertySimpleQuoteBeforeVolume = 2_404,
PropertySimpleQuoteBeforeTurnover = 2_405,
PropertySimpleQuoteAfterPrice = 2_406,
PropertySimpleQuoteAfterPriceChange = 2_407,
PropertySimpleQuoteAfterPriceChangePercentage = 2_408,
PropertySimpleQuoteAfterVolume = 2_409,
PropertySimpleQuoteAfterTurnover = 2_410,
}Variants
PropertySimpleUnknown = 0
未知
PropertySimpleBusinessLongMarginAllowed = 2_101
是否允许融资 (0 = 不允许,1 = 允许)
PropertySimpleBusinessLongMarginMortgageRate = 2_102
融资抵押率 (单位:0.001% 倍率:100000)
PropertySimpleBusinessShortMarginAllowed = 2_103
是否允许融券 (0 = 不允许,1 = 允许)
PropertySimpleBusinessShortMarginInterestRate = 2_104
融券利息率 (单位:0.0001% 倍率:1000000)
PropertySimpleBusinessLongMarginBailRate = 2_105
融资保证金率 (单位:0.001% 倍率:100000)
PropertySimpleBusinessShortMarginBailRate = 2_106
融券保证金率 (单位:0.001% 倍率:100000)
PropertySimpleQuotePrice = 2_201
最新价格 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceTodayOpen = 2_202
今开价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceLastClose = 2_203
昨收价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceTodayHigh = 2_204
今最高价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceTodayLow = 2_205
今最低价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceChangeRate = 2_206
涨跌速率 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceBid = 2_207
买入价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceAsk = 2_208
卖出价 (单位:0.001元 倍率:1000)
PropertySimpleQuotePriceTo52weekHighRatio = 2_209
(现价 - 52周最高)/52周最高 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceTo52weekLowRatio = 2_210
(现价 - 52周最低)/52周最低 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceTodayHighTo52weekHighRatio = 2_211
(今日最高 - 52周最高)/52周最高 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceTodayLowTo52weekLowRatio = 2_212
(今日最低 - 52周最低)/52周最低 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceChangeIn5min = 2_213
五分钟价格涨跌幅 (单位:0.001% 倍率:100000)
PropertySimpleQuotePriceChangeFromBeginningOfThisYear = 2_214
年初至今价格涨跌幅 (单位:0.001% 倍率:100000)
PropertySimpleQuoteVolumeBid = 2_215
买入量 (单位:1股 倍率:1)
PropertySimpleQuoteVolumeAsk = 2_216
买入量 (单位:1股 倍率:1)
PropertySimpleQuoteVolumeRatio = 2_217
量比 (单位:0.001% 倍率:100000)
PropertySimpleQuoteBidAskRatio = 2_218
委比 (单位:0.001% 倍率:10000000)
PropertySimpleQuoteLotPrice = 2_219
每手价格 (单位:0.001元 倍率:1000)
PropertySimpleInfoMarketCapital = 2_301
市值 (单位:0.001元 倍率:1000)
PropertySimpleInfoPeAnnual = 2_302
年化(静态)市盈率 (单位:0.001% 倍率:100000)
PropertySimpleInfoPeTtm = 2_303
TTM市盈率 (单位:0.001% 倍率:100000)
PropertySimpleInfoPb = 2_304
市净率 (单位:0.001% 倍率:100000)
PropertySimpleInfoDividendRatio = 2_305
股息率 (单位:0.001% 倍率:100000)
PropertySimpleInfoListedDate = 2_306
上市时间(时间戳)
PropertySimpleInfoListedDays = 2_307
上市天数(单位:1,倍率: 1)
PropertySimpleQuoteBeforePrice = 2_401
盘前盘后数据
盘前价格(单位:0.001元 倍率:1000)
PropertySimpleQuoteBeforePriceChange = 2_402
盘前涨跌额(单位:0.001元 倍率:1000)
PropertySimpleQuoteBeforePriceChangePercentage = 2_403
盘前涨跌幅(单位:0.001% 倍率:100000)
PropertySimpleQuoteBeforeVolume = 2_404
盘前成交量(单位:1股 倍率:1)
PropertySimpleQuoteBeforeTurnover = 2_405
盘前成交额(单位:0.001元 倍率:1000)
PropertySimpleQuoteAfterPrice = 2_406
盘后价格(单位:0.001元 倍率:1000)
PropertySimpleQuoteAfterPriceChange = 2_407
盘后涨跌额(单位:0.001元 倍率:1000)
PropertySimpleQuoteAfterPriceChangePercentage = 2_408
盘后涨跌幅(单位:0.001% 倍率:100000)
PropertySimpleQuoteAfterVolume = 2_409
盘后成交量(单位:1股 倍率:1)
PropertySimpleQuoteAfterTurnover = 2_410
盘后成交额(单位:0.001元 倍率:1000)
Implementations
Sourceimpl PropertyNameSimple
impl PropertyNameSimple
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.