pub struct PropertyFeatured {
pub name: Option<i32>,
pub period: Option<i32>,
pub range_period: Option<i32>,
}Fields
name: Option<i32>枚举如上Featured所示
period: Option<i32>K线周期,用于指标解读
range_period: Option<i32>范围周期(用于公司估值)枚举如上RangePeriod所示
Implementations
Sourceimpl PropertyFeatured
impl PropertyFeatured
Sourcepub fn period(&self) -> Period
pub fn period(&self) -> Period
Returns the enum value of period, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: Period)
pub fn set_period(&mut self, value: Period)
Sets period to the provided enum value.
Sourcepub fn range_period(&self) -> i32
pub fn range_period(&self) -> i32
Returns the value of range_period, or the default value if range_period is unset.