#[repr(i32)]pub enum TradingCapability {
Show 29 variants
NaForex = 1,
NaCrypto = 2,
HkStocks = 3,
HkStockOptions = 4,
HkIndexOptions = 5,
HkFutures = 6,
HkMutualFunds = 7,
HkBonds = 8,
HkStructureNotes = 9,
UsStocks = 10,
UsStockOptions = 11,
UsIndexOptions = 12,
UsFuturesOptions = 13,
UsFutures = 14,
CnStocks = 15,
SgStocks = 16,
SgFutures = 17,
SgMutualFunds = 18,
SgBonds = 19,
SgStuctureNotes = 20,
AuStocks = 21,
JpStocks = 22,
JpFutures = 23,
MyStocks = 24,
MyFutures = 25,
CaStocks = 26,
NaMutualFunds = 27,
JpStockOptions = 28,
JpIndexOptions = 29,
}Expand description
Variants
NaForex = 1
外汇(无市场概念)
NaCrypto = 2
数字货币(无市场概念)
HkStocks = 3
正股(香港市场)
HkStockOptions = 4
股票期权(香港市场)
HkIndexOptions = 5
指数期权(香港市场)
HkFutures = 6
期货(香港市场)
HkMutualFunds = 7
已废弃,原本含义基金(香港市场),现在判断基金交易能力使用NA_MUTUAL_FUNDS
HkBonds = 8
债券(香港市场)
HkStructureNotes = 9
结构化票据(香港市场)
UsStocks = 10
正股(美国市场)
UsStockOptions = 11
股票期权(美国市场)
UsIndexOptions = 12
指数期权(美国市场)
UsFuturesOptions = 13
期货期权(美国市场)
UsFutures = 14
期货(美国市场)
CnStocks = 15
正股(大陆市场)
SgStocks = 16
正股(新加坡市场)
SgFutures = 17
期货(新加坡市场)
SgMutualFunds = 18
已废弃,原本含义基金(香港市场),现在判断基金交易能力使用NA_MUTUAL_FUNDS
SgBonds = 19
债券(新加坡市场)
SgStuctureNotes = 20
结构化票据(新加坡市场)
AuStocks = 21
正股(澳洲市场)
JpStocks = 22
正股(日本市场)
JpFutures = 23
期货(日本市场)
MyStocks = 24
正股(马来西亚市场)
MyFutures = 25
期货(马来西亚市场)
CaStocks = 26
正股(加拿大市场)
NaMutualFunds = 27
基金(无市场概念)
JpStockOptions = 28
该字段之前是MY_MUTUAL_FUNDS,特指MY市场基金,目前除了MY之外, 其他支持Trading Capability的主体,都还不支持基金能力,所以计划 把基金的交易能力统一收拢在该字段,対该字段重命名
股票期权(日本市场)
JpIndexOptions = 29
指数期权(日本市场)
Implementations
Sourceimpl TradingCapability
impl TradingCapability
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.