pub struct DlcItem {Show 17 fields
pub stock_id: Option<u64>,
pub stock_owner: Option<u64>,
pub issuer_id: Option<u32>,
pub dlc_type: Option<i32>,
pub maturity_date: Option<u64>,
pub current_price: Option<u32>,
pub change_rate: Option<i64>,
pub change_value: Option<i64>,
pub volume: Option<u64>,
pub turnover: Option<u64>,
pub sell_vol: Option<u64>,
pub buy_vol: Option<u64>,
pub sell_price: Option<u32>,
pub buy_price: Option<u32>,
pub status: Option<i32>,
pub last_trade_date: Option<u64>,
pub currency_code: Option<String>,
}Expand description
dlc信息
Fields
stock_id: Option<u64>静态数据项
股票id
stock_owner: Option<u64>正股id
issuer_id: Option<u32>发行商id
dlc_type: Option<i32>dlc类型, 枚举定义查看 DLC_TYPE
maturity_date: Option<u64>到期日
current_price: Option<u32>动态数据项
当前价 *1000
change_rate: Option<i64>涨跌幅 *1000000
change_value: Option<i64>涨跌额 *1000
volume: Option<u64>成交量
turnover: Option<u64>成交额 *1000
sell_vol: Option<u64>卖量
buy_vol: Option<u64>买量
sell_price: Option<u32>卖价 *1000
buy_price: Option<u32>买价 *1000
status: Option<i32>状态 枚举定义查看 WarrantStatus
last_trade_date: Option<u64>最后交易日
currency_code: Option<String>币种 枚举定义查看公共协议currency.proto中ECurrency
Implementations
Sourceimpl DlcItem
impl DlcItem
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn stock_owner(&self) -> u64
pub fn stock_owner(&self) -> u64
Returns the value of stock_owner, or the default value if stock_owner is unset.
Sourcepub fn issuer_id(&self) -> u32
pub fn issuer_id(&self) -> u32
Returns the value of issuer_id, or the default value if issuer_id is unset.
Sourcepub fn dlc_type(&self) -> i32
pub fn dlc_type(&self) -> i32
Returns the value of dlc_type, or the default value if dlc_type is unset.
Sourcepub fn maturity_date(&self) -> u64
pub fn maturity_date(&self) -> u64
Returns the value of maturity_date, or the default value if maturity_date is unset.
Sourcepub fn current_price(&self) -> u32
pub fn current_price(&self) -> u32
Returns the value of current_price, or the default value if current_price is unset.
Sourcepub fn change_rate(&self) -> i64
pub fn change_rate(&self) -> i64
Returns the value of change_rate, or the default value if change_rate is unset.
Sourcepub fn change_value(&self) -> i64
pub fn change_value(&self) -> i64
Returns the value of change_value, or the default value if change_value is unset.
Sourcepub fn volume(&self) -> u64
pub fn volume(&self) -> u64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn turnover(&self) -> u64
pub fn turnover(&self) -> u64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn sell_vol(&self) -> u64
pub fn sell_vol(&self) -> u64
Returns the value of sell_vol, or the default value if sell_vol is unset.
Sourcepub fn buy_vol(&self) -> u64
pub fn buy_vol(&self) -> u64
Returns the value of buy_vol, or the default value if buy_vol is unset.
Sourcepub fn sell_price(&self) -> u32
pub fn sell_price(&self) -> u32
Returns the value of sell_price, or the default value if sell_price is unset.
Sourcepub fn buy_price(&self) -> u32
pub fn buy_price(&self) -> u32
Returns the value of buy_price, or the default value if buy_price is unset.
Sourcepub fn status(&self) -> i32
pub fn status(&self) -> i32
Returns the value of status, or the default value if status is unset.
Sourcepub fn last_trade_date(&self) -> u64
pub fn last_trade_date(&self) -> u64
Returns the value of last_trade_date, or the default value if last_trade_date is unset.
Sourcepub fn currency_code(&self) -> &str
pub fn currency_code(&self) -> &str
Returns the value of currency_code, or the default value if currency_code is unset.