#[repr(i32)]pub enum SortId {
Show 42 variants
Code = 2_001,
Name = 2_002,
LatestPrice = 2_003,
ChangeRate = 2_004,
BidPrice = 2_005,
SellingPrice = 2_006,
BidQuantity = 2_007,
SellingQuantity = 2_008,
Volume = 2_009,
Turnover = 2_010,
PremiumPct = 2_011,
EffectiveLeverage = 2_012,
Delta = 2_013,
ImpliedVolatility = 2_014,
Type = 2_015,
ExecutivePrice = 2_016,
BreakEvenPoint = 2_017,
ExpiryDate = 2_018,
LastTradingDay = 2_019,
LeveragedRate = 2_020,
InOutTheMoneyPct = 2_021,
CallPrice = 2_022,
SharePriceCallPricePct = 2_023,
ChangePrices = 2_024,
ChangePct = 2_025,
OutstandingQuantity = 2_026,
Amplitude = 2_027,
Issuer = 2_028,
PriceChangeVal = 2_029,
Status = 2_030,
Score = 2_031,
FxScore = 2_032,
IpoTime = 2_033,
StreetVol = 2_034,
LotSize = 2_035,
IssueSize = 2_036,
IpoPrice = 2_037,
Equity = 2_038,
LowerStrikePrice = 2_039,
UpperStrikePrice = 2_040,
IwPriceStatus = 2_041,
Sensitivity = 2_042,
}Expand description
所有的排序列及id
Variants
Code = 2_001
代码
Name = 2_002
名称
LatestPrice = 2_003
最新价
ChangeRate = 2_004
涨跌%
BidPrice = 2_005
买价
SellingPrice = 2_006
卖价
BidQuantity = 2_007
买量
SellingQuantity = 2_008
卖量
Volume = 2_009
成交量
Turnover = 2_010
成交额
PremiumPct = 2_011
溢价%
EffectiveLeverage = 2_012
有效杠杆
Delta = 2_013
对冲值
ImpliedVolatility = 2_014
引伸波幅
Type = 2_015
类型
ExecutivePrice = 2_016
行权价
BreakEvenPoint = 2_017
打和点
ExpiryDate = 2_018
到期日
LastTradingDay = 2_019
最后交易日
LeveragedRate = 2_020
杠杆比率
InOutTheMoneyPct = 2_021
价内/价外%
CallPrice = 2_022
收回价
正股价距收回价%
ChangePrices = 2_024
换股价
ChangePct = 2_025
换股比率
OutstandingQuantity = 2_026
街货比例
Amplitude = 2_027
振幅
Issuer = 2_028
发行人
PriceChangeVal = 2_029
涨跌额
Status = 2_030
状态
Score = 2_031
权证评分
FxScore = 2_032
法兴评分
IpoTime = 2_033
上市日期
StreetVol = 2_034
街货量
LotSize = 2_035
每手
IssueSize = 2_036
发行量
IpoPrice = 2_037
发行价
Equity = 2_038
正股
LowerStrikePrice = 2_039
下限价
UpperStrikePrice = 2_040
上限价
IwPriceStatus = 2_041
界内界外
Sensitivity = 2_042
敏感度
Implementations
Sourceimpl SortId
impl SortId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.