pub struct WarrantItem {Show 43 fields
pub stock_id: Option<u64>,
pub stock_owner: Option<u64>,
pub issuer_id: Option<u32>,
pub warrant_type: Option<i32>,
pub strick_price: Option<u32>,
pub maturity_date: Option<u64>,
pub last_trade_date: Option<u64>,
pub conversion_ratio: Option<u32>,
pub lastclose_price: Option<u32>,
pub recovery_price: Option<u32>,
pub stock_owner_price: Option<u32>,
pub current_price: Option<u32>,
pub volume: Option<u64>,
pub turnover: Option<u64>,
pub sell_vol: Option<u64>,
pub buy_vol: Option<u64>,
pub sell_price: Option<u32>,
pub buy_price: Option<u32>,
pub street_rate: Option<u32>,
pub high_price: Option<u32>,
pub low_price: Option<u32>,
pub implied_volatility: Option<u32>,
pub delta: Option<i32>,
pub status: Option<i32>,
pub street_rate_new: Option<u32>,
pub score: Option<u32>,
pub premium: Option<i64>,
pub leverage: Option<u64>,
pub effective_leverage: Option<i64>,
pub break_even_point: Option<u32>,
pub ipop: Option<i64>,
pub amplitude: Option<i64>,
pub fx_score: Option<u32>,
pub ipo_time: Option<u64>,
pub street_vol: Option<u64>,
pub lot_size: Option<u32>,
pub issue_size: Option<u64>,
pub ipo_price: Option<u32>,
pub upper_strike_price: Option<u64>,
pub lower_strike_price: Option<u64>,
pub iw_price_status: Option<u32>,
pub sensitivity: Option<i32>,
pub price_recovery_ratio: Option<i64>,
}Fields
stock_id: Option<u64>静态数据项:
股票id
stock_owner: Option<u64>正股id
issuer_id: Option<u32>发行商id
warrant_type: Option<i32>窝轮类型
strick_price: Option<u32>行使价
maturity_date: Option<u64>到期日
last_trade_date: Option<u64>最后交易日
conversion_ratio: Option<u32>换股比率
lastclose_price: Option<u32>昨收价
recovery_price: Option<u32>回收价
stock_owner_price: Option<u32>动态数据项
正股价格
current_price: Option<u32>当前价 *1000
volume: Option<u64>成交量
turnover: Option<u64>成交额
sell_vol: Option<u64>卖量
buy_vol: Option<u64>买量
sell_price: Option<u32>卖价
buy_price: Option<u32>买价
street_rate: Option<u32>街货占比, client展现为: street_rate/1000
high_price: Option<u32>最高价 *1000
low_price: Option<u32>最低价
implied_volatility: Option<u32>引伸波幅
delta: Option<i32>对冲值
status: Option<i32>WarrantStatus
street_rate_new: Option<u32>另一个街货占比, =street_rate/100, 即client展现为:street_rate_new/10, 为了与推送逻辑保持一致,
score: Option<u32>因BMP行情状态下,两边需要统一计算
权证评分
溢价%,*100000
leverage: Option<u64>杠杆比例(倍),*1000
effective_leverage: Option<i64>有效杠杆,*1000
break_even_point: Option<u32>打和点,*1000
ipop: Option<i64>价内/价外%, *100000
amplitude: Option<i64>振幅%,*100000
fx_score: Option<u32>法兴评分
ipo_time: Option<u64>上市日期
street_vol: Option<u64>街货量
lot_size: Option<u32>每手
issue_size: Option<u64>发行量
ipo_price: Option<u32>发行价,*1000
upper_strike_price: Option<u64>上限价 倍数 *10^9
lower_strike_price: Option<u64>下限价 倍数 *10^9
iw_price_status: Option<u32>界内/界外状态标志,0为界内,1为界外
sensitivity: Option<i32>敏感度 *1000(精确到0.001)
price_recovery_ratio: Option<i64>正股距回收价% 1001000
Implementations
Sourceimpl WarrantItem
impl WarrantItem
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn stock_owner(&self) -> u64
pub fn stock_owner(&self) -> u64
Returns the value of stock_owner, or the default value if stock_owner is unset.
Sourcepub fn issuer_id(&self) -> u32
pub fn issuer_id(&self) -> u32
Returns the value of issuer_id, or the default value if issuer_id is unset.
Sourcepub fn warrant_type(&self) -> i32
pub fn warrant_type(&self) -> i32
Returns the value of warrant_type, or the default value if warrant_type is unset.
Sourcepub fn strick_price(&self) -> u32
pub fn strick_price(&self) -> u32
Returns the value of strick_price, or the default value if strick_price is unset.
Sourcepub fn maturity_date(&self) -> u64
pub fn maturity_date(&self) -> u64
Returns the value of maturity_date, or the default value if maturity_date is unset.
Sourcepub fn last_trade_date(&self) -> u64
pub fn last_trade_date(&self) -> u64
Returns the value of last_trade_date, or the default value if last_trade_date is unset.
Sourcepub fn conversion_ratio(&self) -> u32
pub fn conversion_ratio(&self) -> u32
Returns the value of conversion_ratio, or the default value if conversion_ratio is unset.
Sourcepub fn lastclose_price(&self) -> u32
pub fn lastclose_price(&self) -> u32
Returns the value of lastclose_price, or the default value if lastclose_price is unset.
Sourcepub fn recovery_price(&self) -> u32
pub fn recovery_price(&self) -> u32
Returns the value of recovery_price, or the default value if recovery_price is unset.
Sourcepub fn stock_owner_price(&self) -> u32
pub fn stock_owner_price(&self) -> u32
Returns the value of stock_owner_price, or the default value if stock_owner_price is unset.
Sourcepub fn current_price(&self) -> u32
pub fn current_price(&self) -> u32
Returns the value of current_price, or the default value if current_price is unset.
Sourcepub fn volume(&self) -> u64
pub fn volume(&self) -> u64
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn turnover(&self) -> u64
pub fn turnover(&self) -> u64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn sell_vol(&self) -> u64
pub fn sell_vol(&self) -> u64
Returns the value of sell_vol, or the default value if sell_vol is unset.
Sourcepub fn buy_vol(&self) -> u64
pub fn buy_vol(&self) -> u64
Returns the value of buy_vol, or the default value if buy_vol is unset.
Sourcepub fn sell_price(&self) -> u32
pub fn sell_price(&self) -> u32
Returns the value of sell_price, or the default value if sell_price is unset.
Sourcepub fn buy_price(&self) -> u32
pub fn buy_price(&self) -> u32
Returns the value of buy_price, or the default value if buy_price is unset.
Sourcepub fn street_rate(&self) -> u32
pub fn street_rate(&self) -> u32
Returns the value of street_rate, or the default value if street_rate is unset.
Sourcepub fn high_price(&self) -> u32
pub fn high_price(&self) -> u32
Returns the value of high_price, or the default value if high_price is unset.
Sourcepub fn low_price(&self) -> u32
pub fn low_price(&self) -> u32
Returns the value of low_price, or the default value if low_price is unset.
Sourcepub fn implied_volatility(&self) -> u32
pub fn implied_volatility(&self) -> u32
Returns the value of implied_volatility, or the default value if implied_volatility is unset.
Sourcepub fn status(&self) -> i32
pub fn status(&self) -> i32
Returns the value of status, or the default value if status is unset.
Sourcepub fn street_rate_new(&self) -> u32
pub fn street_rate_new(&self) -> u32
Returns the value of street_rate_new, or the default value if street_rate_new is unset.
Returns the value of premium, or the default value if premium is unset.
Sourcepub fn leverage(&self) -> u64
pub fn leverage(&self) -> u64
Returns the value of leverage, or the default value if leverage is unset.
Sourcepub fn effective_leverage(&self) -> i64
pub fn effective_leverage(&self) -> i64
Returns the value of effective_leverage, or the default value if effective_leverage is unset.
Sourcepub fn break_even_point(&self) -> u32
pub fn break_even_point(&self) -> u32
Returns the value of break_even_point, or the default value if break_even_point is unset.
Sourcepub fn amplitude(&self) -> i64
pub fn amplitude(&self) -> i64
Returns the value of amplitude, or the default value if amplitude is unset.
Sourcepub fn fx_score(&self) -> u32
pub fn fx_score(&self) -> u32
Returns the value of fx_score, or the default value if fx_score is unset.
Sourcepub fn ipo_time(&self) -> u64
pub fn ipo_time(&self) -> u64
Returns the value of ipo_time, or the default value if ipo_time is unset.
Sourcepub fn street_vol(&self) -> u64
pub fn street_vol(&self) -> u64
Returns the value of street_vol, or the default value if street_vol is unset.
Sourcepub fn lot_size(&self) -> u32
pub fn lot_size(&self) -> u32
Returns the value of lot_size, or the default value if lot_size is unset.
Sourcepub fn issue_size(&self) -> u64
pub fn issue_size(&self) -> u64
Returns the value of issue_size, or the default value if issue_size is unset.
Sourcepub fn ipo_price(&self) -> u32
pub fn ipo_price(&self) -> u32
Returns the value of ipo_price, or the default value if ipo_price is unset.
Sourcepub fn upper_strike_price(&self) -> u64
pub fn upper_strike_price(&self) -> u64
Returns the value of upper_strike_price, or the default value if upper_strike_price is unset.
Sourcepub fn lower_strike_price(&self) -> u64
pub fn lower_strike_price(&self) -> u64
Returns the value of lower_strike_price, or the default value if lower_strike_price is unset.
Sourcepub fn iw_price_status(&self) -> u32
pub fn iw_price_status(&self) -> u32
Returns the value of iw_price_status, or the default value if iw_price_status is unset.
Sourcepub fn sensitivity(&self) -> i32
pub fn sensitivity(&self) -> i32
Returns the value of sensitivity, or the default value if sensitivity is unset.
Sourcepub fn price_recovery_ratio(&self) -> i64
pub fn price_recovery_ratio(&self) -> i64
Returns the value of price_recovery_ratio, or the default value if price_recovery_ratio is unset.