pub struct Option {Show 14 fields
pub option_id: Option<u64>,
pub strike_price: Option<u64>,
pub sequence: Option<u64>,
pub option_name: Option<String>,
pub option_string_code: Option<String>,
pub underlying_security_id: Option<u64>,
pub delisting_flag: Option<u32>,
pub strike_date: Option<u32>,
pub hp_strike_price: Option<u64>,
pub option_type: Option<i32>,
pub market: Option<String>,
pub suspend_flag: Option<u32>,
pub contract_share_size: Option<u32>,
pub option_price: Option<i64>,
}Fields
option_id: Option<u64>期权ID
strike_price: Option<u64>行权价
sequence: Option<u64>option_name: Option<String>期权名称, 例如AAPL 170314 140.02C
option_string_code: Option<String>期权字符串code, example AAPL170324C140020
underlying_security_id: Option<u64>标的股票id
delisting_flag: Option<u32>退市标志, 非0表示退市 0表示不退市
strike_date: Option<u32>行权时间戳
hp_strike_price: Option<u64>行权价 价格*10的9次方
option_type: Option<i32>期权类型 call or put
market: Option<String>发行市场 CBOE等
suspend_flag: Option<u32>停牌标记 1表示停牌, 0正常
一份合约里的股数,默认100
option_price: Option<i64>期权价格 * 1000000000
Implementations
Sourceimpl Option
impl Option
Sourcepub fn option_id(&self) -> u64
pub fn option_id(&self) -> u64
Returns the value of option_id, or the default value if option_id is unset.
Sourcepub fn strike_price(&self) -> u64
pub fn strike_price(&self) -> u64
Returns the value of strike_price, or the default value if strike_price is unset.
Sourcepub fn sequence(&self) -> u64
pub fn sequence(&self) -> u64
Returns the value of sequence, or the default value if sequence is unset.
Sourcepub fn option_name(&self) -> &str
pub fn option_name(&self) -> &str
Returns the value of option_name, or the default value if option_name is unset.
Sourcepub fn option_string_code(&self) -> &str
pub fn option_string_code(&self) -> &str
Returns the value of option_string_code, or the default value if option_string_code is unset.
Sourcepub fn underlying_security_id(&self) -> u64
pub fn underlying_security_id(&self) -> u64
Returns the value of underlying_security_id, or the default value if underlying_security_id is unset.
Sourcepub fn delisting_flag(&self) -> u32
pub fn delisting_flag(&self) -> u32
Returns the value of delisting_flag, or the default value if delisting_flag is unset.
Sourcepub fn strike_date(&self) -> u32
pub fn strike_date(&self) -> u32
Returns the value of strike_date, or the default value if strike_date is unset.
Sourcepub fn hp_strike_price(&self) -> u64
pub fn hp_strike_price(&self) -> u64
Returns the value of hp_strike_price, or the default value if hp_strike_price is unset.
Sourcepub fn option_type(&self) -> i32
pub fn option_type(&self) -> i32
Returns the value of option_type, or the default value if option_type is unset.
Sourcepub fn market(&self) -> &str
pub fn market(&self) -> &str
Returns the value of market, or the default value if market is unset.
Sourcepub fn suspend_flag(&self) -> u32
pub fn suspend_flag(&self) -> u32
Returns the value of suspend_flag, or the default value if suspend_flag is unset.
Returns the value of contract_share_size, or the default value if contract_share_size is unset.
Sourcepub fn option_price(&self) -> i64
pub fn option_price(&self) -> i64
Returns the value of option_price, or the default value if option_price is unset.