pub struct HkShortInfo {
pub timestamp: Option<u64>,
pub shares_traded: Option<u64>,
pub turnover: Option<u64>,
pub short_sell_shares_traded_new: Option<u64>,
pub short_sell_turnover: Option<u64>,
pub price_open_new: Option<i64>,
pub price_close_new: Option<i64>,
pub last_close_price: Option<i64>,
pub daily_trade_avg_ratio: Option<i32>,
}Fields
timestamp: Option<u64>turnover: Option<u64>short_sell_turnover: Option<u64>price_open_new: Option<i64>price_close_new: Option<i64>last_close_price: Option<i64>daily_trade_avg_ratio: Option<i32>Implementations
Sourceimpl HkShortInfo
impl HkShortInfo
Sourcepub fn timestamp(&self) -> u64
pub fn timestamp(&self) -> u64
Returns the value of timestamp, or the default value if timestamp is unset.
Returns the value of shares_traded, or the default value if shares_traded is unset.
Sourcepub fn turnover(&self) -> u64
pub fn turnover(&self) -> u64
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn short_sell_turnover(&self) -> u64
pub fn short_sell_turnover(&self) -> u64
Returns the value of short_sell_turnover, or the default value if short_sell_turnover is unset.
Sourcepub fn last_close_price(&self) -> i64
pub fn last_close_price(&self) -> i64
Returns the value of last_close_price, or the default value if last_close_price is unset.
Sourcepub fn price_open_new(&self) -> i64
pub fn price_open_new(&self) -> i64
Returns the value of price_open_new, or the default value if price_open_new is unset.
Sourcepub fn price_close_new(&self) -> i64
pub fn price_close_new(&self) -> i64
Returns the value of price_close_new, or the default value if price_close_new is unset.
Sourcepub fn daily_trade_avg_ratio(&self) -> i32
pub fn daily_trade_avg_ratio(&self) -> i32
Returns the value of daily_trade_avg_ratio, or the default value if daily_trade_avg_ratio is unset.
Returns the value of short_sell_shares_traded_new, or the default value if short_sell_shares_traded_new is unset.