pub struct ManualOrderCreate {
pub cid: Option<u64>,
pub account_id: Option<u64>,
pub order_id_up: Option<String>,
pub symbol: Option<String>,
pub side: Option<u32>,
pub order_qty: Option<String>,
pub price: Option<String>,
pub manual_ord_type: Option<u32>,
pub remark: Option<String>,
}Fields
cid: Option<u64>customer_id
account_id: Option<u64>账户ID,长 ID
order_id_up: Option<String>上游订单 ID
symbol: Option<String>symbol,eg. BTC/USD
side: Option<u32>详见公共协议cryptotrade_cmn.OrderSide
order_qty: Option<String>订单数量
price: Option<String>订单价格
manual_ord_type: Option<u32>人工单类型,详见公共协议cryptotrade_cmn.ManualOrdType
remark: Option<String>备注
Implementations
Sourceimpl ManualOrderCreate
impl ManualOrderCreate
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn order_id_up(&self) -> &str
pub fn order_id_up(&self) -> &str
Returns the value of order_id_up, or the default value if order_id_up is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn order_qty(&self) -> &str
pub fn order_qty(&self) -> &str
Returns the value of order_qty, or the default value if order_qty is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn manual_ord_type(&self) -> u32
pub fn manual_ord_type(&self) -> u32
Returns the value of manual_ord_type, or the default value if manual_ord_type is unset.