pub struct ManualOrder {Show 16 fields
pub manual_order_id: Option<u64>,
pub cid: Option<u64>,
pub account_id: Option<u64>,
pub order_id_up: Option<String>,
pub customer_name: Option<String>,
pub symbol: Option<String>,
pub side: Option<u32>,
pub order_qty: Option<String>,
pub price: Option<String>,
pub order_time: Option<i64>,
pub input_time: Option<i64>,
pub manual_ord_type: Option<u32>,
pub remark: Option<String>,
pub status: Option<u32>,
pub creator_name: Option<String>,
pub reviewer_name: Option<String>,
}Fields
manual_order_id: Option<u64>人工单 ID
cid: Option<u64>customer_id
account_id: Option<u64>账户ID,长 ID
order_id_up: Option<String>上游订单 ID
customer_name: Option<String>用户姓名
symbol: Option<String>symbol,eg. BTC/USD
side: Option<u32>交易方向,详见公共协议cryptotrade_cmn.OrderSide
order_qty: Option<String>订单数量
price: Option<String>订单价格
order_time: Option<i64>订单下单时间,微秒
input_time: Option<i64>人工单创建时间,微秒
manual_ord_type: Option<u32>人工单类型,详见公共协议cryptotrade_cmn.ManualOrdType
remark: Option<String>备注
status: Option<u32>人工单状态,详见公共协议cryptotrade_cmn.ManualOrdStatus
creator_name: Option<String>创建人名字
reviewer_name: Option<String>审批人名字
Implementations
Sourceimpl ManualOrder
impl ManualOrder
Sourcepub fn manual_order_id(&self) -> u64
pub fn manual_order_id(&self) -> u64
Returns the value of manual_order_id, or the default value if manual_order_id is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn order_id_up(&self) -> &str
pub fn order_id_up(&self) -> &str
Returns the value of order_id_up, or the default value if order_id_up is unset.
Sourcepub fn customer_name(&self) -> &str
pub fn customer_name(&self) -> &str
Returns the value of customer_name, or the default value if customer_name is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn order_qty(&self) -> &str
pub fn order_qty(&self) -> &str
Returns the value of order_qty, or the default value if order_qty is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn order_time(&self) -> i64
pub fn order_time(&self) -> i64
Returns the value of order_time, or the default value if order_time is unset.
Sourcepub fn input_time(&self) -> i64
pub fn input_time(&self) -> i64
Returns the value of input_time, or the default value if input_time is unset.
Sourcepub fn manual_ord_type(&self) -> u32
pub fn manual_ord_type(&self) -> u32
Returns the value of manual_ord_type, or the default value if manual_ord_type is unset.
Sourcepub fn remark(&self) -> &str
pub fn remark(&self) -> &str
Returns the value of remark, or the default value if remark is unset.
Sourcepub fn status(&self) -> u32
pub fn status(&self) -> u32
Returns the value of status, or the default value if status is unset.
Sourcepub fn creator_name(&self) -> &str
pub fn creator_name(&self) -> &str
Returns the value of creator_name, or the default value if creator_name is unset.
Sourcepub fn reviewer_name(&self) -> &str
pub fn reviewer_name(&self) -> &str
Returns the value of reviewer_name, or the default value if reviewer_name is unset.