pub struct OrderNewReq {
pub msg_header: Option<CryptoMsgHeader>,
pub side: Option<u32>,
pub stock_id: Option<u64>,
pub symbol: Option<String>,
pub exchange: Option<String>,
pub price: Option<String>,
pub order_qty: Option<String>,
pub ord_type: Option<u32>,
pub time_in_force: Option<u32>,
pub text: Option<String>,
pub security_type: Option<u32>,
pub market: Option<u32>,
}Fields
msg_header: Option<CryptoMsgHeader>side: Option<u32>详见公共协议cryptotrade_cmn.OrderSide
stock_id: Option<u64>symbol: Option<String>futu_symbol
exchange: Option<String>交易所
price: Option<String>order_qty: Option<String>ord_type: Option<u32>详见公共协议cryptotrade_cmn.OrderType
time_in_force: Option<u32>详见公共协议cryptotrade_cmn.TimeInForce
text: Option<String>可见字符, 最长100字节, server不根据此字段做任何逻辑, 只存储+校验
security_type: Option<u32>market: Option<u32>详见公共协议cryptotrade_cmn.StockMarket
Implementations
Sourceimpl OrderNewReq
impl OrderNewReq
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn order_qty(&self) -> &str
pub fn order_qty(&self) -> &str
Returns the value of order_qty, or the default value if order_qty is unset.
Sourcepub fn ord_type(&self) -> u32
pub fn ord_type(&self) -> u32
Returns the value of ord_type, or the default value if ord_type is unset.
Sourcepub fn time_in_force(&self) -> u32
pub fn time_in_force(&self) -> u32
Returns the value of time_in_force, or the default value if time_in_force is unset.
Sourcepub fn security_type(&self) -> u32
pub fn security_type(&self) -> u32
Returns the value of security_type, or the default value if security_type is unset.