pub struct ClearingFill {Show 30 fields
pub exec_id: Option<String>,
pub exec_id_up: Option<String>,
pub secondary_exec_id_up: Option<String>,
pub order_id_up: Option<String>,
pub side: Option<u32>,
pub symbol_pair: Option<SymbolPair>,
pub trade_date: Option<u32>,
pub clearing_date: Option<u32>,
pub last_qty: Option<String>,
pub last_px: Option<String>,
pub cum_qty: Option<String>,
pub avg_px: Option<String>,
pub leave_qty: Option<String>,
pub transact_time: Option<i64>,
pub account: Option<String>,
pub account_id: Option<u64>,
pub exchange: Option<String>,
pub clearing_firm: Option<String>,
pub input_source: Option<u32>,
pub security_type: Option<u32>,
pub order_id: Option<String>,
pub cid: Option<u64>,
pub ex_destination: Option<u32>,
pub order_time: Option<i64>,
pub order_type: Option<u32>,
pub fee_info_list: Vec<FeeInfo>,
pub last_fill_amount: Option<String>,
pub router_exchange: Option<u32>,
pub fill_id: Option<String>,
pub fill_id_up: Option<String>,
}Fields
exec_id: Option<String>内部执行报告id
exec_id_up: Option<String>上游执行报告id
secondary_exec_id_up: Option<String>上游成交id
order_id_up: Option<String>上游订单ID
side: Option<u32>详见trade_cmn.Side
symbol_pair: Option<SymbolPair>交易对信息
trade_date: Option<u32>交易日
clearing_date: Option<u32>结算日
last_qty: Option<String>本次成交数量
last_px: Option<String>本次成交价格
cum_qty: Option<String>已成交总量
avg_px: Option<String>已成交的均价
leave_qty: Option<String>剩余未成交数量
transact_time: Option<i64>成交时间,微秒
account: Option<String>上游账户
account_id: Option<u64>FUTU 账户长ID
exchange: Option<String>交易所
clearing_firm: Option<String>清算公司
input_source: Option<u32>订单来源 见 InputSourceType
security_type: Option<u32>交易品种 取值参考SecurityType
order_id: Option<String>订单id
cid: Option<u64>customer id
ex_destination: Option<u32>详见公共协议cryptotrade_cmn的ExDestination
order_time: Option<i64>订单时间
order_type: Option<u32>详见公共协议cryptotrade_cmn的OrderType
fee_info_list: Vec<FeeInfo>扣费信息
last_fill_amount: Option<String>本次成交金额=本次成交数量*本次成交价格,截断保留两位
router_exchange: Option<u32>详见公共协议cryptotrade_cmn的RouterExchange
fill_id: Option<String>成交id
fill_id_up: Option<String>上游成交id
Implementations
Sourceimpl ClearingFill
impl ClearingFill
Sourcepub fn exec_id(&self) -> &str
pub fn exec_id(&self) -> &str
Returns the value of exec_id, or the default value if exec_id is unset.
Sourcepub fn exec_id_up(&self) -> &str
pub fn exec_id_up(&self) -> &str
Returns the value of exec_id_up, or the default value if exec_id_up is unset.
Sourcepub fn secondary_exec_id_up(&self) -> &str
pub fn secondary_exec_id_up(&self) -> &str
Returns the value of secondary_exec_id_up, or the default value if secondary_exec_id_up is unset.
Sourcepub fn order_id_up(&self) -> &str
pub fn order_id_up(&self) -> &str
Returns the value of order_id_up, or the default value if order_id_up is unset.
Sourcepub fn trade_date(&self) -> u32
pub fn trade_date(&self) -> u32
Returns the value of trade_date, or the default value if trade_date is unset.
Sourcepub fn clearing_date(&self) -> u32
pub fn clearing_date(&self) -> u32
Returns the value of clearing_date, or the default value if clearing_date is unset.
Sourcepub fn last_qty(&self) -> &str
pub fn last_qty(&self) -> &str
Returns the value of last_qty, or the default value if last_qty is unset.
Sourcepub fn last_px(&self) -> &str
pub fn last_px(&self) -> &str
Returns the value of last_px, or the default value if last_px is unset.
Sourcepub fn cum_qty(&self) -> &str
pub fn cum_qty(&self) -> &str
Returns the value of cum_qty, or the default value if cum_qty is unset.
Sourcepub fn avg_px(&self) -> &str
pub fn avg_px(&self) -> &str
Returns the value of avg_px, or the default value if avg_px is unset.
Sourcepub fn leave_qty(&self) -> &str
pub fn leave_qty(&self) -> &str
Returns the value of leave_qty, or the default value if leave_qty is unset.
Sourcepub fn transact_time(&self) -> i64
pub fn transact_time(&self) -> i64
Returns the value of transact_time, or the default value if transact_time is unset.
Sourcepub fn account(&self) -> &str
pub fn account(&self) -> &str
Returns the value of account, or the default value if account is unset.
Sourcepub fn account_id(&self) -> u64
pub fn account_id(&self) -> u64
Returns the value of account_id, or the default value if account_id is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn clearing_firm(&self) -> &str
pub fn clearing_firm(&self) -> &str
Returns the value of clearing_firm, or the default value if clearing_firm is unset.
Sourcepub fn input_source(&self) -> u32
pub fn input_source(&self) -> u32
Returns the value of input_source, or the default value if input_source is unset.
Sourcepub fn security_type(&self) -> u32
pub fn security_type(&self) -> u32
Returns the value of security_type, or the default value if security_type is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn ex_destination(&self) -> u32
pub fn ex_destination(&self) -> u32
Returns the value of ex_destination, or the default value if ex_destination is unset.
Sourcepub fn order_time(&self) -> i64
pub fn order_time(&self) -> i64
Returns the value of order_time, or the default value if order_time is unset.
Sourcepub fn order_type(&self) -> u32
pub fn order_type(&self) -> u32
Returns the value of order_type, or the default value if order_type is unset.
Sourcepub fn last_fill_amount(&self) -> &str
pub fn last_fill_amount(&self) -> &str
Returns the value of last_fill_amount, or the default value if last_fill_amount is unset.
Sourcepub fn router_exchange(&self) -> u32
pub fn router_exchange(&self) -> u32
Returns the value of router_exchange, or the default value if router_exchange is unset.
Sourcepub fn fill_id(&self) -> &str
pub fn fill_id(&self) -> &str
Returns the value of fill_id, or the default value if fill_id is unset.
Sourcepub fn fill_id_up(&self) -> &str
pub fn fill_id_up(&self) -> &str
Returns the value of fill_id_up, or the default value if fill_id_up is unset.