#[repr(i32)]pub enum ExDestination {
Show 27 variants
Hkcc = 0,
HkOcg = 1,
HkPhilip = 2,
SgPhilip = 3,
FtGreyMarket = 4,
Bmsc = 11,
Ib = 20,
Vt = 21,
FtClearing = 22,
Ifast = 31,
SgxFtClearing = 32,
AuIb = 41,
HkFund = 101,
UsFund = 102,
HkBond = 103,
UsBond = 104,
UsIfastBond = 105,
HkDerivate = 201,
HkFutures = 205,
CmeFutures = 206,
SgxFutures = 207,
JpxFutures = 208,
MyFutures = 209,
FutcHkalgo = 401,
FutcCcalgo = 402,
CryptoGemini = 501,
CryptoCommon = 502,
}Expand description
上游
Variants
Hkcc = 0
hkcc
HkOcg = 1
港交所
HkPhilip = 2
香港辉立
SgPhilip = 3
新加坡辉立
FtGreyMarket = 4
富途暗盘
Bmsc = 11
马来西亚股票
Ib = 20
ib
Vt = 21
vt
FtClearing = 22
富途Clearing
Ifast = 31
新加坡上游ifast
SgxFtClearing = 32
新加坡富途Clearing
AuIb = 41
澳股ib
HkFund = 101
港股基金
UsFund = 102
美股基金
HkBond = 103
港股债券
UsBond = 104
美股债券
UsIfastBond = 105
ifast 美元债券
HkDerivate = 201
港股衍生品-期权
HkFutures = 205
港股期货
CmeFutures = 206
CME期货
SgxFutures = 207
SGX期货
JpxFutures = 208
JPX期货
MyFutures = 209
MY期货
FutcHkalgo = 401
FUTC 港股算法单
FutcCcalgo = 402
FUTC A股通算法单
CryptoGemini = 501
数字币 GEMINI上游
CryptoCommon = 502
数字币 上游(通用)
Implementations
Sourceimpl ExDestination
impl ExDestination
Sourceimpl ExDestination
impl ExDestination
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.