pub struct FillNumMarket {
pub market: Option<u32>,
pub fill_num: Option<i32>,
pub buy_fill_num: Option<i32>,
pub sell_fill_num: Option<i32>,
pub turnover: Option<String>,
pub currency: Option<i32>,
pub fill_order_num: Option<i32>,
}Fields
market: Option<u32>市场, 参考odr_sys_cmn.proto:Market
fill_num: Option<i32>成交笔数
buy_fill_num: Option<i32>买成交笔数,包括:买入,买回
sell_fill_num: Option<i32>卖成交笔数,包括:卖空,卖出
turnover: Option<String>今日成交总额
currency: Option<i32>货币单位,取值看Currency
fill_order_num: Option<i32>成交订单数
Implementations
Sourceimpl FillNumMarket
impl FillNumMarket
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn fill_num(&self) -> i32
pub fn fill_num(&self) -> i32
Returns the value of fill_num, or the default value if fill_num is unset.
Sourcepub fn buy_fill_num(&self) -> i32
pub fn buy_fill_num(&self) -> i32
Returns the value of buy_fill_num, or the default value if buy_fill_num is unset.
Sourcepub fn sell_fill_num(&self) -> i32
pub fn sell_fill_num(&self) -> i32
Returns the value of sell_fill_num, or the default value if sell_fill_num is unset.
Sourcepub fn turnover(&self) -> &str
pub fn turnover(&self) -> &str
Returns the value of turnover, or the default value if turnover is unset.
Sourcepub fn currency(&self) -> i32
pub fn currency(&self) -> i32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn fill_order_num(&self) -> i32
pub fn fill_order_num(&self) -> i32
Returns the value of fill_order_num, or the default value if fill_order_num is unset.