pub struct OrderFill {Show 27 fields
pub side: Option<u32>,
pub market: Option<u32>,
pub symbol: Option<String>,
pub stock_name: Option<String>,
pub order_id: Option<String>,
pub id: Option<String>,
pub qty: Option<String>,
pub price: Option<String>,
pub create_time: Option<u64>,
pub update_time: Option<u64>,
pub counter_broker_id: Option<String>,
pub currency: Option<u32>,
pub security_type: Option<u32>,
pub total_fill_price: Option<String>,
pub counter_broker_name: Option<String>,
pub exchange: Option<String>,
pub is_cancelled: Option<bool>,
pub is_corrected: Option<bool>,
pub original_price: Option<String>,
pub original_qty: Option<String>,
pub original_tatal_fill_price: Option<String>,
pub display_fill_id: Option<String>,
pub dark_pool: Option<u32>,
pub exdestination: Option<u32>,
pub leg_id: Option<String>,
pub input_source: Option<u32>,
pub sub_account_id: Option<u64>,
}Fields
side: Option<u32>取值参考 Side
market: Option<u32>取值参考 Market
symbol: Option<String>stock_name: Option<String>order_id: Option<String>id: Option<String>成交id
qty: Option<String>成交股数
price: Option<String>成交价格
create_time: Option<u64>单位微秒, 成交创建时间
update_time: Option<u64>单位微秒, 成交最新时间(正常情况和create_time一致,除非发生成交撤销或成交更改)
counter_broker_id: Option<String>对手经纪ID
currency: Option<u32>取值参考 Currency
security_type: Option<u32>交易品种 取值参考SecurityType
total_fill_price: Option<String>成交总价
counter_broker_name: Option<String>对手经纪名称
exchange: Option<String>股票所属交易所
is_cancelled: Option<bool>true, 表示该成交被取消,[23,25]字段才有效
is_corrected: Option<bool>true, 表示成交被更改, [23,25]字段才有效
original_price: Option<String>被更正或撤销前的成交价
original_qty: Option<String>被更正或撤销前的成交股数
original_tatal_fill_price: Option<String>被更正或撤销前的成交总价
display_fill_id: Option<String>展示用成交id,目前期货有此字段
dark_pool: Option<u32>暗盘类型,0:非暗盘 1:暗盘,默认为非暗盘
exdestination: Option<u32>上游券商 取值参考ExDestination
leg_id: Option<String>只有多腿订单会放回这个值
input_source: Option<u32>请求源,OrderQueryService使用,客户端用于判断属于普通订单或者行权/指派订单,取值参考InputSourceType
sub_account_id: Option<u64>【日本券商】口座id,sub account ID 在同个账户下,每个子账户id唯一
Implementations
Sourceimpl OrderFill
impl OrderFill
Sourcepub fn market(&self) -> u32
pub fn market(&self) -> u32
Returns the value of market, or the default value if market is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn stock_name(&self) -> &str
pub fn stock_name(&self) -> &str
Returns the value of stock_name, or the default value if stock_name is unset.
Sourcepub fn order_id(&self) -> &str
pub fn order_id(&self) -> &str
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn price(&self) -> &str
pub fn price(&self) -> &str
Returns the value of price, or the default value if price is unset.
Sourcepub fn create_time(&self) -> u64
pub fn create_time(&self) -> u64
Returns the value of create_time, or the default value if create_time is unset.
Sourcepub fn update_time(&self) -> u64
pub fn update_time(&self) -> u64
Returns the value of update_time, or the default value if update_time is unset.
Sourcepub fn counter_broker_id(&self) -> &str
pub fn counter_broker_id(&self) -> &str
Returns the value of counter_broker_id, or the default value if counter_broker_id is unset.
Sourcepub fn currency(&self) -> u32
pub fn currency(&self) -> u32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn security_type(&self) -> u32
pub fn security_type(&self) -> u32
Returns the value of security_type, or the default value if security_type is unset.
Sourcepub fn total_fill_price(&self) -> &str
pub fn total_fill_price(&self) -> &str
Returns the value of total_fill_price, or the default value if total_fill_price is unset.
Sourcepub fn counter_broker_name(&self) -> &str
pub fn counter_broker_name(&self) -> &str
Returns the value of counter_broker_name, or the default value if counter_broker_name is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns the value of is_cancelled, or the default value if is_cancelled is unset.
Sourcepub fn is_corrected(&self) -> bool
pub fn is_corrected(&self) -> bool
Returns the value of is_corrected, or the default value if is_corrected is unset.
Sourcepub fn original_price(&self) -> &str
pub fn original_price(&self) -> &str
Returns the value of original_price, or the default value if original_price is unset.
Sourcepub fn original_qty(&self) -> &str
pub fn original_qty(&self) -> &str
Returns the value of original_qty, or the default value if original_qty is unset.
Sourcepub fn original_tatal_fill_price(&self) -> &str
pub fn original_tatal_fill_price(&self) -> &str
Returns the value of original_tatal_fill_price, or the default value if original_tatal_fill_price is unset.
Sourcepub fn display_fill_id(&self) -> &str
pub fn display_fill_id(&self) -> &str
Returns the value of display_fill_id, or the default value if display_fill_id is unset.
Sourcepub fn dark_pool(&self) -> u32
pub fn dark_pool(&self) -> u32
Returns the value of dark_pool, or the default value if dark_pool is unset.
Sourcepub fn exdestination(&self) -> u32
pub fn exdestination(&self) -> u32
Returns the value of exdestination, or the default value if exdestination is unset.
Sourcepub fn leg_id(&self) -> &str
pub fn leg_id(&self) -> &str
Returns the value of leg_id, or the default value if leg_id is unset.
Sourcepub fn input_source(&self) -> u32
pub fn input_source(&self) -> u32
Returns the value of input_source, or the default value if input_source is unset.
Sourcepub fn sub_account_id(&self) -> u64
pub fn sub_account_id(&self) -> u64
Returns the value of sub_account_id, or the default value if sub_account_id is unset.