GetComboOptionListReq

Struct GetComboOptionListReq 

pub struct GetComboOptionListReq {
    pub strategy: Option<i32>,
    pub stock_id: Option<u64>,
    pub spread: Option<i64>,
    pub strike_date: Option<u64>,
    pub expiration: Option<u32>,
    pub index_option_type: Option<u32>,
    pub standard_type: Option<u32>,
    pub filetr_data: Option<FilterData>,
}
CMD 6736: 查询组合期权列表(Rust daemon 仅使用单腿策略 strategy=1, 起到服务端 Greek filter 的作用)

Fields

strategy: Option<i32>

Rust daemon 填 1 (SingleOption)

stock_id: Option<u64>

标的正股 stock_id

spread: Option<i64>

单腿下填 0

strike_date: Option<u64>

行权日(timestamp,和 CMD 6311 返回对齐)

expiration: Option<u32>

到期类型 ExpirationType

index_option_type: Option<u32>standard_type: Option<u32>filetr_data: Option<FilterData>

注意:字段名是 filetr_data (typo),对齐 C++ 源

Implementations

Source

impl GetComboOptionListReq

pub fn strategy(&self) -> i32

Returns the value of strategy, or the default value if strategy is unset.

pub fn stock_id(&self) -> u64

Returns the value of stock_id, or the default value if stock_id is unset.

pub fn spread(&self) -> i64

Returns the value of spread, or the default value if spread is unset.

pub fn strike_date(&self) -> u64

Returns the value of strike_date, or the default value if strike_date is unset.

pub fn expiration(&self) -> u32

Returns the value of expiration, or the default value if expiration is unset.

pub fn index_option_type(&self) -> u32

Returns the value of index_option_type, or the default value if index_option_type is unset.

pub fn standard_type(&self) -> u32

Returns the value of standard_type, or the default value if standard_type is unset.