pub struct NewStrikeDateItem {
pub strike_date: Option<i64>,
pub symbol: Option<String>,
pub hp_multiplier: Option<u64>,
pub hp_contract_share_size: Option<u64>,
pub left_day: Option<i32>,
pub standard_type: Option<u32>,
pub expiration: Option<u32>,
pub suffix: Option<String>,
pub underlying_id: Option<u64>,
pub exercise_method_type: Option<i32>,
pub settlement_mode: Option<i32>,
}Fields
strike_date: Option<i64>symbol: Option<String>hp_multiplier: Option<u64>left_day: Option<i32>standard_type: Option<u32>expiration: Option<u32>suffix: Option<String>underlying_id: Option<u64>exercise_method_type: Option<i32>settlement_mode: Option<i32>Implementations
Sourceimpl NewStrikeDateItem
impl NewStrikeDateItem
Sourcepub fn strike_date(&self) -> i64
pub fn strike_date(&self) -> i64
Returns the value of strike_date, or the default value if strike_date is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn hp_multiplier(&self) -> u64
pub fn hp_multiplier(&self) -> u64
Returns the value of hp_multiplier, or the default value if hp_multiplier is unset.
Returns the value of hp_contract_share_size, or the default value if hp_contract_share_size is unset.
Sourcepub fn left_day(&self) -> i32
pub fn left_day(&self) -> i32
Returns the value of left_day, or the default value if left_day is unset.
Sourcepub fn standard_type(&self) -> u32
pub fn standard_type(&self) -> u32
Returns the value of standard_type, or the default value if standard_type is unset.
Sourcepub fn expiration(&self) -> u32
pub fn expiration(&self) -> u32
Returns the value of expiration, or the default value if expiration is unset.
Sourcepub fn suffix(&self) -> &str
pub fn suffix(&self) -> &str
Returns the value of suffix, or the default value if suffix is unset.
Sourcepub fn underlying_id(&self) -> u64
pub fn underlying_id(&self) -> u64
Returns the value of underlying_id, or the default value if underlying_id is unset.
Sourcepub fn exercise_method_type(&self) -> i32
pub fn exercise_method_type(&self) -> i32
Returns the value of exercise_method_type, or the default value if exercise_method_type is unset.
Sourcepub fn settlement_mode(&self) -> i32
pub fn settlement_mode(&self) -> i32
Returns the value of settlement_mode, or the default value if settlement_mode is unset.