OrderNewReq

Struct OrderNewReq 

pub struct OrderNewReq {
Show 40 fields pub msg_header: Option<MsgHeader>, pub order_type: Option<u32>, pub order_side: Option<u32>, pub symbol: Option<String>, pub qty: Option<String>, pub price: Option<String>, pub expire_time: Option<u64>, pub text: Option<String>, pub lot_type: Option<u32>, pub security_type: Option<u32>, pub trigger_type: Option<u32>, pub pdt_confirmed: Option<bool>, pub trigger_risk_check: Option<bool>, pub odr_enable_ba_trade: Option<bool>, pub exchange_code: Option<u32>, pub time_in_force: Option<u32>, pub pdt_protection: Option<bool>, pub price_type: Option<u32>, pub disable_auto_short: Option<bool>, pub tickets: Option<Tickets>, pub hk_enable_ba_trade: Option<u32>, pub price_protect: Option<bool>, pub exchange: Option<String>, pub trigger_info: Option<TriggerInfo>, pub aux_price: Option<String>, pub trail_type: Option<u32>, pub trail_percent: Option<String>, pub trail_price: Option<String>, pub algo_info: Option<AlgoInfo>, pub input_source: Option<u32>, pub dt_call_confirmed: Option<bool>, pub order_trade_time_type: Option<u32>, pub fixed_side: Option<bool>, pub cash_order_qty: Option<String>, pub position_id: Option<String>, pub margin_trade_info: Option<MarginTradeInfo>, pub force_routing: Option<String>, pub batch_risk_confirm_code: Vec<u32>, pub combo_id: Option<String>, pub owner_broker_id: Option<String>,
}
股票, 期权, 基金, 都用同一条协议, 不依赖conn去做分流了 基金order_type填 odr_sys_cmn.ORDER_TYPE_LIMIT, price填1, lot_type填odr_sys_cmn.LOT_TYPE_ODD

Fields

msg_header: Option<MsgHeader>order_type: Option<u32>

取值参考 OrderType

order_side: Option<u32>

取值参考 Side

symbol: Option<String>qty: Option<String>

普通单下单数量

price: Option<String>

普通单下单价格 (市价单、竞价市价单不填);期货平仓下单price取不到不填,svr按照price_type取价格

expire_time: Option<u64>

订单过期时间戳(客户端暂时不需要用到这个), 单位为微秒

text: Option<String>

可见字符, 最长100字节, server不根据此字段做任何逻辑, 只存储+校验

lot_type: Option<u32>

取值参考 LotType

security_type: Option<u32>

服务器内部传递需要,不好删除,客户端是填在msg_header.security_type,且必须填

trigger_type: Option<u32>

【废弃!!!】

pdt_confirmed: Option<bool>

废弃!!

trigger_risk_check: Option<bool>

是否需要过风控检查,条件单需要过风控则填true

odr_enable_ba_trade: Option<bool>

【美股】是否允许盘前盘后时段生效

exchange_code: Option<u32>

期货所属交易所代码, 从行情获得,【期货】必填

time_in_force: Option<u32>

订单期限,取值参考OrderTimeInForce

pdt_protection: Option<bool>

防止被标记为pdt用户,true:开启保护;false:关闭保护

price_type: Option<u32>

对价或最新价格,取值参考 PriceType, 目前期货/股票平仓用到

disable_auto_short: Option<bool>

是否禁止卖单自动转换为卖空单或者买单转buyback

tickets: Option<Tickets>

券列表

hk_enable_ba_trade: Option<u32>

【港股】是否允许盘前竞价提交,优先级高于odr_enable_ba_trade,取值参考EnableBATradeType

price_protect: Option<bool>

价格保护,true:允许价格保护,false:不允许价格保护

exchange: Option<String>

股票所属交易所

trigger_info: Option<TriggerInfo>

高级订单所需信息

【废弃!!!】

aux_price: Option<String>

basic fields

辅助价格,表示止损价差、止盈止损触发价

trail_type: Option<u32>

extended order fields

跟踪止损的跟踪标的,取值参考TrailType

trail_percent: Option<String>

跟踪止损的跟踪额百分比 >0:涨幅超过,<0:跌幅超过

trail_price: Option<String>

跟踪止损的跟踪额 >0:涨幅超过,<0:跌幅超过

algo_info: Option<AlgoInfo>

算法参数信息

input_source: Option<u32>

订单来源 参考 InputSourceType

dt_call_confirmed: Option<bool>

将产生DTCall是否确认,OpenAPI下单使用

order_trade_time_type: Option<u32>

订单交易时段类型,参考OrderTradeTimeType,美股优先级高于odr_enable_ba_trade与hk_enable_ba_trade

fixed_side: Option<bool>

交易方向是否不随持仓自动变化,默认false不固定方向

cash_order_qty: Option<String>

下单金额,金额单必填

position_id: Option<String>

optional group_condition.Condition condition = 65; // 组合条件订单的组合条件,组合条件订单必填

持仓id。单笔持仓平仓时必填,同资产系统中的posion_id;组合持仓平仓时不填。目前JP信用交易平仓时使用

margin_trade_info: Option<MarginTradeInfo>

JP信用交易相关信息,JP信用交易必填

force_routing: Option<String>

指定订单需要发往哪个上游,非必填,取值:目前仅支持CBOE,MY美股期权使用,表示订单固定走到美股CBOE交易所

batch_risk_confirm_code: Vec<u32>

不进行二次确认的风控错误码,非必填,目前TradingView使用

combo_id: Option<String>

组合持仓id。组合持仓平仓时必填,同资产系统中的combo_id;单笔持仓平仓时不填。目前JP信用交易平仓时使用。资产概念参考:https://futu.feishu.cn/wiki/TKyqwLIDviGAqTk5ClpcjViBnrg?fromScene=spaceOverview

owner_broker_id: Option<String>

券商所属经纪号,OM交易暗盘机构下单必填,零售交易暂未使用

Implementations

Source

impl OrderNewReq

pub fn order_type(&self) -> u32

Returns the value of order_type, or the default value if order_type is unset.

pub fn order_side(&self) -> u32

Returns the value of order_side, or the default value if order_side is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn qty(&self) -> &str

Returns the value of qty, or the default value if qty is unset.

pub fn price(&self) -> &str

Returns the value of price, or the default value if price is unset.

pub fn expire_time(&self) -> u64

Returns the value of expire_time, or the default value if expire_time is unset.

pub fn text(&self) -> &str

Returns the value of text, or the default value if text is unset.

pub fn lot_type(&self) -> u32

Returns the value of lot_type, or the default value if lot_type is unset.

pub fn security_type(&self) -> u32

Returns the value of security_type, or the default value if security_type is unset.

pub fn trigger_type(&self) -> u32

Returns the value of trigger_type, or the default value if trigger_type is unset.

pub fn pdt_confirmed(&self) -> bool

Returns the value of pdt_confirmed, or the default value if pdt_confirmed is unset.

pub fn trigger_risk_check(&self) -> bool

Returns the value of trigger_risk_check, or the default value if trigger_risk_check is unset.

pub fn odr_enable_ba_trade(&self) -> bool

Returns the value of odr_enable_ba_trade, or the default value if odr_enable_ba_trade is unset.

pub fn exchange_code(&self) -> u32

Returns the value of exchange_code, or the default value if exchange_code is unset.

pub fn time_in_force(&self) -> u32

Returns the value of time_in_force, or the default value if time_in_force is unset.

pub fn pdt_protection(&self) -> bool

Returns the value of pdt_protection, or the default value if pdt_protection is unset.

pub fn price_type(&self) -> u32

Returns the value of price_type, or the default value if price_type is unset.

pub fn disable_auto_short(&self) -> bool

Returns the value of disable_auto_short, or the default value if disable_auto_short is unset.

pub fn hk_enable_ba_trade(&self) -> u32

Returns the value of hk_enable_ba_trade, or the default value if hk_enable_ba_trade is unset.

pub fn price_protect(&self) -> bool

Returns the value of price_protect, or the default value if price_protect is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn aux_price(&self) -> &str

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn trail_type(&self) -> u32

Returns the value of trail_type, or the default value if trail_type is unset.

pub fn trail_percent(&self) -> &str

Returns the value of trail_percent, or the default value if trail_percent is unset.

pub fn trail_price(&self) -> &str

Returns the value of trail_price, or the default value if trail_price is unset.

pub fn input_source(&self) -> u32

Returns the value of input_source, or the default value if input_source is unset.

pub fn dt_call_confirmed(&self) -> bool

Returns the value of dt_call_confirmed, or the default value if dt_call_confirmed is unset.

pub fn order_trade_time_type(&self) -> u32

Returns the value of order_trade_time_type, or the default value if order_trade_time_type is unset.

pub fn fixed_side(&self) -> bool

Returns the value of fixed_side, or the default value if fixed_side is unset.

pub fn cash_order_qty(&self) -> &str

Returns the value of cash_order_qty, or the default value if cash_order_qty is unset.

pub fn position_id(&self) -> &str

Returns the value of position_id, or the default value if position_id is unset.

pub fn force_routing(&self) -> &str

Returns the value of force_routing, or the default value if force_routing is unset.

pub fn combo_id(&self) -> &str

Returns the value of combo_id, or the default value if combo_id is unset.

pub fn owner_broker_id(&self) -> &str

Returns the value of owner_broker_id, or the default value if owner_broker_id is unset.