pub struct RatingDetail {
pub stock_id: Option<u64>,
pub rating: Option<i32>,
pub total: Option<i32>,
pub strong_buy: Option<i32>,
pub hold: Option<i32>,
pub sell: Option<i32>,
pub update_time: Option<i64>,
pub buy: Option<i32>,
pub underperform: Option<i32>,
}Fields
stock_id: Option<u64>rating: Option<i32>total: Option<i32>strong_buy: Option<i32>hold: Option<i32>sell: Option<i32>update_time: Option<i64>buy: Option<i32>underperform: Option<i32>Implementations
Sourceimpl RatingDetail
impl RatingDetail
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn rating(&self) -> i32
pub fn rating(&self) -> i32
Returns the value of rating, or the default value if rating is unset.
Sourcepub fn strong_buy(&self) -> i32
pub fn strong_buy(&self) -> i32
Returns the value of strong_buy, or the default value if strong_buy is unset.
Sourcepub fn update_time(&self) -> i64
pub fn update_time(&self) -> i64
Returns the value of update_time, or the default value if update_time is unset.
Sourcepub fn underperform(&self) -> i32
pub fn underperform(&self) -> i32
Returns the value of underperform, or the default value if underperform is unset.