pub struct TargetPriceInfo {
pub stock_id: Option<u64>,
pub highest: Option<i64>,
pub average: Option<i64>,
pub lowest: Option<i64>,
pub number_of_analysts: Option<i32>,
pub update_time: Option<i64>,
}Fields
stock_id: Option<u64>highest: Option<i64>average: Option<i64>lowest: Option<i64>number_of_analysts: Option<i32>update_time: Option<i64>Implementations
Sourceimpl TargetPriceInfo
impl TargetPriceInfo
Sourcepub fn stock_id(&self) -> u64
pub fn stock_id(&self) -> u64
Returns the value of stock_id, or the default value if stock_id is unset.
Sourcepub fn highest(&self) -> i64
pub fn highest(&self) -> i64
Returns the value of highest, or the default value if highest is unset.
Sourcepub fn average(&self) -> i64
pub fn average(&self) -> i64
Returns the value of average, or the default value if average is unset.
Sourcepub fn lowest(&self) -> i64
pub fn lowest(&self) -> i64
Returns the value of lowest, or the default value if lowest is unset.
Sourcepub fn number_of_analysts(&self) -> i32
pub fn number_of_analysts(&self) -> i32
Returns the value of number_of_analysts, or the default value if number_of_analysts is unset.
Sourcepub fn update_time(&self) -> i64
pub fn update_time(&self) -> i64
Returns the value of update_time, or the default value if update_time is unset.