#[repr(i32)]pub enum CurrencyCode {
Show 57 variants
Ivd = 0,
Aed = 1,
Ats = 2,
Aud = 3,
Bdt = 4,
Bec = 5,
Bel = 6,
Bhd = 7,
Bnd = 8,
Brc = 9,
Buk = 10,
Cad = 11,
Chf = 12,
Cny = 13,
Cyp = 14,
Dem = 15,
Dkk = 16,
Ecu = 17,
Esp = 18,
Eur = 19,
Fim = 20,
Fjd = 21,
Frf = 22,
Gbp = 23,
Hkd = 24,
Idr = 25,
Iep = 26,
Inr = 27,
Itl = 28,
Jpy = 29,
Kes = 30,
Krw = 31,
Kwd = 32,
Lbp = 33,
Lkr = 34,
Mop = 35,
Mur = 36,
Mxn = 37,
Myr = 38,
Ngn = 39,
Nlg = 40,
Nok = 41,
Nzd = 42,
Omr = 43,
Php = 44,
Pkr = 45,
Pte = 46,
Qar = 47,
Sar = 48,
Scr = 49,
Sdr = 50,
Sek = 51,
Sgd = 52,
Sll = 53,
Thb = 54,
Usd = 55,
Zar = 56,
}Variants
Ivd = 0
invalid
Aed = 1
U.A.E. Dirhams
Ats = 2
Austrian Schillings
Aud = 3
Australian Dollars
Bdt = 4
Bangladesh Takas
Bec = 5
Belgian Francs Commercial
Bel = 6
Belgian Francs Financial
Bhd = 7
Bahraini Dinars
Bnd = 8
Brunei Dollars
Brc = 9
Brazil Cruzeiros
Buk = 10
Burmese Kyats
Cad = 11
Canadian Dollars
Chf = 12
Swiss Francs
Cny = 13
Chinese Renminbi
Cyp = 14
Cypriot Pounds
Dem = 15
Deutsche Marks
Dkk = 16
Danish Kroners
Ecu = 17
European Currency Unit
Esp = 18
Spanish Pesetas
Eur = 19
Euro
Fim = 20
Finnish Markkas
Fjd = 21
Fiji Dollars
Frf = 22
French Francs
Gbp = 23
Sterling Pounds
Hkd = 24
Hong Kong Dollars
Idr = 25
Indonesian Rupiahs
Iep = 26
Irish Punt
Inr = 27
Indian Rupees
Itl = 28
Italian Lira
Jpy = 29
Japanese Yen
Kes = 30
Kenyan Shillings
Krw = 31
South Korean Won
Kwd = 32
Kuwaiti Dinars
Lbp = 33
Lebanese Pounds
Lkr = 34
Sri Lanka Rupees
Mop = 35
Macau Patacas
Mur = 36
Mauritius Rupees
Mxn = 37
Mexican Peso
Myr = 38
Malaysian Ringgit
Ngn = 39
Nigerian Naira
Nlg = 40
Dutch Guilders
Nok = 41
Norwegian Kroners
Nzd = 42
New Zealand Dollars
Omr = 43
Omani Rials
Php = 44
Philippine Pesos
Pkr = 45
Pakistan Rupees
Pte = 46
Portuguese Escudos
Qar = 47
Qatar Riyals
Sar = 48
Saudi Arabian Riyals
Scr = 49
Seychelles Rupees
Sdr = 50
Special Drawing Rights
Sek = 51
Swedish Kroners
Sgd = 52
Singapore Dollars
Sll = 53
Sierra Leone Leones
Thb = 54
Thailand Bahts
Usd = 55
US Dollars
Zar = 56
South African Rands
Implementations
Sourceimpl CurrencyCode
impl CurrencyCode
Sourceimpl CurrencyCode
impl CurrencyCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.