pub struct QueryIndicatorPositional {
pub position: i32,
pub period: i32,
pub period_type: Option<i32>,
pub first_indicator: i32,
pub first_indicator_name: Option<i32>,
pub second_indicator: Option<i32>,
pub second_value: Option<i64>,
pub f_second_value: Option<f64>,
pub first_indicator_params: Vec<i64>,
pub second_indicator_params: Vec<i64>,
pub continuous_period: Option<i32>,
pub intervals: Vec<Interval>,
}Fields
position: i32指标相对位置查询
period: i32指标因子(旧),已废弃,仅老版本客户端使用,新接入请使用period_type
period_type: Option<i32>指标因子(新),参考枚举Period,替换字段period
first_indicator: i32指标因子(旧),已废弃,仅老版本客户端使用,新接入请使用first_indicator_name
first_indicator_name: Option<i32>指标因子(新),参考枚举Indicator,替换字段first_indicator
second_indicator: Option<i32>second_value: Option<i64>f_second_value: Option<f64>AI问题专用字段。仅在AI问答专用接口才使用该字段,其他场景均使用second_value
first_indicator_params: Vec<i64>动态参数(如MA6,设置6即可;BOLL(15,3),则按顺序设置15, 3;KDJ(9,4,4),则按顺序设置9,4,4)
second_indicator_params: Vec<i64>动态参数(如MA6,设置6即可;BOLL(15,3),则按顺序设置15, 3;KDJ(9,4,4),则按顺序设置9,4,4)
continuous_period: Option<i32>连续周期
intervals: Vec<Interval>区间(多个区间是 或 的关系)
Implementations
Sourceimpl QueryIndicatorPositional
impl QueryIndicatorPositional
Sourcepub fn position(&self) -> Position
pub fn position(&self) -> Position
Returns the enum value of position, or the default if the field is set to an invalid enum value.
Sourcepub fn set_position(&mut self, value: Position)
pub fn set_position(&mut self, value: Position)
Sets position to the provided enum value.
Sourcepub fn period(&self) -> Period
pub fn period(&self) -> Period
Returns the enum value of period, or the default if the field is set to an invalid enum value.
Sourcepub fn set_period(&mut self, value: Period)
pub fn set_period(&mut self, value: Period)
Sets period to the provided enum value.
Sourcepub fn first_indicator(&self) -> Indicator
pub fn first_indicator(&self) -> Indicator
Returns the enum value of first_indicator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_first_indicator(&mut self, value: Indicator)
pub fn set_first_indicator(&mut self, value: Indicator)
Sets first_indicator to the provided enum value.
Sourcepub fn second_indicator(&self) -> Indicator
pub fn second_indicator(&self) -> Indicator
Returns the enum value of second_indicator, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_second_indicator(&mut self, value: Indicator)
pub fn set_second_indicator(&mut self, value: Indicator)
Sets second_indicator to the provided enum value.
Sourcepub fn second_value(&self) -> i64
pub fn second_value(&self) -> i64
Returns the value of second_value, or the default value if second_value is unset.
Sourcepub fn continuous_period(&self) -> i32
pub fn continuous_period(&self) -> i32
Returns the value of continuous_period, or the default value if continuous_period is unset.
Sourcepub fn f_second_value(&self) -> f64
pub fn f_second_value(&self) -> f64
Returns the value of f_second_value, or the default value if f_second_value is unset.
Sourcepub fn first_indicator_name(&self) -> i32
pub fn first_indicator_name(&self) -> i32
Returns the value of first_indicator_name, or the default value if first_indicator_name is unset.
Sourcepub fn period_type(&self) -> i32
pub fn period_type(&self) -> i32
Returns the value of period_type, or the default value if period_type is unset.