pub struct SessionAuth {
pub stock_hk_auth: Option<i32>,
pub stock_us_auth: Option<i32>,
pub stock_cn_auth: Option<i32>,
pub stock_sg_auth: Option<i32>,
pub stock_ca_auth: Option<i32>,
pub stock_au_auth: Option<i32>,
pub stock_cn_bjs_auth: Option<i32>,
pub stock_ja_auth: Option<i32>,
pub stock_my_auth: Option<i32>,
}Fields
stock_hk_auth: Option<i32>港股权限
stock_us_auth: Option<i32>美股权限
stock_cn_auth: Option<i32>A股权限
stock_sg_auth: Option<i32>新加坡股票权限
stock_ca_auth: Option<i32>加拿大股票权限
stock_au_auth: Option<i32>澳大利亚股票权限
stock_cn_bjs_auth: Option<i32>A股北交所权限
stock_ja_auth: Option<i32>日本权限
stock_my_auth: Option<i32>马来西亚权限
Implementations
Sourceimpl SessionAuth
impl SessionAuth
Sourcepub fn stock_hk_auth(&self) -> AuthState
pub fn stock_hk_auth(&self) -> AuthState
Returns the enum value of stock_hk_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_hk_auth(&mut self, value: AuthState)
pub fn set_stock_hk_auth(&mut self, value: AuthState)
Sets stock_hk_auth to the provided enum value.
Sourcepub fn stock_us_auth(&self) -> AuthState
pub fn stock_us_auth(&self) -> AuthState
Returns the enum value of stock_us_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_us_auth(&mut self, value: AuthState)
pub fn set_stock_us_auth(&mut self, value: AuthState)
Sets stock_us_auth to the provided enum value.
Sourcepub fn stock_cn_auth(&self) -> AuthState
pub fn stock_cn_auth(&self) -> AuthState
Returns the enum value of stock_cn_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_cn_auth(&mut self, value: AuthState)
pub fn set_stock_cn_auth(&mut self, value: AuthState)
Sets stock_cn_auth to the provided enum value.
Sourcepub fn stock_sg_auth(&self) -> AuthState
pub fn stock_sg_auth(&self) -> AuthState
Returns the enum value of stock_sg_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_sg_auth(&mut self, value: AuthState)
pub fn set_stock_sg_auth(&mut self, value: AuthState)
Sets stock_sg_auth to the provided enum value.
Sourcepub fn stock_ca_auth(&self) -> AuthState
pub fn stock_ca_auth(&self) -> AuthState
Returns the enum value of stock_ca_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_ca_auth(&mut self, value: AuthState)
pub fn set_stock_ca_auth(&mut self, value: AuthState)
Sets stock_ca_auth to the provided enum value.
Sourcepub fn stock_au_auth(&self) -> AuthState
pub fn stock_au_auth(&self) -> AuthState
Returns the enum value of stock_au_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_au_auth(&mut self, value: AuthState)
pub fn set_stock_au_auth(&mut self, value: AuthState)
Sets stock_au_auth to the provided enum value.
Sourcepub fn stock_cn_bjs_auth(&self) -> AuthState
pub fn stock_cn_bjs_auth(&self) -> AuthState
Returns the enum value of stock_cn_bjs_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_cn_bjs_auth(&mut self, value: AuthState)
pub fn set_stock_cn_bjs_auth(&mut self, value: AuthState)
Sets stock_cn_bjs_auth to the provided enum value.
Sourcepub fn stock_ja_auth(&self) -> AuthState
pub fn stock_ja_auth(&self) -> AuthState
Returns the enum value of stock_ja_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_ja_auth(&mut self, value: AuthState)
pub fn set_stock_ja_auth(&mut self, value: AuthState)
Sets stock_ja_auth to the provided enum value.
Sourcepub fn stock_my_auth(&self) -> AuthState
pub fn stock_my_auth(&self) -> AuthState
Returns the enum value of stock_my_auth, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stock_my_auth(&mut self, value: AuthState)
pub fn set_stock_my_auth(&mut self, value: AuthState)
Sets stock_my_auth to the provided enum value.