pub struct CryptoCltActionOpenUrl {
pub title: Option<String>,
pub content: Option<String>,
pub confirm_button_title: Option<String>,
pub target: Option<u32>,
pub cancel_button_title: Option<String>,
}Fields
title: Option<String>显示弹窗标题文案
content: Option<String>显示弹窗内容文案
显示确认按钮文案
target: Option<u32>跳转的url地址
显示取消按钮文案
Implementations
Sourceimpl CryptoCltActionOpenUrl
impl CryptoCltActionOpenUrl
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn content(&self) -> &str
pub fn content(&self) -> &str
Returns the value of content, or the default value if content is unset.
Returns the value of confirm_button_title, or the default value if confirm_button_title is unset.
Sourcepub fn target(&self) -> u32
pub fn target(&self) -> u32
Returns the value of target, or the default value if target is unset.
Returns the value of cancel_button_title, or the default value if cancel_button_title is unset.